/* libdino.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __LIBDINO_LIBDINO_H__
#define __LIBDINO_LIBDINO_H__

#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <gee.h>
#include "qlite.h"
#include "xmpp-vala.h"
#include <float.h>
#include <math.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <dino_i18n.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define DINO_ENTITIES_CALL_DIRECTION_OUTGOING TRUE
#define DINO_ENTITIES_CALL_DIRECTION_INCOMING FALSE
#define DINO_ENTITIES_FILE_TRANSFER_DIRECTION_SENT TRUE
#define DINO_ENTITIES_FILE_TRANSFER_DIRECTION_RECEIVED FALSE
#define DINO_ENTITIES_MESSAGE_DIRECTION_SENT TRUE
#define DINO_ENTITIES_MESSAGE_DIRECTION_RECEIVED FALSE
#define DINO_MESSAGE_ITEM_TYPE "message"
#define DINO_FILE_ITEM_TYPE "file"
#define DINO_CALL_ITEM_TYPE "call"
#define DINO_FILE_MANAGER_HTTP_PROVIDER_ID 0
#define DINO_FILE_MANAGER_SFS_PROVIDER_ID 2
#define DINO_STATELESS_FILE_SHARING_SFS_PROVIDER_ID 2
#define DINO_VERSION "0.5.1"

#define DINO_TYPE_APPLICATION (dino_application_get_type ())
#define DINO_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_APPLICATION, DinoApplication))
#define DINO_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_APPLICATION))
#define DINO_APPLICATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_APPLICATION, DinoApplicationIface))

typedef struct _DinoApplication DinoApplication;
typedef struct _DinoApplicationIface DinoApplicationIface;

#define DINO_TYPE_DATABASE (dino_database_get_type ())
#define DINO_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_DATABASE, DinoDatabase))
#define DINO_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_DATABASE, DinoDatabaseClass))
#define DINO_IS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_DATABASE))
#define DINO_IS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_DATABASE))
#define DINO_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_DATABASE, DinoDatabaseClass))

typedef struct _DinoDatabase DinoDatabase;
typedef struct _DinoDatabaseClass DinoDatabaseClass;

#define DINO_ENTITIES_TYPE_SETTINGS (dino_entities_settings_get_type ())
#define DINO_ENTITIES_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_ENTITIES_TYPE_SETTINGS, DinoEntitiesSettings))
#define DINO_ENTITIES_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_ENTITIES_TYPE_SETTINGS, DinoEntitiesSettingsClass))
#define DINO_ENTITIES_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_ENTITIES_TYPE_SETTINGS))
#define DINO_ENTITIES_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_ENTITIES_TYPE_SETTINGS))
#define DINO_ENTITIES_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_ENTITIES_TYPE_SETTINGS, DinoEntitiesSettingsClass))

typedef struct _DinoEntitiesSettings DinoEntitiesSettings;
typedef struct _DinoEntitiesSettingsClass DinoEntitiesSettingsClass;

#define DINO_TYPE_STREAM_INTERACTOR (dino_stream_interactor_get_type ())
#define DINO_STREAM_INTERACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_STREAM_INTERACTOR, DinoStreamInteractor))
#define DINO_STREAM_INTERACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_STREAM_INTERACTOR, DinoStreamInteractorClass))
#define DINO_IS_STREAM_INTERACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_STREAM_INTERACTOR))
#define DINO_IS_STREAM_INTERACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_STREAM_INTERACTOR))
#define DINO_STREAM_INTERACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_STREAM_INTERACTOR, DinoStreamInteractorClass))

typedef struct _DinoStreamInteractor DinoStreamInteractor;
typedef struct _DinoStreamInteractorClass DinoStreamInteractorClass;

#define DINO_PLUGINS_TYPE_REGISTRY (dino_plugins_registry_get_type ())
#define DINO_PLUGINS_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_REGISTRY, DinoPluginsRegistry))
#define DINO_PLUGINS_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_PLUGINS_TYPE_REGISTRY, DinoPluginsRegistryClass))
#define DINO_PLUGINS_IS_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_REGISTRY))
#define DINO_PLUGINS_IS_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_PLUGINS_TYPE_REGISTRY))
#define DINO_PLUGINS_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_PLUGINS_TYPE_REGISTRY, DinoPluginsRegistryClass))

typedef struct _DinoPluginsRegistry DinoPluginsRegistry;
typedef struct _DinoPluginsRegistryClass DinoPluginsRegistryClass;

#define DINO_TYPE_SEARCH_PATH_GENERATOR (dino_search_path_generator_get_type ())
#define DINO_SEARCH_PATH_GENERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_SEARCH_PATH_GENERATOR, DinoSearchPathGenerator))
#define DINO_SEARCH_PATH_GENERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_SEARCH_PATH_GENERATOR, DinoSearchPathGeneratorClass))
#define DINO_IS_SEARCH_PATH_GENERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_SEARCH_PATH_GENERATOR))
#define DINO_IS_SEARCH_PATH_GENERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_SEARCH_PATH_GENERATOR))
#define DINO_SEARCH_PATH_GENERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_SEARCH_PATH_GENERATOR, DinoSearchPathGeneratorClass))

typedef struct _DinoSearchPathGenerator DinoSearchPathGenerator;
typedef struct _DinoSearchPathGeneratorClass DinoSearchPathGeneratorClass;

#define DINO_ENTITIES_TYPE_ACCOUNT (dino_entities_account_get_type ())
#define DINO_ENTITIES_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_ENTITIES_TYPE_ACCOUNT, DinoEntitiesAccount))
#define DINO_ENTITIES_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_ENTITIES_TYPE_ACCOUNT, DinoEntitiesAccountClass))
#define DINO_ENTITIES_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_ENTITIES_TYPE_ACCOUNT))
#define DINO_ENTITIES_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_ENTITIES_TYPE_ACCOUNT))
#define DINO_ENTITIES_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_ENTITIES_TYPE_ACCOUNT, DinoEntitiesAccountClass))

typedef struct _DinoEntitiesAccount DinoEntitiesAccount;
typedef struct _DinoEntitiesAccountClass DinoEntitiesAccountClass;

#define DINO_TYPE_LOGIN1_MANAGER (dino_login1_manager_get_type ())
#define DINO_LOGIN1_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_LOGIN1_MANAGER, DinoLogin1Manager))
#define DINO_IS_LOGIN1_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_LOGIN1_MANAGER))
#define DINO_LOGIN1_MANAGER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_LOGIN1_MANAGER, DinoLogin1ManagerIface))

typedef struct _DinoLogin1Manager DinoLogin1Manager;
typedef struct _DinoLogin1ManagerIface DinoLogin1ManagerIface;

#define DINO_TYPE_LOGIN1_MANAGER_PROXY (dino_login1_manager_proxy_get_type ())

#define DINO_TYPE_DBUS_NOTIFICATIONS (dino_dbus_notifications_get_type ())
#define DINO_DBUS_NOTIFICATIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_DBUS_NOTIFICATIONS, DinoDBusNotifications))
#define DINO_IS_DBUS_NOTIFICATIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_DBUS_NOTIFICATIONS))
#define DINO_DBUS_NOTIFICATIONS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_DBUS_NOTIFICATIONS, DinoDBusNotificationsIface))

typedef struct _DinoDBusNotifications DinoDBusNotifications;
typedef struct _DinoDBusNotificationsIface DinoDBusNotificationsIface;

#define DINO_TYPE_DBUS_NOTIFICATIONS_PROXY (dino_dbus_notifications_proxy_get_type ())

#define DINO_TYPE_UPOWER (dino_upower_get_type ())
#define DINO_UPOWER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_UPOWER, DinoUPower))
#define DINO_IS_UPOWER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_UPOWER))
#define DINO_UPOWER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_UPOWER, DinoUPowerIface))

typedef struct _DinoUPower DinoUPower;
typedef struct _DinoUPowerIface DinoUPowerIface;

#define DINO_TYPE_UPOWER_PROXY (dino_upower_proxy_get_type ())
typedef struct _DinoEntitiesAccountPrivate DinoEntitiesAccountPrivate;

#define DINO_ENTITIES_TYPE_CALL (dino_entities_call_get_type ())
#define DINO_ENTITIES_CALL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_ENTITIES_TYPE_CALL, DinoEntitiesCall))
#define DINO_ENTITIES_CALL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_ENTITIES_TYPE_CALL, DinoEntitiesCallClass))
#define DINO_ENTITIES_IS_CALL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_ENTITIES_TYPE_CALL))
#define DINO_ENTITIES_IS_CALL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_ENTITIES_TYPE_CALL))
#define DINO_ENTITIES_CALL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_ENTITIES_TYPE_CALL, DinoEntitiesCallClass))

typedef struct _DinoEntitiesCall DinoEntitiesCall;
typedef struct _DinoEntitiesCallClass DinoEntitiesCallClass;
typedef struct _DinoEntitiesCallPrivate DinoEntitiesCallPrivate;
typedef enum  {
	DINO_ENTITIES_CALL_STATE_RINGING,
	DINO_ENTITIES_CALL_STATE_ESTABLISHING,
	DINO_ENTITIES_CALL_STATE_IN_PROGRESS,
	DINO_ENTITIES_CALL_STATE_OTHER_DEVICE,
	DINO_ENTITIES_CALL_STATE_ENDED,
	DINO_ENTITIES_CALL_STATE_DECLINED,
	DINO_ENTITIES_CALL_STATE_MISSED,
	DINO_ENTITIES_CALL_STATE_FAILED
} DinoEntitiesCallState;

#define DINO_ENTITIES_CALL_TYPE_STATE (dino_entities_call_state_get_type ())
typedef enum  {
	DINO_ENTITIES_ENCRYPTION_NONE,
	DINO_ENTITIES_ENCRYPTION_PGP,
	DINO_ENTITIES_ENCRYPTION_OMEMO,
	DINO_ENTITIES_ENCRYPTION_DTLS_SRTP,
	DINO_ENTITIES_ENCRYPTION_SRTP,
	DINO_ENTITIES_ENCRYPTION_UNKNOWN
} DinoEntitiesEncryption;

#define DINO_ENTITIES_TYPE_ENCRYPTION (dino_entities_encryption_get_type ())

#define DINO_ENTITIES_TYPE_CONVERSATION (dino_entities_conversation_get_type ())
#define DINO_ENTITIES_CONVERSATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_ENTITIES_TYPE_CONVERSATION, DinoEntitiesConversation))
#define DINO_ENTITIES_CONVERSATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_ENTITIES_TYPE_CONVERSATION, DinoEntitiesConversationClass))
#define DINO_ENTITIES_IS_CONVERSATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_ENTITIES_TYPE_CONVERSATION))
#define DINO_ENTITIES_IS_CONVERSATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_ENTITIES_TYPE_CONVERSATION))
#define DINO_ENTITIES_CONVERSATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_ENTITIES_TYPE_CONVERSATION, DinoEntitiesConversationClass))

typedef struct _DinoEntitiesConversation DinoEntitiesConversation;
typedef struct _DinoEntitiesConversationClass DinoEntitiesConversationClass;
typedef struct _DinoEntitiesConversationPrivate DinoEntitiesConversationPrivate;
typedef enum  {
	DINO_ENTITIES_CONVERSATION_TYPE_CHAT,
	DINO_ENTITIES_CONVERSATION_TYPE_GROUPCHAT,
	DINO_ENTITIES_CONVERSATION_TYPE_GROUPCHAT_PM
} DinoEntitiesConversationType;

#define DINO_ENTITIES_CONVERSATION_TYPE_TYPE (dino_entities_conversation_type_get_type ())
typedef enum  {
	DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_DEFAULT,
	DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_ON,
	DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_OFF,
	DINO_ENTITIES_CONVERSATION_NOTIFY_SETTING_HIGHLIGHT
} DinoEntitiesConversationNotifySetting;

#define DINO_ENTITIES_CONVERSATION_TYPE_NOTIFY_SETTING (dino_entities_conversation_notify_setting_get_type ())
typedef enum  {
	DINO_ENTITIES_CONVERSATION_SETTING_DEFAULT,
	DINO_ENTITIES_CONVERSATION_SETTING_ON,
	DINO_ENTITIES_CONVERSATION_SETTING_OFF
} DinoEntitiesConversationSetting;

#define DINO_ENTITIES_CONVERSATION_TYPE_SETTING (dino_entities_conversation_setting_get_type ())

#define DINO_ENTITIES_TYPE_MESSAGE (dino_entities_message_get_type ())
#define DINO_ENTITIES_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_ENTITIES_TYPE_MESSAGE, DinoEntitiesMessage))
#define DINO_ENTITIES_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_ENTITIES_TYPE_MESSAGE, DinoEntitiesMessageClass))
#define DINO_ENTITIES_IS_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_ENTITIES_TYPE_MESSAGE))
#define DINO_ENTITIES_IS_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_ENTITIES_TYPE_MESSAGE))
#define DINO_ENTITIES_MESSAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_ENTITIES_TYPE_MESSAGE, DinoEntitiesMessageClass))

typedef struct _DinoEntitiesMessage DinoEntitiesMessage;
typedef struct _DinoEntitiesMessageClass DinoEntitiesMessageClass;

#define DINO_ENTITIES_TYPE_FILE_TRANSFER (dino_entities_file_transfer_get_type ())
#define DINO_ENTITIES_FILE_TRANSFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_ENTITIES_TYPE_FILE_TRANSFER, DinoEntitiesFileTransfer))
#define DINO_ENTITIES_FILE_TRANSFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_ENTITIES_TYPE_FILE_TRANSFER, DinoEntitiesFileTransferClass))
#define DINO_ENTITIES_IS_FILE_TRANSFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_ENTITIES_TYPE_FILE_TRANSFER))
#define DINO_ENTITIES_IS_FILE_TRANSFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_ENTITIES_TYPE_FILE_TRANSFER))
#define DINO_ENTITIES_FILE_TRANSFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_ENTITIES_TYPE_FILE_TRANSFER, DinoEntitiesFileTransferClass))

typedef struct _DinoEntitiesFileTransfer DinoEntitiesFileTransfer;
typedef struct _DinoEntitiesFileTransferClass DinoEntitiesFileTransferClass;
typedef struct _DinoEntitiesFileTransferPrivate DinoEntitiesFileTransferPrivate;
typedef enum  {
	DINO_ENTITIES_FILE_TRANSFER_STATE_COMPLETE,
	DINO_ENTITIES_FILE_TRANSFER_STATE_IN_PROGRESS,
	DINO_ENTITIES_FILE_TRANSFER_STATE_NOT_STARTED,
	DINO_ENTITIES_FILE_TRANSFER_STATE_FAILED
} DinoEntitiesFileTransferState;

#define DINO_ENTITIES_FILE_TRANSFER_TYPE_STATE (dino_entities_file_transfer_state_get_type ())
typedef struct _DinoEntitiesMessagePrivate DinoEntitiesMessagePrivate;
typedef enum  {
	DINO_ENTITIES_MESSAGE_MARKED_NONE,
	DINO_ENTITIES_MESSAGE_MARKED_RECEIVED,
	DINO_ENTITIES_MESSAGE_MARKED_READ,
	DINO_ENTITIES_MESSAGE_MARKED_ACKNOWLEDGED,
	DINO_ENTITIES_MESSAGE_MARKED_UNSENT,
	DINO_ENTITIES_MESSAGE_MARKED_WONTSEND,
	DINO_ENTITIES_MESSAGE_MARKED_SENDING,
	DINO_ENTITIES_MESSAGE_MARKED_SENT,
	DINO_ENTITIES_MESSAGE_MARKED_ERROR
} DinoEntitiesMessageMarked;

#define DINO_ENTITIES_MESSAGE_TYPE_MARKED (dino_entities_message_marked_get_type ())
typedef enum  {
	DINO_ENTITIES_MESSAGE_TYPE_ERROR,
	DINO_ENTITIES_MESSAGE_TYPE_CHAT,
	DINO_ENTITIES_MESSAGE_TYPE_GROUPCHAT,
	DINO_ENTITIES_MESSAGE_TYPE_GROUPCHAT_PM,
	DINO_ENTITIES_MESSAGE_TYPE_UNKNOWN
} DinoEntitiesMessageType;

#define DINO_ENTITIES_MESSAGE_TYPE_TYPE (dino_entities_message_type_get_type ())
typedef struct _DinoEntitiesSettingsPrivate DinoEntitiesSettingsPrivate;
typedef enum  {
	DINO_PLUGINS_PRIORITY_LOWEST,
	DINO_PLUGINS_PRIORITY_LOWER,
	DINO_PLUGINS_PRIORITY_DEFAULT,
	DINO_PLUGINS_PRIORITY_HIGHER,
	DINO_PLUGINS_PRIORITY_HIGHEST
} DinoPluginsPriority;

#define DINO_PLUGINS_TYPE_PRIORITY (dino_plugins_priority_get_type ())
typedef enum  {
	DINO_PLUGINS_WIDGET_TYPE_GTK3,
	DINO_PLUGINS_WIDGET_TYPE_GTK4
} DinoPluginsWidgetType;

#define DINO_PLUGINS_TYPE_WIDGET_TYPE (dino_plugins_widget_type_get_type ())

#define DINO_PLUGINS_TYPE_ROOT_INTERFACE (dino_plugins_root_interface_get_type ())
#define DINO_PLUGINS_ROOT_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_ROOT_INTERFACE, DinoPluginsRootInterface))
#define DINO_PLUGINS_IS_ROOT_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_ROOT_INTERFACE))
#define DINO_PLUGINS_ROOT_INTERFACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_ROOT_INTERFACE, DinoPluginsRootInterfaceIface))

typedef struct _DinoPluginsRootInterface DinoPluginsRootInterface;
typedef struct _DinoPluginsRootInterfaceIface DinoPluginsRootInterfaceIface;

#define DINO_PLUGINS_TYPE_ENCRYPTION_LIST_ENTRY (dino_plugins_encryption_list_entry_get_type ())
#define DINO_PLUGINS_ENCRYPTION_LIST_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_ENCRYPTION_LIST_ENTRY, DinoPluginsEncryptionListEntry))
#define DINO_PLUGINS_IS_ENCRYPTION_LIST_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_ENCRYPTION_LIST_ENTRY))
#define DINO_PLUGINS_ENCRYPTION_LIST_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_ENCRYPTION_LIST_ENTRY, DinoPluginsEncryptionListEntryIface))

typedef struct _DinoPluginsEncryptionListEntry DinoPluginsEncryptionListEntry;
typedef struct _DinoPluginsEncryptionListEntryIface DinoPluginsEncryptionListEntryIface;

#define DINO_PLUGINS_TYPE_INPUT_FIELD_STATUS (dino_plugins_input_field_status_get_type ())
#define DINO_PLUGINS_INPUT_FIELD_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_INPUT_FIELD_STATUS, DinoPluginsInputFieldStatus))
#define DINO_PLUGINS_INPUT_FIELD_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_PLUGINS_TYPE_INPUT_FIELD_STATUS, DinoPluginsInputFieldStatusClass))
#define DINO_PLUGINS_IS_INPUT_FIELD_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_INPUT_FIELD_STATUS))
#define DINO_PLUGINS_IS_INPUT_FIELD_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_PLUGINS_TYPE_INPUT_FIELD_STATUS))
#define DINO_PLUGINS_INPUT_FIELD_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_PLUGINS_TYPE_INPUT_FIELD_STATUS, DinoPluginsInputFieldStatusClass))

typedef struct _DinoPluginsInputFieldStatus DinoPluginsInputFieldStatus;
typedef struct _DinoPluginsInputFieldStatusClass DinoPluginsInputFieldStatusClass;
typedef void (*DinoPluginsSetInputFieldStatus) (DinoPluginsInputFieldStatus* field_status, gpointer user_data);

#define DINO_TYPE_CONTENT_ITEM (dino_content_item_get_type ())
#define DINO_CONTENT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CONTENT_ITEM, DinoContentItem))
#define DINO_CONTENT_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CONTENT_ITEM, DinoContentItemClass))
#define DINO_IS_CONTENT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CONTENT_ITEM))
#define DINO_IS_CONTENT_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CONTENT_ITEM))
#define DINO_CONTENT_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CONTENT_ITEM, DinoContentItemClass))

typedef struct _DinoContentItem DinoContentItem;
typedef struct _DinoContentItemClass DinoContentItemClass;

#define DINO_PLUGINS_TYPE_CALL_ENCRYPTION_ENTRY (dino_plugins_call_encryption_entry_get_type ())
#define DINO_PLUGINS_CALL_ENCRYPTION_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_CALL_ENCRYPTION_ENTRY, DinoPluginsCallEncryptionEntry))
#define DINO_PLUGINS_IS_CALL_ENCRYPTION_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_CALL_ENCRYPTION_ENTRY))
#define DINO_PLUGINS_CALL_ENCRYPTION_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_CALL_ENCRYPTION_ENTRY, DinoPluginsCallEncryptionEntryIface))

typedef struct _DinoPluginsCallEncryptionEntry DinoPluginsCallEncryptionEntry;
typedef struct _DinoPluginsCallEncryptionEntryIface DinoPluginsCallEncryptionEntryIface;

#define DINO_PLUGINS_TYPE_CALL_ENCRYPTION_WIDGET (dino_plugins_call_encryption_widget_get_type ())
#define DINO_PLUGINS_CALL_ENCRYPTION_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_CALL_ENCRYPTION_WIDGET, DinoPluginsCallEncryptionWidget))
#define DINO_PLUGINS_IS_CALL_ENCRYPTION_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_CALL_ENCRYPTION_WIDGET))
#define DINO_PLUGINS_CALL_ENCRYPTION_WIDGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_CALL_ENCRYPTION_WIDGET, DinoPluginsCallEncryptionWidgetIface))

typedef struct _DinoPluginsCallEncryptionWidget DinoPluginsCallEncryptionWidget;
typedef struct _DinoPluginsCallEncryptionWidgetIface DinoPluginsCallEncryptionWidgetIface;

#define DINO_PLUGINS_TYPE_ACCOUNT_SETTINGS_ENTRY (dino_plugins_account_settings_entry_get_type ())
#define DINO_PLUGINS_ACCOUNT_SETTINGS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_ACCOUNT_SETTINGS_ENTRY, DinoPluginsAccountSettingsEntry))
#define DINO_PLUGINS_ACCOUNT_SETTINGS_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_PLUGINS_TYPE_ACCOUNT_SETTINGS_ENTRY, DinoPluginsAccountSettingsEntryClass))
#define DINO_PLUGINS_IS_ACCOUNT_SETTINGS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_ACCOUNT_SETTINGS_ENTRY))
#define DINO_PLUGINS_IS_ACCOUNT_SETTINGS_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_PLUGINS_TYPE_ACCOUNT_SETTINGS_ENTRY))
#define DINO_PLUGINS_ACCOUNT_SETTINGS_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_PLUGINS_TYPE_ACCOUNT_SETTINGS_ENTRY, DinoPluginsAccountSettingsEntryClass))

typedef struct _DinoPluginsAccountSettingsEntry DinoPluginsAccountSettingsEntry;
typedef struct _DinoPluginsAccountSettingsEntryClass DinoPluginsAccountSettingsEntryClass;
typedef struct _DinoPluginsAccountSettingsEntryPrivate DinoPluginsAccountSettingsEntryPrivate;

#define DINO_PLUGINS_TYPE_ENCRYPTION_PREFERENCES_ENTRY (dino_plugins_encryption_preferences_entry_get_type ())
#define DINO_PLUGINS_ENCRYPTION_PREFERENCES_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_ENCRYPTION_PREFERENCES_ENTRY, DinoPluginsEncryptionPreferencesEntry))
#define DINO_PLUGINS_ENCRYPTION_PREFERENCES_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_PLUGINS_TYPE_ENCRYPTION_PREFERENCES_ENTRY, DinoPluginsEncryptionPreferencesEntryClass))
#define DINO_PLUGINS_IS_ENCRYPTION_PREFERENCES_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_ENCRYPTION_PREFERENCES_ENTRY))
#define DINO_PLUGINS_IS_ENCRYPTION_PREFERENCES_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_PLUGINS_TYPE_ENCRYPTION_PREFERENCES_ENTRY))
#define DINO_PLUGINS_ENCRYPTION_PREFERENCES_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_PLUGINS_TYPE_ENCRYPTION_PREFERENCES_ENTRY, DinoPluginsEncryptionPreferencesEntryClass))

typedef struct _DinoPluginsEncryptionPreferencesEntry DinoPluginsEncryptionPreferencesEntry;
typedef struct _DinoPluginsEncryptionPreferencesEntryClass DinoPluginsEncryptionPreferencesEntryClass;
typedef struct _DinoPluginsEncryptionPreferencesEntryPrivate DinoPluginsEncryptionPreferencesEntryPrivate;

#define DINO_PLUGINS_TYPE_CONTACT_DETAILS_PROVIDER (dino_plugins_contact_details_provider_get_type ())
#define DINO_PLUGINS_CONTACT_DETAILS_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_CONTACT_DETAILS_PROVIDER, DinoPluginsContactDetailsProvider))
#define DINO_PLUGINS_IS_CONTACT_DETAILS_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_CONTACT_DETAILS_PROVIDER))
#define DINO_PLUGINS_CONTACT_DETAILS_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_CONTACT_DETAILS_PROVIDER, DinoPluginsContactDetailsProviderIface))

typedef struct _DinoPluginsContactDetailsProvider DinoPluginsContactDetailsProvider;
typedef struct _DinoPluginsContactDetailsProviderIface DinoPluginsContactDetailsProviderIface;

#define DINO_PLUGINS_TYPE_CONTACT_DETAILS (dino_plugins_contact_details_get_type ())
#define DINO_PLUGINS_CONTACT_DETAILS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_CONTACT_DETAILS, DinoPluginsContactDetails))
#define DINO_PLUGINS_CONTACT_DETAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_PLUGINS_TYPE_CONTACT_DETAILS, DinoPluginsContactDetailsClass))
#define DINO_PLUGINS_IS_CONTACT_DETAILS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_CONTACT_DETAILS))
#define DINO_PLUGINS_IS_CONTACT_DETAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_PLUGINS_TYPE_CONTACT_DETAILS))
#define DINO_PLUGINS_CONTACT_DETAILS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_PLUGINS_TYPE_CONTACT_DETAILS, DinoPluginsContactDetailsClass))

typedef struct _DinoPluginsContactDetails DinoPluginsContactDetails;
typedef struct _DinoPluginsContactDetailsClass DinoPluginsContactDetailsClass;
typedef struct _DinoPluginsContactDetailsPrivate DinoPluginsContactDetailsPrivate;

#define DINO_PLUGINS_TYPE_TEXT_COMMAND (dino_plugins_text_command_get_type ())
#define DINO_PLUGINS_TEXT_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_TEXT_COMMAND, DinoPluginsTextCommand))
#define DINO_PLUGINS_IS_TEXT_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_TEXT_COMMAND))
#define DINO_PLUGINS_TEXT_COMMAND_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_TEXT_COMMAND, DinoPluginsTextCommandIface))

typedef struct _DinoPluginsTextCommand DinoPluginsTextCommand;
typedef struct _DinoPluginsTextCommandIface DinoPluginsTextCommandIface;

#define DINO_PLUGINS_TYPE_CONVERSATION_TITLEBAR_ENTRY (dino_plugins_conversation_titlebar_entry_get_type ())
#define DINO_PLUGINS_CONVERSATION_TITLEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_CONVERSATION_TITLEBAR_ENTRY, DinoPluginsConversationTitlebarEntry))
#define DINO_PLUGINS_IS_CONVERSATION_TITLEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_CONVERSATION_TITLEBAR_ENTRY))
#define DINO_PLUGINS_CONVERSATION_TITLEBAR_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_CONVERSATION_TITLEBAR_ENTRY, DinoPluginsConversationTitlebarEntryIface))

typedef struct _DinoPluginsConversationTitlebarEntry DinoPluginsConversationTitlebarEntry;
typedef struct _DinoPluginsConversationTitlebarEntryIface DinoPluginsConversationTitlebarEntryIface;

#define DINO_PLUGINS_TYPE_CONVERSATION_ITEM_POPULATOR (dino_plugins_conversation_item_populator_get_type ())
#define DINO_PLUGINS_CONVERSATION_ITEM_POPULATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ITEM_POPULATOR, DinoPluginsConversationItemPopulator))
#define DINO_PLUGINS_IS_CONVERSATION_ITEM_POPULATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ITEM_POPULATOR))
#define DINO_PLUGINS_CONVERSATION_ITEM_POPULATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ITEM_POPULATOR, DinoPluginsConversationItemPopulatorIface))

typedef struct _DinoPluginsConversationItemPopulator DinoPluginsConversationItemPopulator;
typedef struct _DinoPluginsConversationItemPopulatorIface DinoPluginsConversationItemPopulatorIface;

#define DINO_PLUGINS_TYPE_CONVERSATION_ITEM_COLLECTION (dino_plugins_conversation_item_collection_get_type ())
#define DINO_PLUGINS_CONVERSATION_ITEM_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ITEM_COLLECTION, DinoPluginsConversationItemCollection))
#define DINO_PLUGINS_IS_CONVERSATION_ITEM_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ITEM_COLLECTION))
#define DINO_PLUGINS_CONVERSATION_ITEM_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ITEM_COLLECTION, DinoPluginsConversationItemCollectionIface))

typedef struct _DinoPluginsConversationItemCollection DinoPluginsConversationItemCollection;
typedef struct _DinoPluginsConversationItemCollectionIface DinoPluginsConversationItemCollectionIface;

#define DINO_PLUGINS_TYPE_META_CONVERSATION_ITEM (dino_plugins_meta_conversation_item_get_type ())
#define DINO_PLUGINS_META_CONVERSATION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_META_CONVERSATION_ITEM, DinoPluginsMetaConversationItem))
#define DINO_PLUGINS_META_CONVERSATION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_PLUGINS_TYPE_META_CONVERSATION_ITEM, DinoPluginsMetaConversationItemClass))
#define DINO_PLUGINS_IS_META_CONVERSATION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_META_CONVERSATION_ITEM))
#define DINO_PLUGINS_IS_META_CONVERSATION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_PLUGINS_TYPE_META_CONVERSATION_ITEM))
#define DINO_PLUGINS_META_CONVERSATION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_PLUGINS_TYPE_META_CONVERSATION_ITEM, DinoPluginsMetaConversationItemClass))

typedef struct _DinoPluginsMetaConversationItem DinoPluginsMetaConversationItem;
typedef struct _DinoPluginsMetaConversationItemClass DinoPluginsMetaConversationItemClass;

#define DINO_PLUGINS_TYPE_CONVERSATION_ADDITION_POPULATOR (dino_plugins_conversation_addition_populator_get_type ())
#define DINO_PLUGINS_CONVERSATION_ADDITION_POPULATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ADDITION_POPULATOR, DinoPluginsConversationAdditionPopulator))
#define DINO_PLUGINS_IS_CONVERSATION_ADDITION_POPULATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ADDITION_POPULATOR))
#define DINO_PLUGINS_CONVERSATION_ADDITION_POPULATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ADDITION_POPULATOR, DinoPluginsConversationAdditionPopulatorIface))

typedef struct _DinoPluginsConversationAdditionPopulator DinoPluginsConversationAdditionPopulator;
typedef struct _DinoPluginsConversationAdditionPopulatorIface DinoPluginsConversationAdditionPopulatorIface;

#define DINO_PLUGINS_TYPE_VIDEO_CALL_PLUGIN (dino_plugins_video_call_plugin_get_type ())
#define DINO_PLUGINS_VIDEO_CALL_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_VIDEO_CALL_PLUGIN, DinoPluginsVideoCallPlugin))
#define DINO_PLUGINS_IS_VIDEO_CALL_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_VIDEO_CALL_PLUGIN))
#define DINO_PLUGINS_VIDEO_CALL_PLUGIN_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_VIDEO_CALL_PLUGIN, DinoPluginsVideoCallPluginIface))

typedef struct _DinoPluginsVideoCallPlugin DinoPluginsVideoCallPlugin;
typedef struct _DinoPluginsVideoCallPluginIface DinoPluginsVideoCallPluginIface;

#define DINO_PLUGINS_TYPE_VIDEO_CALL_WIDGET (dino_plugins_video_call_widget_get_type ())
#define DINO_PLUGINS_VIDEO_CALL_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_VIDEO_CALL_WIDGET, DinoPluginsVideoCallWidget))
#define DINO_PLUGINS_IS_VIDEO_CALL_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_VIDEO_CALL_WIDGET))
#define DINO_PLUGINS_VIDEO_CALL_WIDGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_VIDEO_CALL_WIDGET, DinoPluginsVideoCallWidgetIface))

typedef struct _DinoPluginsVideoCallWidget DinoPluginsVideoCallWidget;
typedef struct _DinoPluginsVideoCallWidgetIface DinoPluginsVideoCallWidgetIface;

#define DINO_PLUGINS_TYPE_MEDIA_DEVICE (dino_plugins_media_device_get_type ())
#define DINO_PLUGINS_MEDIA_DEVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_MEDIA_DEVICE, DinoPluginsMediaDevice))
#define DINO_PLUGINS_IS_MEDIA_DEVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_MEDIA_DEVICE))
#define DINO_PLUGINS_MEDIA_DEVICE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_MEDIA_DEVICE, DinoPluginsMediaDeviceIface))

typedef struct _DinoPluginsMediaDevice DinoPluginsMediaDevice;
typedef struct _DinoPluginsMediaDeviceIface DinoPluginsMediaDeviceIface;

#define DINO_PLUGINS_TYPE_NOTIFICATION_POPULATOR (dino_plugins_notification_populator_get_type ())
#define DINO_PLUGINS_NOTIFICATION_POPULATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_NOTIFICATION_POPULATOR, DinoPluginsNotificationPopulator))
#define DINO_PLUGINS_IS_NOTIFICATION_POPULATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_NOTIFICATION_POPULATOR))
#define DINO_PLUGINS_NOTIFICATION_POPULATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_NOTIFICATION_POPULATOR, DinoPluginsNotificationPopulatorIface))

typedef struct _DinoPluginsNotificationPopulator DinoPluginsNotificationPopulator;
typedef struct _DinoPluginsNotificationPopulatorIface DinoPluginsNotificationPopulatorIface;

#define DINO_PLUGINS_TYPE_NOTIFICATION_COLLECTION (dino_plugins_notification_collection_get_type ())
#define DINO_PLUGINS_NOTIFICATION_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_NOTIFICATION_COLLECTION, DinoPluginsNotificationCollection))
#define DINO_PLUGINS_IS_NOTIFICATION_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_NOTIFICATION_COLLECTION))
#define DINO_PLUGINS_NOTIFICATION_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_NOTIFICATION_COLLECTION, DinoPluginsNotificationCollectionIface))

typedef struct _DinoPluginsNotificationCollection DinoPluginsNotificationCollection;
typedef struct _DinoPluginsNotificationCollectionIface DinoPluginsNotificationCollectionIface;
typedef struct _DinoPluginsMetaConversationItemPrivate DinoPluginsMetaConversationItemPrivate;

#define DINO_PLUGINS_TYPE_CONVERSATION_ITEM_WIDGET_INTERFACE (dino_plugins_conversation_item_widget_interface_get_type ())
#define DINO_PLUGINS_CONVERSATION_ITEM_WIDGET_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ITEM_WIDGET_INTERFACE, DinoPluginsConversationItemWidgetInterface))
#define DINO_PLUGINS_IS_CONVERSATION_ITEM_WIDGET_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ITEM_WIDGET_INTERFACE))
#define DINO_PLUGINS_CONVERSATION_ITEM_WIDGET_INTERFACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_PLUGINS_TYPE_CONVERSATION_ITEM_WIDGET_INTERFACE, DinoPluginsConversationItemWidgetInterfaceIface))

typedef struct _DinoPluginsConversationItemWidgetInterface DinoPluginsConversationItemWidgetInterface;
typedef struct _DinoPluginsConversationItemWidgetInterfaceIface DinoPluginsConversationItemWidgetInterfaceIface;

#define DINO_PLUGINS_TYPE_MESSAGE_ACTION (dino_plugins_message_action_get_type ())
#define DINO_PLUGINS_MESSAGE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_MESSAGE_ACTION, DinoPluginsMessageAction))
#define DINO_PLUGINS_MESSAGE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_PLUGINS_TYPE_MESSAGE_ACTION, DinoPluginsMessageActionClass))
#define DINO_PLUGINS_IS_MESSAGE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_MESSAGE_ACTION))
#define DINO_PLUGINS_IS_MESSAGE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_PLUGINS_TYPE_MESSAGE_ACTION))
#define DINO_PLUGINS_MESSAGE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_PLUGINS_TYPE_MESSAGE_ACTION, DinoPluginsMessageActionClass))

typedef struct _DinoPluginsMessageAction DinoPluginsMessageAction;
typedef struct _DinoPluginsMessageActionClass DinoPluginsMessageActionClass;
typedef void (*DinoPluginsMessageActionEvoked) (GVariant* variant, gpointer user_data);
typedef struct _DinoPluginsMessageActionPrivate DinoPluginsMessageActionPrivate;

#define DINO_PLUGINS_TYPE_META_CONVERSATION_NOTIFICATION (dino_plugins_meta_conversation_notification_get_type ())
#define DINO_PLUGINS_META_CONVERSATION_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_META_CONVERSATION_NOTIFICATION, DinoPluginsMetaConversationNotification))
#define DINO_PLUGINS_META_CONVERSATION_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_PLUGINS_TYPE_META_CONVERSATION_NOTIFICATION, DinoPluginsMetaConversationNotificationClass))
#define DINO_PLUGINS_IS_META_CONVERSATION_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_META_CONVERSATION_NOTIFICATION))
#define DINO_PLUGINS_IS_META_CONVERSATION_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_PLUGINS_TYPE_META_CONVERSATION_NOTIFICATION))
#define DINO_PLUGINS_META_CONVERSATION_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_PLUGINS_TYPE_META_CONVERSATION_NOTIFICATION, DinoPluginsMetaConversationNotificationClass))

typedef struct _DinoPluginsMetaConversationNotification DinoPluginsMetaConversationNotification;
typedef struct _DinoPluginsMetaConversationNotificationClass DinoPluginsMetaConversationNotificationClass;
typedef struct _DinoPluginsMetaConversationNotificationPrivate DinoPluginsMetaConversationNotificationPrivate;
typedef struct _DinoPluginsInputFieldStatusPrivate DinoPluginsInputFieldStatusPrivate;
typedef enum  {
	DINO_PLUGINS_INPUT_FIELD_STATUS_MESSAGE_TYPE_NONE,
	DINO_PLUGINS_INPUT_FIELD_STATUS_MESSAGE_TYPE_INFO,
	DINO_PLUGINS_INPUT_FIELD_STATUS_MESSAGE_TYPE_WARNING,
	DINO_PLUGINS_INPUT_FIELD_STATUS_MESSAGE_TYPE_ERROR
} DinoPluginsInputFieldStatusMessageType;

#define DINO_PLUGINS_INPUT_FIELD_STATUS_TYPE_MESSAGE_TYPE (dino_plugins_input_field_status_message_type_get_type ())
typedef enum  {
	DINO_PLUGINS_INPUT_FIELD_STATUS_INPUT_STATE_NORMAL,
	DINO_PLUGINS_INPUT_FIELD_STATUS_INPUT_STATE_DISABLED,
	DINO_PLUGINS_INPUT_FIELD_STATUS_INPUT_STATE_NO_SEND
} DinoPluginsInputFieldStatusInputState;

#define DINO_PLUGINS_INPUT_FIELD_STATUS_TYPE_INPUT_STATE (dino_plugins_input_field_status_input_state_get_type ())

#define DINO_PLUGINS_TYPE_LOADER (dino_plugins_loader_get_type ())
#define DINO_PLUGINS_LOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_PLUGINS_TYPE_LOADER, DinoPluginsLoader))
#define DINO_PLUGINS_LOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_PLUGINS_TYPE_LOADER, DinoPluginsLoaderClass))
#define DINO_PLUGINS_IS_LOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_PLUGINS_TYPE_LOADER))
#define DINO_PLUGINS_IS_LOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_PLUGINS_TYPE_LOADER))
#define DINO_PLUGINS_LOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_PLUGINS_TYPE_LOADER, DinoPluginsLoaderClass))

typedef struct _DinoPluginsLoader DinoPluginsLoader;
typedef struct _DinoPluginsLoaderClass DinoPluginsLoaderClass;
typedef struct _DinoPluginsLoaderPrivate DinoPluginsLoaderPrivate;
typedef struct _DinoPluginsRegistryPrivate DinoPluginsRegistryPrivate;

#define DINO_TYPE_STREAM_INTERACTION_MODULE (dino_stream_interaction_module_get_type ())
#define DINO_STREAM_INTERACTION_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_STREAM_INTERACTION_MODULE, DinoStreamInteractionModule))
#define DINO_IS_STREAM_INTERACTION_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_STREAM_INTERACTION_MODULE))
#define DINO_STREAM_INTERACTION_MODULE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_STREAM_INTERACTION_MODULE, DinoStreamInteractionModuleIface))

typedef struct _DinoStreamInteractionModule DinoStreamInteractionModule;
typedef struct _DinoStreamInteractionModuleIface DinoStreamInteractionModuleIface;

#define DINO_TYPE_AVATAR_MANAGER (dino_avatar_manager_get_type ())
#define DINO_AVATAR_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_AVATAR_MANAGER, DinoAvatarManager))
#define DINO_AVATAR_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_AVATAR_MANAGER, DinoAvatarManagerClass))
#define DINO_IS_AVATAR_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_AVATAR_MANAGER))
#define DINO_IS_AVATAR_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_AVATAR_MANAGER))
#define DINO_AVATAR_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_AVATAR_MANAGER, DinoAvatarManagerClass))

typedef struct _DinoAvatarManager DinoAvatarManager;
typedef struct _DinoAvatarManagerClass DinoAvatarManagerClass;
typedef struct _DinoAvatarManagerPrivate DinoAvatarManagerPrivate;

#define DINO_TYPE_MODULE_IDENTITY (dino_module_identity_get_type ())
#define DINO_MODULE_IDENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_MODULE_IDENTITY, DinoModuleIdentity))
#define DINO_MODULE_IDENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_MODULE_IDENTITY, DinoModuleIdentityClass))
#define DINO_IS_MODULE_IDENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_MODULE_IDENTITY))
#define DINO_IS_MODULE_IDENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_MODULE_IDENTITY))
#define DINO_MODULE_IDENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_MODULE_IDENTITY, DinoModuleIdentityClass))

typedef struct _DinoModuleIdentity DinoModuleIdentity;
typedef struct _DinoModuleIdentityClass DinoModuleIdentityClass;

#define DINO_TYPE_BLOCKING_MANAGER (dino_blocking_manager_get_type ())
#define DINO_BLOCKING_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_BLOCKING_MANAGER, DinoBlockingManager))
#define DINO_BLOCKING_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_BLOCKING_MANAGER, DinoBlockingManagerClass))
#define DINO_IS_BLOCKING_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_BLOCKING_MANAGER))
#define DINO_IS_BLOCKING_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_BLOCKING_MANAGER))
#define DINO_BLOCKING_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_BLOCKING_MANAGER, DinoBlockingManagerClass))

typedef struct _DinoBlockingManager DinoBlockingManager;
typedef struct _DinoBlockingManagerClass DinoBlockingManagerClass;
typedef struct _DinoBlockingManagerPrivate DinoBlockingManagerPrivate;

#define DINO_TYPE_CALL_STORE (dino_call_store_get_type ())
#define DINO_CALL_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CALL_STORE, DinoCallStore))
#define DINO_CALL_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CALL_STORE, DinoCallStoreClass))
#define DINO_IS_CALL_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CALL_STORE))
#define DINO_IS_CALL_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CALL_STORE))
#define DINO_CALL_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CALL_STORE, DinoCallStoreClass))

typedef struct _DinoCallStore DinoCallStore;
typedef struct _DinoCallStoreClass DinoCallStoreClass;
typedef struct _DinoCallStorePrivate DinoCallStorePrivate;

#define DINO_TYPE_CALL_STATE (dino_call_state_get_type ())
#define DINO_CALL_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CALL_STATE, DinoCallState))
#define DINO_CALL_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CALL_STATE, DinoCallStateClass))
#define DINO_IS_CALL_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CALL_STATE))
#define DINO_IS_CALL_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CALL_STATE))
#define DINO_CALL_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CALL_STATE, DinoCallStateClass))

typedef struct _DinoCallState DinoCallState;
typedef struct _DinoCallStateClass DinoCallStateClass;
typedef struct _DinoCallStatePrivate DinoCallStatePrivate;

#define DINO_TYPE_PEER_STATE (dino_peer_state_get_type ())
#define DINO_PEER_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_PEER_STATE, DinoPeerState))
#define DINO_PEER_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_PEER_STATE, DinoPeerStateClass))
#define DINO_IS_PEER_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_PEER_STATE))
#define DINO_IS_PEER_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_PEER_STATE))
#define DINO_PEER_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_PEER_STATE, DinoPeerStateClass))

typedef struct _DinoPeerState DinoPeerState;
typedef struct _DinoPeerStateClass DinoPeerStateClass;
typedef struct _DinoPeerStatePrivate DinoPeerStatePrivate;

#define DINO_TYPE_CALLS (dino_calls_get_type ())
#define DINO_CALLS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CALLS, DinoCalls))
#define DINO_CALLS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CALLS, DinoCallsClass))
#define DINO_IS_CALLS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CALLS))
#define DINO_IS_CALLS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CALLS))
#define DINO_CALLS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CALLS, DinoCallsClass))

typedef struct _DinoCalls DinoCalls;
typedef struct _DinoCallsClass DinoCallsClass;

#define DINO_TYPE_PEER_INFO (dino_peer_info_get_type ())
#define DINO_PEER_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_PEER_INFO, DinoPeerInfo))
#define DINO_PEER_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_PEER_INFO, DinoPeerInfoClass))
#define DINO_IS_PEER_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_PEER_INFO))
#define DINO_IS_PEER_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_PEER_INFO))
#define DINO_PEER_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_PEER_INFO, DinoPeerInfoClass))

typedef struct _DinoPeerInfo DinoPeerInfo;
typedef struct _DinoPeerInfoClass DinoPeerInfoClass;

#define DINO_TYPE_PEER_CONTENT_INFO (dino_peer_content_info_get_type ())
#define DINO_PEER_CONTENT_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_PEER_CONTENT_INFO, DinoPeerContentInfo))
#define DINO_PEER_CONTENT_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_PEER_CONTENT_INFO, DinoPeerContentInfoClass))
#define DINO_IS_PEER_CONTENT_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_PEER_CONTENT_INFO))
#define DINO_IS_PEER_CONTENT_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_PEER_CONTENT_INFO))
#define DINO_PEER_CONTENT_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_PEER_CONTENT_INFO, DinoPeerContentInfoClass))

typedef struct _DinoPeerContentInfo DinoPeerContentInfo;
typedef struct _DinoPeerContentInfoClass DinoPeerContentInfoClass;
typedef struct _DinoPeerContentInfoPrivate DinoPeerContentInfoPrivate;
typedef struct _DinoPeerInfoPrivate DinoPeerInfoPrivate;
typedef struct _DinoCallsPrivate DinoCallsPrivate;

#define DINO_TYPE_CHAT_INTERACTION (dino_chat_interaction_get_type ())
#define DINO_CHAT_INTERACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CHAT_INTERACTION, DinoChatInteraction))
#define DINO_CHAT_INTERACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CHAT_INTERACTION, DinoChatInteractionClass))
#define DINO_IS_CHAT_INTERACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CHAT_INTERACTION))
#define DINO_IS_CHAT_INTERACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CHAT_INTERACTION))
#define DINO_CHAT_INTERACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CHAT_INTERACTION, DinoChatInteractionClass))

typedef struct _DinoChatInteraction DinoChatInteraction;
typedef struct _DinoChatInteractionClass DinoChatInteractionClass;
typedef struct _DinoChatInteractionPrivate DinoChatInteractionPrivate;

#define DINO_TYPE_CONNECTION_MANAGER (dino_connection_manager_get_type ())
#define DINO_CONNECTION_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CONNECTION_MANAGER, DinoConnectionManager))
#define DINO_CONNECTION_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CONNECTION_MANAGER, DinoConnectionManagerClass))
#define DINO_IS_CONNECTION_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CONNECTION_MANAGER))
#define DINO_IS_CONNECTION_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CONNECTION_MANAGER))
#define DINO_CONNECTION_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CONNECTION_MANAGER, DinoConnectionManagerClass))

typedef struct _DinoConnectionManager DinoConnectionManager;
typedef struct _DinoConnectionManagerClass DinoConnectionManagerClass;
typedef struct _DinoConnectionManagerPrivate DinoConnectionManagerPrivate;
typedef enum  {
	DINO_CONNECTION_MANAGER_CONNECTION_STATE_CONNECTED,
	DINO_CONNECTION_MANAGER_CONNECTION_STATE_CONNECTING,
	DINO_CONNECTION_MANAGER_CONNECTION_STATE_DISCONNECTED
} DinoConnectionManagerConnectionState;

#define DINO_CONNECTION_MANAGER_TYPE_CONNECTION_STATE (dino_connection_manager_connection_state_get_type ())

#define DINO_TYPE_MODULE_MANAGER (dino_module_manager_get_type ())
#define DINO_MODULE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_MODULE_MANAGER, DinoModuleManager))
#define DINO_MODULE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_MODULE_MANAGER, DinoModuleManagerClass))
#define DINO_IS_MODULE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_MODULE_MANAGER))
#define DINO_IS_MODULE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_MODULE_MANAGER))
#define DINO_MODULE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_MODULE_MANAGER, DinoModuleManagerClass))

typedef struct _DinoModuleManager DinoModuleManager;
typedef struct _DinoModuleManagerClass DinoModuleManagerClass;

#define DINO_CONNECTION_MANAGER_TYPE_CONNECTION_ERROR (dino_connection_manager_connection_error_get_type ())
#define DINO_CONNECTION_MANAGER_CONNECTION_ERROR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_CONNECTION_MANAGER_TYPE_CONNECTION_ERROR, DinoConnectionManagerConnectionError))
#define DINO_CONNECTION_MANAGER_CONNECTION_ERROR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_CONNECTION_MANAGER_TYPE_CONNECTION_ERROR, DinoConnectionManagerConnectionErrorClass))
#define DINO_CONNECTION_MANAGER_IS_CONNECTION_ERROR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_CONNECTION_MANAGER_TYPE_CONNECTION_ERROR))
#define DINO_CONNECTION_MANAGER_IS_CONNECTION_ERROR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_CONNECTION_MANAGER_TYPE_CONNECTION_ERROR))
#define DINO_CONNECTION_MANAGER_CONNECTION_ERROR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_CONNECTION_MANAGER_TYPE_CONNECTION_ERROR, DinoConnectionManagerConnectionErrorClass))

typedef struct _DinoConnectionManagerConnectionError DinoConnectionManagerConnectionError;
typedef struct _DinoConnectionManagerConnectionErrorClass DinoConnectionManagerConnectionErrorClass;
typedef struct _DinoConnectionManagerConnectionErrorPrivate DinoConnectionManagerConnectionErrorPrivate;
typedef enum  {
	DINO_CONNECTION_MANAGER_CONNECTION_ERROR_SOURCE_CONNECTION,
	DINO_CONNECTION_MANAGER_CONNECTION_ERROR_SOURCE_SASL,
	DINO_CONNECTION_MANAGER_CONNECTION_ERROR_SOURCE_TLS,
	DINO_CONNECTION_MANAGER_CONNECTION_ERROR_SOURCE_STREAM_ERROR
} DinoConnectionManagerConnectionErrorSource;

#define DINO_CONNECTION_MANAGER_CONNECTION_ERROR_TYPE_SOURCE (dino_connection_manager_connection_error_source_get_type ())
typedef enum  {
	DINO_CONNECTION_MANAGER_CONNECTION_ERROR_RECONNECT_NOW,
	DINO_CONNECTION_MANAGER_CONNECTION_ERROR_RECONNECT_LATER,
	DINO_CONNECTION_MANAGER_CONNECTION_ERROR_RECONNECT_NEVER
} DinoConnectionManagerConnectionErrorReconnect;

#define DINO_CONNECTION_MANAGER_CONNECTION_ERROR_TYPE_RECONNECT (dino_connection_manager_connection_error_reconnect_get_type ())

#define DINO_MODEL_TYPE_CONVERSATION_DISPLAY_NAME (dino_model_conversation_display_name_get_type ())
#define DINO_MODEL_CONVERSATION_DISPLAY_NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_MODEL_TYPE_CONVERSATION_DISPLAY_NAME, DinoModelConversationDisplayName))
#define DINO_MODEL_CONVERSATION_DISPLAY_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_MODEL_TYPE_CONVERSATION_DISPLAY_NAME, DinoModelConversationDisplayNameClass))
#define DINO_MODEL_IS_CONVERSATION_DISPLAY_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_MODEL_TYPE_CONVERSATION_DISPLAY_NAME))
#define DINO_MODEL_IS_CONVERSATION_DISPLAY_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_MODEL_TYPE_CONVERSATION_DISPLAY_NAME))
#define DINO_MODEL_CONVERSATION_DISPLAY_NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_MODEL_TYPE_CONVERSATION_DISPLAY_NAME, DinoModelConversationDisplayNameClass))

typedef struct _DinoModelConversationDisplayName DinoModelConversationDisplayName;
typedef struct _DinoModelConversationDisplayNameClass DinoModelConversationDisplayNameClass;
typedef struct _DinoModelConversationDisplayNamePrivate DinoModelConversationDisplayNamePrivate;

#define DINO_TYPE_CONTACT_MODELS (dino_contact_models_get_type ())
#define DINO_CONTACT_MODELS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CONTACT_MODELS, DinoContactModels))
#define DINO_CONTACT_MODELS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CONTACT_MODELS, DinoContactModelsClass))
#define DINO_IS_CONTACT_MODELS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CONTACT_MODELS))
#define DINO_IS_CONTACT_MODELS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CONTACT_MODELS))
#define DINO_CONTACT_MODELS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CONTACT_MODELS, DinoContactModelsClass))

typedef struct _DinoContactModels DinoContactModels;
typedef struct _DinoContactModelsClass DinoContactModelsClass;
typedef struct _DinoContactModelsPrivate DinoContactModelsPrivate;

#define DINO_TYPE_CONTENT_ITEM_STORE (dino_content_item_store_get_type ())
#define DINO_CONTENT_ITEM_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CONTENT_ITEM_STORE, DinoContentItemStore))
#define DINO_CONTENT_ITEM_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CONTENT_ITEM_STORE, DinoContentItemStoreClass))
#define DINO_IS_CONTENT_ITEM_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CONTENT_ITEM_STORE))
#define DINO_IS_CONTENT_ITEM_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CONTENT_ITEM_STORE))
#define DINO_CONTENT_ITEM_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CONTENT_ITEM_STORE, DinoContentItemStoreClass))

typedef struct _DinoContentItemStore DinoContentItemStore;
typedef struct _DinoContentItemStoreClass DinoContentItemStoreClass;
typedef struct _DinoContentItemStorePrivate DinoContentItemStorePrivate;

#define DINO_TYPE_CONTENT_ITEM_COLLECTION (dino_content_item_collection_get_type ())
#define DINO_CONTENT_ITEM_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CONTENT_ITEM_COLLECTION, DinoContentItemCollection))
#define DINO_IS_CONTENT_ITEM_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CONTENT_ITEM_COLLECTION))
#define DINO_CONTENT_ITEM_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_CONTENT_ITEM_COLLECTION, DinoContentItemCollectionIface))

typedef struct _DinoContentItemCollection DinoContentItemCollection;
typedef struct _DinoContentItemCollectionIface DinoContentItemCollectionIface;
typedef struct _DinoContentItemPrivate DinoContentItemPrivate;

#define DINO_TYPE_MESSAGE_ITEM (dino_message_item_get_type ())
#define DINO_MESSAGE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_MESSAGE_ITEM, DinoMessageItem))
#define DINO_MESSAGE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_MESSAGE_ITEM, DinoMessageItemClass))
#define DINO_IS_MESSAGE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_MESSAGE_ITEM))
#define DINO_IS_MESSAGE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_MESSAGE_ITEM))
#define DINO_MESSAGE_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_MESSAGE_ITEM, DinoMessageItemClass))

typedef struct _DinoMessageItem DinoMessageItem;
typedef struct _DinoMessageItemClass DinoMessageItemClass;
typedef struct _DinoMessageItemPrivate DinoMessageItemPrivate;

#define DINO_TYPE_FILE_ITEM (dino_file_item_get_type ())
#define DINO_FILE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_ITEM, DinoFileItem))
#define DINO_FILE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_FILE_ITEM, DinoFileItemClass))
#define DINO_IS_FILE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_ITEM))
#define DINO_IS_FILE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_FILE_ITEM))
#define DINO_FILE_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_FILE_ITEM, DinoFileItemClass))

typedef struct _DinoFileItem DinoFileItem;
typedef struct _DinoFileItemClass DinoFileItemClass;
typedef struct _DinoFileItemPrivate DinoFileItemPrivate;

#define DINO_TYPE_CALL_ITEM (dino_call_item_get_type ())
#define DINO_CALL_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CALL_ITEM, DinoCallItem))
#define DINO_CALL_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CALL_ITEM, DinoCallItemClass))
#define DINO_IS_CALL_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CALL_ITEM))
#define DINO_IS_CALL_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CALL_ITEM))
#define DINO_CALL_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CALL_ITEM, DinoCallItemClass))

typedef struct _DinoCallItem DinoCallItem;
typedef struct _DinoCallItemClass DinoCallItemClass;
typedef struct _DinoCallItemPrivate DinoCallItemPrivate;

#define DINO_TYPE_CONVERSATION_MANAGER (dino_conversation_manager_get_type ())
#define DINO_CONVERSATION_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CONVERSATION_MANAGER, DinoConversationManager))
#define DINO_CONVERSATION_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CONVERSATION_MANAGER, DinoConversationManagerClass))
#define DINO_IS_CONVERSATION_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CONVERSATION_MANAGER))
#define DINO_IS_CONVERSATION_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CONVERSATION_MANAGER))
#define DINO_CONVERSATION_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CONVERSATION_MANAGER, DinoConversationManagerClass))

typedef struct _DinoConversationManager DinoConversationManager;
typedef struct _DinoConversationManagerClass DinoConversationManagerClass;
typedef struct _DinoConversationManagerPrivate DinoConversationManagerPrivate;

#define DINO_TYPE_COUNTERPART_INTERACTION_MANAGER (dino_counterpart_interaction_manager_get_type ())
#define DINO_COUNTERPART_INTERACTION_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_COUNTERPART_INTERACTION_MANAGER, DinoCounterpartInteractionManager))
#define DINO_COUNTERPART_INTERACTION_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_COUNTERPART_INTERACTION_MANAGER, DinoCounterpartInteractionManagerClass))
#define DINO_IS_COUNTERPART_INTERACTION_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_COUNTERPART_INTERACTION_MANAGER))
#define DINO_IS_COUNTERPART_INTERACTION_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_COUNTERPART_INTERACTION_MANAGER))
#define DINO_COUNTERPART_INTERACTION_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_COUNTERPART_INTERACTION_MANAGER, DinoCounterpartInteractionManagerClass))

typedef struct _DinoCounterpartInteractionManager DinoCounterpartInteractionManager;
typedef struct _DinoCounterpartInteractionManagerClass DinoCounterpartInteractionManagerClass;
typedef struct _DinoCounterpartInteractionManagerPrivate DinoCounterpartInteractionManagerPrivate;
typedef struct _DinoDatabasePrivate DinoDatabasePrivate;

#define DINO_DATABASE_TYPE_ACCOUNT_TABLE (dino_database_account_table_get_type ())
#define DINO_DATABASE_ACCOUNT_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_ACCOUNT_TABLE, DinoDatabaseAccountTable))
#define DINO_DATABASE_ACCOUNT_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_ACCOUNT_TABLE, DinoDatabaseAccountTableClass))
#define DINO_DATABASE_IS_ACCOUNT_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_ACCOUNT_TABLE))
#define DINO_DATABASE_IS_ACCOUNT_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_ACCOUNT_TABLE))
#define DINO_DATABASE_ACCOUNT_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_ACCOUNT_TABLE, DinoDatabaseAccountTableClass))

typedef struct _DinoDatabaseAccountTable DinoDatabaseAccountTable;
typedef struct _DinoDatabaseAccountTableClass DinoDatabaseAccountTableClass;

#define DINO_DATABASE_TYPE_JID_TABLE (dino_database_jid_table_get_type ())
#define DINO_DATABASE_JID_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_JID_TABLE, DinoDatabaseJidTable))
#define DINO_DATABASE_JID_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_JID_TABLE, DinoDatabaseJidTableClass))
#define DINO_DATABASE_IS_JID_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_JID_TABLE))
#define DINO_DATABASE_IS_JID_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_JID_TABLE))
#define DINO_DATABASE_JID_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_JID_TABLE, DinoDatabaseJidTableClass))

typedef struct _DinoDatabaseJidTable DinoDatabaseJidTable;
typedef struct _DinoDatabaseJidTableClass DinoDatabaseJidTableClass;

#define DINO_DATABASE_TYPE_ENTITY_TABLE (dino_database_entity_table_get_type ())
#define DINO_DATABASE_ENTITY_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_ENTITY_TABLE, DinoDatabaseEntityTable))
#define DINO_DATABASE_ENTITY_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_ENTITY_TABLE, DinoDatabaseEntityTableClass))
#define DINO_DATABASE_IS_ENTITY_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_ENTITY_TABLE))
#define DINO_DATABASE_IS_ENTITY_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_ENTITY_TABLE))
#define DINO_DATABASE_ENTITY_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_ENTITY_TABLE, DinoDatabaseEntityTableClass))

typedef struct _DinoDatabaseEntityTable DinoDatabaseEntityTable;
typedef struct _DinoDatabaseEntityTableClass DinoDatabaseEntityTableClass;

#define DINO_DATABASE_TYPE_CONTENT_ITEM_TABLE (dino_database_content_item_table_get_type ())
#define DINO_DATABASE_CONTENT_ITEM_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_CONTENT_ITEM_TABLE, DinoDatabaseContentItemTable))
#define DINO_DATABASE_CONTENT_ITEM_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_CONTENT_ITEM_TABLE, DinoDatabaseContentItemTableClass))
#define DINO_DATABASE_IS_CONTENT_ITEM_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_CONTENT_ITEM_TABLE))
#define DINO_DATABASE_IS_CONTENT_ITEM_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_CONTENT_ITEM_TABLE))
#define DINO_DATABASE_CONTENT_ITEM_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_CONTENT_ITEM_TABLE, DinoDatabaseContentItemTableClass))

typedef struct _DinoDatabaseContentItemTable DinoDatabaseContentItemTable;
typedef struct _DinoDatabaseContentItemTableClass DinoDatabaseContentItemTableClass;

#define DINO_DATABASE_TYPE_MESSAGE_TABLE (dino_database_message_table_get_type ())
#define DINO_DATABASE_MESSAGE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_MESSAGE_TABLE, DinoDatabaseMessageTable))
#define DINO_DATABASE_MESSAGE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_MESSAGE_TABLE, DinoDatabaseMessageTableClass))
#define DINO_DATABASE_IS_MESSAGE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_MESSAGE_TABLE))
#define DINO_DATABASE_IS_MESSAGE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_MESSAGE_TABLE))
#define DINO_DATABASE_MESSAGE_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_MESSAGE_TABLE, DinoDatabaseMessageTableClass))

typedef struct _DinoDatabaseMessageTable DinoDatabaseMessageTable;
typedef struct _DinoDatabaseMessageTableClass DinoDatabaseMessageTableClass;

#define DINO_DATABASE_TYPE_BODY_META (dino_database_body_meta_get_type ())
#define DINO_DATABASE_BODY_META(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_BODY_META, DinoDatabaseBodyMeta))
#define DINO_DATABASE_BODY_META_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_BODY_META, DinoDatabaseBodyMetaClass))
#define DINO_DATABASE_IS_BODY_META(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_BODY_META))
#define DINO_DATABASE_IS_BODY_META_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_BODY_META))
#define DINO_DATABASE_BODY_META_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_BODY_META, DinoDatabaseBodyMetaClass))

typedef struct _DinoDatabaseBodyMeta DinoDatabaseBodyMeta;
typedef struct _DinoDatabaseBodyMetaClass DinoDatabaseBodyMetaClass;

#define DINO_DATABASE_TYPE_REPLY_TABLE (dino_database_reply_table_get_type ())
#define DINO_DATABASE_REPLY_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_REPLY_TABLE, DinoDatabaseReplyTable))
#define DINO_DATABASE_REPLY_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_REPLY_TABLE, DinoDatabaseReplyTableClass))
#define DINO_DATABASE_IS_REPLY_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_REPLY_TABLE))
#define DINO_DATABASE_IS_REPLY_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_REPLY_TABLE))
#define DINO_DATABASE_REPLY_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_REPLY_TABLE, DinoDatabaseReplyTableClass))

typedef struct _DinoDatabaseReplyTable DinoDatabaseReplyTable;
typedef struct _DinoDatabaseReplyTableClass DinoDatabaseReplyTableClass;

#define DINO_DATABASE_TYPE_MESSAGE_CORRECTION_TABLE (dino_database_message_correction_table_get_type ())
#define DINO_DATABASE_MESSAGE_CORRECTION_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_MESSAGE_CORRECTION_TABLE, DinoDatabaseMessageCorrectionTable))
#define DINO_DATABASE_MESSAGE_CORRECTION_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_MESSAGE_CORRECTION_TABLE, DinoDatabaseMessageCorrectionTableClass))
#define DINO_DATABASE_IS_MESSAGE_CORRECTION_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_MESSAGE_CORRECTION_TABLE))
#define DINO_DATABASE_IS_MESSAGE_CORRECTION_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_MESSAGE_CORRECTION_TABLE))
#define DINO_DATABASE_MESSAGE_CORRECTION_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_MESSAGE_CORRECTION_TABLE, DinoDatabaseMessageCorrectionTableClass))

typedef struct _DinoDatabaseMessageCorrectionTable DinoDatabaseMessageCorrectionTable;
typedef struct _DinoDatabaseMessageCorrectionTableClass DinoDatabaseMessageCorrectionTableClass;

#define DINO_DATABASE_TYPE_REAL_JID_TABLE (dino_database_real_jid_table_get_type ())
#define DINO_DATABASE_REAL_JID_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_REAL_JID_TABLE, DinoDatabaseRealJidTable))
#define DINO_DATABASE_REAL_JID_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_REAL_JID_TABLE, DinoDatabaseRealJidTableClass))
#define DINO_DATABASE_IS_REAL_JID_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_REAL_JID_TABLE))
#define DINO_DATABASE_IS_REAL_JID_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_REAL_JID_TABLE))
#define DINO_DATABASE_REAL_JID_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_REAL_JID_TABLE, DinoDatabaseRealJidTableClass))

typedef struct _DinoDatabaseRealJidTable DinoDatabaseRealJidTable;
typedef struct _DinoDatabaseRealJidTableClass DinoDatabaseRealJidTableClass;

#define DINO_DATABASE_TYPE_OCCUPANT_ID_TABLE (dino_database_occupant_id_table_get_type ())
#define DINO_DATABASE_OCCUPANT_ID_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_OCCUPANT_ID_TABLE, DinoDatabaseOccupantIdTable))
#define DINO_DATABASE_OCCUPANT_ID_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_OCCUPANT_ID_TABLE, DinoDatabaseOccupantIdTableClass))
#define DINO_DATABASE_IS_OCCUPANT_ID_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_OCCUPANT_ID_TABLE))
#define DINO_DATABASE_IS_OCCUPANT_ID_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_OCCUPANT_ID_TABLE))
#define DINO_DATABASE_OCCUPANT_ID_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_OCCUPANT_ID_TABLE, DinoDatabaseOccupantIdTableClass))

typedef struct _DinoDatabaseOccupantIdTable DinoDatabaseOccupantIdTable;
typedef struct _DinoDatabaseOccupantIdTableClass DinoDatabaseOccupantIdTableClass;

#define DINO_DATABASE_TYPE_FILE_TRANSFER_TABLE (dino_database_file_transfer_table_get_type ())
#define DINO_DATABASE_FILE_TRANSFER_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_FILE_TRANSFER_TABLE, DinoDatabaseFileTransferTable))
#define DINO_DATABASE_FILE_TRANSFER_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_FILE_TRANSFER_TABLE, DinoDatabaseFileTransferTableClass))
#define DINO_DATABASE_IS_FILE_TRANSFER_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_FILE_TRANSFER_TABLE))
#define DINO_DATABASE_IS_FILE_TRANSFER_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_FILE_TRANSFER_TABLE))
#define DINO_DATABASE_FILE_TRANSFER_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_FILE_TRANSFER_TABLE, DinoDatabaseFileTransferTableClass))

typedef struct _DinoDatabaseFileTransferTable DinoDatabaseFileTransferTable;
typedef struct _DinoDatabaseFileTransferTableClass DinoDatabaseFileTransferTableClass;

#define DINO_DATABASE_TYPE_FILE_HASHES_TABLE (dino_database_file_hashes_table_get_type ())
#define DINO_DATABASE_FILE_HASHES_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_FILE_HASHES_TABLE, DinoDatabaseFileHashesTable))
#define DINO_DATABASE_FILE_HASHES_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_FILE_HASHES_TABLE, DinoDatabaseFileHashesTableClass))
#define DINO_DATABASE_IS_FILE_HASHES_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_FILE_HASHES_TABLE))
#define DINO_DATABASE_IS_FILE_HASHES_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_FILE_HASHES_TABLE))
#define DINO_DATABASE_FILE_HASHES_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_FILE_HASHES_TABLE, DinoDatabaseFileHashesTableClass))

typedef struct _DinoDatabaseFileHashesTable DinoDatabaseFileHashesTable;
typedef struct _DinoDatabaseFileHashesTableClass DinoDatabaseFileHashesTableClass;

#define DINO_DATABASE_TYPE_FILE_THUMBNAILS_TABLE (dino_database_file_thumbnails_table_get_type ())
#define DINO_DATABASE_FILE_THUMBNAILS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_FILE_THUMBNAILS_TABLE, DinoDatabaseFileThumbnailsTable))
#define DINO_DATABASE_FILE_THUMBNAILS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_FILE_THUMBNAILS_TABLE, DinoDatabaseFileThumbnailsTableClass))
#define DINO_DATABASE_IS_FILE_THUMBNAILS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_FILE_THUMBNAILS_TABLE))
#define DINO_DATABASE_IS_FILE_THUMBNAILS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_FILE_THUMBNAILS_TABLE))
#define DINO_DATABASE_FILE_THUMBNAILS_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_FILE_THUMBNAILS_TABLE, DinoDatabaseFileThumbnailsTableClass))

typedef struct _DinoDatabaseFileThumbnailsTable DinoDatabaseFileThumbnailsTable;
typedef struct _DinoDatabaseFileThumbnailsTableClass DinoDatabaseFileThumbnailsTableClass;

#define DINO_DATABASE_TYPE_SOURCES_TABLE (dino_database_sources_table_get_type ())
#define DINO_DATABASE_SOURCES_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_SOURCES_TABLE, DinoDatabaseSourcesTable))
#define DINO_DATABASE_SOURCES_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_SOURCES_TABLE, DinoDatabaseSourcesTableClass))
#define DINO_DATABASE_IS_SOURCES_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_SOURCES_TABLE))
#define DINO_DATABASE_IS_SOURCES_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_SOURCES_TABLE))
#define DINO_DATABASE_SOURCES_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_SOURCES_TABLE, DinoDatabaseSourcesTableClass))

typedef struct _DinoDatabaseSourcesTable DinoDatabaseSourcesTable;
typedef struct _DinoDatabaseSourcesTableClass DinoDatabaseSourcesTableClass;

#define DINO_DATABASE_TYPE_CALL_TABLE (dino_database_call_table_get_type ())
#define DINO_DATABASE_CALL_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_CALL_TABLE, DinoDatabaseCallTable))
#define DINO_DATABASE_CALL_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_CALL_TABLE, DinoDatabaseCallTableClass))
#define DINO_DATABASE_IS_CALL_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_CALL_TABLE))
#define DINO_DATABASE_IS_CALL_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_CALL_TABLE))
#define DINO_DATABASE_CALL_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_CALL_TABLE, DinoDatabaseCallTableClass))

typedef struct _DinoDatabaseCallTable DinoDatabaseCallTable;
typedef struct _DinoDatabaseCallTableClass DinoDatabaseCallTableClass;

#define DINO_DATABASE_TYPE_CALL_COUNTERPART_TABLE (dino_database_call_counterpart_table_get_type ())
#define DINO_DATABASE_CALL_COUNTERPART_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_CALL_COUNTERPART_TABLE, DinoDatabaseCallCounterpartTable))
#define DINO_DATABASE_CALL_COUNTERPART_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_CALL_COUNTERPART_TABLE, DinoDatabaseCallCounterpartTableClass))
#define DINO_DATABASE_IS_CALL_COUNTERPART_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_CALL_COUNTERPART_TABLE))
#define DINO_DATABASE_IS_CALL_COUNTERPART_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_CALL_COUNTERPART_TABLE))
#define DINO_DATABASE_CALL_COUNTERPART_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_CALL_COUNTERPART_TABLE, DinoDatabaseCallCounterpartTableClass))

typedef struct _DinoDatabaseCallCounterpartTable DinoDatabaseCallCounterpartTable;
typedef struct _DinoDatabaseCallCounterpartTableClass DinoDatabaseCallCounterpartTableClass;

#define DINO_DATABASE_TYPE_CONVERSATION_TABLE (dino_database_conversation_table_get_type ())
#define DINO_DATABASE_CONVERSATION_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_CONVERSATION_TABLE, DinoDatabaseConversationTable))
#define DINO_DATABASE_CONVERSATION_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_CONVERSATION_TABLE, DinoDatabaseConversationTableClass))
#define DINO_DATABASE_IS_CONVERSATION_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_CONVERSATION_TABLE))
#define DINO_DATABASE_IS_CONVERSATION_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_CONVERSATION_TABLE))
#define DINO_DATABASE_CONVERSATION_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_CONVERSATION_TABLE, DinoDatabaseConversationTableClass))

typedef struct _DinoDatabaseConversationTable DinoDatabaseConversationTable;
typedef struct _DinoDatabaseConversationTableClass DinoDatabaseConversationTableClass;

#define DINO_DATABASE_TYPE_AVATAR_TABLE (dino_database_avatar_table_get_type ())
#define DINO_DATABASE_AVATAR_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_AVATAR_TABLE, DinoDatabaseAvatarTable))
#define DINO_DATABASE_AVATAR_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_AVATAR_TABLE, DinoDatabaseAvatarTableClass))
#define DINO_DATABASE_IS_AVATAR_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_AVATAR_TABLE))
#define DINO_DATABASE_IS_AVATAR_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_AVATAR_TABLE))
#define DINO_DATABASE_AVATAR_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_AVATAR_TABLE, DinoDatabaseAvatarTableClass))

typedef struct _DinoDatabaseAvatarTable DinoDatabaseAvatarTable;
typedef struct _DinoDatabaseAvatarTableClass DinoDatabaseAvatarTableClass;

#define DINO_DATABASE_TYPE_ENTITY_IDENTITY_TABLE (dino_database_entity_identity_table_get_type ())
#define DINO_DATABASE_ENTITY_IDENTITY_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_ENTITY_IDENTITY_TABLE, DinoDatabaseEntityIdentityTable))
#define DINO_DATABASE_ENTITY_IDENTITY_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_ENTITY_IDENTITY_TABLE, DinoDatabaseEntityIdentityTableClass))
#define DINO_DATABASE_IS_ENTITY_IDENTITY_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_ENTITY_IDENTITY_TABLE))
#define DINO_DATABASE_IS_ENTITY_IDENTITY_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_ENTITY_IDENTITY_TABLE))
#define DINO_DATABASE_ENTITY_IDENTITY_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_ENTITY_IDENTITY_TABLE, DinoDatabaseEntityIdentityTableClass))

typedef struct _DinoDatabaseEntityIdentityTable DinoDatabaseEntityIdentityTable;
typedef struct _DinoDatabaseEntityIdentityTableClass DinoDatabaseEntityIdentityTableClass;

#define DINO_DATABASE_TYPE_ENTITY_FEATURE_TABLE (dino_database_entity_feature_table_get_type ())
#define DINO_DATABASE_ENTITY_FEATURE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_ENTITY_FEATURE_TABLE, DinoDatabaseEntityFeatureTable))
#define DINO_DATABASE_ENTITY_FEATURE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_ENTITY_FEATURE_TABLE, DinoDatabaseEntityFeatureTableClass))
#define DINO_DATABASE_IS_ENTITY_FEATURE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_ENTITY_FEATURE_TABLE))
#define DINO_DATABASE_IS_ENTITY_FEATURE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_ENTITY_FEATURE_TABLE))
#define DINO_DATABASE_ENTITY_FEATURE_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_ENTITY_FEATURE_TABLE, DinoDatabaseEntityFeatureTableClass))

typedef struct _DinoDatabaseEntityFeatureTable DinoDatabaseEntityFeatureTable;
typedef struct _DinoDatabaseEntityFeatureTableClass DinoDatabaseEntityFeatureTableClass;

#define DINO_DATABASE_TYPE_ROSTER_TABLE (dino_database_roster_table_get_type ())
#define DINO_DATABASE_ROSTER_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_ROSTER_TABLE, DinoDatabaseRosterTable))
#define DINO_DATABASE_ROSTER_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_ROSTER_TABLE, DinoDatabaseRosterTableClass))
#define DINO_DATABASE_IS_ROSTER_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_ROSTER_TABLE))
#define DINO_DATABASE_IS_ROSTER_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_ROSTER_TABLE))
#define DINO_DATABASE_ROSTER_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_ROSTER_TABLE, DinoDatabaseRosterTableClass))

typedef struct _DinoDatabaseRosterTable DinoDatabaseRosterTable;
typedef struct _DinoDatabaseRosterTableClass DinoDatabaseRosterTableClass;

#define DINO_DATABASE_TYPE_MAM_CATCHUP_TABLE (dino_database_mam_catchup_table_get_type ())
#define DINO_DATABASE_MAM_CATCHUP_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_MAM_CATCHUP_TABLE, DinoDatabaseMamCatchupTable))
#define DINO_DATABASE_MAM_CATCHUP_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_MAM_CATCHUP_TABLE, DinoDatabaseMamCatchupTableClass))
#define DINO_DATABASE_IS_MAM_CATCHUP_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_MAM_CATCHUP_TABLE))
#define DINO_DATABASE_IS_MAM_CATCHUP_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_MAM_CATCHUP_TABLE))
#define DINO_DATABASE_MAM_CATCHUP_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_MAM_CATCHUP_TABLE, DinoDatabaseMamCatchupTableClass))

typedef struct _DinoDatabaseMamCatchupTable DinoDatabaseMamCatchupTable;
typedef struct _DinoDatabaseMamCatchupTableClass DinoDatabaseMamCatchupTableClass;

#define DINO_DATABASE_TYPE_REACTION_TABLE (dino_database_reaction_table_get_type ())
#define DINO_DATABASE_REACTION_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_REACTION_TABLE, DinoDatabaseReactionTable))
#define DINO_DATABASE_REACTION_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_REACTION_TABLE, DinoDatabaseReactionTableClass))
#define DINO_DATABASE_IS_REACTION_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_REACTION_TABLE))
#define DINO_DATABASE_IS_REACTION_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_REACTION_TABLE))
#define DINO_DATABASE_REACTION_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_REACTION_TABLE, DinoDatabaseReactionTableClass))

typedef struct _DinoDatabaseReactionTable DinoDatabaseReactionTable;
typedef struct _DinoDatabaseReactionTableClass DinoDatabaseReactionTableClass;

#define DINO_DATABASE_TYPE_SETTINGS_TABLE (dino_database_settings_table_get_type ())
#define DINO_DATABASE_SETTINGS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_SETTINGS_TABLE, DinoDatabaseSettingsTable))
#define DINO_DATABASE_SETTINGS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_SETTINGS_TABLE, DinoDatabaseSettingsTableClass))
#define DINO_DATABASE_IS_SETTINGS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_SETTINGS_TABLE))
#define DINO_DATABASE_IS_SETTINGS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_SETTINGS_TABLE))
#define DINO_DATABASE_SETTINGS_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_SETTINGS_TABLE, DinoDatabaseSettingsTableClass))

typedef struct _DinoDatabaseSettingsTable DinoDatabaseSettingsTable;
typedef struct _DinoDatabaseSettingsTableClass DinoDatabaseSettingsTableClass;

#define DINO_DATABASE_TYPE_ACCOUNT_SETTINGS_TABLE (dino_database_account_settings_table_get_type ())
#define DINO_DATABASE_ACCOUNT_SETTINGS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_ACCOUNT_SETTINGS_TABLE, DinoDatabaseAccountSettingsTable))
#define DINO_DATABASE_ACCOUNT_SETTINGS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_ACCOUNT_SETTINGS_TABLE, DinoDatabaseAccountSettingsTableClass))
#define DINO_DATABASE_IS_ACCOUNT_SETTINGS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_ACCOUNT_SETTINGS_TABLE))
#define DINO_DATABASE_IS_ACCOUNT_SETTINGS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_ACCOUNT_SETTINGS_TABLE))
#define DINO_DATABASE_ACCOUNT_SETTINGS_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_ACCOUNT_SETTINGS_TABLE, DinoDatabaseAccountSettingsTableClass))

typedef struct _DinoDatabaseAccountSettingsTable DinoDatabaseAccountSettingsTable;
typedef struct _DinoDatabaseAccountSettingsTableClass DinoDatabaseAccountSettingsTableClass;

#define DINO_DATABASE_TYPE_CONVERSATION_SETTINGS_TABLE (dino_database_conversation_settings_table_get_type ())
#define DINO_DATABASE_CONVERSATION_SETTINGS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_CONVERSATION_SETTINGS_TABLE, DinoDatabaseConversationSettingsTable))
#define DINO_DATABASE_CONVERSATION_SETTINGS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_CONVERSATION_SETTINGS_TABLE, DinoDatabaseConversationSettingsTableClass))
#define DINO_DATABASE_IS_CONVERSATION_SETTINGS_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_CONVERSATION_SETTINGS_TABLE))
#define DINO_DATABASE_IS_CONVERSATION_SETTINGS_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_CONVERSATION_SETTINGS_TABLE))
#define DINO_DATABASE_CONVERSATION_SETTINGS_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_CONVERSATION_SETTINGS_TABLE, DinoDatabaseConversationSettingsTableClass))

typedef struct _DinoDatabaseConversationSettingsTable DinoDatabaseConversationSettingsTable;
typedef struct _DinoDatabaseConversationSettingsTableClass DinoDatabaseConversationSettingsTableClass;
typedef struct _DinoDatabaseAccountTablePrivate DinoDatabaseAccountTablePrivate;
typedef struct _DinoDatabaseJidTablePrivate DinoDatabaseJidTablePrivate;
typedef struct _DinoDatabaseEntityTablePrivate DinoDatabaseEntityTablePrivate;
typedef struct _DinoDatabaseContentItemTablePrivate DinoDatabaseContentItemTablePrivate;
typedef struct _DinoDatabaseMessageTablePrivate DinoDatabaseMessageTablePrivate;
typedef struct _DinoDatabaseBodyMetaPrivate DinoDatabaseBodyMetaPrivate;
typedef struct _DinoDatabaseMessageCorrectionTablePrivate DinoDatabaseMessageCorrectionTablePrivate;
typedef struct _DinoDatabaseReplyTablePrivate DinoDatabaseReplyTablePrivate;
typedef struct _DinoDatabaseRealJidTablePrivate DinoDatabaseRealJidTablePrivate;
typedef struct _DinoDatabaseOccupantIdTablePrivate DinoDatabaseOccupantIdTablePrivate;

#define DINO_DATABASE_TYPE_UNDECRYPTED_TABLE (dino_database_undecrypted_table_get_type ())
#define DINO_DATABASE_UNDECRYPTED_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_DATABASE_TYPE_UNDECRYPTED_TABLE, DinoDatabaseUndecryptedTable))
#define DINO_DATABASE_UNDECRYPTED_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_DATABASE_TYPE_UNDECRYPTED_TABLE, DinoDatabaseUndecryptedTableClass))
#define DINO_DATABASE_IS_UNDECRYPTED_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_DATABASE_TYPE_UNDECRYPTED_TABLE))
#define DINO_DATABASE_IS_UNDECRYPTED_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_DATABASE_TYPE_UNDECRYPTED_TABLE))
#define DINO_DATABASE_UNDECRYPTED_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_DATABASE_TYPE_UNDECRYPTED_TABLE, DinoDatabaseUndecryptedTableClass))

typedef struct _DinoDatabaseUndecryptedTable DinoDatabaseUndecryptedTable;
typedef struct _DinoDatabaseUndecryptedTableClass DinoDatabaseUndecryptedTableClass;
typedef struct _DinoDatabaseUndecryptedTablePrivate DinoDatabaseUndecryptedTablePrivate;
typedef struct _DinoDatabaseFileTransferTablePrivate DinoDatabaseFileTransferTablePrivate;
typedef struct _DinoDatabaseFileHashesTablePrivate DinoDatabaseFileHashesTablePrivate;
typedef struct _DinoDatabaseFileThumbnailsTablePrivate DinoDatabaseFileThumbnailsTablePrivate;
typedef struct _DinoDatabaseSourcesTablePrivate DinoDatabaseSourcesTablePrivate;
typedef struct _DinoDatabaseCallTablePrivate DinoDatabaseCallTablePrivate;
typedef struct _DinoDatabaseCallCounterpartTablePrivate DinoDatabaseCallCounterpartTablePrivate;
typedef struct _DinoDatabaseConversationTablePrivate DinoDatabaseConversationTablePrivate;
typedef struct _DinoDatabaseAvatarTablePrivate DinoDatabaseAvatarTablePrivate;
typedef struct _DinoDatabaseEntityIdentityTablePrivate DinoDatabaseEntityIdentityTablePrivate;
typedef struct _DinoDatabaseEntityFeatureTablePrivate DinoDatabaseEntityFeatureTablePrivate;
typedef struct _DinoDatabaseRosterTablePrivate DinoDatabaseRosterTablePrivate;
typedef struct _DinoDatabaseMamCatchupTablePrivate DinoDatabaseMamCatchupTablePrivate;
typedef struct _DinoDatabaseReactionTablePrivate DinoDatabaseReactionTablePrivate;
typedef struct _DinoDatabaseSettingsTablePrivate DinoDatabaseSettingsTablePrivate;
typedef struct _DinoDatabaseAccountSettingsTablePrivate DinoDatabaseAccountSettingsTablePrivate;
typedef struct _DinoDatabaseConversationSettingsTablePrivate DinoDatabaseConversationSettingsTablePrivate;

#define DINO_TYPE_ENTITY_CAPABILITIES_STORAGE (dino_entity_capabilities_storage_get_type ())
#define DINO_ENTITY_CAPABILITIES_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_ENTITY_CAPABILITIES_STORAGE, DinoEntityCapabilitiesStorage))
#define DINO_ENTITY_CAPABILITIES_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_ENTITY_CAPABILITIES_STORAGE, DinoEntityCapabilitiesStorageClass))
#define DINO_IS_ENTITY_CAPABILITIES_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_ENTITY_CAPABILITIES_STORAGE))
#define DINO_IS_ENTITY_CAPABILITIES_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_ENTITY_CAPABILITIES_STORAGE))
#define DINO_ENTITY_CAPABILITIES_STORAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_ENTITY_CAPABILITIES_STORAGE, DinoEntityCapabilitiesStorageClass))

typedef struct _DinoEntityCapabilitiesStorage DinoEntityCapabilitiesStorage;
typedef struct _DinoEntityCapabilitiesStorageClass DinoEntityCapabilitiesStorageClass;
typedef struct _DinoEntityCapabilitiesStoragePrivate DinoEntityCapabilitiesStoragePrivate;

#define DINO_TYPE_ENTITY_INFO (dino_entity_info_get_type ())
#define DINO_ENTITY_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_ENTITY_INFO, DinoEntityInfo))
#define DINO_ENTITY_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_ENTITY_INFO, DinoEntityInfoClass))
#define DINO_IS_ENTITY_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_ENTITY_INFO))
#define DINO_IS_ENTITY_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_ENTITY_INFO))
#define DINO_ENTITY_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_ENTITY_INFO, DinoEntityInfoClass))

typedef struct _DinoEntityInfo DinoEntityInfo;
typedef struct _DinoEntityInfoClass DinoEntityInfoClass;
typedef struct _DinoEntityInfoPrivate DinoEntityInfoPrivate;

#define DINO_TYPE_CAPS_CACHE_IMPL (dino_caps_cache_impl_get_type ())
#define DINO_CAPS_CACHE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_CAPS_CACHE_IMPL, DinoCapsCacheImpl))
#define DINO_CAPS_CACHE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_CAPS_CACHE_IMPL, DinoCapsCacheImplClass))
#define DINO_IS_CAPS_CACHE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_CAPS_CACHE_IMPL))
#define DINO_IS_CAPS_CACHE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_CAPS_CACHE_IMPL))
#define DINO_CAPS_CACHE_IMPL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_CAPS_CACHE_IMPL, DinoCapsCacheImplClass))

typedef struct _DinoCapsCacheImpl DinoCapsCacheImpl;
typedef struct _DinoCapsCacheImplClass DinoCapsCacheImplClass;
typedef struct _DinoCapsCacheImplPrivate DinoCapsCacheImplPrivate;

#define DINO_TYPE_FALLBACK_BODY (dino_fallback_body_get_type ())
#define DINO_FALLBACK_BODY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FALLBACK_BODY, DinoFallbackBody))
#define DINO_FALLBACK_BODY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_FALLBACK_BODY, DinoFallbackBodyClass))
#define DINO_IS_FALLBACK_BODY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FALLBACK_BODY))
#define DINO_IS_FALLBACK_BODY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_FALLBACK_BODY))
#define DINO_FALLBACK_BODY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_FALLBACK_BODY, DinoFallbackBodyClass))

typedef struct _DinoFallbackBody DinoFallbackBody;
typedef struct _DinoFallbackBodyClass DinoFallbackBodyClass;
typedef struct _DinoFallbackBodyPrivate DinoFallbackBodyPrivate;

#define DINO_TYPE_FILE_MANAGER (dino_file_manager_get_type ())
#define DINO_FILE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_MANAGER, DinoFileManager))
#define DINO_FILE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_FILE_MANAGER, DinoFileManagerClass))
#define DINO_IS_FILE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_MANAGER))
#define DINO_IS_FILE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_FILE_MANAGER))
#define DINO_FILE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_FILE_MANAGER, DinoFileManagerClass))

typedef struct _DinoFileManager DinoFileManager;
typedef struct _DinoFileManagerClass DinoFileManagerClass;
typedef struct _DinoFileManagerPrivate DinoFileManagerPrivate;

#define DINO_TYPE_FILE_PROVIDER (dino_file_provider_get_type ())
#define DINO_FILE_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_PROVIDER, DinoFileProvider))
#define DINO_IS_FILE_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_PROVIDER))
#define DINO_FILE_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_FILE_PROVIDER, DinoFileProviderIface))

typedef struct _DinoFileProvider DinoFileProvider;
typedef struct _DinoFileProviderIface DinoFileProviderIface;

#define DINO_TYPE_FILE_RECEIVE_DATA (dino_file_receive_data_get_type ())
#define DINO_FILE_RECEIVE_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_RECEIVE_DATA, DinoFileReceiveData))
#define DINO_FILE_RECEIVE_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_FILE_RECEIVE_DATA, DinoFileReceiveDataClass))
#define DINO_IS_FILE_RECEIVE_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_RECEIVE_DATA))
#define DINO_IS_FILE_RECEIVE_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_FILE_RECEIVE_DATA))
#define DINO_FILE_RECEIVE_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_FILE_RECEIVE_DATA, DinoFileReceiveDataClass))

typedef struct _DinoFileReceiveData DinoFileReceiveData;
typedef struct _DinoFileReceiveDataClass DinoFileReceiveDataClass;

#define DINO_TYPE_FILE_META (dino_file_meta_get_type ())
#define DINO_FILE_META(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_META, DinoFileMeta))
#define DINO_FILE_META_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_FILE_META, DinoFileMetaClass))
#define DINO_IS_FILE_META(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_META))
#define DINO_IS_FILE_META_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_FILE_META))
#define DINO_FILE_META_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_FILE_META, DinoFileMetaClass))

typedef struct _DinoFileMeta DinoFileMeta;
typedef struct _DinoFileMetaClass DinoFileMetaClass;

#define DINO_TYPE_FILE_RECEIVE_ERROR (dino_file_receive_error_get_type ())

#define DINO_TYPE_FILE_SENDER (dino_file_sender_get_type ())
#define DINO_FILE_SENDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_SENDER, DinoFileSender))
#define DINO_IS_FILE_SENDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_SENDER))
#define DINO_FILE_SENDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_FILE_SENDER, DinoFileSenderIface))

typedef struct _DinoFileSender DinoFileSender;
typedef struct _DinoFileSenderIface DinoFileSenderIface;

#define DINO_TYPE_FILE_SEND_DATA (dino_file_send_data_get_type ())
#define DINO_FILE_SEND_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_SEND_DATA, DinoFileSendData))
#define DINO_FILE_SEND_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_FILE_SEND_DATA, DinoFileSendDataClass))
#define DINO_IS_FILE_SEND_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_SEND_DATA))
#define DINO_IS_FILE_SEND_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_FILE_SEND_DATA))
#define DINO_FILE_SEND_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_FILE_SEND_DATA, DinoFileSendDataClass))

typedef struct _DinoFileSendData DinoFileSendData;
typedef struct _DinoFileSendDataClass DinoFileSendDataClass;

#define DINO_TYPE_FILE_SEND_ERROR (dino_file_send_error_get_type ())

#define DINO_TYPE_FILE_ENCRYPTOR (dino_file_encryptor_get_type ())
#define DINO_FILE_ENCRYPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_ENCRYPTOR, DinoFileEncryptor))
#define DINO_IS_FILE_ENCRYPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_ENCRYPTOR))
#define DINO_FILE_ENCRYPTOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_FILE_ENCRYPTOR, DinoFileEncryptorIface))

typedef struct _DinoFileEncryptor DinoFileEncryptor;
typedef struct _DinoFileEncryptorIface DinoFileEncryptorIface;

#define DINO_TYPE_FILE_DECRYPTOR (dino_file_decryptor_get_type ())
#define DINO_FILE_DECRYPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_DECRYPTOR, DinoFileDecryptor))
#define DINO_IS_FILE_DECRYPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_DECRYPTOR))
#define DINO_FILE_DECRYPTOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_FILE_DECRYPTOR, DinoFileDecryptorIface))

typedef struct _DinoFileDecryptor DinoFileDecryptor;
typedef struct _DinoFileDecryptorIface DinoFileDecryptorIface;

#define DINO_TYPE_FILE_METADATA_PROVIDER (dino_file_metadata_provider_get_type ())
#define DINO_FILE_METADATA_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_METADATA_PROVIDER, DinoFileMetadataProvider))
#define DINO_IS_FILE_METADATA_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_METADATA_PROVIDER))
#define DINO_FILE_METADATA_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_FILE_METADATA_PROVIDER, DinoFileMetadataProviderIface))

typedef struct _DinoFileMetadataProvider DinoFileMetadataProvider;
typedef struct _DinoFileMetadataProviderIface DinoFileMetadataProviderIface;

#define DINO_TYPE_STATELESS_FILE_SHARING (dino_stateless_file_sharing_get_type ())
#define DINO_STATELESS_FILE_SHARING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_STATELESS_FILE_SHARING, DinoStatelessFileSharing))
#define DINO_STATELESS_FILE_SHARING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_STATELESS_FILE_SHARING, DinoStatelessFileSharingClass))
#define DINO_IS_STATELESS_FILE_SHARING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_STATELESS_FILE_SHARING))
#define DINO_IS_STATELESS_FILE_SHARING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_STATELESS_FILE_SHARING))
#define DINO_STATELESS_FILE_SHARING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_STATELESS_FILE_SHARING, DinoStatelessFileSharingClass))

typedef struct _DinoStatelessFileSharing DinoStatelessFileSharing;
typedef struct _DinoStatelessFileSharingClass DinoStatelessFileSharingClass;
typedef struct _DinoFileMetaPrivate DinoFileMetaPrivate;

#define DINO_TYPE_HTTP_FILE_META (dino_http_file_meta_get_type ())
#define DINO_HTTP_FILE_META(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_HTTP_FILE_META, DinoHttpFileMeta))
#define DINO_HTTP_FILE_META_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_HTTP_FILE_META, DinoHttpFileMetaClass))
#define DINO_IS_HTTP_FILE_META(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_HTTP_FILE_META))
#define DINO_IS_HTTP_FILE_META_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_HTTP_FILE_META))
#define DINO_HTTP_FILE_META_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_HTTP_FILE_META, DinoHttpFileMetaClass))

typedef struct _DinoHttpFileMeta DinoHttpFileMeta;
typedef struct _DinoHttpFileMetaClass DinoHttpFileMetaClass;
typedef struct _DinoHttpFileMetaPrivate DinoHttpFileMetaPrivate;
typedef struct _DinoFileSendDataPrivate DinoFileSendDataPrivate;

#define DINO_TYPE_HTTP_FILE_SEND_DATA (dino_http_file_send_data_get_type ())
#define DINO_HTTP_FILE_SEND_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_HTTP_FILE_SEND_DATA, DinoHttpFileSendData))
#define DINO_HTTP_FILE_SEND_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_HTTP_FILE_SEND_DATA, DinoHttpFileSendDataClass))
#define DINO_IS_HTTP_FILE_SEND_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_HTTP_FILE_SEND_DATA))
#define DINO_IS_HTTP_FILE_SEND_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_HTTP_FILE_SEND_DATA))
#define DINO_HTTP_FILE_SEND_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_HTTP_FILE_SEND_DATA, DinoHttpFileSendDataClass))

typedef struct _DinoHttpFileSendData DinoHttpFileSendData;
typedef struct _DinoHttpFileSendDataClass DinoHttpFileSendDataClass;
typedef struct _DinoHttpFileSendDataPrivate DinoHttpFileSendDataPrivate;
typedef struct _DinoFileReceiveDataPrivate DinoFileReceiveDataPrivate;

#define DINO_TYPE_HTTP_FILE_RECEIVE_DATA (dino_http_file_receive_data_get_type ())
#define DINO_HTTP_FILE_RECEIVE_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_HTTP_FILE_RECEIVE_DATA, DinoHttpFileReceiveData))
#define DINO_HTTP_FILE_RECEIVE_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_HTTP_FILE_RECEIVE_DATA, DinoHttpFileReceiveDataClass))
#define DINO_IS_HTTP_FILE_RECEIVE_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_HTTP_FILE_RECEIVE_DATA))
#define DINO_IS_HTTP_FILE_RECEIVE_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_HTTP_FILE_RECEIVE_DATA))
#define DINO_HTTP_FILE_RECEIVE_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_HTTP_FILE_RECEIVE_DATA, DinoHttpFileReceiveDataClass))

typedef struct _DinoHttpFileReceiveData DinoHttpFileReceiveData;
typedef struct _DinoHttpFileReceiveDataClass DinoHttpFileReceiveDataClass;
typedef struct _DinoHttpFileReceiveDataPrivate DinoHttpFileReceiveDataPrivate;

#define DINO_TYPE_FILE_TRANSFER_STORAGE (dino_file_transfer_storage_get_type ())
#define DINO_FILE_TRANSFER_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_FILE_TRANSFER_STORAGE, DinoFileTransferStorage))
#define DINO_FILE_TRANSFER_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_FILE_TRANSFER_STORAGE, DinoFileTransferStorageClass))
#define DINO_IS_FILE_TRANSFER_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_FILE_TRANSFER_STORAGE))
#define DINO_IS_FILE_TRANSFER_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_FILE_TRANSFER_STORAGE))
#define DINO_FILE_TRANSFER_STORAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_FILE_TRANSFER_STORAGE, DinoFileTransferStorageClass))

typedef struct _DinoFileTransferStorage DinoFileTransferStorage;
typedef struct _DinoFileTransferStorageClass DinoFileTransferStorageClass;
typedef struct _DinoFileTransferStoragePrivate DinoFileTransferStoragePrivate;

#define DINO_TYPE_HISTORY_SYNC (dino_history_sync_get_type ())
#define DINO_HISTORY_SYNC(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_HISTORY_SYNC, DinoHistorySync))
#define DINO_HISTORY_SYNC_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_HISTORY_SYNC, DinoHistorySyncClass))
#define DINO_IS_HISTORY_SYNC(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_HISTORY_SYNC))
#define DINO_IS_HISTORY_SYNC_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_HISTORY_SYNC))
#define DINO_HISTORY_SYNC_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_HISTORY_SYNC, DinoHistorySyncClass))

typedef struct _DinoHistorySync DinoHistorySync;
typedef struct _DinoHistorySyncClass DinoHistorySyncClass;
typedef struct _DinoHistorySyncPrivate DinoHistorySyncPrivate;

#define TYPE_WEAK_MAP (weak_map_get_type ())
#define WEAK_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WEAK_MAP, WeakMap))
#define WEAK_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_WEAK_MAP, WeakMapClass))
#define IS_WEAK_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WEAK_MAP))
#define IS_WEAK_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_WEAK_MAP))
#define WEAK_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_WEAK_MAP, WeakMapClass))

typedef struct _WeakMap WeakMap;
typedef struct _WeakMapClass WeakMapClass;

#define DINO_TYPE_JINGLE_FILE_ENCRYPTION_HELPER (dino_jingle_file_encryption_helper_get_type ())
#define DINO_JINGLE_FILE_ENCRYPTION_HELPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_JINGLE_FILE_ENCRYPTION_HELPER, DinoJingleFileEncryptionHelper))
#define DINO_IS_JINGLE_FILE_ENCRYPTION_HELPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_JINGLE_FILE_ENCRYPTION_HELPER))
#define DINO_JINGLE_FILE_ENCRYPTION_HELPER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_JINGLE_FILE_ENCRYPTION_HELPER, DinoJingleFileEncryptionHelperIface))

typedef struct _DinoJingleFileEncryptionHelper DinoJingleFileEncryptionHelper;
typedef struct _DinoJingleFileEncryptionHelperIface DinoJingleFileEncryptionHelperIface;

#define DINO_TYPE_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY (dino_jingle_file_encryption_helper_transfer_only_get_type ())
#define DINO_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY, DinoJingleFileEncryptionHelperTransferOnly))
#define DINO_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY, DinoJingleFileEncryptionHelperTransferOnlyClass))
#define DINO_IS_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY))
#define DINO_IS_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY))
#define DINO_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_JINGLE_FILE_ENCRYPTION_HELPER_TRANSFER_ONLY, DinoJingleFileEncryptionHelperTransferOnlyClass))

typedef struct _DinoJingleFileEncryptionHelperTransferOnly DinoJingleFileEncryptionHelperTransferOnly;
typedef struct _DinoJingleFileEncryptionHelperTransferOnlyClass DinoJingleFileEncryptionHelperTransferOnlyClass;
typedef struct _DinoJingleFileEncryptionHelperTransferOnlyPrivate DinoJingleFileEncryptionHelperTransferOnlyPrivate;

#define DINO_TYPE_JINGLE_FILE_HELPER_REGISTRY (dino_jingle_file_helper_registry_get_type ())
#define DINO_JINGLE_FILE_HELPER_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_JINGLE_FILE_HELPER_REGISTRY, DinoJingleFileHelperRegistry))
#define DINO_JINGLE_FILE_HELPER_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_JINGLE_FILE_HELPER_REGISTRY, DinoJingleFileHelperRegistryClass))
#define DINO_IS_JINGLE_FILE_HELPER_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_JINGLE_FILE_HELPER_REGISTRY))
#define DINO_IS_JINGLE_FILE_HELPER_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_JINGLE_FILE_HELPER_REGISTRY))
#define DINO_JINGLE_FILE_HELPER_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_JINGLE_FILE_HELPER_REGISTRY, DinoJingleFileHelperRegistryClass))

typedef struct _DinoJingleFileHelperRegistry DinoJingleFileHelperRegistry;
typedef struct _DinoJingleFileHelperRegistryClass DinoJingleFileHelperRegistryClass;
typedef struct _DinoJingleFileHelperRegistryPrivate DinoJingleFileHelperRegistryPrivate;

#define DINO_TYPE_JINGLE_FILE_PROVIDER (dino_jingle_file_provider_get_type ())
#define DINO_JINGLE_FILE_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_JINGLE_FILE_PROVIDER, DinoJingleFileProvider))
#define DINO_JINGLE_FILE_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_JINGLE_FILE_PROVIDER, DinoJingleFileProviderClass))
#define DINO_IS_JINGLE_FILE_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_JINGLE_FILE_PROVIDER))
#define DINO_IS_JINGLE_FILE_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_JINGLE_FILE_PROVIDER))
#define DINO_JINGLE_FILE_PROVIDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_JINGLE_FILE_PROVIDER, DinoJingleFileProviderClass))

typedef struct _DinoJingleFileProvider DinoJingleFileProvider;
typedef struct _DinoJingleFileProviderClass DinoJingleFileProviderClass;
typedef struct _DinoJingleFileProviderPrivate DinoJingleFileProviderPrivate;

#define DINO_TYPE_JINGLE_FILE_SENDER (dino_jingle_file_sender_get_type ())
#define DINO_JINGLE_FILE_SENDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_JINGLE_FILE_SENDER, DinoJingleFileSender))
#define DINO_JINGLE_FILE_SENDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_JINGLE_FILE_SENDER, DinoJingleFileSenderClass))
#define DINO_IS_JINGLE_FILE_SENDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_JINGLE_FILE_SENDER))
#define DINO_IS_JINGLE_FILE_SENDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_JINGLE_FILE_SENDER))
#define DINO_JINGLE_FILE_SENDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_JINGLE_FILE_SENDER, DinoJingleFileSenderClass))

typedef struct _DinoJingleFileSender DinoJingleFileSender;
typedef struct _DinoJingleFileSenderClass DinoJingleFileSenderClass;
typedef struct _DinoJingleFileSenderPrivate DinoJingleFileSenderPrivate;

#define DINO_TYPE_MESSAGE_LISTENER (dino_message_listener_get_type ())
#define DINO_MESSAGE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_MESSAGE_LISTENER, DinoMessageListener))
#define DINO_MESSAGE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_MESSAGE_LISTENER, DinoMessageListenerClass))
#define DINO_IS_MESSAGE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_MESSAGE_LISTENER))
#define DINO_IS_MESSAGE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_MESSAGE_LISTENER))
#define DINO_MESSAGE_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_MESSAGE_LISTENER, DinoMessageListenerClass))

typedef struct _DinoMessageListener DinoMessageListener;
typedef struct _DinoMessageListenerClass DinoMessageListenerClass;
typedef struct _DinoMessageListenerPrivate DinoMessageListenerPrivate;

#define DINO_TYPE_MESSAGE_CORRECTION (dino_message_correction_get_type ())
#define DINO_MESSAGE_CORRECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_MESSAGE_CORRECTION, DinoMessageCorrection))
#define DINO_MESSAGE_CORRECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_MESSAGE_CORRECTION, DinoMessageCorrectionClass))
#define DINO_IS_MESSAGE_CORRECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_MESSAGE_CORRECTION))
#define DINO_IS_MESSAGE_CORRECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_MESSAGE_CORRECTION))
#define DINO_MESSAGE_CORRECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_MESSAGE_CORRECTION, DinoMessageCorrectionClass))

typedef struct _DinoMessageCorrection DinoMessageCorrection;
typedef struct _DinoMessageCorrectionClass DinoMessageCorrectionClass;
typedef struct _DinoMessageCorrectionPrivate DinoMessageCorrectionPrivate;

#define DINO_TYPE_MESSAGE_PROCESSOR (dino_message_processor_get_type ())
#define DINO_MESSAGE_PROCESSOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_MESSAGE_PROCESSOR, DinoMessageProcessor))
#define DINO_MESSAGE_PROCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_MESSAGE_PROCESSOR, DinoMessageProcessorClass))
#define DINO_IS_MESSAGE_PROCESSOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_MESSAGE_PROCESSOR))
#define DINO_IS_MESSAGE_PROCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_MESSAGE_PROCESSOR))
#define DINO_MESSAGE_PROCESSOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_MESSAGE_PROCESSOR, DinoMessageProcessorClass))

typedef struct _DinoMessageProcessor DinoMessageProcessor;
typedef struct _DinoMessageProcessorClass DinoMessageProcessorClass;
typedef struct _DinoMessageProcessorPrivate DinoMessageProcessorPrivate;

#define DINO_TYPE_MESSAGE_LISTENER_HOLDER (dino_message_listener_holder_get_type ())
#define DINO_MESSAGE_LISTENER_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_MESSAGE_LISTENER_HOLDER, DinoMessageListenerHolder))
#define DINO_MESSAGE_LISTENER_HOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_MESSAGE_LISTENER_HOLDER, DinoMessageListenerHolderClass))
#define DINO_IS_MESSAGE_LISTENER_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_MESSAGE_LISTENER_HOLDER))
#define DINO_IS_MESSAGE_LISTENER_HOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_MESSAGE_LISTENER_HOLDER))
#define DINO_MESSAGE_LISTENER_HOLDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_MESSAGE_LISTENER_HOLDER, DinoMessageListenerHolderClass))

typedef struct _DinoMessageListenerHolder DinoMessageListenerHolder;
typedef struct _DinoMessageListenerHolderClass DinoMessageListenerHolderClass;
typedef struct _DinoMessageListenerHolderPrivate DinoMessageListenerHolderPrivate;

#define DINO_TYPE_MESSAGE_STORAGE (dino_message_storage_get_type ())
#define DINO_MESSAGE_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_MESSAGE_STORAGE, DinoMessageStorage))
#define DINO_MESSAGE_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_MESSAGE_STORAGE, DinoMessageStorageClass))
#define DINO_IS_MESSAGE_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_MESSAGE_STORAGE))
#define DINO_IS_MESSAGE_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_MESSAGE_STORAGE))
#define DINO_MESSAGE_STORAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_MESSAGE_STORAGE, DinoMessageStorageClass))

typedef struct _DinoMessageStorage DinoMessageStorage;
typedef struct _DinoMessageStorageClass DinoMessageStorageClass;
typedef struct _DinoMessageStoragePrivate DinoMessageStoragePrivate;
typedef struct _DinoModuleManagerPrivate DinoModuleManagerPrivate;

#define DINO_TYPE_MUC_MANAGER (dino_muc_manager_get_type ())
#define DINO_MUC_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_MUC_MANAGER, DinoMucManager))
#define DINO_MUC_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_MUC_MANAGER, DinoMucManagerClass))
#define DINO_IS_MUC_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_MUC_MANAGER))
#define DINO_IS_MUC_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_MUC_MANAGER))
#define DINO_MUC_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_MUC_MANAGER, DinoMucManagerClass))

typedef struct _DinoMucManager DinoMucManager;
typedef struct _DinoMucManagerClass DinoMucManagerClass;
typedef struct _DinoMucManagerPrivate DinoMucManagerPrivate;

#define DINO_TYPE_NOTIFICATION_EVENTS (dino_notification_events_get_type ())
#define DINO_NOTIFICATION_EVENTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_NOTIFICATION_EVENTS, DinoNotificationEvents))
#define DINO_NOTIFICATION_EVENTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_NOTIFICATION_EVENTS, DinoNotificationEventsClass))
#define DINO_IS_NOTIFICATION_EVENTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_NOTIFICATION_EVENTS))
#define DINO_IS_NOTIFICATION_EVENTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_NOTIFICATION_EVENTS))
#define DINO_NOTIFICATION_EVENTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_NOTIFICATION_EVENTS, DinoNotificationEventsClass))

typedef struct _DinoNotificationEvents DinoNotificationEvents;
typedef struct _DinoNotificationEventsClass DinoNotificationEventsClass;
typedef struct _DinoNotificationEventsPrivate DinoNotificationEventsPrivate;

#define DINO_TYPE_NOTIFICATION_PROVIDER (dino_notification_provider_get_type ())
#define DINO_NOTIFICATION_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_NOTIFICATION_PROVIDER, DinoNotificationProvider))
#define DINO_IS_NOTIFICATION_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_NOTIFICATION_PROVIDER))
#define DINO_NOTIFICATION_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DINO_TYPE_NOTIFICATION_PROVIDER, DinoNotificationProviderIface))

typedef struct _DinoNotificationProvider DinoNotificationProvider;
typedef struct _DinoNotificationProviderIface DinoNotificationProviderIface;

#define DINO_TYPE_PRESENCE_MANAGER (dino_presence_manager_get_type ())
#define DINO_PRESENCE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_PRESENCE_MANAGER, DinoPresenceManager))
#define DINO_PRESENCE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_PRESENCE_MANAGER, DinoPresenceManagerClass))
#define DINO_IS_PRESENCE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_PRESENCE_MANAGER))
#define DINO_IS_PRESENCE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_PRESENCE_MANAGER))
#define DINO_PRESENCE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_PRESENCE_MANAGER, DinoPresenceManagerClass))

typedef struct _DinoPresenceManager DinoPresenceManager;
typedef struct _DinoPresenceManagerClass DinoPresenceManagerClass;
typedef struct _DinoPresenceManagerPrivate DinoPresenceManagerPrivate;

#define DINO_TYPE_REPLIES (dino_replies_get_type ())
#define DINO_REPLIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_REPLIES, DinoReplies))
#define DINO_REPLIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_REPLIES, DinoRepliesClass))
#define DINO_IS_REPLIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_REPLIES))
#define DINO_IS_REPLIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_REPLIES))
#define DINO_REPLIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_REPLIES, DinoRepliesClass))

typedef struct _DinoReplies DinoReplies;
typedef struct _DinoRepliesClass DinoRepliesClass;
typedef struct _DinoRepliesPrivate DinoRepliesPrivate;

#define DINO_TYPE_REACTIONS (dino_reactions_get_type ())
#define DINO_REACTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_REACTIONS, DinoReactions))
#define DINO_REACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_REACTIONS, DinoReactionsClass))
#define DINO_IS_REACTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_REACTIONS))
#define DINO_IS_REACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_REACTIONS))
#define DINO_REACTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_REACTIONS, DinoReactionsClass))

typedef struct _DinoReactions DinoReactions;
typedef struct _DinoReactionsClass DinoReactionsClass;
typedef struct _DinoReactionsPrivate DinoReactionsPrivate;

#define DINO_TYPE_REACTION_USERS (dino_reaction_users_get_type ())
#define DINO_REACTION_USERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_REACTION_USERS, DinoReactionUsers))
#define DINO_REACTION_USERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_REACTION_USERS, DinoReactionUsersClass))
#define DINO_IS_REACTION_USERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_REACTION_USERS))
#define DINO_IS_REACTION_USERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_REACTION_USERS))
#define DINO_REACTION_USERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_REACTION_USERS, DinoReactionUsersClass))

typedef struct _DinoReactionUsers DinoReactionUsers;
typedef struct _DinoReactionUsersClass DinoReactionUsersClass;
typedef struct _DinoReactionUsersPrivate DinoReactionUsersPrivate;

#define DINO_TYPE_REACTION_INFO (dino_reaction_info_get_type ())
#define DINO_REACTION_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_REACTION_INFO, DinoReactionInfo))
#define DINO_REACTION_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_REACTION_INFO, DinoReactionInfoClass))
#define DINO_IS_REACTION_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_REACTION_INFO))
#define DINO_IS_REACTION_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_REACTION_INFO))
#define DINO_REACTION_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_REACTION_INFO, DinoReactionInfoClass))

typedef struct _DinoReactionInfo DinoReactionInfo;
typedef struct _DinoReactionInfoClass DinoReactionInfoClass;
typedef struct _DinoReactionInfoPrivate DinoReactionInfoPrivate;

#define DINO_TYPE_REGISTER (dino_register_get_type ())
#define DINO_REGISTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_REGISTER, DinoRegister))
#define DINO_REGISTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_REGISTER, DinoRegisterClass))
#define DINO_IS_REGISTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_REGISTER))
#define DINO_IS_REGISTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_REGISTER))
#define DINO_REGISTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_REGISTER, DinoRegisterClass))

typedef struct _DinoRegister DinoRegister;
typedef struct _DinoRegisterClass DinoRegisterClass;
typedef struct _DinoRegisterPrivate DinoRegisterPrivate;

#define DINO_REGISTER_TYPE_SERVER_AVAILABILITY_RETURN (dino_register_server_availability_return_get_type ())
#define DINO_REGISTER_SERVER_AVAILABILITY_RETURN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_REGISTER_TYPE_SERVER_AVAILABILITY_RETURN, DinoRegisterServerAvailabilityReturn))
#define DINO_REGISTER_SERVER_AVAILABILITY_RETURN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_REGISTER_TYPE_SERVER_AVAILABILITY_RETURN, DinoRegisterServerAvailabilityReturnClass))
#define DINO_REGISTER_IS_SERVER_AVAILABILITY_RETURN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_REGISTER_TYPE_SERVER_AVAILABILITY_RETURN))
#define DINO_REGISTER_IS_SERVER_AVAILABILITY_RETURN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_REGISTER_TYPE_SERVER_AVAILABILITY_RETURN))
#define DINO_REGISTER_SERVER_AVAILABILITY_RETURN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_REGISTER_TYPE_SERVER_AVAILABILITY_RETURN, DinoRegisterServerAvailabilityReturnClass))

typedef struct _DinoRegisterServerAvailabilityReturn DinoRegisterServerAvailabilityReturn;
typedef struct _DinoRegisterServerAvailabilityReturnClass DinoRegisterServerAvailabilityReturnClass;

#define DINO_REGISTER_TYPE_REGISTRATION_FORM_RETURN (dino_register_registration_form_return_get_type ())
#define DINO_REGISTER_REGISTRATION_FORM_RETURN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_REGISTER_TYPE_REGISTRATION_FORM_RETURN, DinoRegisterRegistrationFormReturn))
#define DINO_REGISTER_REGISTRATION_FORM_RETURN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_REGISTER_TYPE_REGISTRATION_FORM_RETURN, DinoRegisterRegistrationFormReturnClass))
#define DINO_REGISTER_IS_REGISTRATION_FORM_RETURN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_REGISTER_TYPE_REGISTRATION_FORM_RETURN))
#define DINO_REGISTER_IS_REGISTRATION_FORM_RETURN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_REGISTER_TYPE_REGISTRATION_FORM_RETURN))
#define DINO_REGISTER_REGISTRATION_FORM_RETURN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_REGISTER_TYPE_REGISTRATION_FORM_RETURN, DinoRegisterRegistrationFormReturnClass))

typedef struct _DinoRegisterRegistrationFormReturn DinoRegisterRegistrationFormReturn;
typedef struct _DinoRegisterRegistrationFormReturnClass DinoRegisterRegistrationFormReturnClass;
typedef struct _DinoRegisterServerAvailabilityReturnPrivate DinoRegisterServerAvailabilityReturnPrivate;
typedef struct _DinoRegisterRegistrationFormReturnPrivate DinoRegisterRegistrationFormReturnPrivate;

#define DINO_TYPE_ROSTER_MANAGER (dino_roster_manager_get_type ())
#define DINO_ROSTER_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_ROSTER_MANAGER, DinoRosterManager))
#define DINO_ROSTER_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_ROSTER_MANAGER, DinoRosterManagerClass))
#define DINO_IS_ROSTER_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_ROSTER_MANAGER))
#define DINO_IS_ROSTER_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_ROSTER_MANAGER))
#define DINO_ROSTER_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_ROSTER_MANAGER, DinoRosterManagerClass))

typedef struct _DinoRosterManager DinoRosterManager;
typedef struct _DinoRosterManagerClass DinoRosterManagerClass;
typedef struct _DinoRosterManagerPrivate DinoRosterManagerPrivate;

#define DINO_TYPE_ROSTER_STORE_IMPL (dino_roster_store_impl_get_type ())
#define DINO_ROSTER_STORE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_ROSTER_STORE_IMPL, DinoRosterStoreImpl))
#define DINO_ROSTER_STORE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_ROSTER_STORE_IMPL, DinoRosterStoreImplClass))
#define DINO_IS_ROSTER_STORE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_ROSTER_STORE_IMPL))
#define DINO_IS_ROSTER_STORE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_ROSTER_STORE_IMPL))
#define DINO_ROSTER_STORE_IMPL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_ROSTER_STORE_IMPL, DinoRosterStoreImplClass))

typedef struct _DinoRosterStoreImpl DinoRosterStoreImpl;
typedef struct _DinoRosterStoreImplClass DinoRosterStoreImplClass;
typedef struct _DinoRosterStoreImplPrivate DinoRosterStoreImplPrivate;

#define DINO_TYPE_SEARCH_PROCESSOR (dino_search_processor_get_type ())
#define DINO_SEARCH_PROCESSOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_SEARCH_PROCESSOR, DinoSearchProcessor))
#define DINO_SEARCH_PROCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_SEARCH_PROCESSOR, DinoSearchProcessorClass))
#define DINO_IS_SEARCH_PROCESSOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_SEARCH_PROCESSOR))
#define DINO_IS_SEARCH_PROCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_SEARCH_PROCESSOR))
#define DINO_SEARCH_PROCESSOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_SEARCH_PROCESSOR, DinoSearchProcessorClass))

typedef struct _DinoSearchProcessor DinoSearchProcessor;
typedef struct _DinoSearchProcessorClass DinoSearchProcessorClass;
typedef struct _DinoSearchProcessorPrivate DinoSearchProcessorPrivate;

#define DINO_TYPE_SEARCH_SUGGESTION (dino_search_suggestion_get_type ())
#define DINO_SEARCH_SUGGESTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_SEARCH_SUGGESTION, DinoSearchSuggestion))
#define DINO_SEARCH_SUGGESTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_SEARCH_SUGGESTION, DinoSearchSuggestionClass))
#define DINO_IS_SEARCH_SUGGESTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_SEARCH_SUGGESTION))
#define DINO_IS_SEARCH_SUGGESTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_SEARCH_SUGGESTION))
#define DINO_SEARCH_SUGGESTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_SEARCH_SUGGESTION, DinoSearchSuggestionClass))

typedef struct _DinoSearchSuggestion DinoSearchSuggestion;
typedef struct _DinoSearchSuggestionClass DinoSearchSuggestionClass;
typedef struct _DinoSearchSuggestionPrivate DinoSearchSuggestionPrivate;

#define DINO_TYPE_IMAGE_FILE_METADATA_PROVIDER (dino_image_file_metadata_provider_get_type ())
#define DINO_IMAGE_FILE_METADATA_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_IMAGE_FILE_METADATA_PROVIDER, DinoImageFileMetadataProvider))
#define DINO_IMAGE_FILE_METADATA_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_IMAGE_FILE_METADATA_PROVIDER, DinoImageFileMetadataProviderClass))
#define DINO_IS_IMAGE_FILE_METADATA_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_IMAGE_FILE_METADATA_PROVIDER))
#define DINO_IS_IMAGE_FILE_METADATA_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_IMAGE_FILE_METADATA_PROVIDER))
#define DINO_IMAGE_FILE_METADATA_PROVIDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_IMAGE_FILE_METADATA_PROVIDER, DinoImageFileMetadataProviderClass))

typedef struct _DinoImageFileMetadataProvider DinoImageFileMetadataProvider;
typedef struct _DinoImageFileMetadataProviderClass DinoImageFileMetadataProviderClass;
typedef struct _DinoImageFileMetadataProviderPrivate DinoImageFileMetadataProviderPrivate;
typedef struct _DinoStatelessFileSharingPrivate DinoStatelessFileSharingPrivate;
typedef struct _DinoStreamInteractorPrivate DinoStreamInteractorPrivate;
typedef struct _DinoModuleIdentityPrivate DinoModuleIdentityPrivate;

#define DINO_TYPE_UTIL (dino_util_get_type ())
#define DINO_UTIL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_UTIL, DinoUtil))
#define DINO_UTIL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_UTIL, DinoUtilClass))
#define DINO_IS_UTIL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_UTIL))
#define DINO_IS_UTIL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_UTIL))
#define DINO_UTIL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_UTIL, DinoUtilClass))

typedef struct _DinoUtil DinoUtil;
typedef struct _DinoUtilClass DinoUtilClass;
typedef struct _DinoUtilPrivate DinoUtilPrivate;

#define DINO_TYPE_LIMIT_INPUT_STREAM (dino_limit_input_stream_get_type ())
#define DINO_LIMIT_INPUT_STREAM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_LIMIT_INPUT_STREAM, DinoLimitInputStream))
#define DINO_LIMIT_INPUT_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_LIMIT_INPUT_STREAM, DinoLimitInputStreamClass))
#define DINO_IS_LIMIT_INPUT_STREAM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_LIMIT_INPUT_STREAM))
#define DINO_IS_LIMIT_INPUT_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_LIMIT_INPUT_STREAM))
#define DINO_LIMIT_INPUT_STREAM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_LIMIT_INPUT_STREAM, DinoLimitInputStreamClass))

typedef struct _DinoLimitInputStream DinoLimitInputStream;
typedef struct _DinoLimitInputStreamClass DinoLimitInputStreamClass;
typedef struct _DinoLimitInputStreamPrivate DinoLimitInputStreamPrivate;
typedef struct _DinoSearchPathGeneratorPrivate DinoSearchPathGeneratorPrivate;
typedef struct _WeakMapPrivate WeakMapPrivate;

#define DINO_TYPE_WEAK_TIMEOUT (dino_weak_timeout_get_type ())
#define DINO_WEAK_TIMEOUT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_TYPE_WEAK_TIMEOUT, DinoWeakTimeout))
#define DINO_WEAK_TIMEOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_TYPE_WEAK_TIMEOUT, DinoWeakTimeoutClass))
#define DINO_IS_WEAK_TIMEOUT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_TYPE_WEAK_TIMEOUT))
#define DINO_IS_WEAK_TIMEOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_TYPE_WEAK_TIMEOUT))
#define DINO_WEAK_TIMEOUT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_TYPE_WEAK_TIMEOUT, DinoWeakTimeoutClass))

typedef struct _DinoWeakTimeout DinoWeakTimeout;
typedef struct _DinoWeakTimeoutClass DinoWeakTimeoutClass;
typedef struct _DinoWeakTimeoutPrivate DinoWeakTimeoutPrivate;
typedef gboolean (*DinoWeakTimeoutSourceFunc) (gconstpointer object);
typedef void (*DinoWeakTimeoutSourceOnceFunc) (gconstpointer object);

struct _DinoApplicationIface {
	GTypeInterface parent_iface;
	void (*handle_uri) (DinoApplication* self, const gchar* jid, const gchar* query, GeeMap* options);
	DinoDatabase* (*get_db) (DinoApplication* self);
	void (*set_db) (DinoApplication* self, DinoDatabase* value);
	DinoEntitiesSettings* (*get_settings) (DinoApplication* self);
	void (*set_settings) (DinoApplication* self, DinoEntitiesSettings* value);
	DinoStreamInteractor* (*get_stream_interactor) (DinoApplication* self);
	void (*set_stream_interactor) (DinoApplication* self, DinoStreamInteractor* value);
	DinoPluginsRegistry* (*get_plugin_registry) (DinoApplication* self);
	void (*set_plugin_registry) (DinoApplication* self, DinoPluginsRegistry* value);
	DinoSearchPathGenerator* (*get_search_path_generator) (DinoApplication* self);
	void (*set_search_path_generator) (DinoApplication* self, DinoSearchPathGenerator* value);
};

struct _DinoLogin1ManagerIface {
	GTypeInterface parent_iface;
};

struct _DinoDBusNotificationsIface {
	GTypeInterface parent_iface;
	void (*notify) (DinoDBusNotifications* self, const gchar* app_name, guint32 replaces_id, const gchar* app_icon, const gchar* summary, const gchar* body, gchar** actions, gint actions_length1, GHashTable* hints, gint32 expire_timeout, GAsyncReadyCallback _callback_, gpointer _user_data_);
	guint32 (*notify_finish) (DinoDBusNotifications* self, GAsyncResult* _res_, GError** error);
	void (*get_capabilities) (DinoDBusNotifications* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*get_capabilities_finish) (DinoDBusNotifications* self, GAsyncResult* _res_, gchar*** capabilities, gint* capabilities_length1, GError** error);
	void (*close_notification) (DinoDBusNotifications* self, guint id, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*close_notification_finish) (DinoDBusNotifications* self, GAsyncResult* _res_, GError** error);
	void (*get_server_information) (DinoDBusNotifications* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*get_server_information_finish) (DinoDBusNotifications* self, GAsyncResult* _res_, gchar** name, gchar** vendor, gchar** version, gchar** spec_version, GError** error);
};

struct _DinoUPowerIface {
	GTypeInterface parent_iface;
};

struct _DinoEntitiesAccount {
	GObject parent_instance;
	DinoEntitiesAccountPrivate * priv;
};

struct _DinoEntitiesAccountClass {
	GObjectClass parent_class;
};

struct _DinoEntitiesCall {
	GObject parent_instance;
	DinoEntitiesCallPrivate * priv;
	GeeList* counterparts;
};

struct _DinoEntitiesCallClass {
	GObjectClass parent_class;
};

struct _DinoEntitiesConversation {
	GObject parent_instance;
	DinoEntitiesConversationPrivate * priv;
};

struct _DinoEntitiesConversationClass {
	GObjectClass parent_class;
};

struct _DinoEntitiesFileTransfer {
	GObject parent_instance;
	DinoEntitiesFileTransferPrivate * priv;
	GeeList* hashes;
	GeeList* sfs_sources;
	GeeList* thumbnails;
};

struct _DinoEntitiesFileTransferClass {
	GObjectClass parent_class;
};

struct _DinoEntitiesMessage {
	GObject parent_instance;
	DinoEntitiesMessagePrivate * priv;
	gchar* edit_to;
};

struct _DinoEntitiesMessageClass {
	GObjectClass parent_class;
};

struct _DinoEntitiesSettings {
	GObject parent_instance;
	DinoEntitiesSettingsPrivate * priv;
};

struct _DinoEntitiesSettingsClass {
	GObjectClass parent_class;
};

struct _DinoPluginsRootInterfaceIface {
	GTypeInterface parent_iface;
	void (*registered) (DinoPluginsRootInterface* self, DinoApplication* app);
	void (*shutdown) (DinoPluginsRootInterface* self);
};

struct _DinoPluginsEncryptionListEntryIface {
	GTypeInterface parent_iface;
	void (*encryption_activated) (DinoPluginsEncryptionListEntry* self, DinoEntitiesConversation* conversation, DinoPluginsSetInputFieldStatus callback, gpointer callback_target);
	GObject* (*get_encryption_icon) (DinoPluginsEncryptionListEntry* self, DinoEntitiesConversation* conversation, DinoContentItem* content_item);
	gchar* (*get_encryption_icon_name) (DinoPluginsEncryptionListEntry* self, DinoEntitiesConversation* conversation, DinoContentItem* content_item);
	DinoEntitiesEncryption (*get_encryption) (DinoPluginsEncryptionListEntry* self);
	const gchar* (*get_name) (DinoPluginsEncryptionListEntry* self);
};

struct _DinoPluginsCallEncryptionWidgetIface {
	GTypeInterface parent_iface;
	gchar* (*get_title) (DinoPluginsCallEncryptionWidget* self);
	gboolean (*show_keys) (DinoPluginsCallEncryptionWidget* self);
	gchar* (*get_icon_name) (DinoPluginsCallEncryptionWidget* self);
};

struct _DinoPluginsCallEncryptionEntryIface {
	GTypeInterface parent_iface;
	DinoPluginsCallEncryptionWidget* (*get_widget) (DinoPluginsCallEncryptionEntry* self, DinoEntitiesAccount* account, XmppXepJingleContentEncryption* encryption);
};

struct _DinoPluginsAccountSettingsEntry {
	GObject parent_instance;
	DinoPluginsAccountSettingsEntryPrivate * priv;
};

struct _DinoPluginsAccountSettingsEntryClass {
	GObjectClass parent_class;
	void (*deactivate) (DinoPluginsAccountSettingsEntry* self);
	void (*set_account) (DinoPluginsAccountSettingsEntry* self, DinoEntitiesAccount* account);
	GObject* (*get_widget) (DinoPluginsAccountSettingsEntry* self, DinoPluginsWidgetType type);
	const gchar* (*get_id) (DinoPluginsAccountSettingsEntry* self);
	DinoPluginsPriority (*get_priority) (DinoPluginsAccountSettingsEntry* self);
	const gchar* (*get_name) (DinoPluginsAccountSettingsEntry* self);
	gint16 (*get_label_top_padding) (DinoPluginsAccountSettingsEntry* self);
};

struct _DinoPluginsEncryptionPreferencesEntry {
	GObject parent_instance;
	DinoPluginsEncryptionPreferencesEntryPrivate * priv;
};

struct _DinoPluginsEncryptionPreferencesEntryClass {
	GObjectClass parent_class;
	GObject* (*get_widget) (DinoPluginsEncryptionPreferencesEntry* self, DinoEntitiesAccount* account, DinoPluginsWidgetType type);
	const gchar* (*get_id) (DinoPluginsEncryptionPreferencesEntry* self);
	DinoPluginsPriority (*get_priority) (DinoPluginsEncryptionPreferencesEntry* self);
};

struct _DinoPluginsContactDetailsProviderIface {
	GTypeInterface parent_iface;
	void (*populate) (DinoPluginsContactDetailsProvider* self, DinoEntitiesConversation* conversation, DinoPluginsContactDetails* contact_details, DinoPluginsWidgetType type);
	GObject* (*get_widget) (DinoPluginsContactDetailsProvider* self, DinoEntitiesConversation* conversation);
	const gchar* (*get_id) (DinoPluginsContactDetailsProvider* self);
	const gchar* (*get_tab) (DinoPluginsContactDetailsProvider* self);
};

struct _DinoPluginsContactDetails {
	GObject parent_instance;
	DinoPluginsContactDetailsPrivate * priv;
};

struct _DinoPluginsContactDetailsClass {
	GObjectClass parent_class;
};

struct _DinoPluginsTextCommandIface {
	GTypeInterface parent_iface;
	gchar* (*handle_command) (DinoPluginsTextCommand* self, const gchar* text, DinoEntitiesConversation* conversation);
	const gchar* (*get_cmd) (DinoPluginsTextCommand* self);
};

struct _DinoPluginsConversationTitlebarEntryIface {
	GTypeInterface parent_iface;
	GObject* (*get_widget) (DinoPluginsConversationTitlebarEntry* self, DinoPluginsWidgetType type);
	void (*set_conversation) (DinoPluginsConversationTitlebarEntry* self, DinoEntitiesConversation* conversation);
	void (*unset_conversation) (DinoPluginsConversationTitlebarEntry* self);
	const gchar* (*get_id) (DinoPluginsConversationTitlebarEntry* self);
	gdouble (*get_order) (DinoPluginsConversationTitlebarEntry* self);
};

struct _DinoPluginsConversationItemCollectionIface {
	GTypeInterface parent_iface;
	void (*insert_item) (DinoPluginsConversationItemCollection* self, DinoPluginsMetaConversationItem* item);
	void (*remove_item) (DinoPluginsConversationItemCollection* self, DinoPluginsMetaConversationItem* item);
};

struct _DinoPluginsConversationItemPopulatorIface {
	GTypeInterface parent_iface;
	void (*init) (DinoPluginsConversationItemPopulator* self, DinoEntitiesConversation* conversation, DinoPluginsConversationItemCollection* summary, DinoPluginsWidgetType type);
	void (*close) (DinoPluginsConversationItemPopulator* self, DinoEntitiesConversation* conversation);
	const gchar* (*get_id) (DinoPluginsConversationItemPopulator* self);
};

struct _DinoPluginsConversationAdditionPopulatorIface {
	GTypeInterface parent_iface;
	void (*populate_timespan) (DinoPluginsConversationAdditionPopulator* self, DinoEntitiesConversation* conversation, GDateTime* from, GDateTime* to);
};

struct _DinoPluginsMediaDeviceIface {
	GTypeInterface parent_iface;
	gchar* (*get_id) (DinoPluginsMediaDevice* self);
	gchar* (*get_display_name) (DinoPluginsMediaDevice* self);
	gchar* (*get_detail_name) (DinoPluginsMediaDevice* self);
	gchar* (*get_media) (DinoPluginsMediaDevice* self);
	gboolean (*get_incoming) (DinoPluginsMediaDevice* self);
};

struct _DinoPluginsVideoCallWidgetIface {
	GTypeInterface parent_iface;
	void (*display_stream) (DinoPluginsVideoCallWidget* self, XmppXepJingleRtpStream* stream, XmppJid* jid);
	void (*display_device) (DinoPluginsVideoCallWidget* self, DinoPluginsMediaDevice* device);
	void (*detach) (DinoPluginsVideoCallWidget* self);
};

struct _DinoPluginsVideoCallPluginIface {
	GTypeInterface parent_iface;
	gboolean (*supported) (DinoPluginsVideoCallPlugin* self);
	DinoPluginsVideoCallWidget* (*create_widget) (DinoPluginsVideoCallPlugin* self, DinoPluginsWidgetType type);
	GeeList* (*get_devices) (DinoPluginsVideoCallPlugin* self, const gchar* media, gboolean incoming);
	DinoPluginsMediaDevice* (*get_preferred_device) (DinoPluginsVideoCallPlugin* self, const gchar* media, gboolean incoming);
	DinoPluginsMediaDevice* (*get_device) (DinoPluginsVideoCallPlugin* self, XmppXepJingleRtpStream* stream, gboolean incoming);
	void (*set_pause) (DinoPluginsVideoCallPlugin* self, XmppXepJingleRtpStream* stream, gboolean pause);
	void (*set_device) (DinoPluginsVideoCallPlugin* self, XmppXepJingleRtpStream* stream, DinoPluginsMediaDevice* device);
	void (*dump_dot) (DinoPluginsVideoCallPlugin* self);
};

struct _DinoPluginsNotificationCollectionIface {
	GTypeInterface parent_iface;
};

struct _DinoPluginsNotificationPopulatorIface {
	GTypeInterface parent_iface;
	void (*init) (DinoPluginsNotificationPopulator* self, DinoEntitiesConversation* conversation, DinoPluginsNotificationCollection* summary, DinoPluginsWidgetType type);
	void (*close) (DinoPluginsNotificationPopulator* self, DinoEntitiesConversation* conversation);
	const gchar* (*get_id) (DinoPluginsNotificationPopulator* self);
};

struct _DinoPluginsConversationItemWidgetInterfaceIface {
	GTypeInterface parent_iface;
	void (*set_widget) (DinoPluginsConversationItemWidgetInterface* self, GObject* object, DinoPluginsWidgetType type, gint priority);
};

struct _DinoPluginsMetaConversationItem {
	GObject parent_instance;
	DinoPluginsMetaConversationItemPrivate * priv;
};

struct _DinoPluginsMetaConversationItemClass {
	GObjectClass parent_class;
	GObject* (*get_widget) (DinoPluginsMetaConversationItem* self, DinoPluginsConversationItemWidgetInterface* outer, DinoPluginsWidgetType type);
	GeeList* (*get_item_actions) (DinoPluginsMetaConversationItem* self, DinoPluginsWidgetType type);
	const gchar* (*get_populator_id) (DinoPluginsMetaConversationItem* self);
	void (*set_populator_id) (DinoPluginsMetaConversationItem* self, const gchar* value);
	XmppJid* (*get_jid) (DinoPluginsMetaConversationItem* self);
	void (*set_jid) (DinoPluginsMetaConversationItem* self, XmppJid* value);
	GDateTime* (*get_time) (DinoPluginsMetaConversationItem* self);
	void (*set_time) (DinoPluginsMetaConversationItem* self, GDateTime* value);
	gint (*get_secondary_sort_indicator) (DinoPluginsMetaConversationItem* self);
	void (*set_secondary_sort_indicator) (DinoPluginsMetaConversationItem* self, gint value);
	DinoEntitiesEncryption (*get_encryption) (DinoPluginsMetaConversationItem* self);
	void (*set_encryption) (DinoPluginsMetaConversationItem* self, DinoEntitiesEncryption value);
	DinoEntitiesMessageMarked (*get_mark) (DinoPluginsMetaConversationItem* self);
	void (*set_mark) (DinoPluginsMetaConversationItem* self, DinoEntitiesMessageMarked value);
};

struct _DinoPluginsMessageAction {
	GObject parent_instance;
	DinoPluginsMessageActionPrivate * priv;
	gchar* name;
	gboolean sensitive;
	gchar* icon_name;
	gchar* tooltip;
	GObject* popover;
	DinoPluginsMessageActionEvoked callback;
	gpointer callback_target;
	GDestroyNotify callback_target_destroy_notify;
};

struct _DinoPluginsMessageActionClass {
	GObjectClass parent_class;
};

struct _DinoPluginsMetaConversationNotification {
	GObject parent_instance;
	DinoPluginsMetaConversationNotificationPrivate * priv;
};

struct _DinoPluginsMetaConversationNotificationClass {
	GObjectClass parent_class;
	GObject* (*get_widget) (DinoPluginsMetaConversationNotification* self, DinoPluginsWidgetType type);
};

struct _DinoPluginsInputFieldStatus {
	GObject parent_instance;
	DinoPluginsInputFieldStatusPrivate * priv;
	gchar* message;
	DinoPluginsInputFieldStatusMessageType message_type;
	DinoPluginsInputFieldStatusInputState input_state;
	gboolean contains_markup;
};

struct _DinoPluginsInputFieldStatusClass {
	GObjectClass parent_class;
};

struct _DinoPluginsLoader {
	GObject parent_instance;
	DinoPluginsLoaderPrivate * priv;
};

struct _DinoPluginsLoaderClass {
	GObjectClass parent_class;
};

struct _DinoPluginsRegistry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoPluginsRegistryPrivate * priv;
	GeeHashMap* encryption_list_entries;
	GeeHashMap* call_encryption_entries;
	GeeArrayList* account_settings_entries;
	GeeArrayList* encryption_preferences_entries;
	GeeArrayList* contact_details_entries;
	GeeMap* text_commands;
	GeeList* conversation_addition_populators;
	GeeList* notification_populators;
	GeeCollection* conversation_titlebar_entries;
	DinoPluginsVideoCallPlugin* video_call_plugin;
};

struct _DinoPluginsRegistryClass {
	GTypeClass parent_class;
	void (*finalize) (DinoPluginsRegistry *self);
};

struct _DinoStreamInteractionModuleIface {
	GTypeInterface parent_iface;
	const gchar* (*get_id) (DinoStreamInteractionModule* self);
};

struct _DinoAvatarManager {
	GObject parent_instance;
	DinoAvatarManagerPrivate * priv;
};

struct _DinoAvatarManagerClass {
	GObjectClass parent_class;
};

struct _DinoBlockingManager {
	GObject parent_instance;
	DinoBlockingManagerPrivate * priv;
};

struct _DinoBlockingManagerClass {
	GObjectClass parent_class;
};

struct _DinoCallStore {
	GObject parent_instance;
	DinoCallStorePrivate * priv;
};

struct _DinoCallStoreClass {
	GObjectClass parent_class;
};

struct _DinoCallState {
	GObject parent_instance;
	DinoCallStatePrivate * priv;
	DinoStreamInteractor* stream_interactor;
	DinoPluginsVideoCallPlugin* call_plugin;
	DinoEntitiesCall* call;
	XmppJid* invited_to_group_call;
	gboolean use_cim;
	gchar* cim_call_id;
	XmppJid* cim_counterpart;
	GeeArrayList* cim_jids_to_inform;
	GeeHashMap* peers;
};

struct _DinoCallStateClass {
	GObjectClass parent_class;
};

struct _DinoPeerState {
	GObject parent_instance;
	DinoPeerStatePrivate * priv;
	DinoStreamInteractor* stream_interactor;
	DinoCallState* call_state;
	DinoCalls* calls;
	DinoEntitiesCall* call;
	XmppJid* jid;
	XmppXepJingleSession* session;
	gchar* sid;
	gchar* internal_id;
	XmppXepJingleRtpParameters* audio_content_parameter;
	XmppXepJingleRtpParameters* video_content_parameter;
	XmppXepJingleContent* audio_content;
	XmppXepJingleContent* video_content;
	XmppXepJingleContentEncryption* video_encryption;
	XmppXepJingleContentEncryption* audio_encryption;
	gboolean encryption_keys_same;
	GeeHashMap* video_encryptions;
	GeeHashMap* audio_encryptions;
	gboolean first_peer;
	gboolean waiting_for_inbound_muji_connection;
	gboolean counterpart_sends_video;
};

struct _DinoPeerStateClass {
	GObjectClass parent_class;
};

struct _DinoPeerContentInfo {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoPeerContentInfoPrivate * priv;
};

struct _DinoPeerContentInfoClass {
	GTypeClass parent_class;
	void (*finalize) (DinoPeerContentInfo *self);
};

struct _DinoPeerInfo {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoPeerInfoPrivate * priv;
	DinoPeerContentInfo* audio;
	DinoPeerContentInfo* video;
};

struct _DinoPeerInfoClass {
	GTypeClass parent_class;
	void (*finalize) (DinoPeerInfo *self);
};

struct _DinoCalls {
	GObject parent_instance;
	DinoCallsPrivate * priv;
	GeeHashMap* jmi_request_peer;
	GeeHashMap* call_states;
};

struct _DinoCallsClass {
	GObjectClass parent_class;
};

struct _DinoChatInteraction {
	GObject parent_instance;
	DinoChatInteractionPrivate * priv;
};

struct _DinoChatInteractionClass {
	GObjectClass parent_class;
};

struct _DinoConnectionManager {
	GObject parent_instance;
	DinoConnectionManagerPrivate * priv;
	gchar* log_options;
};

struct _DinoConnectionManagerClass {
	GObjectClass parent_class;
};

struct _DinoConnectionManagerConnectionError {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoConnectionManagerConnectionErrorPrivate * priv;
	DinoConnectionManagerConnectionErrorSource source;
	gchar* identifier;
};

struct _DinoConnectionManagerConnectionErrorClass {
	GTypeClass parent_class;
	void (*finalize) (DinoConnectionManagerConnectionError *self);
};

struct _DinoModelConversationDisplayName {
	GObject parent_instance;
	DinoModelConversationDisplayNamePrivate * priv;
};

struct _DinoModelConversationDisplayNameClass {
	GObjectClass parent_class;
};

struct _DinoContactModels {
	GObject parent_instance;
	DinoContactModelsPrivate * priv;
};

struct _DinoContactModelsClass {
	GObjectClass parent_class;
};

struct _DinoContentItemStore {
	GObject parent_instance;
	DinoContentItemStorePrivate * priv;
};

struct _DinoContentItemStoreClass {
	GObjectClass parent_class;
};

struct _DinoContentItemCollectionIface {
	GTypeInterface parent_iface;
	void (*insert_item) (DinoContentItemCollection* self, DinoContentItem* item);
	void (*remove_item) (DinoContentItemCollection* self, DinoContentItem* item);
};

struct _DinoContentItem {
	GObject parent_instance;
	DinoContentItemPrivate * priv;
};

struct _DinoContentItemClass {
	GObjectClass parent_class;
};

struct _DinoMessageItem {
	DinoContentItem parent_instance;
	DinoMessageItemPrivate * priv;
	DinoEntitiesMessage* message;
	DinoEntitiesConversation* conversation;
};

struct _DinoMessageItemClass {
	DinoContentItemClass parent_class;
};

struct _DinoFileItem {
	DinoContentItem parent_instance;
	DinoFileItemPrivate * priv;
	DinoEntitiesFileTransfer* file_transfer;
	DinoEntitiesConversation* conversation;
};

struct _DinoFileItemClass {
	DinoContentItemClass parent_class;
};

struct _DinoCallItem {
	DinoContentItem parent_instance;
	DinoCallItemPrivate * priv;
	DinoEntitiesCall* call;
	DinoEntitiesConversation* conversation;
};

struct _DinoCallItemClass {
	DinoContentItemClass parent_class;
};

struct _DinoConversationManager {
	GObject parent_instance;
	DinoConversationManagerPrivate * priv;
};

struct _DinoConversationManagerClass {
	GObjectClass parent_class;
};

struct _DinoCounterpartInteractionManager {
	GObject parent_instance;
	DinoCounterpartInteractionManagerPrivate * priv;
};

struct _DinoCounterpartInteractionManagerClass {
	GObjectClass parent_class;
};

struct _DinoDatabase {
	QliteDatabase parent_instance;
	DinoDatabasePrivate * priv;
	GeeMap* jid_table_cache;
	GeeMap* jid_table_reverse;
	GeeMap* account_table_cache;
};

struct _DinoDatabaseClass {
	QliteDatabaseClass parent_class;
};

struct _DinoDatabaseAccountTable {
	QliteTable parent_instance;
	DinoDatabaseAccountTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* bare_jid;
	QliteColumn* resourcepart;
	QliteColumn* password;
	QliteColumn* alias;
	QliteColumn* enabled;
	QliteColumn* roster_version;
	QliteColumn* mam_earliest_synced;
};

struct _DinoDatabaseAccountTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseJidTable {
	QliteTable parent_instance;
	DinoDatabaseJidTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* bare_jid;
};

struct _DinoDatabaseJidTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseEntityTable {
	QliteTable parent_instance;
	DinoDatabaseEntityTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* account_id;
	QliteColumn* jid_id;
	QliteColumn* resource;
	QliteColumn* caps_hash;
	QliteColumn* last_seen;
};

struct _DinoDatabaseEntityTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseContentItemTable {
	QliteTable parent_instance;
	DinoDatabaseContentItemTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* conversation_id;
	QliteColumn* time;
	QliteColumn* local_time;
	QliteColumn* content_type;
	QliteColumn* foreign_id;
	QliteColumn* hide;
};

struct _DinoDatabaseContentItemTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseMessageTable {
	QliteTable parent_instance;
	DinoDatabaseMessageTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* stanza_id;
	QliteColumn* server_id;
	QliteColumn* account_id;
	QliteColumn* counterpart_id;
	QliteColumn* counterpart_resource;
	QliteColumn* our_resource;
	QliteColumn* direction;
	QliteColumn* type_;
	QliteColumn* time;
	QliteColumn* local_time;
	QliteColumn* body;
	QliteColumn* encryption;
	QliteColumn* marked;
};

struct _DinoDatabaseMessageTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseBodyMeta {
	QliteTable parent_instance;
	DinoDatabaseBodyMetaPrivate * priv;
	QliteColumn* id;
	QliteColumn* message_id;
	QliteColumn* from_char;
	QliteColumn* to_char;
	QliteColumn* info_type;
	QliteColumn* info;
};

struct _DinoDatabaseBodyMetaClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseMessageCorrectionTable {
	QliteTable parent_instance;
	DinoDatabaseMessageCorrectionTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* message_id;
	QliteColumn* to_stanza_id;
};

struct _DinoDatabaseMessageCorrectionTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseReplyTable {
	QliteTable parent_instance;
	DinoDatabaseReplyTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* message_id;
	QliteColumn* quoted_content_item_id;
	QliteColumn* quoted_message_stanza_id;
	QliteColumn* quoted_message_from;
};

struct _DinoDatabaseReplyTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseRealJidTable {
	QliteTable parent_instance;
	DinoDatabaseRealJidTablePrivate * priv;
	QliteColumn* message_id;
	QliteColumn* real_jid;
};

struct _DinoDatabaseRealJidTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseOccupantIdTable {
	QliteTable parent_instance;
	DinoDatabaseOccupantIdTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* account_id;
	QliteColumn* last_nick;
	QliteColumn* jid_id;
	QliteColumn* occupant_id;
};

struct _DinoDatabaseOccupantIdTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseUndecryptedTable {
	QliteTable parent_instance;
	DinoDatabaseUndecryptedTablePrivate * priv;
	QliteColumn* message_id;
	QliteColumn* type_;
	QliteColumn* data;
};

struct _DinoDatabaseUndecryptedTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseFileTransferTable {
	QliteTable parent_instance;
	DinoDatabaseFileTransferTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* file_sharing_id;
	QliteColumn* account_id;
	QliteColumn* counterpart_id;
	QliteColumn* counterpart_resource;
	QliteColumn* our_resource;
	QliteColumn* direction;
	QliteColumn* time;
	QliteColumn* local_time;
	QliteColumn* encryption;
	QliteColumn* file_name;
	QliteColumn* path;
	QliteColumn* mime_type;
	QliteColumn* size;
	QliteColumn* state;
	QliteColumn* provider;
	QliteColumn* info;
	QliteColumn* modification_date;
	QliteColumn* width;
	QliteColumn* height;
	QliteColumn* length;
};

struct _DinoDatabaseFileTransferTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseFileHashesTable {
	QliteTable parent_instance;
	DinoDatabaseFileHashesTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* algo;
	QliteColumn* value;
};

struct _DinoDatabaseFileHashesTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseFileThumbnailsTable {
	QliteTable parent_instance;
	DinoDatabaseFileThumbnailsTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* uri;
	QliteColumn* mime_type;
	QliteColumn* width;
	QliteColumn* height;
};

struct _DinoDatabaseFileThumbnailsTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseSourcesTable {
	QliteTable parent_instance;
	DinoDatabaseSourcesTablePrivate * priv;
	QliteColumn* file_transfer_id;
	QliteColumn* type;
	QliteColumn* data;
};

struct _DinoDatabaseSourcesTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseCallTable {
	QliteTable parent_instance;
	DinoDatabaseCallTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* account_id;
	QliteColumn* counterpart_id;
	QliteColumn* counterpart_resource;
	QliteColumn* our_resource;
	QliteColumn* direction;
	QliteColumn* time;
	QliteColumn* local_time;
	QliteColumn* end_time;
	QliteColumn* encryption;
	QliteColumn* state;
};

struct _DinoDatabaseCallTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseCallCounterpartTable {
	QliteTable parent_instance;
	DinoDatabaseCallCounterpartTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* call_id;
	QliteColumn* jid_id;
	QliteColumn* resource;
};

struct _DinoDatabaseCallCounterpartTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseConversationTable {
	QliteTable parent_instance;
	DinoDatabaseConversationTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* account_id;
	QliteColumn* jid_id;
	QliteColumn* resource;
	QliteColumn* active;
	QliteColumn* active_last_changed;
	QliteColumn* last_active;
	QliteColumn* type_;
	QliteColumn* encryption;
	QliteColumn* read_up_to;
	QliteColumn* read_up_to_item;
	QliteColumn* notification;
	QliteColumn* send_typing;
	QliteColumn* send_marker;
	QliteColumn* pinned;
};

struct _DinoDatabaseConversationTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseAvatarTable {
	QliteTable parent_instance;
	DinoDatabaseAvatarTablePrivate * priv;
	QliteColumn* jid_id;
	QliteColumn* account_id;
	QliteColumn* hash;
	QliteColumn* type_;
};

struct _DinoDatabaseAvatarTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseEntityIdentityTable {
	QliteTable parent_instance;
	DinoDatabaseEntityIdentityTablePrivate * priv;
	QliteColumn* entity;
	QliteColumn* category;
	QliteColumn* type;
	QliteColumn* entity_name;
};

struct _DinoDatabaseEntityIdentityTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseEntityFeatureTable {
	QliteTable parent_instance;
	DinoDatabaseEntityFeatureTablePrivate * priv;
	QliteColumn* entity;
	QliteColumn* feature;
};

struct _DinoDatabaseEntityFeatureTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseRosterTable {
	QliteTable parent_instance;
	DinoDatabaseRosterTablePrivate * priv;
	QliteColumn* account_id;
	QliteColumn* jid;
	QliteColumn* handle;
	QliteColumn* subscription;
	QliteColumn* ask;
};

struct _DinoDatabaseRosterTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseMamCatchupTable {
	QliteTable parent_instance;
	DinoDatabaseMamCatchupTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* account_id;
	QliteColumn* server_jid;
	QliteColumn* from_id;
	QliteColumn* from_time;
	QliteColumn* from_end;
	QliteColumn* to_id;
	QliteColumn* to_time;
};

struct _DinoDatabaseMamCatchupTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseReactionTable {
	QliteTable parent_instance;
	DinoDatabaseReactionTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* account_id;
	QliteColumn* occupant_id;
	QliteColumn* content_item_id;
	QliteColumn* time;
	QliteColumn* jid_id;
	QliteColumn* emojis;
};

struct _DinoDatabaseReactionTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseSettingsTable {
	QliteTable parent_instance;
	DinoDatabaseSettingsTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* key;
	QliteColumn* value;
};

struct _DinoDatabaseSettingsTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseAccountSettingsTable {
	QliteTable parent_instance;
	DinoDatabaseAccountSettingsTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* account_id;
	QliteColumn* key;
	QliteColumn* value;
};

struct _DinoDatabaseAccountSettingsTableClass {
	QliteTableClass parent_class;
};

struct _DinoDatabaseConversationSettingsTable {
	QliteTable parent_instance;
	DinoDatabaseConversationSettingsTablePrivate * priv;
	QliteColumn* id;
	QliteColumn* conversation_id;
	QliteColumn* key;
	QliteColumn* value;
};

struct _DinoDatabaseConversationSettingsTableClass {
	QliteTableClass parent_class;
};

struct _DinoEntityCapabilitiesStorage {
	GObject parent_instance;
	DinoEntityCapabilitiesStoragePrivate * priv;
};

struct _DinoEntityCapabilitiesStorageClass {
	GObjectClass parent_class;
};

struct _DinoEntityInfo {
	GObject parent_instance;
	DinoEntityInfoPrivate * priv;
};

struct _DinoEntityInfoClass {
	GObjectClass parent_class;
};

struct _DinoCapsCacheImpl {
	GObject parent_instance;
	DinoCapsCacheImplPrivate * priv;
};

struct _DinoCapsCacheImplClass {
	GObjectClass parent_class;
};

struct _DinoFallbackBody {
	GObject parent_instance;
	DinoFallbackBodyPrivate * priv;
};

struct _DinoFallbackBodyClass {
	GObjectClass parent_class;
};

struct _DinoFileManager {
	GObject parent_instance;
	DinoFileManagerPrivate * priv;
};

struct _DinoFileManagerClass {
	GObjectClass parent_class;
};

typedef enum  {
	DINO_FILE_RECEIVE_ERROR_GET_METADATA_FAILED,
	DINO_FILE_RECEIVE_ERROR_DECRYPTION_FAILED
} DinoFileReceiveError;
#define DINO_FILE_RECEIVE_ERROR dino_file_receive_error_quark ()

struct _DinoFileProviderIface {
	GTypeInterface parent_iface;
	DinoEntitiesEncryption (*get_encryption) (DinoFileProvider* self, DinoEntitiesFileTransfer* file_transfer, DinoFileReceiveData* receive_data, DinoFileMeta* file_meta);
	DinoFileMeta* (*get_file_meta) (DinoFileProvider* self, DinoEntitiesFileTransfer* file_transfer, GError** error);
	DinoFileReceiveData* (*get_file_receive_data) (DinoFileProvider* self, DinoEntitiesFileTransfer* file_transfer);
	void (*get_meta_info) (DinoFileProvider* self, DinoEntitiesFileTransfer* file_transfer, DinoFileReceiveData* receive_data, DinoFileMeta* file_meta, GAsyncReadyCallback _callback_, gpointer _user_data_);
	DinoFileMeta* (*get_meta_info_finish) (DinoFileProvider* self, GAsyncResult* _res_, GError** error);
	void (*download) (DinoFileProvider* self, DinoEntitiesFileTransfer* file_transfer, DinoFileReceiveData* receive_data, DinoFileMeta* file_meta, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*download_finish) (DinoFileProvider* self, GAsyncResult* _res_, GError** error);
	gint (*get_id) (DinoFileProvider* self);
};

typedef enum  {
	DINO_FILE_SEND_ERROR_ENCRYPTION_FAILED,
	DINO_FILE_SEND_ERROR_UPLOAD_FAILED,
	DINO_FILE_SEND_ERROR_SAVE_FAILED
} DinoFileSendError;
#define DINO_FILE_SEND_ERROR dino_file_send_error_quark ()

struct _DinoFileSenderIface {
	GTypeInterface parent_iface;
	void (*is_upload_available) (DinoFileSender* self, DinoEntitiesConversation* conversation, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*is_upload_available_finish) (DinoFileSender* self, GAsyncResult* _res_);
	void (*get_file_size_limit) (DinoFileSender* self, DinoEntitiesConversation* conversation, GAsyncReadyCallback _callback_, gpointer _user_data_);
	glong (*get_file_size_limit_finish) (DinoFileSender* self, GAsyncResult* _res_);
	void (*can_send) (DinoFileSender* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*can_send_finish) (DinoFileSender* self, GAsyncResult* _res_);
	void (*prepare_send_file) (DinoFileSender* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, DinoFileMeta* file_meta, GAsyncReadyCallback _callback_, gpointer _user_data_);
	DinoFileSendData* (*prepare_send_file_finish) (DinoFileSender* self, GAsyncResult* _res_, GError** error);
	void (*send_file) (DinoFileSender* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, DinoFileSendData* file_send_data, DinoFileMeta* file_meta, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*send_file_finish) (DinoFileSender* self, GAsyncResult* _res_, GError** error);
	void (*can_encrypt) (DinoFileSender* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*can_encrypt_finish) (DinoFileSender* self, GAsyncResult* _res_);
	gint (*get_id) (DinoFileSender* self);
	gfloat (*get_priority) (DinoFileSender* self);
};

struct _DinoFileEncryptorIface {
	GTypeInterface parent_iface;
	gboolean (*can_encrypt_file) (DinoFileEncryptor* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer);
	DinoFileMeta* (*encrypt_file) (DinoFileEncryptor* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, GError** error);
	DinoFileSendData* (*preprocess_send_file) (DinoFileEncryptor* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, DinoFileSendData* file_send_data, DinoFileMeta* file_meta, GError** error);
};

struct _DinoFileDecryptorIface {
	GTypeInterface parent_iface;
	DinoEntitiesEncryption (*get_encryption) (DinoFileDecryptor* self);
	DinoFileReceiveData* (*prepare_get_meta_info) (DinoFileDecryptor* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, DinoFileReceiveData* receive_data);
	DinoFileMeta* (*prepare_download_file) (DinoFileDecryptor* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, DinoFileReceiveData* receive_data, DinoFileMeta* file_meta);
	gboolean (*can_decrypt_file) (DinoFileDecryptor* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, DinoFileReceiveData* receive_data);
	void (*decrypt_file) (DinoFileDecryptor* self, GInputStream* encrypted_stream, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, DinoFileReceiveData* receive_data, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*decrypt_file_finish) (DinoFileDecryptor* self, GAsyncResult* _res_, GError** error);
};

struct _DinoFileMetadataProviderIface {
	GTypeInterface parent_iface;
	gboolean (*supports_file) (DinoFileMetadataProvider* self, GFile* file);
	void (*fill_metadata) (DinoFileMetadataProvider* self, GFile* file, XmppXepFileMetadataElementFileMetadata* metadata, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*fill_metadata_finish) (DinoFileMetadataProvider* self, GAsyncResult* _res_);
};

struct _DinoFileMeta {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoFileMetaPrivate * priv;
	gint64 size;
	gchar* mime_type;
	gchar* file_name;
	DinoEntitiesEncryption encryption;
};

struct _DinoFileMetaClass {
	GTypeClass parent_class;
	void (*finalize) (DinoFileMeta *self);
};

struct _DinoHttpFileMeta {
	DinoFileMeta parent_instance;
	DinoHttpFileMetaPrivate * priv;
	DinoEntitiesMessage* message;
};

struct _DinoHttpFileMetaClass {
	DinoFileMetaClass parent_class;
};

struct _DinoFileSendData {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoFileSendDataPrivate * priv;
};

struct _DinoFileSendDataClass {
	GTypeClass parent_class;
	void (*finalize) (DinoFileSendData *self);
};

struct _DinoHttpFileSendData {
	DinoFileSendData parent_instance;
	DinoHttpFileSendDataPrivate * priv;
};

struct _DinoHttpFileSendDataClass {
	DinoFileSendDataClass parent_class;
};

struct _DinoFileReceiveData {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoFileReceiveDataPrivate * priv;
};

struct _DinoFileReceiveDataClass {
	GTypeClass parent_class;
	void (*finalize) (DinoFileReceiveData *self);
};

struct _DinoHttpFileReceiveData {
	DinoFileReceiveData parent_instance;
	DinoHttpFileReceiveDataPrivate * priv;
};

struct _DinoHttpFileReceiveDataClass {
	DinoFileReceiveDataClass parent_class;
};

struct _DinoFileTransferStorage {
	GObject parent_instance;
	DinoFileTransferStoragePrivate * priv;
};

struct _DinoFileTransferStorageClass {
	GObjectClass parent_class;
};

struct _DinoHistorySync {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoHistorySyncPrivate * priv;
	GeeHashMap* current_catchup_id;
	WeakMap* sync_streams;
	GeeHashMap* cancellables;
	GeeHashMap* mam_times;
	GeeHashMap* hitted_range;
	GeeHashMap* catchup_until_id;
	GeeHashMap* catchup_until_time;
};

struct _DinoHistorySyncClass {
	GTypeClass parent_class;
	void (*finalize) (DinoHistorySync *self);
};

struct _DinoJingleFileEncryptionHelperIface {
	GTypeInterface parent_iface;
	gboolean (*can_transfer) (DinoJingleFileEncryptionHelper* self, DinoEntitiesConversation* conversation);
	void (*can_encrypt) (DinoJingleFileEncryptionHelper* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer, XmppJid* full_jid, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*can_encrypt_finish) (DinoJingleFileEncryptionHelper* self, GAsyncResult* _res_);
	gchar* (*get_precondition_name) (DinoJingleFileEncryptionHelper* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer);
	GObject* (*get_precondition_options) (DinoJingleFileEncryptionHelper* self, DinoEntitiesConversation* conversation, DinoEntitiesFileTransfer* file_transfer);
	DinoEntitiesEncryption (*get_encryption) (DinoJingleFileEncryptionHelper* self, XmppXepJingleFileTransferFileTransfer* jingle_transfer);
};

struct _DinoJingleFileEncryptionHelperTransferOnly {
	GObject parent_instance;
	DinoJingleFileEncryptionHelperTransferOnlyPrivate * priv;
};

struct _DinoJingleFileEncryptionHelperTransferOnlyClass {
	GObjectClass parent_class;
};

struct _DinoJingleFileHelperRegistry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoJingleFileHelperRegistryPrivate * priv;
	GeeHashMap* encryption_helpers;
};

struct _DinoJingleFileHelperRegistryClass {
	GTypeClass parent_class;
	void (*finalize) (DinoJingleFileHelperRegistry *self);
};

struct _DinoJingleFileProvider {
	GObject parent_instance;
	DinoJingleFileProviderPrivate * priv;
};

struct _DinoJingleFileProviderClass {
	GObjectClass parent_class;
};

struct _DinoJingleFileSender {
	GObject parent_instance;
	DinoJingleFileSenderPrivate * priv;
};

struct _DinoJingleFileSenderClass {
	GObjectClass parent_class;
};

struct _DinoMessageListener {
	XmppOrderedListener parent_instance;
	DinoMessageListenerPrivate * priv;
};

struct _DinoMessageListenerClass {
	XmppOrderedListenerClass parent_class;
	void (*run) (DinoMessageListener* self, DinoEntitiesMessage* message, XmppMessageStanza* stanza, DinoEntitiesConversation* conversation, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*run_finish) (DinoMessageListener* self, GAsyncResult* _res_);
};

struct _DinoMessageCorrection {
	DinoMessageListener parent_instance;
	DinoMessageCorrectionPrivate * priv;
	gchar** after_actions_const;
	gint after_actions_const_length1;
};

struct _DinoMessageCorrectionClass {
	DinoMessageListenerClass parent_class;
};

struct _DinoMessageProcessor {
	GObject parent_instance;
	DinoMessageProcessorPrivate * priv;
	DinoHistorySync* history_sync;
	DinoMessageListenerHolder* received_pipeline;
};

struct _DinoMessageProcessorClass {
	GObjectClass parent_class;
};

struct _DinoMessageListenerHolder {
	XmppListenerHolder parent_instance;
	DinoMessageListenerHolderPrivate * priv;
};

struct _DinoMessageListenerHolderClass {
	XmppListenerHolderClass parent_class;
};

struct _DinoMessageStorage {
	GObject parent_instance;
	DinoMessageStoragePrivate * priv;
};

struct _DinoMessageStorageClass {
	GObjectClass parent_class;
};

struct _DinoModuleManager {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoModuleManagerPrivate * priv;
};

struct _DinoModuleManagerClass {
	GTypeClass parent_class;
	void (*finalize) (DinoModuleManager *self);
};

struct _DinoMucManager {
	GObject parent_instance;
	DinoMucManagerPrivate * priv;
	GeeHashMap* default_muc_server;
};

struct _DinoMucManagerClass {
	GObjectClass parent_class;
};

struct _DinoNotificationEvents {
	GObject parent_instance;
	DinoNotificationEventsPrivate * priv;
};

struct _DinoNotificationEventsClass {
	GObjectClass parent_class;
};

struct _DinoNotificationProviderIface {
	GTypeInterface parent_iface;
	gdouble (*get_priority) (DinoNotificationProvider* self);
	void (*notify_message) (DinoNotificationProvider* self, DinoEntitiesMessage* message, DinoEntitiesConversation* conversation, const gchar* conversation_display_name, const gchar* participant_display_name, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*notify_message_finish) (DinoNotificationProvider* self, GAsyncResult* _res_);
	void (*notify_file) (DinoNotificationProvider* self, DinoEntitiesFileTransfer* file_transfer, DinoEntitiesConversation* conversation, gboolean is_image, const gchar* conversation_display_name, const gchar* participant_display_name, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*notify_file_finish) (DinoNotificationProvider* self, GAsyncResult* _res_);
	void (*notify_call) (DinoNotificationProvider* self, DinoEntitiesCall* call, DinoEntitiesConversation* conversation, gboolean video, gboolean multiparty, const gchar* conversation_display_name, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*notify_call_finish) (DinoNotificationProvider* self, GAsyncResult* _res_);
	void (*retract_call_notification) (DinoNotificationProvider* self, DinoEntitiesCall* call, DinoEntitiesConversation* conversation, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*retract_call_notification_finish) (DinoNotificationProvider* self, GAsyncResult* _res_);
	void (*notify_subscription_request) (DinoNotificationProvider* self, DinoEntitiesConversation* conversation, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*notify_subscription_request_finish) (DinoNotificationProvider* self, GAsyncResult* _res_);
	void (*notify_connection_error) (DinoNotificationProvider* self, DinoEntitiesAccount* account, DinoConnectionManagerConnectionError* _error_, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*notify_connection_error_finish) (DinoNotificationProvider* self, GAsyncResult* _res_);
	void (*notify_muc_invite) (DinoNotificationProvider* self, DinoEntitiesAccount* account, XmppJid* room_jid, XmppJid* from_jid, const gchar* inviter_display_name, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*notify_muc_invite_finish) (DinoNotificationProvider* self, GAsyncResult* _res_);
	void (*notify_voice_request) (DinoNotificationProvider* self, DinoEntitiesConversation* conversation, XmppJid* from_jid, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*notify_voice_request_finish) (DinoNotificationProvider* self, GAsyncResult* _res_);
	void (*retract_content_item_notifications) (DinoNotificationProvider* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*retract_content_item_notifications_finish) (DinoNotificationProvider* self, GAsyncResult* _res_);
	void (*retract_conversation_notifications) (DinoNotificationProvider* self, DinoEntitiesConversation* conversation, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*retract_conversation_notifications_finish) (DinoNotificationProvider* self, GAsyncResult* _res_);
};

struct _DinoPresenceManager {
	GObject parent_instance;
	DinoPresenceManagerPrivate * priv;
};

struct _DinoPresenceManagerClass {
	GObjectClass parent_class;
};

struct _DinoReplies {
	GObject parent_instance;
	DinoRepliesPrivate * priv;
};

struct _DinoRepliesClass {
	GObjectClass parent_class;
};

struct _DinoReactions {
	GObject parent_instance;
	DinoReactionsPrivate * priv;
};

struct _DinoReactionsClass {
	GObjectClass parent_class;
};

struct _DinoReactionUsers {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoReactionUsersPrivate * priv;
};

struct _DinoReactionUsersClass {
	GTypeClass parent_class;
	void (*finalize) (DinoReactionUsers *self);
};

struct _DinoReactionInfo {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoReactionInfoPrivate * priv;
};

struct _DinoReactionInfoClass {
	GTypeClass parent_class;
	void (*finalize) (DinoReactionInfo *self);
};

struct _DinoRegister {
	GObject parent_instance;
	DinoRegisterPrivate * priv;
};

struct _DinoRegisterClass {
	GObjectClass parent_class;
};

struct _DinoRegisterServerAvailabilityReturn {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoRegisterServerAvailabilityReturnPrivate * priv;
};

struct _DinoRegisterServerAvailabilityReturnClass {
	GTypeClass parent_class;
	void (*finalize) (DinoRegisterServerAvailabilityReturn *self);
};

struct _DinoRegisterRegistrationFormReturn {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoRegisterRegistrationFormReturnPrivate * priv;
};

struct _DinoRegisterRegistrationFormReturnClass {
	GTypeClass parent_class;
	void (*finalize) (DinoRegisterRegistrationFormReturn *self);
};

struct _DinoRosterManager {
	GObject parent_instance;
	DinoRosterManagerPrivate * priv;
};

struct _DinoRosterManagerClass {
	GObjectClass parent_class;
};

struct _DinoRosterStoreImpl {
	GObject parent_instance;
	DinoRosterStoreImplPrivate * priv;
};

struct _DinoRosterStoreImplClass {
	GObjectClass parent_class;
};

struct _DinoSearchProcessor {
	GObject parent_instance;
	DinoSearchProcessorPrivate * priv;
};

struct _DinoSearchProcessorClass {
	GObjectClass parent_class;
};

struct _DinoSearchSuggestion {
	GObject parent_instance;
	DinoSearchSuggestionPrivate * priv;
};

struct _DinoSearchSuggestionClass {
	GObjectClass parent_class;
};

struct _DinoImageFileMetadataProvider {
	GObject parent_instance;
	DinoImageFileMetadataProviderPrivate * priv;
};

struct _DinoImageFileMetadataProviderClass {
	GObjectClass parent_class;
};

struct _DinoStatelessFileSharing {
	GObject parent_instance;
	DinoStatelessFileSharingPrivate * priv;
};

struct _DinoStatelessFileSharingClass {
	GObjectClass parent_class;
};

struct _DinoStreamInteractor {
	GObject parent_instance;
	DinoStreamInteractorPrivate * priv;
	DinoModuleManager* module_manager;
	DinoConnectionManager* connection_manager;
};

struct _DinoStreamInteractorClass {
	GObjectClass parent_class;
};

struct _DinoModuleIdentity {
	GObject parent_instance;
	DinoModuleIdentityPrivate * priv;
};

struct _DinoModuleIdentityClass {
	GObjectClass parent_class;
};

struct _DinoUtil {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoUtilPrivate * priv;
};

struct _DinoUtilClass {
	GTypeClass parent_class;
	void (*finalize) (DinoUtil *self);
};

struct _DinoLimitInputStream {
	GInputStream parent_instance;
	DinoLimitInputStreamPrivate * priv;
};

struct _DinoLimitInputStreamClass {
	GInputStreamClass parent_class;
};

struct _DinoSearchPathGenerator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoSearchPathGeneratorPrivate * priv;
};

struct _DinoSearchPathGeneratorClass {
	GTypeClass parent_class;
	void (*finalize) (DinoSearchPathGenerator *self);
};

struct _WeakMap {
	GeeAbstractMap parent_instance;
	WeakMapPrivate * priv;
	GeeHashDataFunc key_hash_func;
	gpointer key_hash_func_target;
	GDestroyNotify key_hash_func_target_destroy_notify;
	GeeEqualDataFunc key_equal_func;
	gpointer key_equal_func_target;
	GDestroyNotify key_equal_func_target_destroy_notify;
	GeeEqualDataFunc value_equal_func;
	gpointer value_equal_func_target;
	GDestroyNotify value_equal_func_target_destroy_notify;
};

struct _WeakMapClass {
	GeeAbstractMapClass parent_class;
};

struct _DinoWeakTimeout {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoWeakTimeoutPrivate * priv;
};

struct _DinoWeakTimeoutClass {
	GTypeClass parent_class;
	void (*finalize) (DinoWeakTimeout *self);
};

VALA_EXTERN gchar* dino_get_version (void);
VALA_EXTERN gchar* dino_get_short_version (void);
VALA_EXTERN GType dino_database_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabase, qlite_database_unref)
VALA_EXTERN GType dino_entities_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoEntitiesSettings, g_object_unref)
VALA_EXTERN GType dino_stream_interactor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoStreamInteractor, g_object_unref)
VALA_EXTERN gpointer dino_plugins_registry_ref (gpointer instance);
VALA_EXTERN void dino_plugins_registry_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_plugins_param_spec_registry (const gchar* name,
                                              const gchar* nick,
                                              const gchar* blurb,
                                              GType object_type,
                                              GParamFlags flags);
VALA_EXTERN void dino_plugins_value_set_registry (GValue* value,
                                      gpointer v_object);
VALA_EXTERN void dino_plugins_value_take_registry (GValue* value,
                                       gpointer v_object);
VALA_EXTERN gpointer dino_plugins_value_get_registry (const GValue* value);
VALA_EXTERN GType dino_plugins_registry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsRegistry, dino_plugins_registry_unref)
VALA_EXTERN gpointer dino_search_path_generator_ref (gpointer instance);
VALA_EXTERN void dino_search_path_generator_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_search_path_generator (const gchar* name,
                                                   const gchar* nick,
                                                   const gchar* blurb,
                                                   GType object_type,
                                                   GParamFlags flags);
VALA_EXTERN void dino_value_set_search_path_generator (GValue* value,
                                           gpointer v_object);
VALA_EXTERN void dino_value_take_search_path_generator (GValue* value,
                                            gpointer v_object);
VALA_EXTERN gpointer dino_value_get_search_path_generator (const GValue* value);
VALA_EXTERN GType dino_search_path_generator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoSearchPathGenerator, dino_search_path_generator_unref)
VALA_EXTERN GType dino_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoApplication, g_object_unref)
VALA_EXTERN void dino_application_handle_uri (DinoApplication* self,
                                  const gchar* jid,
                                  const gchar* query,
                                  GeeMap* options);
VALA_EXTERN void dino_application_init (DinoApplication* self,
                            GError** error);
VALA_EXTERN gchar* dino_application_get_storage_dir (void);
VALA_EXTERN DinoApplication* dino_application_get_default (void);
VALA_EXTERN void dino_application_create_actions (DinoApplication* self);
VALA_EXTERN GType dino_entities_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoEntitiesAccount, g_object_unref)
VALA_EXTERN void dino_application_add_connection (DinoApplication* self,
                                      DinoEntitiesAccount* account);
VALA_EXTERN void dino_application_remove_connection (DinoApplication* self,
                                         DinoEntitiesAccount* account);
VALA_EXTERN DinoDatabase* dino_application_get_db (DinoApplication* self);
VALA_EXTERN void dino_application_set_db (DinoApplication* self,
                              DinoDatabase* value);
VALA_EXTERN DinoEntitiesSettings* dino_application_get_settings (DinoApplication* self);
VALA_EXTERN void dino_application_set_settings (DinoApplication* self,
                                    DinoEntitiesSettings* value);
VALA_EXTERN DinoStreamInteractor* dino_application_get_stream_interactor (DinoApplication* self);
VALA_EXTERN void dino_application_set_stream_interactor (DinoApplication* self,
                                             DinoStreamInteractor* value);
VALA_EXTERN DinoPluginsRegistry* dino_application_get_plugin_registry (DinoApplication* self);
VALA_EXTERN void dino_application_set_plugin_registry (DinoApplication* self,
                                           DinoPluginsRegistry* value);
VALA_EXTERN DinoSearchPathGenerator* dino_application_get_search_path_generator (DinoApplication* self);
VALA_EXTERN void dino_application_set_search_path_generator (DinoApplication* self,
                                                 DinoSearchPathGenerator* value);
VALA_EXTERN GType dino_login1_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoLogin1Manager, g_object_unref)
VALA_EXTERN GType dino_login1_manager_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint dino_login1_manager_register_object (void* object,
                                           GDBusConnection* connection,
                                           const gchar* path,
                                           GError** error);
VALA_EXTERN void dino_get_login1 (GAsyncReadyCallback _callback_,
                      gpointer _user_data_);
VALA_EXTERN DinoLogin1Manager* dino_get_login1_finish (GAsyncResult* _res_);
VALA_EXTERN GType dino_dbus_notifications_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint dino_dbus_notifications_register_object (void* object,
                                               GDBusConnection* connection,
                                               const gchar* path,
                                               GError** error);
VALA_EXTERN GType dino_dbus_notifications_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDBusNotifications, g_object_unref)
VALA_EXTERN void dino_dbus_notifications_notify (DinoDBusNotifications* self,
                                     const gchar* app_name,
                                     guint32 replaces_id,
                                     const gchar* app_icon,
                                     const gchar* summary,
                                     const gchar* body,
                                     gchar** actions,
                                     gint actions_length1,
                                     GHashTable* hints,
                                     gint32 expire_timeout,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
VALA_EXTERN guint32 dino_dbus_notifications_notify_finish (DinoDBusNotifications* self,
                                               GAsyncResult* _res_,
                                               GError** error);
VALA_EXTERN void dino_dbus_notifications_get_capabilities (DinoDBusNotifications* self,
                                               GAsyncReadyCallback _callback_,
                                               gpointer _user_data_);
VALA_EXTERN void dino_dbus_notifications_get_capabilities_finish (DinoDBusNotifications* self,
                                                      GAsyncResult* _res_,
                                                      gchar*** capabilities,
                                                      gint* capabilities_length1,
                                                      GError** error);
VALA_EXTERN void dino_dbus_notifications_close_notification (DinoDBusNotifications* self,
                                                 guint id,
                                                 GAsyncReadyCallback _callback_,
                                                 gpointer _user_data_);
VALA_EXTERN void dino_dbus_notifications_close_notification_finish (DinoDBusNotifications* self,
                                                        GAsyncResult* _res_,
                                                        GError** error);
VALA_EXTERN void dino_dbus_notifications_get_server_information (DinoDBusNotifications* self,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN void dino_dbus_notifications_get_server_information_finish (DinoDBusNotifications* self,
                                                            GAsyncResult* _res_,
                                                            gchar** name,
                                                            gchar** vendor,
                                                            gchar** version,
                                                            gchar** spec_version,
                                                            GError** error);
VALA_EXTERN void dino_get_notifications_dbus (GAsyncReadyCallback _callback_,
                                  gpointer _user_data_);
VALA_EXTERN DinoDBusNotifications* dino_get_notifications_dbus_finish (GAsyncResult* _res_);
VALA_EXTERN GType dino_upower_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUPower, g_object_unref)
VALA_EXTERN GType dino_upower_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint dino_upower_register_object (void* object,
                                   GDBusConnection* connection,
                                   const gchar* path,
                                   GError** error);
VALA_EXTERN DinoUPower* dino_get_upower (void);
VALA_EXTERN DinoEntitiesAccount* dino_entities_account_new (XmppJid* bare_jid,
                                                const gchar* password);
VALA_EXTERN DinoEntitiesAccount* dino_entities_account_construct (GType object_type,
                                                      XmppJid* bare_jid,
                                                      const gchar* password);
VALA_EXTERN DinoEntitiesAccount* dino_entities_account_new_from_row (DinoDatabase* db,
                                                         QliteRow* row,
                                                         GError** error);
VALA_EXTERN DinoEntitiesAccount* dino_entities_account_construct_from_row (GType object_type,
                                                               DinoDatabase* db,
                                                               QliteRow* row,
                                                               GError** error);
VALA_EXTERN void dino_entities_account_persist (DinoEntitiesAccount* self,
                                    DinoDatabase* db);
VALA_EXTERN void dino_entities_account_remove (DinoEntitiesAccount* self);
VALA_EXTERN void dino_entities_account_set_random_resource (DinoEntitiesAccount* self);
VALA_EXTERN gboolean dino_entities_account_equals (DinoEntitiesAccount* self,
                                       DinoEntitiesAccount* acc);
VALA_EXTERN gboolean dino_entities_account_equals_func (DinoEntitiesAccount* acc1,
                                            DinoEntitiesAccount* acc2);
VALA_EXTERN guint dino_entities_account_hash_func (DinoEntitiesAccount* acc);
VALA_EXTERN gint dino_entities_account_get_id (DinoEntitiesAccount* self);
VALA_EXTERN void dino_entities_account_set_id (DinoEntitiesAccount* self,
                                   gint value);
VALA_EXTERN const gchar* dino_entities_account_get_localpart (DinoEntitiesAccount* self);
VALA_EXTERN const gchar* dino_entities_account_get_domainpart (DinoEntitiesAccount* self);
VALA_EXTERN const gchar* dino_entities_account_get_resourcepart (DinoEntitiesAccount* self);
VALA_EXTERN XmppJid* dino_entities_account_get_bare_jid (DinoEntitiesAccount* self);
VALA_EXTERN XmppJid* dino_entities_account_get_full_jid (DinoEntitiesAccount* self);
VALA_EXTERN const gchar* dino_entities_account_get_password (DinoEntitiesAccount* self);
VALA_EXTERN void dino_entities_account_set_password (DinoEntitiesAccount* self,
                                         const gchar* value);
VALA_EXTERN gchar* dino_entities_account_get_display_name (DinoEntitiesAccount* self);
VALA_EXTERN const gchar* dino_entities_account_get_alias (DinoEntitiesAccount* self);
VALA_EXTERN void dino_entities_account_set_alias (DinoEntitiesAccount* self,
                                      const gchar* value);
VALA_EXTERN gboolean dino_entities_account_get_enabled (DinoEntitiesAccount* self);
VALA_EXTERN void dino_entities_account_set_enabled (DinoEntitiesAccount* self,
                                        gboolean value);
VALA_EXTERN const gchar* dino_entities_account_get_roster_version (DinoEntitiesAccount* self);
VALA_EXTERN void dino_entities_account_set_roster_version (DinoEntitiesAccount* self,
                                               const gchar* value);
VALA_EXTERN GType dino_entities_call_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoEntitiesCall, g_object_unref)
VALA_EXTERN GType dino_entities_call_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN DinoEntitiesCall* dino_entities_call_new_from_row (DinoDatabase* db,
                                                   QliteRow* row,
                                                   GError** error);
VALA_EXTERN DinoEntitiesCall* dino_entities_call_construct_from_row (GType object_type,
                                                         DinoDatabase* db,
                                                         QliteRow* row,
                                                         GError** error);
VALA_EXTERN void dino_entities_call_persist (DinoEntitiesCall* self,
                                 DinoDatabase* db);
VALA_EXTERN void dino_entities_call_add_peer (DinoEntitiesCall* self,
                                  XmppJid* peer);
VALA_EXTERN gboolean dino_entities_call_equals (DinoEntitiesCall* self,
                                    DinoEntitiesCall* c);
VALA_EXTERN gboolean dino_entities_call_equals_func (DinoEntitiesCall* c1,
                                         DinoEntitiesCall* c2);
VALA_EXTERN guint dino_entities_call_hash_func (DinoEntitiesCall* call);
VALA_EXTERN DinoEntitiesCall* dino_entities_call_new (void);
VALA_EXTERN DinoEntitiesCall* dino_entities_call_construct (GType object_type);
VALA_EXTERN gint dino_entities_call_get_id (DinoEntitiesCall* self);
VALA_EXTERN void dino_entities_call_set_id (DinoEntitiesCall* self,
                                gint value);
VALA_EXTERN DinoEntitiesAccount* dino_entities_call_get_account (DinoEntitiesCall* self);
VALA_EXTERN void dino_entities_call_set_account (DinoEntitiesCall* self,
                                     DinoEntitiesAccount* value);
VALA_EXTERN XmppJid* dino_entities_call_get_counterpart (DinoEntitiesCall* self);
VALA_EXTERN void dino_entities_call_set_counterpart (DinoEntitiesCall* self,
                                         XmppJid* value);
VALA_EXTERN XmppJid* dino_entities_call_get_ourpart (DinoEntitiesCall* self);
VALA_EXTERN void dino_entities_call_set_ourpart (DinoEntitiesCall* self,
                                     XmppJid* value);
VALA_EXTERN XmppJid* dino_entities_call_get_proposer (DinoEntitiesCall* self);
VALA_EXTERN gboolean dino_entities_call_get_direction (DinoEntitiesCall* self);
VALA_EXTERN void dino_entities_call_set_direction (DinoEntitiesCall* self,
                                       gboolean value);
VALA_EXTERN GDateTime* dino_entities_call_get_time (DinoEntitiesCall* self);
VALA_EXTERN void dino_entities_call_set_time (DinoEntitiesCall* self,
                                  GDateTime* value);
VALA_EXTERN GDateTime* dino_entities_call_get_local_time (DinoEntitiesCall* self);
VALA_EXTERN void dino_entities_call_set_local_time (DinoEntitiesCall* self,
                                        GDateTime* value);
VALA_EXTERN GDateTime* dino_entities_call_get_end_time (DinoEntitiesCall* self);
VALA_EXTERN void dino_entities_call_set_end_time (DinoEntitiesCall* self,
                                      GDateTime* value);
VALA_EXTERN GType dino_entities_encryption_get_type (void) G_GNUC_CONST ;
VALA_EXTERN DinoEntitiesEncryption dino_entities_call_get_encryption (DinoEntitiesCall* self);
VALA_EXTERN void dino_entities_call_set_encryption (DinoEntitiesCall* self,
                                        DinoEntitiesEncryption value);
VALA_EXTERN DinoEntitiesCallState dino_entities_call_get_state (DinoEntitiesCall* self);
VALA_EXTERN void dino_entities_call_set_state (DinoEntitiesCall* self,
                                   DinoEntitiesCallState value);
VALA_EXTERN GType dino_entities_conversation_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoEntitiesConversation, g_object_unref)
VALA_EXTERN GType dino_entities_conversation_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gboolean dino_entities_conversation_type_is_muc_semantic (DinoEntitiesConversationType self);
VALA_EXTERN GType dino_entities_conversation_notify_setting_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType dino_entities_conversation_setting_get_type (void) G_GNUC_CONST ;
VALA_EXTERN DinoEntitiesConversation* dino_entities_conversation_new (XmppJid* jid,
                                                          DinoEntitiesAccount* account,
                                                          DinoEntitiesConversationType type);
VALA_EXTERN DinoEntitiesConversation* dino_entities_conversation_construct (GType object_type,
                                                                XmppJid* jid,
                                                                DinoEntitiesAccount* account,
                                                                DinoEntitiesConversationType type);
VALA_EXTERN DinoEntitiesConversation* dino_entities_conversation_new_from_row (DinoDatabase* db,
                                                                   QliteRow* row,
                                                                   GError** error);
VALA_EXTERN DinoEntitiesConversation* dino_entities_conversation_construct_from_row (GType object_type,
                                                                         DinoDatabase* db,
                                                                         QliteRow* row,
                                                                         GError** error);
VALA_EXTERN void dino_entities_conversation_persist (DinoEntitiesConversation* self,
                                         DinoDatabase* db);
VALA_EXTERN DinoEntitiesConversationNotifySetting dino_entities_conversation_get_notification_setting (DinoEntitiesConversation* self,
                                                                                           DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoEntitiesConversationNotifySetting dino_entities_conversation_get_notification_default_setting (DinoEntitiesConversation* self,
                                                                                                   DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoEntitiesConversationSetting dino_entities_conversation_get_send_typing_setting (DinoEntitiesConversation* self,
                                                                                    DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoEntitiesConversationSetting dino_entities_conversation_get_send_marker_setting (DinoEntitiesConversation* self,
                                                                                    DinoStreamInteractor* stream_interactor);
VALA_EXTERN gboolean dino_entities_conversation_equals (DinoEntitiesConversation* self,
                                            DinoEntitiesConversation* conversation);
VALA_EXTERN gboolean dino_entities_conversation_equals_func (DinoEntitiesConversation* conversation1,
                                                 DinoEntitiesConversation* conversation2);
VALA_EXTERN guint dino_entities_conversation_hash_func (DinoEntitiesConversation* conversation);
VALA_EXTERN gint dino_entities_conversation_get_id (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_id (DinoEntitiesConversation* self,
                                        gint value);
VALA_EXTERN DinoEntitiesConversationType dino_entities_conversation_get_type_ (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_type_ (DinoEntitiesConversation* self,
                                           DinoEntitiesConversationType value);
VALA_EXTERN DinoEntitiesAccount* dino_entities_conversation_get_account (DinoEntitiesConversation* self);
VALA_EXTERN XmppJid* dino_entities_conversation_get_counterpart (DinoEntitiesConversation* self);
VALA_EXTERN const gchar* dino_entities_conversation_get_nickname (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_nickname (DinoEntitiesConversation* self,
                                              const gchar* value);
VALA_EXTERN gboolean dino_entities_conversation_get_active (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_active (DinoEntitiesConversation* self,
                                            gboolean value);
VALA_EXTERN GDateTime* dino_entities_conversation_get_active_last_changed (DinoEntitiesConversation* self);
VALA_EXTERN GDateTime* dino_entities_conversation_get_last_active (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_last_active (DinoEntitiesConversation* self,
                                                 GDateTime* value);
VALA_EXTERN DinoEntitiesEncryption dino_entities_conversation_get_encryption (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_encryption (DinoEntitiesConversation* self,
                                                DinoEntitiesEncryption value);
VALA_EXTERN GType dino_entities_message_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoEntitiesMessage, g_object_unref)
VALA_EXTERN DinoEntitiesMessage* dino_entities_conversation_get_read_up_to (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_read_up_to (DinoEntitiesConversation* self,
                                                DinoEntitiesMessage* value);
VALA_EXTERN gint dino_entities_conversation_get_read_up_to_item (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_read_up_to_item (DinoEntitiesConversation* self,
                                                     gint value);
VALA_EXTERN DinoEntitiesConversationNotifySetting dino_entities_conversation_get_notify_setting (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_notify_setting (DinoEntitiesConversation* self,
                                                    DinoEntitiesConversationNotifySetting value);
VALA_EXTERN DinoEntitiesConversationSetting dino_entities_conversation_get_send_typing (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_send_typing (DinoEntitiesConversation* self,
                                                 DinoEntitiesConversationSetting value);
VALA_EXTERN DinoEntitiesConversationSetting dino_entities_conversation_get_send_marker (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_send_marker (DinoEntitiesConversation* self,
                                                 DinoEntitiesConversationSetting value);
VALA_EXTERN gint dino_entities_conversation_get_pinned (DinoEntitiesConversation* self);
VALA_EXTERN void dino_entities_conversation_set_pinned (DinoEntitiesConversation* self,
                                            gint value);
VALA_EXTERN gboolean dino_entities_encryption_is_some (DinoEntitiesEncryption self);
VALA_EXTERN GType dino_entities_file_transfer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoEntitiesFileTransfer, g_object_unref)
VALA_EXTERN GType dino_entities_file_transfer_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN DinoEntitiesFileTransfer* dino_entities_file_transfer_new_from_row (DinoDatabase* db,
                                                                    QliteRow* row,
                                                                    const gchar* storage_dir,
                                                                    GError** error);
VALA_EXTERN DinoEntitiesFileTransfer* dino_entities_file_transfer_construct_from_row (GType object_type,
                                                                          DinoDatabase* db,
                                                                          QliteRow* row,
                                                                          const gchar* storage_dir,
                                                                          GError** error);
VALA_EXTERN void dino_entities_file_transfer_persist (DinoEntitiesFileTransfer* self,
                                          DinoDatabase* db);
VALA_EXTERN void dino_entities_file_transfer_add_sfs_source (DinoEntitiesFileTransfer* self,
                                                 XmppXepStatelessFileSharingSource* source);
VALA_EXTERN GFile* dino_entities_file_transfer_get_file (DinoEntitiesFileTransfer* self);
VALA_EXTERN DinoEntitiesFileTransfer* dino_entities_file_transfer_new (void);
VALA_EXTERN DinoEntitiesFileTransfer* dino_entities_file_transfer_construct (GType object_type);
VALA_EXTERN gint dino_entities_file_transfer_get_id (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_id (DinoEntitiesFileTransfer* self,
                                         gint value);
VALA_EXTERN const gchar* dino_entities_file_transfer_get_file_sharing_id (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_file_sharing_id (DinoEntitiesFileTransfer* self,
                                                      const gchar* value);
VALA_EXTERN DinoEntitiesAccount* dino_entities_file_transfer_get_account (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_account (DinoEntitiesFileTransfer* self,
                                              DinoEntitiesAccount* value);
VALA_EXTERN XmppJid* dino_entities_file_transfer_get_counterpart (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_counterpart (DinoEntitiesFileTransfer* self,
                                                  XmppJid* value);
VALA_EXTERN XmppJid* dino_entities_file_transfer_get_ourpart (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_ourpart (DinoEntitiesFileTransfer* self,
                                              XmppJid* value);
VALA_EXTERN XmppJid* dino_entities_file_transfer_get_from (DinoEntitiesFileTransfer* self);
VALA_EXTERN XmppJid* dino_entities_file_transfer_get_to (DinoEntitiesFileTransfer* self);
VALA_EXTERN gboolean dino_entities_file_transfer_get_direction (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_direction (DinoEntitiesFileTransfer* self,
                                                gboolean value);
VALA_EXTERN GDateTime* dino_entities_file_transfer_get_time (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_time (DinoEntitiesFileTransfer* self,
                                           GDateTime* value);
VALA_EXTERN GDateTime* dino_entities_file_transfer_get_local_time (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_local_time (DinoEntitiesFileTransfer* self,
                                                 GDateTime* value);
VALA_EXTERN DinoEntitiesEncryption dino_entities_file_transfer_get_encryption (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_encryption (DinoEntitiesFileTransfer* self,
                                                 DinoEntitiesEncryption value);
VALA_EXTERN GInputStream* dino_entities_file_transfer_get_input_stream (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_input_stream (DinoEntitiesFileTransfer* self,
                                                   GInputStream* value);
VALA_EXTERN const gchar* dino_entities_file_transfer_get_file_name (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_file_name (DinoEntitiesFileTransfer* self,
                                                const gchar* value);
VALA_EXTERN const gchar* dino_entities_file_transfer_get_server_file_name (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_server_file_name (DinoEntitiesFileTransfer* self,
                                                       const gchar* value);
VALA_EXTERN const gchar* dino_entities_file_transfer_get_path (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_path (DinoEntitiesFileTransfer* self,
                                           const gchar* value);
VALA_EXTERN const gchar* dino_entities_file_transfer_get_mime_type (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_mime_type (DinoEntitiesFileTransfer* self,
                                                const gchar* value);
VALA_EXTERN gint64 dino_entities_file_transfer_get_size (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_size (DinoEntitiesFileTransfer* self,
                                           gint64 value);
VALA_EXTERN DinoEntitiesFileTransferState dino_entities_file_transfer_get_state (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_state (DinoEntitiesFileTransfer* self,
                                            DinoEntitiesFileTransferState value);
VALA_EXTERN gint dino_entities_file_transfer_get_provider (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_provider (DinoEntitiesFileTransfer* self,
                                               gint value);
VALA_EXTERN const gchar* dino_entities_file_transfer_get_info (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_info (DinoEntitiesFileTransfer* self,
                                           const gchar* value);
VALA_EXTERN GCancellable* dino_entities_file_transfer_get_cancellable (DinoEntitiesFileTransfer* self);
VALA_EXTERN gint64 dino_entities_file_transfer_get_transferred_bytes (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_transferred_bytes (DinoEntitiesFileTransfer* self,
                                                        gint64 value);
VALA_EXTERN XmppXepFileMetadataElementFileMetadata* dino_entities_file_transfer_get_file_metadata (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_file_metadata (DinoEntitiesFileTransfer* self,
                                                    XmppXepFileMetadataElementFileMetadata* value);
VALA_EXTERN const gchar* dino_entities_file_transfer_get_desc (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_desc (DinoEntitiesFileTransfer* self,
                                           const gchar* value);
VALA_EXTERN GDateTime* dino_entities_file_transfer_get_modification_date (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_modification_date (DinoEntitiesFileTransfer* self,
                                                        GDateTime* value);
VALA_EXTERN gint dino_entities_file_transfer_get_width (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_width (DinoEntitiesFileTransfer* self,
                                            gint value);
VALA_EXTERN gint dino_entities_file_transfer_get_height (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_height (DinoEntitiesFileTransfer* self,
                                             gint value);
VALA_EXTERN gint64 dino_entities_file_transfer_get_length (DinoEntitiesFileTransfer* self);
VALA_EXTERN void dino_entities_file_transfer_set_length (DinoEntitiesFileTransfer* self,
                                             gint64 value);
VALA_EXTERN GType dino_entities_message_marked_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType dino_entities_message_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gboolean dino_entities_message_type_is_muc_semantic (DinoEntitiesMessageType self);
VALA_EXTERN DinoEntitiesMessageMarked* dino_entities_message_MARKED_RECEIVED;
VALA_EXTERN gint dino_entities_message_MARKED_RECEIVED_length1;
VALA_EXTERN DinoEntitiesMessage* dino_entities_message_new (const gchar* body);
VALA_EXTERN DinoEntitiesMessage* dino_entities_message_construct (GType object_type,
                                                      const gchar* body);
VALA_EXTERN DinoEntitiesMessage* dino_entities_message_new_from_row (DinoDatabase* db,
                                                         QliteRow* row,
                                                         GError** error);
VALA_EXTERN DinoEntitiesMessage* dino_entities_message_construct_from_row (GType object_type,
                                                               DinoDatabase* db,
                                                               QliteRow* row,
                                                               GError** error);
VALA_EXTERN void dino_entities_message_persist (DinoEntitiesMessage* self,
                                    DinoDatabase* db);
VALA_EXTERN void dino_entities_message_set_quoted_item (DinoEntitiesMessage* self,
                                            gint quoted_content_item_id);
VALA_EXTERN GeeList* dino_entities_message_get_fallbacks (DinoEntitiesMessage* self);
VALA_EXTERN GeeList* dino_entities_message_get_markups (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_persist_markups (DinoEntitiesMessage* self,
                                            GeeList* markups,
                                            gint message_id);
VALA_EXTERN void dino_entities_message_set_fallbacks (DinoEntitiesMessage* self,
                                          GeeList* fallbacks);
VALA_EXTERN void dino_entities_message_set_type_string (DinoEntitiesMessage* self,
                                            const gchar* type);
VALA_EXTERN gchar* dino_entities_message_get_type_string (DinoEntitiesMessage* self);
VALA_EXTERN gboolean dino_entities_message_equals (DinoEntitiesMessage* self,
                                       DinoEntitiesMessage* m);
VALA_EXTERN gboolean dino_entities_message_equals_func (DinoEntitiesMessage* m1,
                                            DinoEntitiesMessage* m2);
VALA_EXTERN guint dino_entities_message_hash_func (DinoEntitiesMessage* message);
VALA_EXTERN gint dino_entities_message_get_id (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_id (DinoEntitiesMessage* self,
                                   gint value);
VALA_EXTERN DinoEntitiesAccount* dino_entities_message_get_account (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_account (DinoEntitiesMessage* self,
                                        DinoEntitiesAccount* value);
VALA_EXTERN XmppJid* dino_entities_message_get_counterpart (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_counterpart (DinoEntitiesMessage* self,
                                            XmppJid* value);
VALA_EXTERN XmppJid* dino_entities_message_get_ourpart (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_ourpart (DinoEntitiesMessage* self,
                                        XmppJid* value);
VALA_EXTERN XmppJid* dino_entities_message_get_from (DinoEntitiesMessage* self);
VALA_EXTERN XmppJid* dino_entities_message_get_to (DinoEntitiesMessage* self);
VALA_EXTERN gboolean dino_entities_message_get_direction (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_direction (DinoEntitiesMessage* self,
                                          gboolean value);
VALA_EXTERN XmppJid* dino_entities_message_get_real_jid (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_real_jid (DinoEntitiesMessage* self,
                                         XmppJid* value);
VALA_EXTERN DinoEntitiesMessageType dino_entities_message_get_type_ (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_type_ (DinoEntitiesMessage* self,
                                      DinoEntitiesMessageType value);
VALA_EXTERN const gchar* dino_entities_message_get_body (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_body (DinoEntitiesMessage* self,
                                     const gchar* value);
VALA_EXTERN const gchar* dino_entities_message_get_stanza_id (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_stanza_id (DinoEntitiesMessage* self,
                                          const gchar* value);
VALA_EXTERN const gchar* dino_entities_message_get_server_id (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_server_id (DinoEntitiesMessage* self,
                                          const gchar* value);
VALA_EXTERN GDateTime* dino_entities_message_get_time (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_time (DinoEntitiesMessage* self,
                                     GDateTime* value);
VALA_EXTERN GDateTime* dino_entities_message_get_local_time (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_local_time (DinoEntitiesMessage* self,
                                           GDateTime* value);
VALA_EXTERN DinoEntitiesEncryption dino_entities_message_get_encryption (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_encryption (DinoEntitiesMessage* self,
                                           DinoEntitiesEncryption value);
VALA_EXTERN DinoEntitiesMessageMarked dino_entities_message_get_marked (DinoEntitiesMessage* self);
VALA_EXTERN void dino_entities_message_set_marked (DinoEntitiesMessage* self,
                                       DinoEntitiesMessageMarked value);
VALA_EXTERN gint dino_entities_message_get_quoted_item_id (DinoEntitiesMessage* self);
VALA_EXTERN DinoEntitiesSettings* dino_entities_settings_new_from_db (DinoDatabase* db);
VALA_EXTERN DinoEntitiesSettings* dino_entities_settings_construct_from_db (GType object_type,
                                                                DinoDatabase* db);
VALA_EXTERN DinoEntitiesEncryption dino_entities_settings_get_default_encryption (DinoEntitiesSettings* self,
                                                                      DinoEntitiesAccount* account);
VALA_EXTERN void dino_entities_settings_set_default_encryption (DinoEntitiesSettings* self,
                                                    DinoEntitiesAccount* account,
                                                    DinoEntitiesEncryption encryption);
VALA_EXTERN DinoEntitiesSettings* dino_entities_settings_new (void);
VALA_EXTERN DinoEntitiesSettings* dino_entities_settings_construct (GType object_type);
VALA_EXTERN gboolean dino_entities_settings_get_send_typing (DinoEntitiesSettings* self);
VALA_EXTERN void dino_entities_settings_set_send_typing (DinoEntitiesSettings* self,
                                             gboolean value);
VALA_EXTERN gboolean dino_entities_settings_get_send_marker (DinoEntitiesSettings* self);
VALA_EXTERN void dino_entities_settings_set_send_marker (DinoEntitiesSettings* self,
                                             gboolean value);
VALA_EXTERN gboolean dino_entities_settings_get_notifications (DinoEntitiesSettings* self);
VALA_EXTERN void dino_entities_settings_set_notifications (DinoEntitiesSettings* self,
                                               gboolean value);
VALA_EXTERN gboolean dino_entities_settings_get_convert_utf8_smileys (DinoEntitiesSettings* self);
VALA_EXTERN void dino_entities_settings_set_convert_utf8_smileys (DinoEntitiesSettings* self,
                                                      gboolean value);
VALA_EXTERN gboolean dino_entities_settings_get_check_spelling (DinoEntitiesSettings* self);
VALA_EXTERN void dino_entities_settings_set_check_spelling (DinoEntitiesSettings* self,
                                                gboolean value);
VALA_EXTERN GType dino_plugins_priority_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType dino_plugins_widget_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType dino_plugins_root_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsRootInterface, g_object_unref)
VALA_EXTERN void dino_plugins_root_interface_registered (DinoPluginsRootInterface* self,
                                             DinoApplication* app);
VALA_EXTERN void dino_plugins_root_interface_shutdown (DinoPluginsRootInterface* self);
VALA_EXTERN GType dino_plugins_input_field_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsInputFieldStatus, g_object_unref)
VALA_EXTERN GType dino_content_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoContentItem, g_object_unref)
VALA_EXTERN GType dino_plugins_encryption_list_entry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsEncryptionListEntry, g_object_unref)
VALA_EXTERN void dino_plugins_encryption_list_entry_encryption_activated (DinoPluginsEncryptionListEntry* self,
                                                              DinoEntitiesConversation* conversation,
                                                              DinoPluginsSetInputFieldStatus callback,
                                                              gpointer callback_target);
VALA_EXTERN GObject* dino_plugins_encryption_list_entry_get_encryption_icon (DinoPluginsEncryptionListEntry* self,
                                                                 DinoEntitiesConversation* conversation,
                                                                 DinoContentItem* content_item);
VALA_EXTERN gchar* dino_plugins_encryption_list_entry_get_encryption_icon_name (DinoPluginsEncryptionListEntry* self,
                                                                    DinoEntitiesConversation* conversation,
                                                                    DinoContentItem* content_item);
VALA_EXTERN DinoEntitiesEncryption dino_plugins_encryption_list_entry_get_encryption (DinoPluginsEncryptionListEntry* self);
VALA_EXTERN const gchar* dino_plugins_encryption_list_entry_get_name (DinoPluginsEncryptionListEntry* self);
VALA_EXTERN GType dino_plugins_call_encryption_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsCallEncryptionWidget, g_object_unref)
VALA_EXTERN GType dino_plugins_call_encryption_entry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsCallEncryptionEntry, g_object_unref)
VALA_EXTERN DinoPluginsCallEncryptionWidget* dino_plugins_call_encryption_entry_get_widget (DinoPluginsCallEncryptionEntry* self,
                                                                                DinoEntitiesAccount* account,
                                                                                XmppXepJingleContentEncryption* encryption);
VALA_EXTERN gchar* dino_plugins_call_encryption_widget_get_title (DinoPluginsCallEncryptionWidget* self);
VALA_EXTERN gboolean dino_plugins_call_encryption_widget_show_keys (DinoPluginsCallEncryptionWidget* self);
VALA_EXTERN gchar* dino_plugins_call_encryption_widget_get_icon_name (DinoPluginsCallEncryptionWidget* self);
VALA_EXTERN GType dino_plugins_account_settings_entry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsAccountSettingsEntry, g_object_unref)
VALA_EXTERN void dino_plugins_account_settings_entry_deactivate (DinoPluginsAccountSettingsEntry* self);
VALA_EXTERN void dino_plugins_account_settings_entry_set_account (DinoPluginsAccountSettingsEntry* self,
                                                      DinoEntitiesAccount* account);
VALA_EXTERN GObject* dino_plugins_account_settings_entry_get_widget (DinoPluginsAccountSettingsEntry* self,
                                                         DinoPluginsWidgetType type);
VALA_EXTERN DinoPluginsAccountSettingsEntry* dino_plugins_account_settings_entry_construct (GType object_type);
VALA_EXTERN const gchar* dino_plugins_account_settings_entry_get_id (DinoPluginsAccountSettingsEntry* self);
VALA_EXTERN DinoPluginsPriority dino_plugins_account_settings_entry_get_priority (DinoPluginsAccountSettingsEntry* self);
VALA_EXTERN const gchar* dino_plugins_account_settings_entry_get_name (DinoPluginsAccountSettingsEntry* self);
VALA_EXTERN gint16 dino_plugins_account_settings_entry_get_label_top_padding (DinoPluginsAccountSettingsEntry* self);
VALA_EXTERN GType dino_plugins_encryption_preferences_entry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsEncryptionPreferencesEntry, g_object_unref)
VALA_EXTERN GObject* dino_plugins_encryption_preferences_entry_get_widget (DinoPluginsEncryptionPreferencesEntry* self,
                                                               DinoEntitiesAccount* account,
                                                               DinoPluginsWidgetType type);
VALA_EXTERN DinoPluginsEncryptionPreferencesEntry* dino_plugins_encryption_preferences_entry_construct (GType object_type);
VALA_EXTERN const gchar* dino_plugins_encryption_preferences_entry_get_id (DinoPluginsEncryptionPreferencesEntry* self);
VALA_EXTERN DinoPluginsPriority dino_plugins_encryption_preferences_entry_get_priority (DinoPluginsEncryptionPreferencesEntry* self);
VALA_EXTERN GType dino_plugins_contact_details_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsContactDetails, g_object_unref)
VALA_EXTERN GType dino_plugins_contact_details_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsContactDetailsProvider, g_object_unref)
VALA_EXTERN void dino_plugins_contact_details_provider_populate (DinoPluginsContactDetailsProvider* self,
                                                     DinoEntitiesConversation* conversation,
                                                     DinoPluginsContactDetails* contact_details,
                                                     DinoPluginsWidgetType type);
VALA_EXTERN GObject* dino_plugins_contact_details_provider_get_widget (DinoPluginsContactDetailsProvider* self,
                                                           DinoEntitiesConversation* conversation);
VALA_EXTERN const gchar* dino_plugins_contact_details_provider_get_id (DinoPluginsContactDetailsProvider* self);
VALA_EXTERN const gchar* dino_plugins_contact_details_provider_get_tab (DinoPluginsContactDetailsProvider* self);
VALA_EXTERN DinoPluginsContactDetails* dino_plugins_contact_details_new (void);
VALA_EXTERN DinoPluginsContactDetails* dino_plugins_contact_details_construct (GType object_type);
VALA_EXTERN GType dino_plugins_text_command_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsTextCommand, g_object_unref)
VALA_EXTERN gchar* dino_plugins_text_command_handle_command (DinoPluginsTextCommand* self,
                                                 const gchar* text,
                                                 DinoEntitiesConversation* conversation);
VALA_EXTERN const gchar* dino_plugins_text_command_get_cmd (DinoPluginsTextCommand* self);
VALA_EXTERN GType dino_plugins_conversation_titlebar_entry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsConversationTitlebarEntry, g_object_unref)
VALA_EXTERN GObject* dino_plugins_conversation_titlebar_entry_get_widget (DinoPluginsConversationTitlebarEntry* self,
                                                              DinoPluginsWidgetType type);
VALA_EXTERN void dino_plugins_conversation_titlebar_entry_set_conversation (DinoPluginsConversationTitlebarEntry* self,
                                                                DinoEntitiesConversation* conversation);
VALA_EXTERN void dino_plugins_conversation_titlebar_entry_unset_conversation (DinoPluginsConversationTitlebarEntry* self);
VALA_EXTERN const gchar* dino_plugins_conversation_titlebar_entry_get_id (DinoPluginsConversationTitlebarEntry* self);
VALA_EXTERN gdouble dino_plugins_conversation_titlebar_entry_get_order (DinoPluginsConversationTitlebarEntry* self);
VALA_EXTERN GType dino_plugins_meta_conversation_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsMetaConversationItem, g_object_unref)
VALA_EXTERN GType dino_plugins_conversation_item_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsConversationItemCollection, g_object_unref)
VALA_EXTERN GType dino_plugins_conversation_item_populator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsConversationItemPopulator, g_object_unref)
VALA_EXTERN void dino_plugins_conversation_item_populator_init (DinoPluginsConversationItemPopulator* self,
                                                    DinoEntitiesConversation* conversation,
                                                    DinoPluginsConversationItemCollection* summary,
                                                    DinoPluginsWidgetType type);
VALA_EXTERN void dino_plugins_conversation_item_populator_close (DinoPluginsConversationItemPopulator* self,
                                                     DinoEntitiesConversation* conversation);
VALA_EXTERN const gchar* dino_plugins_conversation_item_populator_get_id (DinoPluginsConversationItemPopulator* self);
VALA_EXTERN GType dino_plugins_conversation_addition_populator_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void dino_plugins_conversation_addition_populator_populate_timespan (DinoPluginsConversationAdditionPopulator* self,
                                                                     DinoEntitiesConversation* conversation,
                                                                     GDateTime* from,
                                                                     GDateTime* to);
VALA_EXTERN GType dino_plugins_media_device_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsMediaDevice, g_object_unref)
VALA_EXTERN GType dino_plugins_video_call_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsVideoCallWidget, g_object_unref)
VALA_EXTERN GType dino_plugins_video_call_plugin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsVideoCallPlugin, g_object_unref)
VALA_EXTERN gboolean dino_plugins_video_call_plugin_supported (DinoPluginsVideoCallPlugin* self);
VALA_EXTERN DinoPluginsVideoCallWidget* dino_plugins_video_call_plugin_create_widget (DinoPluginsVideoCallPlugin* self,
                                                                          DinoPluginsWidgetType type);
VALA_EXTERN GeeList* dino_plugins_video_call_plugin_get_devices (DinoPluginsVideoCallPlugin* self,
                                                     const gchar* media,
                                                     gboolean incoming);
VALA_EXTERN DinoPluginsMediaDevice* dino_plugins_video_call_plugin_get_preferred_device (DinoPluginsVideoCallPlugin* self,
                                                                             const gchar* media,
                                                                             gboolean incoming);
VALA_EXTERN DinoPluginsMediaDevice* dino_plugins_video_call_plugin_get_device (DinoPluginsVideoCallPlugin* self,
                                                                   XmppXepJingleRtpStream* stream,
                                                                   gboolean incoming);
VALA_EXTERN void dino_plugins_video_call_plugin_set_pause (DinoPluginsVideoCallPlugin* self,
                                               XmppXepJingleRtpStream* stream,
                                               gboolean pause);
VALA_EXTERN void dino_plugins_video_call_plugin_set_device (DinoPluginsVideoCallPlugin* self,
                                                XmppXepJingleRtpStream* stream,
                                                DinoPluginsMediaDevice* device);
VALA_EXTERN void dino_plugins_video_call_plugin_dump_dot (DinoPluginsVideoCallPlugin* self);
VALA_EXTERN void dino_plugins_video_call_widget_display_stream (DinoPluginsVideoCallWidget* self,
                                                    XmppXepJingleRtpStream* stream,
                                                    XmppJid* jid);
VALA_EXTERN void dino_plugins_video_call_widget_display_device (DinoPluginsVideoCallWidget* self,
                                                    DinoPluginsMediaDevice* device);
VALA_EXTERN void dino_plugins_video_call_widget_detach (DinoPluginsVideoCallWidget* self);
VALA_EXTERN gchar* dino_plugins_media_device_get_id (DinoPluginsMediaDevice* self);
VALA_EXTERN gchar* dino_plugins_media_device_get_display_name (DinoPluginsMediaDevice* self);
VALA_EXTERN gchar* dino_plugins_media_device_get_detail_name (DinoPluginsMediaDevice* self);
VALA_EXTERN gchar* dino_plugins_media_device_get_media (DinoPluginsMediaDevice* self);
VALA_EXTERN gboolean dino_plugins_media_device_get_incoming (DinoPluginsMediaDevice* self);
VALA_EXTERN GType dino_plugins_notification_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsNotificationCollection, g_object_unref)
VALA_EXTERN GType dino_plugins_notification_populator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsNotificationPopulator, g_object_unref)
VALA_EXTERN void dino_plugins_notification_populator_init (DinoPluginsNotificationPopulator* self,
                                               DinoEntitiesConversation* conversation,
                                               DinoPluginsNotificationCollection* summary,
                                               DinoPluginsWidgetType type);
VALA_EXTERN void dino_plugins_notification_populator_close (DinoPluginsNotificationPopulator* self,
                                                DinoEntitiesConversation* conversation);
VALA_EXTERN const gchar* dino_plugins_notification_populator_get_id (DinoPluginsNotificationPopulator* self);
VALA_EXTERN GType dino_plugins_conversation_item_widget_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsConversationItemWidgetInterface, g_object_unref)
VALA_EXTERN GType dino_plugins_message_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsMessageAction, g_object_unref)
VALA_EXTERN GObject* dino_plugins_meta_conversation_item_get_widget (DinoPluginsMetaConversationItem* self,
                                                         DinoPluginsConversationItemWidgetInterface* outer,
                                                         DinoPluginsWidgetType type);
VALA_EXTERN GeeList* dino_plugins_meta_conversation_item_get_item_actions (DinoPluginsMetaConversationItem* self,
                                                               DinoPluginsWidgetType type);
VALA_EXTERN DinoPluginsMetaConversationItem* dino_plugins_meta_conversation_item_construct (GType object_type);
VALA_EXTERN const gchar* dino_plugins_meta_conversation_item_get_populator_id (DinoPluginsMetaConversationItem* self);
VALA_EXTERN void dino_plugins_meta_conversation_item_set_populator_id (DinoPluginsMetaConversationItem* self,
                                                           const gchar* value);
VALA_EXTERN XmppJid* dino_plugins_meta_conversation_item_get_jid (DinoPluginsMetaConversationItem* self);
VALA_EXTERN void dino_plugins_meta_conversation_item_set_jid (DinoPluginsMetaConversationItem* self,
                                                  XmppJid* value);
VALA_EXTERN GDateTime* dino_plugins_meta_conversation_item_get_time (DinoPluginsMetaConversationItem* self);
VALA_EXTERN void dino_plugins_meta_conversation_item_set_time (DinoPluginsMetaConversationItem* self,
                                                   GDateTime* value);
VALA_EXTERN gint dino_plugins_meta_conversation_item_get_secondary_sort_indicator (DinoPluginsMetaConversationItem* self);
VALA_EXTERN void dino_plugins_meta_conversation_item_set_secondary_sort_indicator (DinoPluginsMetaConversationItem* self,
                                                                       gint value);
VALA_EXTERN DinoEntitiesEncryption dino_plugins_meta_conversation_item_get_encryption (DinoPluginsMetaConversationItem* self);
VALA_EXTERN void dino_plugins_meta_conversation_item_set_encryption (DinoPluginsMetaConversationItem* self,
                                                         DinoEntitiesEncryption value);
VALA_EXTERN DinoEntitiesMessageMarked dino_plugins_meta_conversation_item_get_mark (DinoPluginsMetaConversationItem* self);
VALA_EXTERN void dino_plugins_meta_conversation_item_set_mark (DinoPluginsMetaConversationItem* self,
                                                   DinoEntitiesMessageMarked value);
VALA_EXTERN gboolean dino_plugins_meta_conversation_item_get_can_merge (DinoPluginsMetaConversationItem* self);
VALA_EXTERN void dino_plugins_meta_conversation_item_set_can_merge (DinoPluginsMetaConversationItem* self,
                                                        gboolean value);
VALA_EXTERN gboolean dino_plugins_meta_conversation_item_get_requires_avatar (DinoPluginsMetaConversationItem* self);
VALA_EXTERN void dino_plugins_meta_conversation_item_set_requires_avatar (DinoPluginsMetaConversationItem* self,
                                                              gboolean value);
VALA_EXTERN gboolean dino_plugins_meta_conversation_item_get_requires_header (DinoPluginsMetaConversationItem* self);
VALA_EXTERN void dino_plugins_meta_conversation_item_set_requires_header (DinoPluginsMetaConversationItem* self,
                                                              gboolean value);
VALA_EXTERN gboolean dino_plugins_meta_conversation_item_get_in_edit_mode (DinoPluginsMetaConversationItem* self);
VALA_EXTERN void dino_plugins_meta_conversation_item_set_in_edit_mode (DinoPluginsMetaConversationItem* self,
                                                           gboolean value);
VALA_EXTERN void dino_plugins_conversation_item_widget_interface_set_widget (DinoPluginsConversationItemWidgetInterface* self,
                                                                 GObject* object,
                                                                 DinoPluginsWidgetType type,
                                                                 gint priority);
VALA_EXTERN DinoPluginsMessageAction* dino_plugins_message_action_new (void);
VALA_EXTERN DinoPluginsMessageAction* dino_plugins_message_action_construct (GType object_type);
VALA_EXTERN GType dino_plugins_meta_conversation_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsMetaConversationNotification, g_object_unref)
VALA_EXTERN GObject* dino_plugins_meta_conversation_notification_get_widget (DinoPluginsMetaConversationNotification* self,
                                                                 DinoPluginsWidgetType type);
VALA_EXTERN DinoPluginsMetaConversationNotification* dino_plugins_meta_conversation_notification_construct (GType object_type);
VALA_EXTERN void dino_plugins_conversation_item_collection_insert_item (DinoPluginsConversationItemCollection* self,
                                                            DinoPluginsMetaConversationItem* item);
VALA_EXTERN void dino_plugins_conversation_item_collection_remove_item (DinoPluginsConversationItemCollection* self,
                                                            DinoPluginsMetaConversationItem* item);
VALA_EXTERN GType dino_plugins_input_field_status_message_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType dino_plugins_input_field_status_input_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN DinoPluginsInputFieldStatus* dino_plugins_input_field_status_new (const gchar* message,
                                                                  DinoPluginsInputFieldStatusMessageType message_type,
                                                                  DinoPluginsInputFieldStatusInputState input_state,
                                                                  gboolean contains_markup);
VALA_EXTERN DinoPluginsInputFieldStatus* dino_plugins_input_field_status_construct (GType object_type,
                                                                        const gchar* message,
                                                                        DinoPluginsInputFieldStatusMessageType message_type,
                                                                        DinoPluginsInputFieldStatusInputState input_state,
                                                                        gboolean contains_markup);
VALA_EXTERN GType dino_plugins_loader_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPluginsLoader, g_object_unref)
VALA_EXTERN DinoPluginsLoader* dino_plugins_loader_new (DinoApplication* app);
VALA_EXTERN DinoPluginsLoader* dino_plugins_loader_construct (GType object_type,
                                                  DinoApplication* app);
VALA_EXTERN void dino_plugins_loader_load_all (DinoPluginsLoader* self,
                                   GError** error);
VALA_EXTERN DinoPluginsRootInterface* dino_plugins_loader_load (DinoPluginsLoader* self,
                                                    const gchar* name,
                                                    GError** error);
VALA_EXTERN void dino_plugins_loader_shutdown (DinoPluginsLoader* self);
VALA_EXTERN gboolean dino_plugins_registry_register_encryption_list_entry (DinoPluginsRegistry* self,
                                                               DinoPluginsEncryptionListEntry* entry);
VALA_EXTERN gboolean dino_plugins_registry_register_call_entryption_entry (DinoPluginsRegistry* self,
                                                               const gchar* ns,
                                                               DinoPluginsCallEncryptionEntry* entry);
VALA_EXTERN gboolean dino_plugins_registry_register_account_settings_entry (DinoPluginsRegistry* self,
                                                                DinoPluginsAccountSettingsEntry* entry);
VALA_EXTERN gboolean dino_plugins_registry_register_encryption_preferences_entry (DinoPluginsRegistry* self,
                                                                      DinoPluginsEncryptionPreferencesEntry* entry);
VALA_EXTERN gboolean dino_plugins_registry_register_contact_details_entry (DinoPluginsRegistry* self,
                                                               DinoPluginsContactDetailsProvider* entry);
VALA_EXTERN gboolean dino_plugins_registry_register_text_command (DinoPluginsRegistry* self,
                                                      DinoPluginsTextCommand* cmd);
VALA_EXTERN gboolean dino_plugins_registry_register_contact_titlebar_entry (DinoPluginsRegistry* self,
                                                                DinoPluginsConversationTitlebarEntry* entry);
VALA_EXTERN gboolean dino_plugins_registry_register_conversation_addition_populator (DinoPluginsRegistry* self,
                                                                         DinoPluginsConversationAdditionPopulator* populator);
VALA_EXTERN gboolean dino_plugins_registry_register_notification_populator (DinoPluginsRegistry* self,
                                                                DinoPluginsNotificationPopulator* populator);
VALA_EXTERN DinoPluginsRegistry* dino_plugins_registry_new (void);
VALA_EXTERN DinoPluginsRegistry* dino_plugins_registry_construct (GType object_type);
VALA_EXTERN GType dino_stream_interaction_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoStreamInteractionModule, g_object_unref)
VALA_EXTERN GType dino_avatar_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoAvatarManager, g_object_unref)
VALA_EXTERN GType dino_module_identity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoModuleIdentity, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_avatar_manager_IDENTITY;
VALA_EXTERN void dino_avatar_manager_start (DinoStreamInteractor* stream_interactor,
                                DinoDatabase* db);
VALA_EXTERN GFile* dino_avatar_manager_get_avatar_file (DinoAvatarManager* self,
                                            DinoEntitiesAccount* account,
                                            XmppJid* jid_);
VALA_EXTERN gboolean dino_avatar_manager_has_avatar_cached (DinoAvatarManager* self,
                                                DinoEntitiesAccount* account,
                                                XmppJid* jid) G_GNUC_DEPRECATED ;
VALA_EXTERN gboolean dino_avatar_manager_has_avatar (DinoAvatarManager* self,
                                         DinoEntitiesAccount* account,
                                         XmppJid* jid);
VALA_EXTERN GdkPixbuf* dino_avatar_manager_get_cached_avatar (DinoAvatarManager* self,
                                                  DinoEntitiesAccount* account,
                                                  XmppJid* jid_) G_GNUC_DEPRECATED ;
VALA_EXTERN void dino_avatar_manager_get_avatar (DinoAvatarManager* self,
                                     DinoEntitiesAccount* account,
                                     XmppJid* jid_,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_) G_GNUC_DEPRECATED ;
VALA_EXTERN GdkPixbuf* dino_avatar_manager_get_avatar_finish (DinoAvatarManager* self,
                                                  GAsyncResult* _res_) G_GNUC_DEPRECATED ;
VALA_EXTERN void dino_avatar_manager_publish (DinoAvatarManager* self,
                                  DinoEntitiesAccount* account,
                                  const gchar* file);
VALA_EXTERN void dino_avatar_manager_unset_avatar (DinoAvatarManager* self,
                                       DinoEntitiesAccount* account);
VALA_EXTERN void dino_avatar_manager_set_avatar_hash (DinoAvatarManager* self,
                                          DinoEntitiesAccount* account,
                                          XmppJid* jid,
                                          const gchar* hash,
                                          gint type);
VALA_EXTERN void dino_avatar_manager_remove_avatar_hash (DinoAvatarManager* self,
                                             DinoEntitiesAccount* account,
                                             XmppJid* jid,
                                             gint type);
VALA_EXTERN GeeHashMap* dino_avatar_manager_get_avatar_hashes (DinoAvatarManager* self,
                                                   DinoEntitiesAccount* account,
                                                   gint type);
VALA_EXTERN void dino_avatar_manager_fetch_and_store_for_jid (DinoAvatarManager* self,
                                                  DinoEntitiesAccount* account,
                                                  XmppJid* jid,
                                                  GAsyncReadyCallback _callback_,
                                                  gpointer _user_data_);
VALA_EXTERN gboolean dino_avatar_manager_fetch_and_store_for_jid_finish (DinoAvatarManager* self,
                                                             GAsyncResult* _res_);
VALA_EXTERN gboolean dino_avatar_manager_has_image (DinoAvatarManager* self,
                                        const gchar* id);
VALA_EXTERN void dino_avatar_manager_get_image (DinoAvatarManager* self,
                                    const gchar* id,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN GdkPixbuf* dino_avatar_manager_get_image_finish (DinoAvatarManager* self,
                                                 GAsyncResult* _res_);
VALA_EXTERN GType dino_blocking_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoBlockingManager, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_blocking_manager_IDENTITY;
VALA_EXTERN void dino_blocking_manager_start (DinoStreamInteractor* stream_interactor);
VALA_EXTERN gboolean dino_blocking_manager_is_blocked (DinoBlockingManager* self,
                                           DinoEntitiesAccount* account,
                                           XmppJid* jid);
VALA_EXTERN void dino_blocking_manager_block (DinoBlockingManager* self,
                                  DinoEntitiesAccount* account,
                                  XmppJid* jid);
VALA_EXTERN void dino_blocking_manager_unblock (DinoBlockingManager* self,
                                    DinoEntitiesAccount* account,
                                    XmppJid* jid);
VALA_EXTERN gboolean dino_blocking_manager_is_supported (DinoBlockingManager* self,
                                             DinoEntitiesAccount* account);
VALA_EXTERN GType dino_call_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoCallStore, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_call_store_IDENTITY;
VALA_EXTERN void dino_call_store_start (DinoStreamInteractor* stream_interactor,
                            DinoDatabase* db);
VALA_EXTERN void dino_call_store_add_call (DinoCallStore* self,
                               DinoEntitiesCall* call,
                               DinoEntitiesConversation* conversation);
VALA_EXTERN DinoEntitiesCall* dino_call_store_get_call_by_id (DinoCallStore* self,
                                                  gint id,
                                                  DinoEntitiesConversation* conversation);
VALA_EXTERN GType dino_call_state_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoCallState, g_object_unref)
VALA_EXTERN GType dino_peer_state_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPeerState, g_object_unref)
VALA_EXTERN DinoCallState* dino_call_state_new (DinoEntitiesCall* call,
                                    DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoCallState* dino_call_state_construct (GType object_type,
                                          DinoEntitiesCall* call,
                                          DinoStreamInteractor* stream_interactor);
VALA_EXTERN void dino_call_state_accept (DinoCallState* self);
VALA_EXTERN void dino_call_state_reject (DinoCallState* self);
VALA_EXTERN void dino_call_state_end (DinoCallState* self,
                          const gchar* reason_text);
VALA_EXTERN void dino_call_state_mute_own_audio (DinoCallState* self,
                                     gboolean mute);
VALA_EXTERN void dino_call_state_mute_own_video (DinoCallState* self,
                                     gboolean mute);
VALA_EXTERN gboolean dino_call_state_should_we_send_video (DinoCallState* self);
VALA_EXTERN void dino_call_state_invite_to_call (DinoCallState* self,
                                     XmppJid* invitee,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
VALA_EXTERN void dino_call_state_invite_to_call_finish (DinoCallState* self,
                                            GAsyncResult* _res_);
VALA_EXTERN DinoPluginsMediaDevice* dino_call_state_get_microphone_device (DinoCallState* self);
VALA_EXTERN DinoPluginsMediaDevice* dino_call_state_get_speaker_device (DinoCallState* self);
VALA_EXTERN DinoPluginsMediaDevice* dino_call_state_get_video_device (DinoCallState* self);
VALA_EXTERN void dino_call_state_set_audio_device (DinoCallState* self,
                                       DinoPluginsMediaDevice* device);
VALA_EXTERN void dino_call_state_set_video_device (DinoCallState* self,
                                       DinoPluginsMediaDevice* device);
VALA_EXTERN void dino_call_state_can_convert_into_groupcall (DinoCallState* self,
                                                 GAsyncReadyCallback _callback_,
                                                 gpointer _user_data_);
VALA_EXTERN gboolean dino_call_state_can_convert_into_groupcall_finish (DinoCallState* self,
                                                            GAsyncResult* _res_);
VALA_EXTERN void dino_call_state_convert_into_group_call (DinoCallState* self,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
VALA_EXTERN void dino_call_state_convert_into_group_call_finish (DinoCallState* self,
                                                     GAsyncResult* _res_);
VALA_EXTERN void dino_call_state_join_group_call (DinoCallState* self,
                                      XmppJid* muc_jid,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN void dino_call_state_join_group_call_finish (DinoCallState* self,
                                             GAsyncResult* _res_);
VALA_EXTERN XmppJid* dino_call_state_get_parent_muc (DinoCallState* self);
VALA_EXTERN void dino_call_state_set_parent_muc (DinoCallState* self,
                                     XmppJid* value);
VALA_EXTERN gboolean dino_call_state_get_accepted (DinoCallState* self);
VALA_EXTERN const gchar* dino_call_state_get_cim_message_type (DinoCallState* self);
VALA_EXTERN void dino_call_state_set_cim_message_type (DinoCallState* self,
                                           const gchar* value);
VALA_EXTERN XmppXepMujiGroupCall* dino_call_state_get_group_call (DinoCallState* self);
VALA_EXTERN void dino_call_state_set_group_call (DinoCallState* self,
                                     XmppXepMujiGroupCall* value);
VALA_EXTERN gboolean dino_call_state_get_we_should_send_audio (DinoCallState* self);
VALA_EXTERN void dino_call_state_set_we_should_send_audio (DinoCallState* self,
                                               gboolean value);
VALA_EXTERN gboolean dino_call_state_get_we_should_send_video (DinoCallState* self);
VALA_EXTERN void dino_call_state_set_we_should_send_video (DinoCallState* self,
                                               gboolean value);
VALA_EXTERN GType dino_calls_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoCalls, g_object_unref)
VALA_EXTERN DinoPeerState* dino_peer_state_new (XmppJid* jid,
                                    DinoEntitiesCall* call,
                                    DinoCallState* call_state,
                                    DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoPeerState* dino_peer_state_construct (GType object_type,
                                          XmppJid* jid,
                                          DinoEntitiesCall* call,
                                          DinoCallState* call_state,
                                          DinoStreamInteractor* stream_interactor);
VALA_EXTERN void dino_peer_state_initiate_call (DinoPeerState* self,
                                    XmppJid* counterpart,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN void dino_peer_state_initiate_call_finish (DinoPeerState* self,
                                           GAsyncResult* _res_);
VALA_EXTERN void dino_peer_state_call_resource (DinoPeerState* self,
                                    XmppJid* full_jid,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN void dino_peer_state_call_resource_finish (DinoPeerState* self,
                                           GAsyncResult* _res_);
VALA_EXTERN void dino_peer_state_accept (DinoPeerState* self);
VALA_EXTERN void dino_peer_state_reject (DinoPeerState* self);
VALA_EXTERN void dino_peer_state_end (DinoPeerState* self,
                          const gchar* terminate_reason,
                          const gchar* reason_text);
VALA_EXTERN XmppXepJingleRtpStream* dino_peer_state_get_video_stream (DinoPeerState* self);
VALA_EXTERN XmppXepJingleRtpStream* dino_peer_state_get_audio_stream (DinoPeerState* self);
VALA_EXTERN gpointer dino_peer_info_ref (gpointer instance);
VALA_EXTERN void dino_peer_info_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_peer_info (const gchar* name,
                                       const gchar* nick,
                                       const gchar* blurb,
                                       GType object_type,
                                       GParamFlags flags);
VALA_EXTERN void dino_value_set_peer_info (GValue* value,
                               gpointer v_object);
VALA_EXTERN void dino_value_take_peer_info (GValue* value,
                                gpointer v_object);
VALA_EXTERN gpointer dino_value_get_peer_info (const GValue* value);
VALA_EXTERN GType dino_peer_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPeerInfo, dino_peer_info_unref)
VALA_EXTERN DinoPeerInfo* dino_peer_state_get_info (DinoPeerState* self);
VALA_EXTERN XmppXepMujiGroupCall* dino_peer_state_get_group_call (DinoPeerState* self);
VALA_EXTERN void dino_peer_state_set_group_call (DinoPeerState* self,
                                     XmppXepMujiGroupCall* value);
VALA_EXTERN gboolean dino_peer_state_get_we_should_send_audio (DinoPeerState* self);
VALA_EXTERN void dino_peer_state_set_we_should_send_audio (DinoPeerState* self,
                                               gboolean value);
VALA_EXTERN gboolean dino_peer_state_get_we_should_send_video (DinoPeerState* self);
VALA_EXTERN void dino_peer_state_set_we_should_send_video (DinoPeerState* self,
                                               gboolean value);
VALA_EXTERN gpointer dino_peer_content_info_ref (gpointer instance);
VALA_EXTERN void dino_peer_content_info_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_peer_content_info (const gchar* name,
                                               const gchar* nick,
                                               const gchar* blurb,
                                               GType object_type,
                                               GParamFlags flags);
VALA_EXTERN void dino_value_set_peer_content_info (GValue* value,
                                       gpointer v_object);
VALA_EXTERN void dino_value_take_peer_content_info (GValue* value,
                                        gpointer v_object);
VALA_EXTERN gpointer dino_value_get_peer_content_info (const GValue* value);
VALA_EXTERN GType dino_peer_content_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPeerContentInfo, dino_peer_content_info_unref)
VALA_EXTERN DinoPeerContentInfo* dino_peer_content_info_new (void);
VALA_EXTERN DinoPeerContentInfo* dino_peer_content_info_construct (GType object_type);
VALA_EXTERN gboolean dino_peer_content_info_get_rtp_ready (DinoPeerContentInfo* self);
VALA_EXTERN void dino_peer_content_info_set_rtp_ready (DinoPeerContentInfo* self,
                                           gboolean value);
VALA_EXTERN gboolean dino_peer_content_info_get_rtcp_ready (DinoPeerContentInfo* self);
VALA_EXTERN void dino_peer_content_info_set_rtcp_ready (DinoPeerContentInfo* self,
                                            gboolean value);
VALA_EXTERN gulong* dino_peer_content_info_get_bytes_sent (DinoPeerContentInfo* self);
VALA_EXTERN void dino_peer_content_info_set_bytes_sent (DinoPeerContentInfo* self,
                                            gulong* value);
VALA_EXTERN gulong* dino_peer_content_info_get_bytes_received (DinoPeerContentInfo* self);
VALA_EXTERN void dino_peer_content_info_set_bytes_received (DinoPeerContentInfo* self,
                                                gulong* value);
VALA_EXTERN const gchar* dino_peer_content_info_get_codec (DinoPeerContentInfo* self);
VALA_EXTERN void dino_peer_content_info_set_codec (DinoPeerContentInfo* self,
                                       const gchar* value);
VALA_EXTERN guint32 dino_peer_content_info_get_clockrate (DinoPeerContentInfo* self);
VALA_EXTERN void dino_peer_content_info_set_clockrate (DinoPeerContentInfo* self,
                                           guint32 value);
VALA_EXTERN guint dino_peer_content_info_get_target_receive_bytes (DinoPeerContentInfo* self);
VALA_EXTERN void dino_peer_content_info_set_target_receive_bytes (DinoPeerContentInfo* self,
                                                      guint value);
VALA_EXTERN guint dino_peer_content_info_get_target_send_bytes (DinoPeerContentInfo* self);
VALA_EXTERN void dino_peer_content_info_set_target_send_bytes (DinoPeerContentInfo* self,
                                                   guint value);
VALA_EXTERN DinoPeerInfo* dino_peer_info_new (void);
VALA_EXTERN DinoPeerInfo* dino_peer_info_construct (GType object_type);
VALA_EXTERN DinoModuleIdentity* dino_calls_IDENTITY;
VALA_EXTERN void dino_calls_start (DinoStreamInteractor* stream_interactor,
                       DinoDatabase* db);
VALA_EXTERN void dino_calls_initiate_call (DinoCalls* self,
                               DinoEntitiesConversation* conversation,
                               gboolean video,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
VALA_EXTERN DinoCallState* dino_calls_initiate_call_finish (DinoCalls* self,
                                                GAsyncResult* _res_);
VALA_EXTERN gboolean dino_calls_can_we_do_calls (DinoCalls* self,
                                     DinoEntitiesAccount* account);
VALA_EXTERN void dino_calls_can_conversation_do_calls (DinoCalls* self,
                                           DinoEntitiesConversation* conversation,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
VALA_EXTERN gboolean dino_calls_can_conversation_do_calls_finish (DinoCalls* self,
                                                      GAsyncResult* _res_);
VALA_EXTERN gboolean dino_calls_can_initiate_groupcall (DinoCalls* self,
                                            DinoEntitiesAccount* account);
VALA_EXTERN void dino_calls_get_call_resources (DinoCalls* self,
                                    DinoEntitiesAccount* account,
                                    XmppJid* counterpart,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN GeeList* dino_calls_get_call_resources_finish (DinoCalls* self,
                                               GAsyncResult* _res_);
VALA_EXTERN void dino_calls_contains_jmi_resources (DinoCalls* self,
                                        DinoEntitiesAccount* account,
                                        GeeList* full_jids,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_);
VALA_EXTERN gboolean dino_calls_contains_jmi_resources_finish (DinoCalls* self,
                                                   GAsyncResult* _res_);
VALA_EXTERN gboolean dino_calls_has_jmi_resources (DinoCalls* self,
                                       XmppJid* counterpart);
VALA_EXTERN gboolean dino_calls_is_call_in_progress (DinoCalls* self);
VALA_EXTERN GType dino_chat_interaction_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoChatInteraction, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_chat_interaction_IDENTITY;
VALA_EXTERN void dino_chat_interaction_start (DinoStreamInteractor* stream_interactor);
VALA_EXTERN gint dino_chat_interaction_get_num_unread (DinoChatInteraction* self,
                                           DinoEntitiesConversation* conversation);
VALA_EXTERN gboolean dino_chat_interaction_is_active_focus (DinoChatInteraction* self,
                                                DinoEntitiesConversation* conversation);
VALA_EXTERN void dino_chat_interaction_on_window_focus_in (DinoChatInteraction* self,
                                               DinoEntitiesConversation* conversation);
VALA_EXTERN void dino_chat_interaction_on_window_focus_out (DinoChatInteraction* self,
                                                DinoEntitiesConversation* conversation);
VALA_EXTERN void dino_chat_interaction_on_message_entered (DinoChatInteraction* self,
                                               DinoEntitiesConversation* conversation);
VALA_EXTERN void dino_chat_interaction_on_message_cleared (DinoChatInteraction* self,
                                               DinoEntitiesConversation* conversation);
VALA_EXTERN void dino_chat_interaction_on_conversation_selected (DinoChatInteraction* self,
                                                     DinoEntitiesConversation* conversation);
VALA_EXTERN GType dino_connection_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoConnectionManager, g_object_unref)
VALA_EXTERN GType dino_connection_manager_connection_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gpointer dino_module_manager_ref (gpointer instance);
VALA_EXTERN void dino_module_manager_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_module_manager (const gchar* name,
                                            const gchar* nick,
                                            const gchar* blurb,
                                            GType object_type,
                                            GParamFlags flags);
VALA_EXTERN void dino_value_set_module_manager (GValue* value,
                                    gpointer v_object);
VALA_EXTERN void dino_value_take_module_manager (GValue* value,
                                     gpointer v_object);
VALA_EXTERN gpointer dino_value_get_module_manager (const GValue* value);
VALA_EXTERN GType dino_module_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoModuleManager, dino_module_manager_unref)
VALA_EXTERN DinoConnectionManager* dino_connection_manager_new (DinoModuleManager* module_manager);
VALA_EXTERN DinoConnectionManager* dino_connection_manager_construct (GType object_type,
                                                          DinoModuleManager* module_manager);
VALA_EXTERN XmppXmppStream* dino_connection_manager_get_stream (DinoConnectionManager* self,
                                                    DinoEntitiesAccount* account);
VALA_EXTERN DinoConnectionManagerConnectionState dino_connection_manager_get_state (DinoConnectionManager* self,
                                                                        DinoEntitiesAccount* account);
VALA_EXTERN gpointer dino_connection_manager_connection_error_ref (gpointer instance);
VALA_EXTERN void dino_connection_manager_connection_error_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_connection_manager_param_spec_connection_error (const gchar* name,
                                                                 const gchar* nick,
                                                                 const gchar* blurb,
                                                                 GType object_type,
                                                                 GParamFlags flags);
VALA_EXTERN void dino_connection_manager_value_set_connection_error (GValue* value,
                                                         gpointer v_object);
VALA_EXTERN void dino_connection_manager_value_take_connection_error (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN gpointer dino_connection_manager_value_get_connection_error (const GValue* value);
VALA_EXTERN GType dino_connection_manager_connection_error_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoConnectionManagerConnectionError, dino_connection_manager_connection_error_unref)
VALA_EXTERN DinoConnectionManagerConnectionError* dino_connection_manager_get_error (DinoConnectionManager* self,
                                                                         DinoEntitiesAccount* account);
VALA_EXTERN GeeCollection* dino_connection_manager_get_managed_accounts (DinoConnectionManager* self);
VALA_EXTERN void dino_connection_manager_connect_account (DinoConnectionManager* self,
                                              DinoEntitiesAccount* account);
VALA_EXTERN void dino_connection_manager_make_offline_all (DinoConnectionManager* self);
VALA_EXTERN void dino_connection_manager_disconnect_account (DinoConnectionManager* self,
                                                 DinoEntitiesAccount* account,
                                                 GAsyncReadyCallback _callback_,
                                                 gpointer _user_data_);
VALA_EXTERN void dino_connection_manager_disconnect_account_finish (DinoConnectionManager* self,
                                                        GAsyncResult* _res_);
VALA_EXTERN gboolean dino_connection_manager_on_invalid_certificate (const gchar* domain,
                                                         GTlsCertificate* peer_cert,
                                                         GTlsCertificateFlags errors);
VALA_EXTERN GType dino_connection_manager_connection_error_source_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType dino_connection_manager_connection_error_reconnect_get_type (void) G_GNUC_CONST ;
VALA_EXTERN DinoConnectionManagerConnectionError* dino_connection_manager_connection_error_new (DinoConnectionManagerConnectionErrorSource source,
                                                                                    const gchar* identifier);
VALA_EXTERN DinoConnectionManagerConnectionError* dino_connection_manager_connection_error_construct (GType object_type,
                                                                                          DinoConnectionManagerConnectionErrorSource source,
                                                                                          const gchar* identifier);
VALA_EXTERN DinoConnectionManagerConnectionErrorReconnect dino_connection_manager_connection_error_get_reconnect_recomendation (DinoConnectionManagerConnectionError* self);
VALA_EXTERN void dino_connection_manager_connection_error_set_reconnect_recomendation (DinoConnectionManagerConnectionError* self,
                                                                           DinoConnectionManagerConnectionErrorReconnect value);
VALA_EXTERN GType dino_model_conversation_display_name_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoModelConversationDisplayName, g_object_unref)
VALA_EXTERN DinoModelConversationDisplayName* dino_model_conversation_display_name_new (void);
VALA_EXTERN DinoModelConversationDisplayName* dino_model_conversation_display_name_construct (GType object_type);
VALA_EXTERN const gchar* dino_model_conversation_display_name_get_display_name (DinoModelConversationDisplayName* self);
VALA_EXTERN void dino_model_conversation_display_name_set_display_name (DinoModelConversationDisplayName* self,
                                                            const gchar* value);
VALA_EXTERN GType dino_contact_models_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoContactModels, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_contact_models_IDENTITY;
VALA_EXTERN void dino_contact_models_start (DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoModelConversationDisplayName* dino_contact_models_get_display_name_model (DinoContactModels* self,
                                                                              DinoEntitiesConversation* conversation);
VALA_EXTERN GType dino_content_item_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoContentItemStore, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_content_item_store_IDENTITY;
VALA_EXTERN void dino_content_item_store_start (DinoStreamInteractor* stream_interactor,
                                    DinoDatabase* db);
VALA_EXTERN DinoContentItemStore* dino_content_item_store_new (DinoStreamInteractor* stream_interactor,
                                                   DinoDatabase* db);
VALA_EXTERN DinoContentItemStore* dino_content_item_store_construct (GType object_type,
                                                         DinoStreamInteractor* stream_interactor,
                                                         DinoDatabase* db);
VALA_EXTERN GType dino_content_item_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoContentItemCollection, g_object_unref)
VALA_EXTERN void dino_content_item_store_init (DinoContentItemStore* self,
                                   DinoEntitiesConversation* conversation,
                                   DinoContentItemCollection* item_collection);
VALA_EXTERN void dino_content_item_store_uninit (DinoContentItemStore* self,
                                     DinoEntitiesConversation* conversation,
                                     DinoContentItemCollection* item_collection);
VALA_EXTERN DinoContentItem* dino_content_item_store_get_item_by_foreign (DinoContentItemStore* self,
                                                              DinoEntitiesConversation* conversation,
                                                              gint type,
                                                              gint foreign_id);
VALA_EXTERN DinoContentItem* dino_content_item_store_get_item_by_id (DinoContentItemStore* self,
                                                         DinoEntitiesConversation* conversation,
                                                         gint id);
VALA_EXTERN gchar* dino_content_item_store_get_message_id_for_content_item (DinoContentItemStore* self,
                                                                DinoEntitiesConversation* conversation,
                                                                DinoContentItem* content_item);
VALA_EXTERN XmppJid* dino_content_item_store_get_message_sender_for_content_item (DinoContentItemStore* self,
                                                                      DinoEntitiesConversation* conversation,
                                                                      DinoContentItem* content_item);
VALA_EXTERN DinoEntitiesMessage* dino_content_item_store_get_message_for_content_item (DinoContentItemStore* self,
                                                                           DinoEntitiesConversation* conversation,
                                                                           DinoContentItem* content_item);
VALA_EXTERN DinoContentItem* dino_content_item_store_get_content_item_for_message_id (DinoContentItemStore* self,
                                                                          DinoEntitiesConversation* conversation,
                                                                          const gchar* message_id);
VALA_EXTERN gint dino_content_item_store_get_content_item_id_for_message_id (DinoContentItemStore* self,
                                                                 DinoEntitiesConversation* conversation,
                                                                 const gchar* message_id);
VALA_EXTERN DinoContentItem* dino_content_item_store_get_latest (DinoContentItemStore* self,
                                                     DinoEntitiesConversation* conversation);
VALA_EXTERN GeeList* dino_content_item_store_get_n_latest (DinoContentItemStore* self,
                                               DinoEntitiesConversation* conversation,
                                               gint count);
VALA_EXTERN GeeList* dino_content_item_store_get_before (DinoContentItemStore* self,
                                             DinoEntitiesConversation* conversation,
                                             DinoContentItem* item,
                                             gint count);
VALA_EXTERN GeeList* dino_content_item_store_get_after (DinoContentItemStore* self,
                                            DinoEntitiesConversation* conversation,
                                            DinoContentItem* item,
                                            gint count);
VALA_EXTERN void dino_content_item_store_insert_message (DinoContentItemStore* self,
                                             DinoEntitiesMessage* message,
                                             DinoEntitiesConversation* conversation,
                                             gboolean hide);
VALA_EXTERN gboolean dino_content_item_store_get_item_hide (DinoContentItemStore* self,
                                                DinoContentItem* content_item);
VALA_EXTERN void dino_content_item_store_set_item_hide (DinoContentItemStore* self,
                                            DinoContentItem* content_item,
                                            gboolean hide);
VALA_EXTERN void dino_content_item_collection_insert_item (DinoContentItemCollection* self,
                                               DinoContentItem* item);
VALA_EXTERN void dino_content_item_collection_remove_item (DinoContentItemCollection* self,
                                               DinoContentItem* item);
VALA_EXTERN gint dino_content_item_compare (DinoContentItem* self,
                                DinoContentItem* c);
VALA_EXTERN gint dino_content_item_compare_func (DinoContentItem* a,
                                     DinoContentItem* b);
VALA_EXTERN gint dino_content_item_get_id (DinoContentItem* self);
VALA_EXTERN void dino_content_item_set_id (DinoContentItem* self,
                               gint value);
VALA_EXTERN const gchar* dino_content_item_get_type_ (DinoContentItem* self);
VALA_EXTERN void dino_content_item_set_type_ (DinoContentItem* self,
                                  const gchar* value);
VALA_EXTERN XmppJid* dino_content_item_get_jid (DinoContentItem* self);
VALA_EXTERN void dino_content_item_set_jid (DinoContentItem* self,
                                XmppJid* value);
VALA_EXTERN GDateTime* dino_content_item_get_time (DinoContentItem* self);
VALA_EXTERN void dino_content_item_set_time (DinoContentItem* self,
                                 GDateTime* value);
VALA_EXTERN DinoEntitiesEncryption dino_content_item_get_encryption (DinoContentItem* self);
VALA_EXTERN void dino_content_item_set_encryption (DinoContentItem* self,
                                       DinoEntitiesEncryption value);
VALA_EXTERN DinoEntitiesMessageMarked dino_content_item_get_mark (DinoContentItem* self);
VALA_EXTERN void dino_content_item_set_mark (DinoContentItem* self,
                                 DinoEntitiesMessageMarked value);
VALA_EXTERN GType dino_message_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoMessageItem, g_object_unref)
VALA_EXTERN DinoMessageItem* dino_message_item_new (DinoEntitiesMessage* message,
                                        DinoEntitiesConversation* conversation,
                                        gint id);
VALA_EXTERN DinoMessageItem* dino_message_item_construct (GType object_type,
                                              DinoEntitiesMessage* message,
                                              DinoEntitiesConversation* conversation,
                                              gint id);
VALA_EXTERN GType dino_file_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileItem, g_object_unref)
VALA_EXTERN DinoFileItem* dino_file_item_new (DinoEntitiesFileTransfer* file_transfer,
                                  DinoEntitiesConversation* conversation,
                                  gint id,
                                  DinoEntitiesMessage* message);
VALA_EXTERN DinoFileItem* dino_file_item_construct (GType object_type,
                                        DinoEntitiesFileTransfer* file_transfer,
                                        DinoEntitiesConversation* conversation,
                                        gint id,
                                        DinoEntitiesMessage* message);
VALA_EXTERN GType dino_call_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoCallItem, g_object_unref)
VALA_EXTERN DinoCallItem* dino_call_item_new (DinoEntitiesCall* call,
                                  DinoEntitiesConversation* conversation,
                                  gint id);
VALA_EXTERN DinoCallItem* dino_call_item_construct (GType object_type,
                                        DinoEntitiesCall* call,
                                        DinoEntitiesConversation* conversation,
                                        gint id);
VALA_EXTERN GType dino_conversation_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoConversationManager, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_conversation_manager_IDENTITY;
VALA_EXTERN void dino_conversation_manager_start (DinoStreamInteractor* stream_interactor,
                                      DinoDatabase* db);
VALA_EXTERN DinoEntitiesConversation* dino_conversation_manager_create_conversation (DinoConversationManager* self,
                                                                         XmppJid* jid,
                                                                         DinoEntitiesAccount* account,
                                                                         DinoEntitiesConversationType* type);
VALA_EXTERN DinoEntitiesConversation* dino_conversation_manager_get_conversation_for_message (DinoConversationManager* self,
                                                                                  DinoEntitiesMessage* message);
VALA_EXTERN GeeList* dino_conversation_manager_get_conversations (DinoConversationManager* self,
                                                      XmppJid* jid,
                                                      DinoEntitiesAccount* account);
VALA_EXTERN DinoEntitiesConversation* dino_conversation_manager_get_conversation (DinoConversationManager* self,
                                                                      XmppJid* jid,
                                                                      DinoEntitiesAccount* account,
                                                                      DinoEntitiesConversationType* type);
VALA_EXTERN DinoEntitiesConversation* dino_conversation_manager_approx_conversation_for_stanza (DinoConversationManager* self,
                                                                                    XmppJid* from,
                                                                                    XmppJid* to,
                                                                                    DinoEntitiesAccount* account,
                                                                                    const gchar* msg_ty);
VALA_EXTERN DinoEntitiesConversation* dino_conversation_manager_get_conversation_by_id (DinoConversationManager* self,
                                                                            gint id);
VALA_EXTERN GeeList* dino_conversation_manager_get_active_conversations (DinoConversationManager* self,
                                                             DinoEntitiesAccount* account);
VALA_EXTERN void dino_conversation_manager_start_conversation (DinoConversationManager* self,
                                                   DinoEntitiesConversation* conversation);
VALA_EXTERN void dino_conversation_manager_close_conversation (DinoConversationManager* self,
                                                   DinoEntitiesConversation* conversation);
VALA_EXTERN GType dino_counterpart_interaction_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoCounterpartInteractionManager, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_counterpart_interaction_manager_IDENTITY;
VALA_EXTERN void dino_counterpart_interaction_manager_start (DinoStreamInteractor* stream_interactor);
VALA_EXTERN GeeList* dino_counterpart_interaction_manager_get_typing_jids (DinoCounterpartInteractionManager* self,
                                                               DinoEntitiesConversation* conversation);
VALA_EXTERN DinoDatabase* dino_database_new (const gchar* fileName);
VALA_EXTERN DinoDatabase* dino_database_construct (GType object_type,
                                       const gchar* fileName);
VALA_EXTERN GeeArrayList* dino_database_get_accounts (DinoDatabase* self);
VALA_EXTERN DinoEntitiesAccount* dino_database_get_account_by_id (DinoDatabase* self,
                                                      gint id);
VALA_EXTERN gint dino_database_add_content_item (DinoDatabase* self,
                                     DinoEntitiesConversation* conversation,
                                     GDateTime* time,
                                     GDateTime* local_time,
                                     gint content_type,
                                     gint foreign_id,
                                     gboolean hide);
VALA_EXTERN GeeList* dino_database_get_messages (DinoDatabase* self,
                                     XmppJid* jid,
                                     DinoEntitiesAccount* account,
                                     DinoEntitiesMessageType* type,
                                     gint count,
                                     GDateTime* before,
                                     GDateTime* after,
                                     gint id);
VALA_EXTERN DinoEntitiesMessage* dino_database_get_message_by_id (DinoDatabase* self,
                                                      gint id);
VALA_EXTERN GeeArrayList* dino_database_get_conversations (DinoDatabase* self,
                                               DinoEntitiesAccount* account);
VALA_EXTERN gint dino_database_get_jid_id (DinoDatabase* self,
                               XmppJid* jid_obj);
VALA_EXTERN XmppJid* dino_database_get_jid_by_id (DinoDatabase* self,
                                      gint id,
                                      GError** error);
VALA_EXTERN GType dino_database_account_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseAccountTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseAccountTable* dino_database_get_account (DinoDatabase* self);
VALA_EXTERN GType dino_database_jid_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseJidTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseJidTable* dino_database_get_jid (DinoDatabase* self);
VALA_EXTERN GType dino_database_entity_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseEntityTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseEntityTable* dino_database_get_entity (DinoDatabase* self);
VALA_EXTERN GType dino_database_content_item_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseContentItemTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseContentItemTable* dino_database_get_content_item (DinoDatabase* self);
VALA_EXTERN GType dino_database_message_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseMessageTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseMessageTable* dino_database_get_message (DinoDatabase* self);
VALA_EXTERN GType dino_database_body_meta_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseBodyMeta, qlite_table_unref)
VALA_EXTERN DinoDatabaseBodyMeta* dino_database_get_body_meta (DinoDatabase* self);
VALA_EXTERN GType dino_database_reply_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseReplyTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseReplyTable* dino_database_get_reply (DinoDatabase* self);
VALA_EXTERN GType dino_database_message_correction_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseMessageCorrectionTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseMessageCorrectionTable* dino_database_get_message_correction (DinoDatabase* self);
VALA_EXTERN GType dino_database_real_jid_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseRealJidTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseRealJidTable* dino_database_get_real_jid (DinoDatabase* self);
VALA_EXTERN GType dino_database_occupant_id_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseOccupantIdTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseOccupantIdTable* dino_database_get_occupantid (DinoDatabase* self);
VALA_EXTERN GType dino_database_file_transfer_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseFileTransferTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseFileTransferTable* dino_database_get_file_transfer (DinoDatabase* self);
VALA_EXTERN GType dino_database_file_hashes_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseFileHashesTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseFileHashesTable* dino_database_get_file_hashes (DinoDatabase* self);
VALA_EXTERN GType dino_database_file_thumbnails_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseFileThumbnailsTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseFileThumbnailsTable* dino_database_get_file_thumbnails (DinoDatabase* self);
VALA_EXTERN GType dino_database_sources_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseSourcesTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseSourcesTable* dino_database_get_sfs_sources (DinoDatabase* self);
VALA_EXTERN GType dino_database_call_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseCallTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseCallTable* dino_database_get_call (DinoDatabase* self);
VALA_EXTERN GType dino_database_call_counterpart_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseCallCounterpartTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseCallCounterpartTable* dino_database_get_call_counterpart (DinoDatabase* self);
VALA_EXTERN GType dino_database_conversation_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseConversationTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseConversationTable* dino_database_get_conversation (DinoDatabase* self);
VALA_EXTERN GType dino_database_avatar_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseAvatarTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseAvatarTable* dino_database_get_avatar (DinoDatabase* self);
VALA_EXTERN GType dino_database_entity_identity_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseEntityIdentityTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseEntityIdentityTable* dino_database_get_entity_identity (DinoDatabase* self);
VALA_EXTERN GType dino_database_entity_feature_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseEntityFeatureTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseEntityFeatureTable* dino_database_get_entity_feature (DinoDatabase* self);
VALA_EXTERN GType dino_database_roster_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseRosterTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseRosterTable* dino_database_get_roster (DinoDatabase* self);
VALA_EXTERN GType dino_database_mam_catchup_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseMamCatchupTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseMamCatchupTable* dino_database_get_mam_catchup (DinoDatabase* self);
VALA_EXTERN GType dino_database_reaction_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseReactionTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseReactionTable* dino_database_get_reaction (DinoDatabase* self);
VALA_EXTERN GType dino_database_settings_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseSettingsTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseSettingsTable* dino_database_get_settings (DinoDatabase* self);
VALA_EXTERN GType dino_database_account_settings_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseAccountSettingsTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseAccountSettingsTable* dino_database_get_account_settings (DinoDatabase* self);
VALA_EXTERN GType dino_database_conversation_settings_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseConversationSettingsTable, qlite_table_unref)
VALA_EXTERN DinoDatabaseConversationSettingsTable* dino_database_get_conversation_settings (DinoDatabase* self);
VALA_EXTERN GType dino_database_undecrypted_table_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoDatabaseUndecryptedTable, qlite_table_unref)
VALA_EXTERN gchar* dino_database_account_settings_table_get_value (DinoDatabaseAccountSettingsTable* self,
                                                       gint account_id,
                                                       const gchar* key);
VALA_EXTERN GType dino_entity_capabilities_storage_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoEntityCapabilitiesStorage, g_object_unref)
VALA_EXTERN DinoEntityCapabilitiesStorage* dino_entity_capabilities_storage_new (DinoDatabase* db);
VALA_EXTERN DinoEntityCapabilitiesStorage* dino_entity_capabilities_storage_construct (GType object_type,
                                                                           DinoDatabase* db);
VALA_EXTERN GType dino_entity_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoEntityInfo, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_entity_info_IDENTITY;
VALA_EXTERN void dino_entity_info_start (DinoStreamInteractor* stream_interactor,
                             DinoDatabase* db);
VALA_EXTERN void dino_entity_info_get_identities (DinoEntityInfo* self,
                                      DinoEntitiesAccount* account,
                                      XmppJid* jid,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN GeeSet* dino_entity_info_get_identities_finish (DinoEntityInfo* self,
                                                GAsyncResult* _res_);
VALA_EXTERN void dino_entity_info_get_identity (DinoEntityInfo* self,
                                    DinoEntitiesAccount* account,
                                    XmppJid* jid,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN XmppXepServiceDiscoveryIdentity* dino_entity_info_get_identity_finish (DinoEntityInfo* self,
                                                                       GAsyncResult* _res_);
VALA_EXTERN void dino_entity_info_has_feature (DinoEntityInfo* self,
                                   DinoEntitiesAccount* account,
                                   XmppJid* jid,
                                   const gchar* feature,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
VALA_EXTERN gboolean dino_entity_info_has_feature_finish (DinoEntityInfo* self,
                                              GAsyncResult* _res_);
VALA_EXTERN gboolean dino_entity_info_has_feature_offline (DinoEntityInfo* self,
                                               DinoEntitiesAccount* account,
                                               XmppJid* jid,
                                               const gchar* feature);
VALA_EXTERN gboolean dino_entity_info_has_feature_cached (DinoEntityInfo* self,
                                              DinoEntitiesAccount* account,
                                              XmppJid* jid,
                                              const gchar* feature);
VALA_EXTERN GType dino_caps_cache_impl_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoCapsCacheImpl, g_object_unref)
VALA_EXTERN DinoCapsCacheImpl* dino_caps_cache_impl_new (DinoEntitiesAccount* account,
                                             DinoEntityInfo* entity_info);
VALA_EXTERN DinoCapsCacheImpl* dino_caps_cache_impl_construct (GType object_type,
                                                   DinoEntitiesAccount* account,
                                                   DinoEntityInfo* entity_info);
VALA_EXTERN GType dino_fallback_body_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFallbackBody, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_fallback_body_IDENTITY;
VALA_EXTERN void dino_fallback_body_start (DinoStreamInteractor* stream_interactor,
                               DinoDatabase* db);
VALA_EXTERN gchar* dino_fallback_body_get_quoted_fallback_body (DinoContentItem* content_item);
VALA_EXTERN GType dino_file_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileManager, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_file_manager_IDENTITY;
VALA_EXTERN void dino_file_manager_start (DinoStreamInteractor* stream_interactor,
                              DinoDatabase* db);
VALA_EXTERN gchar* dino_file_manager_get_storage_dir (void);
VALA_EXTERN gpointer dino_file_receive_data_ref (gpointer instance);
VALA_EXTERN void dino_file_receive_data_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_file_receive_data (const gchar* name,
                                               const gchar* nick,
                                               const gchar* blurb,
                                               GType object_type,
                                               GParamFlags flags);
VALA_EXTERN void dino_value_set_file_receive_data (GValue* value,
                                       gpointer v_object);
VALA_EXTERN void dino_value_take_file_receive_data (GValue* value,
                                        gpointer v_object);
VALA_EXTERN gpointer dino_value_get_file_receive_data (const GValue* value);
VALA_EXTERN GType dino_file_receive_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileReceiveData, dino_file_receive_data_unref)
VALA_EXTERN gpointer dino_file_meta_ref (gpointer instance);
VALA_EXTERN void dino_file_meta_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_file_meta (const gchar* name,
                                       const gchar* nick,
                                       const gchar* blurb,
                                       GType object_type,
                                       GParamFlags flags);
VALA_EXTERN void dino_value_set_file_meta (GValue* value,
                               gpointer v_object);
VALA_EXTERN void dino_value_take_file_meta (GValue* value,
                                gpointer v_object);
VALA_EXTERN gpointer dino_value_get_file_meta (const GValue* value);
VALA_EXTERN GType dino_file_meta_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileMeta, dino_file_meta_unref)
VALA_EXTERN GQuark dino_file_receive_error_quark (void);
VALA_EXTERN GType dino_file_receive_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType dino_file_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileProvider, g_object_unref)
VALA_EXTERN DinoFileProvider* dino_file_manager_select_file_provider (DinoFileManager* self,
                                                          DinoEntitiesFileTransfer* file_transfer);
VALA_EXTERN void dino_file_manager_get_file_size_limits (DinoFileManager* self,
                                             DinoEntitiesConversation* conversation,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
VALA_EXTERN GeeHashMap* dino_file_manager_get_file_size_limits_finish (DinoFileManager* self,
                                                           GAsyncResult* _res_);
VALA_EXTERN void dino_file_manager_send_file (DinoFileManager* self,
                                  GFile* file,
                                  DinoEntitiesConversation* conversation,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_);
VALA_EXTERN void dino_file_manager_send_file_finish (DinoFileManager* self,
                                         GAsyncResult* _res_);
VALA_EXTERN void dino_file_manager_download_file (DinoFileManager* self,
                                      DinoEntitiesFileTransfer* file_transfer,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN void dino_file_manager_download_file_finish (DinoFileManager* self,
                                             GAsyncResult* _res_);
VALA_EXTERN void dino_file_manager_is_upload_available (DinoFileManager* self,
                                            DinoEntitiesConversation* conversation,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
VALA_EXTERN gboolean dino_file_manager_is_upload_available_finish (DinoFileManager* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN void dino_file_manager_add_provider (DinoFileManager* self,
                                     DinoFileProvider* file_provider);
VALA_EXTERN gpointer dino_file_send_data_ref (gpointer instance);
VALA_EXTERN void dino_file_send_data_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_file_send_data (const gchar* name,
                                            const gchar* nick,
                                            const gchar* blurb,
                                            GType object_type,
                                            GParamFlags flags);
VALA_EXTERN void dino_value_set_file_send_data (GValue* value,
                                    gpointer v_object);
VALA_EXTERN void dino_value_take_file_send_data (GValue* value,
                                     gpointer v_object);
VALA_EXTERN gpointer dino_value_get_file_send_data (const GValue* value);
VALA_EXTERN GType dino_file_send_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileSendData, dino_file_send_data_unref)
VALA_EXTERN GQuark dino_file_send_error_quark (void);
VALA_EXTERN GType dino_file_send_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType dino_file_sender_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileSender, g_object_unref)
VALA_EXTERN void dino_file_manager_add_sender (DinoFileManager* self,
                                   DinoFileSender* file_sender);
VALA_EXTERN GType dino_file_encryptor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileEncryptor, g_object_unref)
VALA_EXTERN void dino_file_manager_add_file_encryptor (DinoFileManager* self,
                                           DinoFileEncryptor* encryptor);
VALA_EXTERN GType dino_file_decryptor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileDecryptor, g_object_unref)
VALA_EXTERN void dino_file_manager_add_file_decryptor (DinoFileManager* self,
                                           DinoFileDecryptor* decryptor);
VALA_EXTERN GType dino_file_metadata_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileMetadataProvider, g_object_unref)
VALA_EXTERN void dino_file_manager_add_metadata_provider (DinoFileManager* self,
                                              DinoFileMetadataProvider* file_metadata_provider);
VALA_EXTERN gboolean dino_file_manager_is_sender_trustworthy (DinoFileManager* self,
                                                  DinoEntitiesFileTransfer* file_transfer,
                                                  DinoEntitiesConversation* conversation);
VALA_EXTERN DinoEntitiesFileTransfer* dino_file_manager_create_file_transfer_from_provider_incoming (DinoFileManager* self,
                                                                                         DinoFileProvider* file_provider,
                                                                                         const gchar* info,
                                                                                         XmppJid* from,
                                                                                         GDateTime* time,
                                                                                         GDateTime* local_time,
                                                                                         DinoEntitiesConversation* conversation,
                                                                                         DinoFileReceiveData* receive_data,
                                                                                         DinoFileMeta* file_meta);
VALA_EXTERN GType dino_stateless_file_sharing_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoStatelessFileSharing, g_object_unref)
VALA_EXTERN DinoStatelessFileSharing* dino_file_manager_get_sfs (DinoFileManager* self);
VALA_EXTERN DinoFileMeta* dino_file_meta_new (void);
VALA_EXTERN DinoFileMeta* dino_file_meta_construct (GType object_type);
VALA_EXTERN GType dino_http_file_meta_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoHttpFileMeta, dino_file_meta_unref)
VALA_EXTERN DinoHttpFileMeta* dino_http_file_meta_new (void);
VALA_EXTERN DinoHttpFileMeta* dino_http_file_meta_construct (GType object_type);
VALA_EXTERN DinoFileSendData* dino_file_send_data_new (void);
VALA_EXTERN DinoFileSendData* dino_file_send_data_construct (GType object_type);
VALA_EXTERN GType dino_http_file_send_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoHttpFileSendData, dino_file_send_data_unref)
VALA_EXTERN DinoHttpFileSendData* dino_http_file_send_data_new (void);
VALA_EXTERN DinoHttpFileSendData* dino_http_file_send_data_construct (GType object_type);
VALA_EXTERN const gchar* dino_http_file_send_data_get_url_down (DinoHttpFileSendData* self);
VALA_EXTERN void dino_http_file_send_data_set_url_down (DinoHttpFileSendData* self,
                                            const gchar* value);
VALA_EXTERN const gchar* dino_http_file_send_data_get_url_up (DinoHttpFileSendData* self);
VALA_EXTERN void dino_http_file_send_data_set_url_up (DinoHttpFileSendData* self,
                                          const gchar* value);
VALA_EXTERN GeeHashMap* dino_http_file_send_data_get_headers (DinoHttpFileSendData* self);
VALA_EXTERN void dino_http_file_send_data_set_headers (DinoHttpFileSendData* self,
                                           GeeHashMap* value);
VALA_EXTERN gboolean dino_http_file_send_data_get_encrypt_message (DinoHttpFileSendData* self);
VALA_EXTERN void dino_http_file_send_data_set_encrypt_message (DinoHttpFileSendData* self,
                                                   gboolean value);
VALA_EXTERN DinoFileReceiveData* dino_file_receive_data_new (void);
VALA_EXTERN DinoFileReceiveData* dino_file_receive_data_construct (GType object_type);
VALA_EXTERN GType dino_http_file_receive_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoHttpFileReceiveData, dino_file_receive_data_unref)
VALA_EXTERN DinoHttpFileReceiveData* dino_http_file_receive_data_new (void);
VALA_EXTERN DinoHttpFileReceiveData* dino_http_file_receive_data_construct (GType object_type);
VALA_EXTERN const gchar* dino_http_file_receive_data_get_url (DinoHttpFileReceiveData* self);
VALA_EXTERN void dino_http_file_receive_data_set_url (DinoHttpFileReceiveData* self,
                                          const gchar* value);
VALA_EXTERN DinoEntitiesEncryption dino_file_provider_get_encryption (DinoFileProvider* self,
                                                          DinoEntitiesFileTransfer* file_transfer,
                                                          DinoFileReceiveData* receive_data,
                                                          DinoFileMeta* file_meta);
VALA_EXTERN DinoFileMeta* dino_file_provider_get_file_meta (DinoFileProvider* self,
                                                DinoEntitiesFileTransfer* file_transfer,
                                                GError** error);
VALA_EXTERN DinoFileReceiveData* dino_file_provider_get_file_receive_data (DinoFileProvider* self,
                                                               DinoEntitiesFileTransfer* file_transfer);
VALA_EXTERN void dino_file_provider_get_meta_info (DinoFileProvider* self,
                                       DinoEntitiesFileTransfer* file_transfer,
                                       DinoFileReceiveData* receive_data,
                                       DinoFileMeta* file_meta,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN DinoFileMeta* dino_file_provider_get_meta_info_finish (DinoFileProvider* self,
                                                       GAsyncResult* _res_,
                                                       GError** error);
VALA_EXTERN void dino_file_provider_download (DinoFileProvider* self,
                                  DinoEntitiesFileTransfer* file_transfer,
                                  DinoFileReceiveData* receive_data,
                                  DinoFileMeta* file_meta,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_);
VALA_EXTERN GInputStream* dino_file_provider_download_finish (DinoFileProvider* self,
                                                  GAsyncResult* _res_,
                                                  GError** error);
VALA_EXTERN gint dino_file_provider_get_id (DinoFileProvider* self);
VALA_EXTERN void dino_file_sender_is_upload_available (DinoFileSender* self,
                                           DinoEntitiesConversation* conversation,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
VALA_EXTERN gboolean dino_file_sender_is_upload_available_finish (DinoFileSender* self,
                                                      GAsyncResult* _res_);
VALA_EXTERN void dino_file_sender_get_file_size_limit (DinoFileSender* self,
                                           DinoEntitiesConversation* conversation,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
VALA_EXTERN glong dino_file_sender_get_file_size_limit_finish (DinoFileSender* self,
                                                   GAsyncResult* _res_);
VALA_EXTERN void dino_file_sender_can_send (DinoFileSender* self,
                                DinoEntitiesConversation* conversation,
                                DinoEntitiesFileTransfer* file_transfer,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN gboolean dino_file_sender_can_send_finish (DinoFileSender* self,
                                           GAsyncResult* _res_);
VALA_EXTERN void dino_file_sender_prepare_send_file (DinoFileSender* self,
                                         DinoEntitiesConversation* conversation,
                                         DinoEntitiesFileTransfer* file_transfer,
                                         DinoFileMeta* file_meta,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
VALA_EXTERN DinoFileSendData* dino_file_sender_prepare_send_file_finish (DinoFileSender* self,
                                                             GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN void dino_file_sender_send_file (DinoFileSender* self,
                                 DinoEntitiesConversation* conversation,
                                 DinoEntitiesFileTransfer* file_transfer,
                                 DinoFileSendData* file_send_data,
                                 DinoFileMeta* file_meta,
                                 GAsyncReadyCallback _callback_,
                                 gpointer _user_data_);
VALA_EXTERN void dino_file_sender_send_file_finish (DinoFileSender* self,
                                        GAsyncResult* _res_,
                                        GError** error);
VALA_EXTERN void dino_file_sender_can_encrypt (DinoFileSender* self,
                                   DinoEntitiesConversation* conversation,
                                   DinoEntitiesFileTransfer* file_transfer,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
VALA_EXTERN gboolean dino_file_sender_can_encrypt_finish (DinoFileSender* self,
                                              GAsyncResult* _res_);
VALA_EXTERN gint dino_file_sender_get_id (DinoFileSender* self);
VALA_EXTERN gfloat dino_file_sender_get_priority (DinoFileSender* self);
VALA_EXTERN gboolean dino_file_encryptor_can_encrypt_file (DinoFileEncryptor* self,
                                               DinoEntitiesConversation* conversation,
                                               DinoEntitiesFileTransfer* file_transfer);
VALA_EXTERN DinoFileMeta* dino_file_encryptor_encrypt_file (DinoFileEncryptor* self,
                                                DinoEntitiesConversation* conversation,
                                                DinoEntitiesFileTransfer* file_transfer,
                                                GError** error);
VALA_EXTERN DinoFileSendData* dino_file_encryptor_preprocess_send_file (DinoFileEncryptor* self,
                                                            DinoEntitiesConversation* conversation,
                                                            DinoEntitiesFileTransfer* file_transfer,
                                                            DinoFileSendData* file_send_data,
                                                            DinoFileMeta* file_meta,
                                                            GError** error);
VALA_EXTERN DinoEntitiesEncryption dino_file_decryptor_get_encryption (DinoFileDecryptor* self);
VALA_EXTERN DinoFileReceiveData* dino_file_decryptor_prepare_get_meta_info (DinoFileDecryptor* self,
                                                                DinoEntitiesConversation* conversation,
                                                                DinoEntitiesFileTransfer* file_transfer,
                                                                DinoFileReceiveData* receive_data);
VALA_EXTERN DinoFileMeta* dino_file_decryptor_prepare_download_file (DinoFileDecryptor* self,
                                                         DinoEntitiesConversation* conversation,
                                                         DinoEntitiesFileTransfer* file_transfer,
                                                         DinoFileReceiveData* receive_data,
                                                         DinoFileMeta* file_meta);
VALA_EXTERN gboolean dino_file_decryptor_can_decrypt_file (DinoFileDecryptor* self,
                                               DinoEntitiesConversation* conversation,
                                               DinoEntitiesFileTransfer* file_transfer,
                                               DinoFileReceiveData* receive_data);
VALA_EXTERN void dino_file_decryptor_decrypt_file (DinoFileDecryptor* self,
                                       GInputStream* encrypted_stream,
                                       DinoEntitiesConversation* conversation,
                                       DinoEntitiesFileTransfer* file_transfer,
                                       DinoFileReceiveData* receive_data,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN GInputStream* dino_file_decryptor_decrypt_file_finish (DinoFileDecryptor* self,
                                                       GAsyncResult* _res_,
                                                       GError** error);
VALA_EXTERN GType dino_file_transfer_storage_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoFileTransferStorage, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_file_transfer_storage_IDENTITY;
VALA_EXTERN void dino_file_transfer_storage_start (DinoStreamInteractor* stream_interactor,
                                       DinoDatabase* db);
VALA_EXTERN void dino_file_transfer_storage_add_file (DinoFileTransferStorage* self,
                                          DinoEntitiesFileTransfer* file_transfer);
VALA_EXTERN DinoEntitiesFileTransfer* dino_file_transfer_storage_get_file_by_id (DinoFileTransferStorage* self,
                                                                     gint id,
                                                                     DinoEntitiesConversation* conversation);
VALA_EXTERN DinoEntitiesFileTransfer* dino_file_transfer_storage_get_file_by_message_id (DinoFileTransferStorage* self,
                                                                             gint id,
                                                                             DinoEntitiesConversation* conversation);
VALA_EXTERN DinoEntitiesFileTransfer* dino_file_transfer_storage_get_files_by_message_and_file_id (DinoFileTransferStorage* self,
                                                                                       gint message_id,
                                                                                       const gchar* file_sharing_id,
                                                                                       DinoEntitiesConversation* conversation);
VALA_EXTERN gpointer dino_history_sync_ref (gpointer instance);
VALA_EXTERN void dino_history_sync_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_history_sync (const gchar* name,
                                          const gchar* nick,
                                          const gchar* blurb,
                                          GType object_type,
                                          GParamFlags flags);
VALA_EXTERN void dino_value_set_history_sync (GValue* value,
                                  gpointer v_object);
VALA_EXTERN void dino_value_take_history_sync (GValue* value,
                                   gpointer v_object);
VALA_EXTERN gpointer dino_value_get_history_sync (const GValue* value);
VALA_EXTERN GType dino_history_sync_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoHistorySync, dino_history_sync_unref)
VALA_EXTERN GType weak_map_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WeakMap, g_object_unref)
VALA_EXTERN DinoHistorySync* dino_history_sync_new (DinoDatabase* db,
                                        DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoHistorySync* dino_history_sync_construct (GType object_type,
                                              DinoDatabase* db,
                                              DinoStreamInteractor* stream_interactor);
VALA_EXTERN gboolean dino_history_sync_process (DinoHistorySync* self,
                                    DinoEntitiesAccount* account,
                                    XmppMessageStanza* message_stanza);
VALA_EXTERN void dino_history_sync_update_latest_db_range (DinoHistorySync* self,
                                               DinoEntitiesAccount* account,
                                               XmppMessageStanza* message_stanza);
VALA_EXTERN void dino_history_sync_process_mam_message (DinoHistorySync* self,
                                            DinoEntitiesAccount* account,
                                            XmppMessageStanza* message_stanza,
                                            XmppMessageArchiveManagementMessageFlag* mam_flag);
VALA_EXTERN void dino_history_sync_on_server_id_duplicate (DinoHistorySync* self,
                                               DinoEntitiesAccount* account,
                                               XmppMessageStanza* message_stanza,
                                               DinoEntitiesMessage* message);
VALA_EXTERN void dino_history_sync_fetch_everything (DinoHistorySync* self,
                                         DinoEntitiesAccount* account,
                                         XmppJid* mam_server,
                                         GCancellable* cancellable,
                                         GDateTime* until_earliest_time,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
VALA_EXTERN void dino_history_sync_fetch_everything_finish (DinoHistorySync* self,
                                                GAsyncResult* _res_);
VALA_EXTERN void dino_history_sync_fetch_latest_page (DinoHistorySync* self,
                                          DinoEntitiesAccount* account,
                                          XmppJid* mam_server,
                                          QliteRow* latest_row,
                                          GDateTime* until_earliest_time,
                                          GCancellable* cancellable,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN QliteRow* dino_history_sync_fetch_latest_page_finish (DinoHistorySync* self,
                                                      GAsyncResult* _res_);
VALA_EXTERN void dino_history_sync_cleanup_db_ranges (DinoDatabase* db,
                                          DinoEntitiesAccount* account);
VALA_EXTERN GType dino_jingle_file_encryption_helper_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoJingleFileEncryptionHelper, g_object_unref)
VALA_EXTERN gboolean dino_jingle_file_encryption_helper_can_transfer (DinoJingleFileEncryptionHelper* self,
                                                          DinoEntitiesConversation* conversation);
VALA_EXTERN void dino_jingle_file_encryption_helper_can_encrypt (DinoJingleFileEncryptionHelper* self,
                                                     DinoEntitiesConversation* conversation,
                                                     DinoEntitiesFileTransfer* file_transfer,
                                                     XmppJid* full_jid,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN gboolean dino_jingle_file_encryption_helper_can_encrypt_finish (DinoJingleFileEncryptionHelper* self,
                                                                GAsyncResult* _res_);
VALA_EXTERN gchar* dino_jingle_file_encryption_helper_get_precondition_name (DinoJingleFileEncryptionHelper* self,
                                                                 DinoEntitiesConversation* conversation,
                                                                 DinoEntitiesFileTransfer* file_transfer);
VALA_EXTERN GObject* dino_jingle_file_encryption_helper_get_precondition_options (DinoJingleFileEncryptionHelper* self,
                                                                      DinoEntitiesConversation* conversation,
                                                                      DinoEntitiesFileTransfer* file_transfer);
VALA_EXTERN DinoEntitiesEncryption dino_jingle_file_encryption_helper_get_encryption (DinoJingleFileEncryptionHelper* self,
                                                                          XmppXepJingleFileTransferFileTransfer* jingle_transfer);
VALA_EXTERN GType dino_jingle_file_encryption_helper_transfer_only_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoJingleFileEncryptionHelperTransferOnly, g_object_unref)
VALA_EXTERN DinoJingleFileEncryptionHelperTransferOnly* dino_jingle_file_encryption_helper_transfer_only_new (void);
VALA_EXTERN DinoJingleFileEncryptionHelperTransferOnly* dino_jingle_file_encryption_helper_transfer_only_construct (GType object_type);
VALA_EXTERN gpointer dino_jingle_file_helper_registry_ref (gpointer instance);
VALA_EXTERN void dino_jingle_file_helper_registry_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_jingle_file_helper_registry (const gchar* name,
                                                         const gchar* nick,
                                                         const gchar* blurb,
                                                         GType object_type,
                                                         GParamFlags flags);
VALA_EXTERN void dino_value_set_jingle_file_helper_registry (GValue* value,
                                                 gpointer v_object);
VALA_EXTERN void dino_value_take_jingle_file_helper_registry (GValue* value,
                                                  gpointer v_object);
VALA_EXTERN gpointer dino_value_get_jingle_file_helper_registry (const GValue* value);
VALA_EXTERN GType dino_jingle_file_helper_registry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoJingleFileHelperRegistry, dino_jingle_file_helper_registry_unref)
VALA_EXTERN void dino_jingle_file_helper_registry_add_encryption_helper (DinoJingleFileHelperRegistry* self,
                                                             DinoEntitiesEncryption encryption,
                                                             DinoJingleFileEncryptionHelper* helper);
VALA_EXTERN DinoJingleFileEncryptionHelper* dino_jingle_file_helper_registry_get_encryption_helper (DinoJingleFileHelperRegistry* self,
                                                                                        DinoEntitiesEncryption encryption);
VALA_EXTERN DinoJingleFileHelperRegistry* dino_jingle_file_helper_registry_new (void);
VALA_EXTERN DinoJingleFileHelperRegistry* dino_jingle_file_helper_registry_construct (GType object_type);
VALA_EXTERN DinoJingleFileHelperRegistry* dino_jingle_file_helper_registry_get_instance (void);
VALA_EXTERN GType dino_jingle_file_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoJingleFileProvider, g_object_unref)
VALA_EXTERN DinoJingleFileProvider* dino_jingle_file_provider_new (DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoJingleFileProvider* dino_jingle_file_provider_construct (GType object_type,
                                                             DinoStreamInteractor* stream_interactor);
VALA_EXTERN GType dino_jingle_file_sender_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoJingleFileSender, g_object_unref)
VALA_EXTERN DinoJingleFileSender* dino_jingle_file_sender_new (DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoJingleFileSender* dino_jingle_file_sender_construct (GType object_type,
                                                         DinoStreamInteractor* stream_interactor);
VALA_EXTERN GType dino_message_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoMessageListener, g_object_unref)
VALA_EXTERN GType dino_message_correction_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoMessageCorrection, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_message_correction_IDENTITY;
VALA_EXTERN void dino_message_correction_start (DinoStreamInteractor* stream_interactor,
                                    DinoDatabase* db);
VALA_EXTERN DinoMessageCorrection* dino_message_correction_new (DinoStreamInteractor* stream_interactor,
                                                    DinoDatabase* db);
VALA_EXTERN DinoMessageCorrection* dino_message_correction_construct (GType object_type,
                                                          DinoStreamInteractor* stream_interactor,
                                                          DinoDatabase* db);
VALA_EXTERN void dino_message_correction_set_correction (DinoMessageCorrection* self,
                                             DinoEntitiesConversation* conversation,
                                             DinoEntitiesMessage* message,
                                             DinoEntitiesMessage* old_message);
VALA_EXTERN gboolean dino_message_correction_is_own_correction_allowed (DinoMessageCorrection* self,
                                                            DinoEntitiesConversation* conversation,
                                                            DinoEntitiesMessage* message);
VALA_EXTERN void dino_message_correction_on_received_correction (DinoMessageCorrection* self,
                                                     DinoEntitiesConversation* conversation,
                                                     gint message_id);
VALA_EXTERN GType dino_message_processor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoMessageProcessor, g_object_unref)
VALA_EXTERN GType dino_message_listener_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoMessageListenerHolder, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_message_processor_IDENTITY;
VALA_EXTERN void dino_message_processor_start (DinoStreamInteractor* stream_interactor,
                                   DinoDatabase* db);
VALA_EXTERN void dino_message_processor_send_unsent_muc_messages (DinoMessageProcessor* self,
                                                      DinoEntitiesAccount* account,
                                                      XmppJid* muc_jid);
VALA_EXTERN void dino_message_processor_run_pipeline_announce (DinoMessageProcessor* self,
                                                   DinoEntitiesAccount* account,
                                                   XmppMessageStanza* message_stanza,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_);
VALA_EXTERN void dino_message_processor_run_pipeline_announce_finish (DinoMessageProcessor* self,
                                                          GAsyncResult* _res_);
VALA_EXTERN void dino_message_processor_parse_message_stanza (DinoMessageProcessor* self,
                                                  DinoEntitiesAccount* account,
                                                  XmppMessageStanza* message,
                                                  GAsyncReadyCallback _callback_,
                                                  gpointer _user_data_);
VALA_EXTERN DinoEntitiesMessage* dino_message_processor_parse_message_stanza_finish (DinoMessageProcessor* self,
                                                                         GAsyncResult* _res_);
VALA_EXTERN DinoEntitiesMessage* dino_message_processor_create_out_message (DinoMessageProcessor* self,
                                                                const gchar* text,
                                                                DinoEntitiesConversation* conversation);
VALA_EXTERN void dino_message_processor_send_xmpp_message (DinoMessageProcessor* self,
                                               DinoEntitiesMessage* message,
                                               DinoEntitiesConversation* conversation,
                                               gboolean delayed);
VALA_EXTERN void dino_message_listener_run (DinoMessageListener* self,
                                DinoEntitiesMessage* message,
                                XmppMessageStanza* stanza,
                                DinoEntitiesConversation* conversation,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN gboolean dino_message_listener_run_finish (DinoMessageListener* self,
                                           GAsyncResult* _res_);
VALA_EXTERN DinoMessageListener* dino_message_listener_construct (GType object_type);
VALA_EXTERN void dino_message_listener_holder_run (DinoMessageListenerHolder* self,
                                       DinoEntitiesMessage* message,
                                       XmppMessageStanza* stanza,
                                       DinoEntitiesConversation* conversation,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN gboolean dino_message_listener_holder_run_finish (DinoMessageListenerHolder* self,
                                                  GAsyncResult* _res_);
VALA_EXTERN DinoMessageListenerHolder* dino_message_listener_holder_new (void);
VALA_EXTERN DinoMessageListenerHolder* dino_message_listener_holder_construct (GType object_type);
VALA_EXTERN GType dino_message_storage_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoMessageStorage, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_message_storage_IDENTITY;
VALA_EXTERN void dino_message_storage_start (DinoStreamInteractor* stream_interactor,
                                 DinoDatabase* db);
VALA_EXTERN void dino_message_storage_add_message (DinoMessageStorage* self,
                                       DinoEntitiesMessage* message,
                                       DinoEntitiesConversation* conversation);
VALA_EXTERN GeeList* dino_message_storage_get_messages (DinoMessageStorage* self,
                                            DinoEntitiesConversation* conversation,
                                            gint count);
VALA_EXTERN DinoEntitiesMessage* dino_message_storage_get_last_message (DinoMessageStorage* self,
                                                            DinoEntitiesConversation* conversation);
VALA_EXTERN GeeList* dino_message_storage_get_messages_before_message (DinoMessageStorage* self,
                                                           DinoEntitiesConversation* conversation,
                                                           GDateTime* before,
                                                           gint id,
                                                           gint count);
VALA_EXTERN GeeList* dino_message_storage_get_messages_after_message (DinoMessageStorage* self,
                                                          DinoEntitiesConversation* conversation,
                                                          GDateTime* after,
                                                          gint id,
                                                          gint count);
VALA_EXTERN DinoEntitiesMessage* dino_message_storage_get_message_by_id (DinoMessageStorage* self,
                                                             gint id,
                                                             DinoEntitiesConversation* conversation);
VALA_EXTERN DinoEntitiesMessage* dino_message_storage_get_message_by_referencing_id (DinoMessageStorage* self,
                                                                         const gchar* id,
                                                                         DinoEntitiesConversation* conversation);
VALA_EXTERN DinoEntitiesMessage* dino_message_storage_get_message_by_stanza_id (DinoMessageStorage* self,
                                                                    const gchar* stanza_id,
                                                                    DinoEntitiesConversation* conversation);
VALA_EXTERN DinoEntitiesMessage* dino_message_storage_get_message_by_server_id (DinoMessageStorage* self,
                                                                    const gchar* server_id,
                                                                    DinoEntitiesConversation* conversation);
VALA_EXTERN gchar* dino_message_storage_get_reference_id (DinoEntitiesMessage* message);
VALA_EXTERN gpointer dino_module_manager_get_module (DinoModuleManager* self,
                                         GType t_type,
                                         GBoxedCopyFunc t_dup_func,
                                         GDestroyNotify t_destroy_func,
                                         DinoEntitiesAccount* account,
                                         XmppModuleIdentity* identity);
VALA_EXTERN GeeArrayList* dino_module_manager_get_modules (DinoModuleManager* self,
                                               DinoEntitiesAccount* account);
VALA_EXTERN void dino_module_manager_initialize (DinoModuleManager* self,
                                     DinoEntitiesAccount* account);
VALA_EXTERN DinoModuleManager* dino_module_manager_new (void);
VALA_EXTERN DinoModuleManager* dino_module_manager_construct (GType object_type);
VALA_EXTERN GType dino_muc_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoMucManager, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_muc_manager_IDENTITY;
VALA_EXTERN void dino_muc_manager_start (DinoStreamInteractor* stream_interactor);
VALA_EXTERN void dino_muc_manager_join (DinoMucManager* self,
                            DinoEntitiesAccount* account,
                            XmppJid* jid,
                            const gchar* nick,
                            const gchar* password,
                            gboolean already_autojoin,
                            GCancellable* cancellable,
                            GAsyncReadyCallback _callback_,
                            gpointer _user_data_);
VALA_EXTERN XmppXepMucJoinResult* dino_muc_manager_join_finish (DinoMucManager* self,
                                                    GAsyncResult* _res_);
VALA_EXTERN void dino_muc_manager_part (DinoMucManager* self,
                            DinoEntitiesAccount* account,
                            XmppJid* jid);
VALA_EXTERN void dino_muc_manager_get_config_form (DinoMucManager* self,
                                       DinoEntitiesAccount* account,
                                       XmppJid* jid,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN XmppXepDataFormsDataForm* dino_muc_manager_get_config_form_finish (DinoMucManager* self,
                                                                   GAsyncResult* _res_);
VALA_EXTERN void dino_muc_manager_set_config_form (DinoMucManager* self,
                                       DinoEntitiesAccount* account,
                                       XmppJid* jid,
                                       XmppXepDataFormsDataForm* data_form,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN void dino_muc_manager_set_config_form_finish (DinoMucManager* self,
                                              GAsyncResult* _res_);
VALA_EXTERN void dino_muc_manager_change_subject (DinoMucManager* self,
                                      DinoEntitiesAccount* account,
                                      XmppJid* jid,
                                      const gchar* subject);
VALA_EXTERN void dino_muc_manager_change_nick (DinoMucManager* self,
                                   DinoEntitiesConversation* conversation,
                                   const gchar* new_nick,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
VALA_EXTERN void dino_muc_manager_change_nick_finish (DinoMucManager* self,
                                          GAsyncResult* _res_);
VALA_EXTERN void dino_muc_manager_invite (DinoMucManager* self,
                              DinoEntitiesAccount* account,
                              XmppJid* muc,
                              XmppJid* invitee);
VALA_EXTERN void dino_muc_manager_kick (DinoMucManager* self,
                            DinoEntitiesAccount* account,
                            XmppJid* jid,
                            const gchar* nick);
VALA_EXTERN void dino_muc_manager_change_affiliation (DinoMucManager* self,
                                          DinoEntitiesAccount* account,
                                          XmppJid* jid,
                                          const gchar* nick,
                                          const gchar* role);
VALA_EXTERN void dino_muc_manager_change_role (DinoMucManager* self,
                                   DinoEntitiesAccount* account,
                                   XmppJid* jid,
                                   const gchar* nick,
                                   const gchar* role);
VALA_EXTERN void dino_muc_manager_request_voice (DinoMucManager* self,
                                     DinoEntitiesAccount* account,
                                     XmppJid* jid);
VALA_EXTERN gboolean dino_muc_manager_kick_possible (DinoMucManager* self,
                                         DinoEntitiesAccount* account,
                                         XmppJid* occupant);
VALA_EXTERN gboolean dino_muc_manager_is_private_room (DinoMucManager* self,
                                           DinoEntitiesAccount* account,
                                           XmppJid* jid);
VALA_EXTERN gboolean dino_muc_manager_is_moderated_room (DinoMucManager* self,
                                             DinoEntitiesAccount* account,
                                             XmppJid* jid);
VALA_EXTERN gboolean dino_muc_manager_is_public_room (DinoMucManager* self,
                                          DinoEntitiesAccount* account,
                                          XmppJid* jid);
VALA_EXTERN GeeList* dino_muc_manager_get_occupants (DinoMucManager* self,
                                         XmppJid* jid,
                                         DinoEntitiesAccount* account);
VALA_EXTERN GeeList* dino_muc_manager_get_other_occupants (DinoMucManager* self,
                                               XmppJid* jid,
                                               DinoEntitiesAccount* account);
VALA_EXTERN gboolean dino_muc_manager_is_groupchat (DinoMucManager* self,
                                        XmppJid* jid,
                                        DinoEntitiesAccount* account);
VALA_EXTERN gboolean dino_muc_manager_might_be_groupchat (DinoMucManager* self,
                                              XmppJid* jid,
                                              DinoEntitiesAccount* account);
VALA_EXTERN gboolean dino_muc_manager_is_groupchat_occupant (DinoMucManager* self,
                                                 XmppJid* jid,
                                                 DinoEntitiesAccount* account);
VALA_EXTERN void dino_muc_manager_get_bookmarks (DinoMucManager* self,
                                     DinoEntitiesAccount* account,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
VALA_EXTERN GeeSet* dino_muc_manager_get_bookmarks_finish (DinoMucManager* self,
                                               GAsyncResult* _res_);
VALA_EXTERN void dino_muc_manager_add_bookmark (DinoMucManager* self,
                                    DinoEntitiesAccount* account,
                                    XmppConference* conference);
VALA_EXTERN void dino_muc_manager_remove_bookmark (DinoMucManager* self,
                                       DinoEntitiesAccount* account,
                                       XmppConference* conference);
VALA_EXTERN gchar* dino_muc_manager_get_room_name (DinoMucManager* self,
                                       DinoEntitiesAccount* account,
                                       XmppJid* jid);
VALA_EXTERN gchar* dino_muc_manager_get_groupchat_subject (DinoMucManager* self,
                                               XmppJid* jid,
                                               DinoEntitiesAccount* account);
VALA_EXTERN XmppJid* dino_muc_manager_get_real_jid (DinoMucManager* self,
                                        XmppJid* jid,
                                        DinoEntitiesAccount* account);
VALA_EXTERN XmppJid* dino_muc_manager_get_occupant_jid (DinoMucManager* self,
                                            DinoEntitiesAccount* account,
                                            XmppJid* room,
                                            XmppJid* occupant_real_jid);
VALA_EXTERN XmppXepMucRole* dino_muc_manager_get_role (DinoMucManager* self,
                                           XmppJid* jid,
                                           DinoEntitiesAccount* account);
VALA_EXTERN XmppXepMucAffiliation* dino_muc_manager_get_affiliation (DinoMucManager* self,
                                                         XmppJid* muc_jid,
                                                         XmppJid* jid,
                                                         DinoEntitiesAccount* account);
VALA_EXTERN GeeList* dino_muc_manager_get_offline_members (DinoMucManager* self,
                                               XmppJid* jid,
                                               DinoEntitiesAccount* account);
VALA_EXTERN GeeList* dino_muc_manager_get_other_offline_members (DinoMucManager* self,
                                                     XmppJid* jid,
                                                     DinoEntitiesAccount* account);
VALA_EXTERN XmppJid* dino_muc_manager_get_own_jid (DinoMucManager* self,
                                       XmppJid* muc_jid,
                                       DinoEntitiesAccount* account);
VALA_EXTERN gboolean dino_muc_manager_is_own_muc_jid (DinoMucManager* self,
                                          XmppJid* full_jid,
                                          DinoEntitiesAccount* account);
VALA_EXTERN gboolean dino_muc_manager_is_joined (DinoMucManager* self,
                                     XmppJid* jid,
                                     DinoEntitiesAccount* account);
VALA_EXTERN gchar* dino_muc_manager_get_own_occupant_id (DinoMucManager* self,
                                             DinoEntitiesAccount* account,
                                             XmppJid* muc_jid);
VALA_EXTERN GType dino_notification_events_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoNotificationEvents, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_notification_events_IDENTITY;
VALA_EXTERN void dino_notification_events_start (DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoNotificationEvents* dino_notification_events_new (DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoNotificationEvents* dino_notification_events_construct (GType object_type,
                                                            DinoStreamInteractor* stream_interactor);
VALA_EXTERN GType dino_notification_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoNotificationProvider, g_object_unref)
VALA_EXTERN void dino_notification_events_register_notification_provider (DinoNotificationEvents* self,
                                                              DinoNotificationProvider* notification_provider,
                                                              GAsyncReadyCallback _callback_,
                                                              gpointer _user_data_);
VALA_EXTERN void dino_notification_events_register_notification_provider_finish (DinoNotificationEvents* self,
                                                                     GAsyncResult* _res_);
VALA_EXTERN gdouble dino_notification_provider_get_priority (DinoNotificationProvider* self);
VALA_EXTERN void dino_notification_provider_notify_message (DinoNotificationProvider* self,
                                                DinoEntitiesMessage* message,
                                                DinoEntitiesConversation* conversation,
                                                const gchar* conversation_display_name,
                                                const gchar* participant_display_name,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
VALA_EXTERN void dino_notification_provider_notify_message_finish (DinoNotificationProvider* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN void dino_notification_provider_notify_file (DinoNotificationProvider* self,
                                             DinoEntitiesFileTransfer* file_transfer,
                                             DinoEntitiesConversation* conversation,
                                             gboolean is_image,
                                             const gchar* conversation_display_name,
                                             const gchar* participant_display_name,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
VALA_EXTERN void dino_notification_provider_notify_file_finish (DinoNotificationProvider* self,
                                                    GAsyncResult* _res_);
VALA_EXTERN void dino_notification_provider_notify_call (DinoNotificationProvider* self,
                                             DinoEntitiesCall* call,
                                             DinoEntitiesConversation* conversation,
                                             gboolean video,
                                             gboolean multiparty,
                                             const gchar* conversation_display_name,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
VALA_EXTERN void dino_notification_provider_notify_call_finish (DinoNotificationProvider* self,
                                                    GAsyncResult* _res_);
VALA_EXTERN void dino_notification_provider_retract_call_notification (DinoNotificationProvider* self,
                                                           DinoEntitiesCall* call,
                                                           DinoEntitiesConversation* conversation,
                                                           GAsyncReadyCallback _callback_,
                                                           gpointer _user_data_);
VALA_EXTERN void dino_notification_provider_retract_call_notification_finish (DinoNotificationProvider* self,
                                                                  GAsyncResult* _res_);
VALA_EXTERN void dino_notification_provider_notify_subscription_request (DinoNotificationProvider* self,
                                                             DinoEntitiesConversation* conversation,
                                                             GAsyncReadyCallback _callback_,
                                                             gpointer _user_data_);
VALA_EXTERN void dino_notification_provider_notify_subscription_request_finish (DinoNotificationProvider* self,
                                                                    GAsyncResult* _res_);
VALA_EXTERN void dino_notification_provider_notify_connection_error (DinoNotificationProvider* self,
                                                         DinoEntitiesAccount* account,
                                                         DinoConnectionManagerConnectionError* _error_,
                                                         GAsyncReadyCallback _callback_,
                                                         gpointer _user_data_);
VALA_EXTERN void dino_notification_provider_notify_connection_error_finish (DinoNotificationProvider* self,
                                                                GAsyncResult* _res_);
VALA_EXTERN void dino_notification_provider_notify_muc_invite (DinoNotificationProvider* self,
                                                   DinoEntitiesAccount* account,
                                                   XmppJid* room_jid,
                                                   XmppJid* from_jid,
                                                   const gchar* inviter_display_name,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_);
VALA_EXTERN void dino_notification_provider_notify_muc_invite_finish (DinoNotificationProvider* self,
                                                          GAsyncResult* _res_);
VALA_EXTERN void dino_notification_provider_notify_voice_request (DinoNotificationProvider* self,
                                                      DinoEntitiesConversation* conversation,
                                                      XmppJid* from_jid,
                                                      GAsyncReadyCallback _callback_,
                                                      gpointer _user_data_);
VALA_EXTERN void dino_notification_provider_notify_voice_request_finish (DinoNotificationProvider* self,
                                                             GAsyncResult* _res_);
VALA_EXTERN void dino_notification_provider_retract_content_item_notifications (DinoNotificationProvider* self,
                                                                    GAsyncReadyCallback _callback_,
                                                                    gpointer _user_data_);
VALA_EXTERN void dino_notification_provider_retract_content_item_notifications_finish (DinoNotificationProvider* self,
                                                                           GAsyncResult* _res_);
VALA_EXTERN void dino_notification_provider_retract_conversation_notifications (DinoNotificationProvider* self,
                                                                    DinoEntitiesConversation* conversation,
                                                                    GAsyncReadyCallback _callback_,
                                                                    gpointer _user_data_);
VALA_EXTERN void dino_notification_provider_retract_conversation_notifications_finish (DinoNotificationProvider* self,
                                                                           GAsyncResult* _res_);
VALA_EXTERN GType dino_presence_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoPresenceManager, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_presence_manager_IDENTITY;
VALA_EXTERN void dino_presence_manager_start (DinoStreamInteractor* stream_interactor);
VALA_EXTERN gchar* dino_presence_manager_get_last_show (DinoPresenceManager* self,
                                            XmppJid* jid,
                                            DinoEntitiesAccount* account);
VALA_EXTERN GeeList* dino_presence_manager_get_full_jids (DinoPresenceManager* self,
                                              XmppJid* jid,
                                              DinoEntitiesAccount* account);
VALA_EXTERN gboolean dino_presence_manager_exists_subscription_request (DinoPresenceManager* self,
                                                            DinoEntitiesAccount* account,
                                                            XmppJid* jid);
VALA_EXTERN void dino_presence_manager_request_subscription (DinoPresenceManager* self,
                                                 DinoEntitiesAccount* account,
                                                 XmppJid* jid);
VALA_EXTERN void dino_presence_manager_approve_subscription (DinoPresenceManager* self,
                                                 DinoEntitiesAccount* account,
                                                 XmppJid* jid);
VALA_EXTERN void dino_presence_manager_deny_subscription (DinoPresenceManager* self,
                                              DinoEntitiesAccount* account,
                                              XmppJid* jid);
VALA_EXTERN void dino_presence_manager_cancel_subscription (DinoPresenceManager* self,
                                                DinoEntitiesAccount* account,
                                                XmppJid* jid);
VALA_EXTERN GType dino_replies_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoReplies, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_replies_IDENTITY;
VALA_EXTERN void dino_replies_start (DinoStreamInteractor* stream_interactor,
                         DinoDatabase* db);
VALA_EXTERN DinoContentItem* dino_replies_get_quoted_content_item (DinoReplies* self,
                                                       DinoEntitiesMessage* message,
                                                       DinoEntitiesConversation* conversation);
VALA_EXTERN gchar* dino_message_body_without_reply_fallback (DinoEntitiesMessage* message);
VALA_EXTERN GType dino_reactions_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoReactions, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_reactions_IDENTITY;
VALA_EXTERN void dino_reactions_start (DinoStreamInteractor* stream_interactor,
                           DinoDatabase* database);
VALA_EXTERN void dino_reactions_add_reaction (DinoReactions* self,
                                  DinoEntitiesConversation* conversation,
                                  DinoContentItem* content_item,
                                  const gchar* reaction);
VALA_EXTERN void dino_reactions_remove_reaction (DinoReactions* self,
                                     DinoEntitiesConversation* conversation,
                                     DinoContentItem* content_item,
                                     const gchar* reaction);
VALA_EXTERN gpointer dino_reaction_users_ref (gpointer instance);
VALA_EXTERN void dino_reaction_users_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_reaction_users (const gchar* name,
                                            const gchar* nick,
                                            const gchar* blurb,
                                            GType object_type,
                                            GParamFlags flags);
VALA_EXTERN void dino_value_set_reaction_users (GValue* value,
                                    gpointer v_object);
VALA_EXTERN void dino_value_take_reaction_users (GValue* value,
                                     gpointer v_object);
VALA_EXTERN gpointer dino_value_get_reaction_users (const GValue* value);
VALA_EXTERN GType dino_reaction_users_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoReactionUsers, dino_reaction_users_unref)
VALA_EXTERN GeeList* dino_reactions_get_item_reactions (DinoReactions* self,
                                            DinoEntitiesConversation* conversation,
                                            DinoContentItem* content_item);
VALA_EXTERN gboolean dino_reactions_conversation_supports_reactions (DinoReactions* self,
                                                         DinoEntitiesConversation* conversation);
VALA_EXTERN GeeList* dino_reactions_get_chat_message_reactions (DinoReactions* self,
                                                    DinoEntitiesAccount* account,
                                                    DinoContentItem* content_item);
VALA_EXTERN GeeList* dino_reactions_get_muc_message_reactions (DinoReactions* self,
                                                   DinoEntitiesAccount* account,
                                                   DinoContentItem* content_item);
VALA_EXTERN DinoReactionUsers* dino_reaction_users_new (void);
VALA_EXTERN DinoReactionUsers* dino_reaction_users_construct (GType object_type);
VALA_EXTERN const gchar* dino_reaction_users_get_reaction (DinoReactionUsers* self);
VALA_EXTERN void dino_reaction_users_set_reaction (DinoReactionUsers* self,
                                       const gchar* value);
VALA_EXTERN GeeList* dino_reaction_users_get_jids (DinoReactionUsers* self);
VALA_EXTERN void dino_reaction_users_set_jids (DinoReactionUsers* self,
                                   GeeList* value);
VALA_EXTERN gpointer dino_reaction_info_ref (gpointer instance);
VALA_EXTERN void dino_reaction_info_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_reaction_info (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
VALA_EXTERN void dino_value_set_reaction_info (GValue* value,
                                   gpointer v_object);
VALA_EXTERN void dino_value_take_reaction_info (GValue* value,
                                    gpointer v_object);
VALA_EXTERN gpointer dino_value_get_reaction_info (const GValue* value);
VALA_EXTERN GType dino_reaction_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoReactionInfo, dino_reaction_info_unref)
VALA_EXTERN DinoReactionInfo* dino_reaction_info_new (void);
VALA_EXTERN DinoReactionInfo* dino_reaction_info_construct (GType object_type);
VALA_EXTERN DinoEntitiesConversation* dino_reaction_info_get_conversation (DinoReactionInfo* self);
VALA_EXTERN void dino_reaction_info_set_conversation (DinoReactionInfo* self,
                                          DinoEntitiesConversation* value);
VALA_EXTERN XmppJid* dino_reaction_info_get_from_jid (DinoReactionInfo* self);
VALA_EXTERN void dino_reaction_info_set_from_jid (DinoReactionInfo* self,
                                      XmppJid* value);
VALA_EXTERN GeeList* dino_reaction_info_get_reactions (DinoReactionInfo* self);
VALA_EXTERN void dino_reaction_info_set_reactions (DinoReactionInfo* self,
                                       GeeList* value);
VALA_EXTERN XmppMessageStanza* dino_reaction_info_get_stanza (DinoReactionInfo* self);
VALA_EXTERN void dino_reaction_info_set_stanza (DinoReactionInfo* self,
                                    XmppMessageStanza* value);
VALA_EXTERN GDateTime* dino_reaction_info_get_received_time (DinoReactionInfo* self);
VALA_EXTERN void dino_reaction_info_set_received_time (DinoReactionInfo* self,
                                           GDateTime* value);
VALA_EXTERN GType dino_register_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoRegister, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_register_IDENTITY;
VALA_EXTERN void dino_register_start (DinoStreamInteractor* stream_interactor,
                          DinoDatabase* db);
VALA_EXTERN void dino_register_add_check_account (DinoRegister* self,
                                      DinoEntitiesAccount* account,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN DinoConnectionManagerConnectionErrorSource* dino_register_add_check_account_finish (DinoRegister* self,
                                                                                    GAsyncResult* _res_);
VALA_EXTERN void dino_register_change_password (DinoRegister* self,
                                    DinoEntitiesAccount* account,
                                    const gchar* new_pw,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN gchar* dino_register_change_password_finish (DinoRegister* self,
                                             GAsyncResult* _res_);
VALA_EXTERN void dino_register_check_server_availability (XmppJid* jid,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
VALA_EXTERN gpointer dino_register_server_availability_return_ref (gpointer instance);
VALA_EXTERN void dino_register_server_availability_return_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_register_param_spec_server_availability_return (const gchar* name,
                                                                 const gchar* nick,
                                                                 const gchar* blurb,
                                                                 GType object_type,
                                                                 GParamFlags flags);
VALA_EXTERN void dino_register_value_set_server_availability_return (GValue* value,
                                                         gpointer v_object);
VALA_EXTERN void dino_register_value_take_server_availability_return (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN gpointer dino_register_value_get_server_availability_return (const GValue* value);
VALA_EXTERN GType dino_register_server_availability_return_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoRegisterServerAvailabilityReturn, dino_register_server_availability_return_unref)
VALA_EXTERN DinoRegisterServerAvailabilityReturn* dino_register_check_server_availability_finish (GAsyncResult* _res_);
VALA_EXTERN void dino_register_get_registration_form (XmppJid* jid,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN gpointer dino_register_registration_form_return_ref (gpointer instance);
VALA_EXTERN void dino_register_registration_form_return_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_register_param_spec_registration_form_return (const gchar* name,
                                                               const gchar* nick,
                                                               const gchar* blurb,
                                                               GType object_type,
                                                               GParamFlags flags);
VALA_EXTERN void dino_register_value_set_registration_form_return (GValue* value,
                                                       gpointer v_object);
VALA_EXTERN void dino_register_value_take_registration_form_return (GValue* value,
                                                        gpointer v_object);
VALA_EXTERN gpointer dino_register_value_get_registration_form_return (const GValue* value);
VALA_EXTERN GType dino_register_registration_form_return_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoRegisterRegistrationFormReturn, dino_register_registration_form_return_unref)
VALA_EXTERN DinoRegisterRegistrationFormReturn* dino_register_get_registration_form_finish (GAsyncResult* _res_);
VALA_EXTERN void dino_register_submit_form (XmppJid* jid,
                                XmppXepInBandRegistrationForm* form,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN gchar* dino_register_submit_form_finish (GAsyncResult* _res_);
VALA_EXTERN DinoRegisterServerAvailabilityReturn* dino_register_server_availability_return_new (void);
VALA_EXTERN DinoRegisterServerAvailabilityReturn* dino_register_server_availability_return_construct (GType object_type);
VALA_EXTERN gboolean dino_register_server_availability_return_get_available (DinoRegisterServerAvailabilityReturn* self);
VALA_EXTERN void dino_register_server_availability_return_set_available (DinoRegisterServerAvailabilityReturn* self,
                                                             gboolean value);
VALA_EXTERN GTlsCertificateFlags* dino_register_server_availability_return_get_error_flags (DinoRegisterServerAvailabilityReturn* self);
VALA_EXTERN void dino_register_server_availability_return_set_error_flags (DinoRegisterServerAvailabilityReturn* self,
                                                               GTlsCertificateFlags* value);
VALA_EXTERN DinoRegisterRegistrationFormReturn* dino_register_registration_form_return_new (void);
VALA_EXTERN DinoRegisterRegistrationFormReturn* dino_register_registration_form_return_construct (GType object_type);
VALA_EXTERN XmppXepInBandRegistrationForm* dino_register_registration_form_return_get_form (DinoRegisterRegistrationFormReturn* self);
VALA_EXTERN void dino_register_registration_form_return_set_form (DinoRegisterRegistrationFormReturn* self,
                                                      XmppXepInBandRegistrationForm* value);
VALA_EXTERN GTlsCertificateFlags* dino_register_registration_form_return_get_error_flags (DinoRegisterRegistrationFormReturn* self);
VALA_EXTERN void dino_register_registration_form_return_set_error_flags (DinoRegisterRegistrationFormReturn* self,
                                                             GTlsCertificateFlags* value);
VALA_EXTERN GType dino_roster_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoRosterManager, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_roster_manager_IDENTITY;
VALA_EXTERN void dino_roster_manager_start (DinoStreamInteractor* stream_interactor,
                                DinoDatabase* db);
VALA_EXTERN DinoRosterManager* dino_roster_manager_new (DinoStreamInteractor* stream_interactor,
                                            DinoDatabase* db);
VALA_EXTERN DinoRosterManager* dino_roster_manager_construct (GType object_type,
                                                  DinoStreamInteractor* stream_interactor,
                                                  DinoDatabase* db);
VALA_EXTERN GeeCollection* dino_roster_manager_get_roster (DinoRosterManager* self,
                                               DinoEntitiesAccount* account);
VALA_EXTERN XmppRosterItem* dino_roster_manager_get_roster_item (DinoRosterManager* self,
                                                     DinoEntitiesAccount* account,
                                                     XmppJid* jid);
VALA_EXTERN void dino_roster_manager_remove_jid (DinoRosterManager* self,
                                     DinoEntitiesAccount* account,
                                     XmppJid* jid);
VALA_EXTERN void dino_roster_manager_add_jid (DinoRosterManager* self,
                                  DinoEntitiesAccount* account,
                                  XmppJid* jid,
                                  const gchar* handle);
VALA_EXTERN void dino_roster_manager_set_jid_handle (DinoRosterManager* self,
                                         DinoEntitiesAccount* account,
                                         XmppJid* jid,
                                         const gchar* handle);
VALA_EXTERN GType dino_roster_store_impl_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoRosterStoreImpl, g_object_unref)
VALA_EXTERN DinoRosterStoreImpl* dino_roster_store_impl_new (DinoEntitiesAccount* account,
                                                 DinoDatabase* db);
VALA_EXTERN DinoRosterStoreImpl* dino_roster_store_impl_construct (GType object_type,
                                                       DinoEntitiesAccount* account,
                                                       DinoDatabase* db);
VALA_EXTERN XmppRosterItem* dino_roster_store_impl_get_item (DinoRosterStoreImpl* self,
                                                 XmppJid* jid);
VALA_EXTERN GType dino_search_processor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoSearchProcessor, g_object_unref)
VALA_EXTERN DinoModuleIdentity* dino_search_processor_IDENTITY;
VALA_EXTERN void dino_search_processor_start (DinoStreamInteractor* stream_interactor,
                                  DinoDatabase* db);
VALA_EXTERN DinoSearchProcessor* dino_search_processor_new (DinoStreamInteractor* stream_interactor,
                                                DinoDatabase* db);
VALA_EXTERN DinoSearchProcessor* dino_search_processor_construct (GType object_type,
                                                      DinoStreamInteractor* stream_interactor,
                                                      DinoDatabase* db);
VALA_EXTERN GType dino_search_suggestion_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoSearchSuggestion, g_object_unref)
VALA_EXTERN GeeList* dino_search_processor_suggest_auto_complete (DinoSearchProcessor* self,
                                                      const gchar* query,
                                                      gint cursor_position,
                                                      gint limit);
VALA_EXTERN GeeList* dino_search_processor_match_messages (DinoSearchProcessor* self,
                                               const gchar* query,
                                               gint offset);
VALA_EXTERN gint dino_search_processor_count_match_messages (DinoSearchProcessor* self,
                                                 const gchar* query);
VALA_EXTERN DinoSearchSuggestion* dino_search_suggestion_new (DinoEntitiesConversation* conversation,
                                                  XmppJid* jid,
                                                  const gchar* completion,
                                                  gint start_index,
                                                  gint end_index);
VALA_EXTERN DinoSearchSuggestion* dino_search_suggestion_construct (GType object_type,
                                                        DinoEntitiesConversation* conversation,
                                                        XmppJid* jid,
                                                        const gchar* completion,
                                                        gint start_index,
                                                        gint end_index);
VALA_EXTERN DinoEntitiesAccount* dino_search_suggestion_get_account (DinoSearchSuggestion* self);
VALA_EXTERN DinoEntitiesConversation* dino_search_suggestion_get_conversation (DinoSearchSuggestion* self);
VALA_EXTERN XmppJid* dino_search_suggestion_get_jid (DinoSearchSuggestion* self);
VALA_EXTERN const gchar* dino_search_suggestion_get_completion (DinoSearchSuggestion* self);
VALA_EXTERN gint dino_search_suggestion_get_start_index (DinoSearchSuggestion* self);
VALA_EXTERN gint dino_search_suggestion_get_end_index (DinoSearchSuggestion* self);
VALA_EXTERN glong dino_search_suggestion_get_order (DinoSearchSuggestion* self);
VALA_EXTERN void dino_search_suggestion_set_order (DinoSearchSuggestion* self,
                                       glong value);
VALA_EXTERN gboolean dino_file_metadata_provider_supports_file (DinoFileMetadataProvider* self,
                                                    GFile* file);
VALA_EXTERN void dino_file_metadata_provider_fill_metadata (DinoFileMetadataProvider* self,
                                                GFile* file,
                                                XmppXepFileMetadataElementFileMetadata* metadata,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
VALA_EXTERN void dino_file_metadata_provider_fill_metadata_finish (DinoFileMetadataProvider* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN GType dino_image_file_metadata_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoImageFileMetadataProvider, g_object_unref)
VALA_EXTERN DinoImageFileMetadataProvider* dino_image_file_metadata_provider_new (void);
VALA_EXTERN DinoImageFileMetadataProvider* dino_image_file_metadata_provider_construct (GType object_type);
VALA_EXTERN DinoModuleIdentity* dino_stateless_file_sharing_IDENTITY;
VALA_EXTERN void dino_stateless_file_sharing_start (DinoStreamInteractor* stream_interactor,
                                        DinoDatabase* db);
VALA_EXTERN void dino_stateless_file_sharing_create_file_transfer (DinoStatelessFileSharing* self,
                                                       DinoEntitiesConversation* conversation,
                                                       DinoEntitiesMessage* message,
                                                       const gchar* file_sharing_id,
                                                       XmppXepFileMetadataElementFileMetadata* metadata,
                                                       GeeList* sources,
                                                       GAsyncReadyCallback _callback_,
                                                       gpointer _user_data_);
VALA_EXTERN void dino_stateless_file_sharing_create_file_transfer_finish (DinoStatelessFileSharing* self,
                                                              GAsyncResult* _res_);
VALA_EXTERN void dino_stateless_file_sharing_on_received_sources (DinoStatelessFileSharing* self,
                                                      XmppJid* from,
                                                      DinoEntitiesConversation* conversation,
                                                      const gchar* attach_to_message_id,
                                                      const gchar* attach_to_file_id,
                                                      GeeList* sources);
VALA_EXTERN DinoStreamInteractor* dino_stateless_file_sharing_get_stream_interactor (DinoStatelessFileSharing* self);
VALA_EXTERN DinoFileManager* dino_stateless_file_sharing_get_file_manager (DinoStatelessFileSharing* self);
VALA_EXTERN DinoDatabase* dino_stateless_file_sharing_get_db (DinoStatelessFileSharing* self);
VALA_EXTERN DinoStreamInteractor* dino_stream_interactor_new (DinoDatabase* db);
VALA_EXTERN DinoStreamInteractor* dino_stream_interactor_construct (GType object_type,
                                                        DinoDatabase* db);
VALA_EXTERN void dino_stream_interactor_connect_account (DinoStreamInteractor* self,
                                             DinoEntitiesAccount* account);
VALA_EXTERN void dino_stream_interactor_disconnect_account (DinoStreamInteractor* self,
                                                DinoEntitiesAccount* account,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
VALA_EXTERN void dino_stream_interactor_disconnect_account_finish (DinoStreamInteractor* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN GeeArrayList* dino_stream_interactor_get_accounts (DinoStreamInteractor* self);
VALA_EXTERN XmppXmppStream* dino_stream_interactor_get_stream (DinoStreamInteractor* self,
                                                   DinoEntitiesAccount* account);
VALA_EXTERN void dino_stream_interactor_add_module (DinoStreamInteractor* self,
                                        DinoStreamInteractionModule* module);
VALA_EXTERN gpointer dino_stream_interactor_get_module (DinoStreamInteractor* self,
                                            GType t_type,
                                            GBoxedCopyFunc t_dup_func,
                                            GDestroyNotify t_destroy_func,
                                            DinoModuleIdentity* identity);
VALA_EXTERN gpointer dino_stream_interactor_get (DinoStreamInteractor* self,
                                     GType t_type,
                                     GBoxedCopyFunc t_dup_func,
                                     GDestroyNotify t_destroy_func);
VALA_EXTERN DinoModuleIdentity* dino_module_identity_new (GType t_type,
                                              GBoxedCopyFunc t_dup_func,
                                              GDestroyNotify t_destroy_func,
                                              const gchar* id);
VALA_EXTERN DinoModuleIdentity* dino_module_identity_construct (GType object_type,
                                                    GType t_type,
                                                    GBoxedCopyFunc t_dup_func,
                                                    GDestroyNotify t_destroy_func,
                                                    const gchar* id);
VALA_EXTERN gpointer dino_module_identity_cast (DinoModuleIdentity* self,
                                    DinoStreamInteractionModule* module);
VALA_EXTERN gboolean dino_module_identity_matches (DinoModuleIdentity* self,
                                       DinoStreamInteractionModule* module);
VALA_EXTERN const gchar* dino_module_identity_get_id (DinoModuleIdentity* self);
VALA_EXTERN const gchar* dino_stream_interaction_module_get_id (DinoStreamInteractionModule* self);
VALA_EXTERN gpointer dino_util_ref (gpointer instance);
VALA_EXTERN void dino_util_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_util (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
VALA_EXTERN void dino_value_set_util (GValue* value,
                          gpointer v_object);
VALA_EXTERN void dino_value_take_util (GValue* value,
                           gpointer v_object);
VALA_EXTERN gpointer dino_value_get_util (const GValue* value);
VALA_EXTERN GType dino_util_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUtil, dino_util_unref)
VALA_EXTERN DinoEntitiesMessageType dino_util_get_message_type_for_conversation (DinoEntitiesConversation* conversation);
VALA_EXTERN DinoEntitiesConversationType dino_util_get_conversation_type_for_message (DinoEntitiesMessage* message);
VALA_EXTERN gboolean dino_util_is_pixbuf_supported_mime_type (const gchar* mime_type);
VALA_EXTERN DinoUtil* dino_util_new (void);
VALA_EXTERN DinoUtil* dino_util_construct (GType object_type);
VALA_EXTERN gchar* dino_get_conversation_display_name (DinoStreamInteractor* stream_interactor,
                                           DinoEntitiesConversation* conversation,
                                           const gchar* muc_pm_format);
VALA_EXTERN gchar* dino_get_participant_display_name (DinoStreamInteractor* stream_interactor,
                                          DinoEntitiesConversation* conversation,
                                          XmppJid* participant,
                                          const gchar* self_word);
VALA_EXTERN gchar* dino_get_real_display_name (DinoStreamInteractor* stream_interactor,
                                   DinoEntitiesAccount* account,
                                   XmppJid* jid,
                                   const gchar* self_word);
VALA_EXTERN gchar* dino_get_groupchat_display_name (DinoStreamInteractor* stream_interactor,
                                        DinoEntitiesAccount* account,
                                        XmppJid* jid);
VALA_EXTERN gchar* dino_get_occupant_display_name (DinoStreamInteractor* stream_interactor,
                                       DinoEntitiesConversation* conversation,
                                       XmppJid* jid,
                                       const gchar* self_word,
                                       gboolean muc_real_name);
VALA_EXTERN GType dino_limit_input_stream_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoLimitInputStream, g_object_unref)
VALA_EXTERN DinoLimitInputStream* dino_limit_input_stream_new (GInputStream* inner,
                                                   gint64 max_bytes);
VALA_EXTERN DinoLimitInputStream* dino_limit_input_stream_construct (GType object_type,
                                                         GInputStream* inner,
                                                         gint64 max_bytes);
VALA_EXTERN gint64 dino_limit_input_stream_get_max_bytes (DinoLimitInputStream* self);
VALA_EXTERN gint64 dino_limit_input_stream_get_retrieved_bytes (DinoLimitInputStream* self);
VALA_EXTERN gint64 dino_limit_input_stream_get_remaining_bytes (DinoLimitInputStream* self);
VALA_EXTERN void dino_send_message (DinoEntitiesConversation* conversation,
                        const gchar* text,
                        gint reply_to_id,
                        DinoEntitiesMessage* correction_to,
                        GeeList* markups);
VALA_EXTERN DinoSearchPathGenerator* dino_search_path_generator_new (const gchar* exec_path);
VALA_EXTERN DinoSearchPathGenerator* dino_search_path_generator_construct (GType object_type,
                                                               const gchar* exec_path);
VALA_EXTERN gchar* dino_search_path_generator_get_locale_path (DinoSearchPathGenerator* self,
                                                   const gchar* gettext_package,
                                                   const gchar* locale_install_dir);
VALA_EXTERN gchar** dino_search_path_generator_get_plugin_paths (DinoSearchPathGenerator* self,
                                                     gint* result_length1);
VALA_EXTERN const gchar* dino_search_path_generator_get_exec_path (DinoSearchPathGenerator* self);
VALA_EXTERN gchar* dino_get_storage_dir (void);
VALA_EXTERN gchar* dino_get_cache_dir (void);
VALA_EXTERN void dino_internationalize (const gchar* gettext_package,
                            const gchar* locales_dir);
VALA_EXTERN void dino_compute_file_hashes (GFile* file,
                               GeeList* checksum_types,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
VALA_EXTERN GeeHashMap* dino_compute_file_hashes_finish (GAsyncResult* _res_);
VALA_EXTERN WeakMap* weak_map_new (GType k_type,
                       GBoxedCopyFunc k_dup_func,
                       GDestroyNotify k_destroy_func,
                       GType v_type,
                       GBoxedCopyFunc v_dup_func,
                       GDestroyNotify v_destroy_func,
                       GeeHashDataFunc key_hash_func,
                       gpointer key_hash_func_target,
                       GDestroyNotify key_hash_func_target_destroy_notify,
                       GeeEqualDataFunc key_equal_func,
                       gpointer key_equal_func_target,
                       GDestroyNotify key_equal_func_target_destroy_notify,
                       GeeEqualDataFunc value_equal_func,
                       gpointer value_equal_func_target,
                       GDestroyNotify value_equal_func_target_destroy_notify);
VALA_EXTERN WeakMap* weak_map_construct (GType object_type,
                             GType k_type,
                             GBoxedCopyFunc k_dup_func,
                             GDestroyNotify k_destroy_func,
                             GType v_type,
                             GBoxedCopyFunc v_dup_func,
                             GDestroyNotify v_destroy_func,
                             GeeHashDataFunc key_hash_func,
                             gpointer key_hash_func_target,
                             GDestroyNotify key_hash_func_target_destroy_notify,
                             GeeEqualDataFunc key_equal_func,
                             gpointer key_equal_func_target,
                             GDestroyNotify key_equal_func_target_destroy_notify,
                             GeeEqualDataFunc value_equal_func,
                             gpointer value_equal_func_target,
                             GDestroyNotify value_equal_func_target_destroy_notify);
VALA_EXTERN gpointer dino_weak_timeout_ref (gpointer instance);
VALA_EXTERN void dino_weak_timeout_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_param_spec_weak_timeout (const gchar* name,
                                          const gchar* nick,
                                          const gchar* blurb,
                                          GType object_type,
                                          GParamFlags flags);
VALA_EXTERN void dino_value_set_weak_timeout (GValue* value,
                                  gpointer v_object);
VALA_EXTERN void dino_value_take_weak_timeout (GValue* value,
                                   gpointer v_object);
VALA_EXTERN gpointer dino_value_get_weak_timeout (const GValue* value);
VALA_EXTERN GType dino_weak_timeout_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoWeakTimeout, dino_weak_timeout_unref)
VALA_EXTERN guint dino_weak_timeout_add (GType t_type,
                             GBoxedCopyFunc t_dup_func,
                             GDestroyNotify t_destroy_func,
                             guint interval,
                             gconstpointer object,
                             DinoWeakTimeoutSourceFunc function,
                             gint priority);
VALA_EXTERN guint dino_weak_timeout_add_once (GType t_type,
                                  GBoxedCopyFunc t_dup_func,
                                  GDestroyNotify t_destroy_func,
                                  guint interval,
                                  gconstpointer object,
                                  DinoWeakTimeoutSourceOnceFunc function,
                                  gint priority);
VALA_EXTERN guint dino_weak_timeout_add_seconds (GType t_type,
                                     GBoxedCopyFunc t_dup_func,
                                     GDestroyNotify t_destroy_func,
                                     guint interval,
                                     gconstpointer object,
                                     DinoWeakTimeoutSourceFunc function,
                                     gint priority);
VALA_EXTERN guint dino_weak_timeout_add_seconds_once (GType t_type,
                                          GBoxedCopyFunc t_dup_func,
                                          GDestroyNotify t_destroy_func,
                                          guint interval,
                                          gconstpointer object,
                                          DinoWeakTimeoutSourceOnceFunc function,
                                          gint priority);
VALA_EXTERN DinoWeakTimeout* dino_weak_timeout_new (void);
VALA_EXTERN DinoWeakTimeout* dino_weak_timeout_construct (GType object_type);

G_END_DECLS

#endif
