/* xmpp-vala.h generated by valac 0.56.18-dirty, the Vala compiler, do not modify */

#ifndef __XMPP_VALA_XMPP_VALA_H__
#define __XMPP_VALA_XMPP_VALA_H__

#include <glib-object.h>
#include <gio/gio.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <stdarg.h>
#include <float.h>
#include <math.h>
#include <gdk-pixbuf/gdk-pixbuf.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define XMPP_STANZA_ENTRY_ANSI_COLOR_END "\x1b[0m"
#define XMPP_STANZA_ENTRY_ANSI_COLOR_GREEN "\x1b[32m"
#define XMPP_STANZA_ENTRY_ANSI_COLOR_YELLOW "\x1b[33m"
#define XMPP_STANZA_ENTRY_ANSI_COLOR_GRAY "\x1b[37m"
#define XMPP_XMLNS_URI "http://www.w3.org/2000/xmlns/"
#define XMPP_XML_URI "http://www.w3.org/XML/1998/namespace"
#define XMPP_JABBER_URI "jabber:client"
#define XMPP_XMPP_LOG_ANSI_COLOR_END "\x1b[0m"
#define XMPP_XMPP_LOG_ANSI_COLOR_WHITE "\x1b[37;1m"
#define XMPP_XMPP_STREAM_NS_URI "http://etherx.jabber.org/streams"
#define XMPP_IQ_STANZA_TYPE_GET "get"
#define XMPP_IQ_STANZA_TYPE_RESULT "result"
#define XMPP_IQ_STANZA_TYPE_SET "set"
#define XMPP_MESSAGE_STANZA_NODE_BODY "body"
#define XMPP_MESSAGE_STANZA_NODE_SUBJECT "subject"
#define XMPP_MESSAGE_STANZA_NODE_THREAD "thread"
#define XMPP_MESSAGE_STANZA_TYPE_CHAT "chat"
#define XMPP_MESSAGE_STANZA_TYPE_GROUPCHAT "groupchat"
#define XMPP_MESSAGE_STANZA_TYPE_HEADLINE "headline"
#define XMPP_MESSAGE_STANZA_TYPE_NORMAL "normal"
#define XMPP_PRESENCE_STANZA_NODE_PRIORITY "priority"
#define XMPP_PRESENCE_STANZA_NODE_STATUS "status"
#define XMPP_PRESENCE_STANZA_NODE_SHOW "show"
#define XMPP_PRESENCE_STANZA_SHOW_ONLINE "online"
#define XMPP_PRESENCE_STANZA_SHOW_AWAY "away"
#define XMPP_PRESENCE_STANZA_SHOW_CHAT "chat"
#define XMPP_PRESENCE_STANZA_SHOW_DND "dnd"
#define XMPP_PRESENCE_STANZA_SHOW_XA "xa"
#define XMPP_PRESENCE_STANZA_TYPE_AVAILABLE "available"
#define XMPP_PRESENCE_STANZA_TYPE_PROBE "probe"
#define XMPP_PRESENCE_STANZA_TYPE_SUBSCRIBE "subscribe"
#define XMPP_PRESENCE_STANZA_TYPE_SUBSCRIBED "subscribed"
#define XMPP_PRESENCE_STANZA_TYPE_UNAVAILABLE "unavailable"
#define XMPP_PRESENCE_STANZA_TYPE_UNSUBSCRIBE "unsubscribe"
#define XMPP_PRESENCE_STANZA_TYPE_UNSUBSCRIBED "unsubscribed"
#define XMPP_ROSTER_FLAG_ID "roster"
#define XMPP_ROSTER_ITEM_SUBSCRIPTION_NONE "none"
#define XMPP_ROSTER_ITEM_SUBSCRIPTION_TO "to"
#define XMPP_ROSTER_ITEM_SUBSCRIPTION_FROM "from"
#define XMPP_ROSTER_ITEM_SUBSCRIPTION_BOTH "both"
#define XMPP_ROSTER_ITEM_SUBSCRIPTION_REMOVE "remove"
#define XMPP_SASL_MECHANISM_PLAIN "PLAIN"
#define XMPP_SASL_MECHANISM_SCRAM_SHA_1 "SCRAM-SHA-1"
#define XMPP_SASL_MECHANISM_SCRAM_SHA_1_PLUS "SCRAM-SHA-1-PLUS"
#define XMPP_STANZA_ATTRIBUTE_FROM "from"
#define XMPP_STANZA_ATTRIBUTE_ID "id"
#define XMPP_STANZA_ATTRIBUTE_TO "to"
#define XMPP_STANZA_ATTRIBUTE_TYPE "type"
#define XMPP_STANZA_TYPE_ERROR "error"
#define XMPP_ERROR_STANZA_CONDITION_BAD_REQUEST "bad-request"
#define XMPP_ERROR_STANZA_CONDITION_CONFLICT "conflict"
#define XMPP_ERROR_STANZA_CONDITION_FEATURE_NOT_IMPLEMENTED "feature-not-implemented"
#define XMPP_ERROR_STANZA_CONDITION_FORBIDDEN "forbidden"
#define XMPP_ERROR_STANZA_CONDITION_GONE "gone"
#define XMPP_ERROR_STANZA_CONDITION_INTERNAL_SERVER_ERROR "internal-server-error"
#define XMPP_ERROR_STANZA_CONDITION_ITEM_NOT_FOUND "item-not-found"
#define XMPP_ERROR_STANZA_CONDITION_JID_MALFORMED "jid-malformed"
#define XMPP_ERROR_STANZA_CONDITION_NOT_ACCEPTABLE "not-acceptable"
#define XMPP_ERROR_STANZA_CONDITION_NOT_ALLOWED "not-allowed"
#define XMPP_ERROR_STANZA_CONDITION_NOT_AUTHORIZED "not-authorized"
#define XMPP_ERROR_STANZA_CONDITION_POLICY_VIOLATION "policy-violation"
#define XMPP_ERROR_STANZA_CONDITION_RECIPIENT_UNAVAILABLE "recipient-unavailable"
#define XMPP_ERROR_STANZA_CONDITION_REDIRECT "redirect"
#define XMPP_ERROR_STANZA_CONDITION_REGISTRATION_REQUIRED "registration-required"
#define XMPP_ERROR_STANZA_CONDITION_REMOTE_SERVER_NOT_FOUND "remote-server-not-found"
#define XMPP_ERROR_STANZA_CONDITION_REMOTE_SERVER_TIMEOUT "remote-server-timeout"
#define XMPP_ERROR_STANZA_CONDITION_RESOURCE_CONSTRAINT "resource-constraint"
#define XMPP_ERROR_STANZA_CONDITION_SERVICE_UNAVAILABLE "service-unavailable"
#define XMPP_ERROR_STANZA_CONDITION_SUBSCRIPTION_REQUIRED "subscription-required"
#define XMPP_ERROR_STANZA_CONDITION_UNDEFINED_CONDITION "undefined-condition"
#define XMPP_ERROR_STANZA_CONDITION_UNEXPECTED_REQUEST "unexpected-request"
#define XMPP_ERROR_STANZA_TYPE_AUTH "auth"
#define XMPP_ERROR_STANZA_TYPE_CANCEL "cancel"
#define XMPP_ERROR_STANZA_TYPE_CONTINUE "continue"
#define XMPP_ERROR_STANZA_TYPE_MODIFY "modify"
#define XMPP_ERROR_STANZA_TYPE_WAIT "wait"
#define XMPP_XEP_DATA_FORMS_NS_URI "jabber:x:data"
#define XMPP_XEP_SERVICE_DISCOVERY_IDENTITY_CATEGORY_CLIENT "client"
#define XMPP_XEP_SERVICE_DISCOVERY_IDENTITY_CATEGORY_CONFERENCE "conference"
#define XMPP_XEP_SERVICE_DISCOVERY_IDENTITY_TYPE_PC "pc"
#define XMPP_XEP_SERVICE_DISCOVERY_IDENTITY_TYPE_PHONE "phone"
#define XMPP_XEP_SERVICE_DISCOVERY_IDENTITY_TYPE_TABLET "tablet"
#define XMPP_XEP_SERVICE_DISCOVERY_NS_URI "http://jabber.org/protocol/disco"
#define XMPP_XEP_SERVICE_DISCOVERY_NS_URI_INFO XMPP_XEP_SERVICE_DISCOVERY_NS_URI "#info"
#define XMPP_XEP_SERVICE_DISCOVERY_NS_URI_ITEMS XMPP_XEP_SERVICE_DISCOVERY_NS_URI "#items"
#define XMPP_XEP_BOOKMARKS_BOOKMARKS1_CONFERENCE_ATTRIBUTE_AUTOJOIN "autojoin"
#define XMPP_XEP_BOOKMARKS_BOOKMARKS1_CONFERENCE_ATTRIBUTE_JID "jid"
#define XMPP_XEP_BOOKMARKS_BOOKMARKS1_CONFERENCE_ATTRIBUTE_NAME "name"
#define XMPP_XEP_BOOKMARKS_BOOKMARKS1_CONFERENCE_NODE_NICK "nick"
#define XMPP_XEP_BOOKMARKS_BOOKMARKS1_CONFERENCE_NODE_PASSWORD "password"
#define XMPP_XEP_MESSAGE_MARKUP_NS_URI "urn:xmpp:markup:0"
#define XMPP_RESULT_SET_MANAGEMENT_NS_URI "http://jabber.org/protocol/rsm"
#define XMPP_XEP_PUBSUB_NS_URI "http://jabber.org/protocol/pubsub"
#define XMPP_XEP_PUBSUB_NS_URI_ERROR XMPP_XEP_PUBSUB_NS_URI "#errors"
#define XMPP_XEP_PUBSUB_ACCESS_MODEL_AUTHORIZE "authorize"
#define XMPP_XEP_PUBSUB_ACCESS_MODEL_OPEN "open"
#define XMPP_XEP_PUBSUB_ACCESS_MODEL_PRESENCE "presence"
#define XMPP_XEP_PUBSUB_ACCESS_MODEL_ROSTER "roster"
#define XMPP_XEP_PUBSUB_ACCESS_MODEL_WHITELIST "whitelist"
#define XMPP_XEP_OUT_OF_BAND_DATA_NS_URI "jabber:x:oob"
#define XMPP_XEP_IN_BAND_REGISTRATION_NS_URI "jabber:iq:register"
#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_STATE_ACTIVE "active"
#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_STATE_INACTIVE "inactive"
#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_STATE_GONE "gone"
#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_STATE_COMPOSING "composing"
#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_STATE_PAUSED "paused"
#define XMPP_XEP_HTTP_SCHEME_FOR_URL_DATA_NS_URI "http://jabber.org/protocol/url-data"
#define XMPP_XEP_JINGLE_NS_URI "urn:xmpp:jingle:1"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_ALTERNATIVE_SESSION "alternative-session"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_BUSY "busy"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_CANCEL "cancel"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_CONNECTIVITY_ERROR "connectivity-error"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_DECLINE "decline"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_EXPIRED "expired"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_FAILED_APPLICATION "failed_application"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_FAILED_TRANSPORT "failed_transport"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_GENERAL_ERROR "general-error"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_GONE "gone"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_INCOMPATIBLE_PARAMETERS "incompatible-parameters"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_MEDIA_ERROR "media-error"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_SECURITY_ERROR "security-error"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_SUCCESS "success"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_TIMEOUT "timeout"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_UNSUPPORTED_APPLICATIONS "unsupported-applications"
#define XMPP_XEP_JINGLE_REASON_ELEMENT_UNSUPPORTED_TRANSPORTS "unsupported-transports"
#define XMPP_XEP_JINGLE_RTP_HEADER_EXTENSION_NS_URI "urn:xmpp:jingle:apps:rtp:rtp-hdrext:0"
#define XMPP_XEP_JINGLE_RTP_HEADER_EXTENSION_NAME "rtp-hdrext"
#define XMPP_XEP_JINGLE_RTP_NS_URI "urn:xmpp:jingle:apps:rtp:1"
#define XMPP_XEP_JINGLE_RTP_NS_URI_AUDIO "urn:xmpp:jingle:apps:rtp:audio"
#define XMPP_XEP_JINGLE_RTP_NS_URI_VIDEO "urn:xmpp:jingle:apps:rtp:video"
#define XMPP_XEP_JINGLE_RTP_CRYPTO_AES_CM_128_HMAC_SHA1_80 "AES_CM_128_HMAC_SHA1_80"
#define XMPP_XEP_JINGLE_RTP_CRYPTO_AES_CM_128_HMAC_SHA1_32 "AES_CM_128_HMAC_SHA1_32"
#define XMPP_XEP_JINGLE_RTP_CRYPTO_F8_128_HMAC_SHA1_80 "F8_128_HMAC_SHA1_80"
#define XMPP_XEP_JINGLE_RTP_PAYLOAD_TYPE_NAME "payload-type"
#define XMPP_XEP_JINGLE_RTP_RTCP_FEEDBACK_NS_URI "urn:xmpp:jingle:apps:rtp:rtcp-fb:0"
#define XMPP_XEP_JINGLE_RTP_RTCP_FEEDBACK_NAME "rtcp-fb"
#define XMPP_XEP_JINGLE_RTP_SESSION_INFO_TYPE_NS_URI "urn:xmpp:jingle:apps:rtp:info:1"
#define XMPP_XEP_JINGLE_ICE_UDP_NS_URI "urn:xmpp:jingle:transports:ice-udp:1"
#define XMPP_XEP_JINGLE_ICE_UDP_DTLS_NS_URI "urn:xmpp:jingle:apps:dtls:0"
#define XMPP_XEP_JINGLE_RAW_UDP_NS_URI "urn:xmpp:jingle:transports:raw-udp:1"
#define XMPP_XEP_STREAM_MANAGEMENT_NS_URI "urn:xmpp:sm:3"
#define XMPP_XEP_DELAYED_DELIVERY_NS_URI "urn:xmpp:delay"
#define XMPP_XEP_DELAYED_DELIVERY_MESSAGE_FLAG_ID "delayed_delivery"
#define XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_NS_URI "urn:xmpp:thumbs:1"
#define XMPP_XEP_MUJI_NS_URI "urn:xmpp:jingle:muji:0"
#define XMPP_XEP_MESSAGE_CARBONS_MESSAGE_FLAG_ID "message_carbons"
#define XMPP_XEP_MESSAGE_CARBONS_MESSAGE_FLAG_TYPE_RECEIVED "received"
#define XMPP_XEP_MESSAGE_CARBONS_MESSAGE_FLAG_TYPE_SENT "sent"
#define XMPP_STANZA_FORWARDING_NS_URI "urn:xmpp:forward:0"
#define XMPP_XEP_CRYPTOGRAPHIC_HASHES_NS_URI "urn:xmpp:hashes:2"
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_NS_URI "urn:xmpp:mam:2"
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_MESSAGE_FLAG_ID "message_archive_management"
#define XMPP_XEP_CHAT_MARKERS_MARKER_RECEIVED "received"
#define XMPP_XEP_CHAT_MARKERS_MARKER_DISPLAYED "displayed"
#define XMPP_XEP_CHAT_MARKERS_MARKER_ACKNOWLEDGED "acknowledged"
#define XMPP_XEP_MESSAGE_PROCESSING_HINTS_HINT_NO_PERMANENT_STORE "no-permanent-store"
#define XMPP_XEP_MESSAGE_PROCESSING_HINTS_HINT_NO_STORE "no-store"
#define XMPP_XEP_MESSAGE_PROCESSING_HINTS_HINT_NO_COPY "no-copy"
#define XMPP_XEP_MESSAGE_PROCESSING_HINTS_HINT_STORE "store"
#define XMPP_XEP_JINGLE_MESSAGE_INITIATION_NS_URI "urn:xmpp:jingle-message:0"
#define XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_NS_URI "urn:xmpp:sid:0"
#define XMPP_XEP_MESSAGE_ATTACHING_NS_URI "urn:xmpp:message-attaching:1"
#define XMPP_XEP_EXPLICIT_ENCRYPTION_NS_URI "urn:xmpp:eme:0"
#define XMPP_XEP_OMEMO_NS_URI "eu.siacs.conversations.axolotl"
#define XMPP_XEP_OMEMO_NODE_DEVICELIST XMPP_XEP_OMEMO_NS_URI ".devicelist"
#define XMPP_XEP_OMEMO_NODE_BUNDLES XMPP_XEP_OMEMO_NS_URI ".bundles"
#define XMPP_XEP_OMEMO_NODE_VERIFICATION XMPP_XEP_OMEMO_NS_URI ".verification"
#define XMPP_XEP_JET_NS_URI "urn:xmpp:jingle:jet:0"
#define XMPP_XEP_BOOKMARKS2_NS_URI "urn:xmpp:bookmarks:1"
#define XMPP_XEP_BOOKMARKS2_NS_URI_COMPAT XMPP_XEP_BOOKMARKS2_NS_URI "#compat"
#define XMPP_XEP_OCCUPANT_IDS_NS_URI "urn:xmpp:occupant-id:0"
#define XMPP_XEP_FALLBACK_INDICATION_NS_URI "urn:xmpp:fallback:0"
#define XMPP_XEP_REACTIONS_NS_URI "urn:xmpp:reactions:0"
#define XMPP_XEP_FILE_METADATA_ELEMENT_NS_URI "urn:xmpp:file:metadata:0"
#define XMPP_XEP_STATELESS_FILE_SHARING_NS_URI "urn:xmpp:sfs:0"
#define XMPP_XEP_REPLIES_NS_URI "urn:xmpp:reply:0"
#define XMPP_XEP_CALL_INVITES_NS_URI "urn:xmpp:call-invites:0"
#define XMPP_XEP_CALL_INVITES_NS_URI_CUSTOM "urn:xmpp:call-message:1"

#define XMPP_TYPE_XMPP_STREAM (xmpp_xmpp_stream_get_type ())
#define XMPP_XMPP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_XMPP_STREAM, XmppXmppStream))
#define XMPP_XMPP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_XMPP_STREAM, XmppXmppStreamClass))
#define XMPP_IS_XMPP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_XMPP_STREAM))
#define XMPP_IS_XMPP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_XMPP_STREAM))
#define XMPP_XMPP_STREAM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_XMPP_STREAM, XmppXmppStreamClass))

typedef struct _XmppXmppStream XmppXmppStream;
typedef struct _XmppXmppStreamClass XmppXmppStreamClass;
typedef struct _XmppXmppStreamPrivate XmppXmppStreamPrivate;

#define XMPP_TYPE_STANZA_ENTRY (xmpp_stanza_entry_get_type ())
#define XMPP_STANZA_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_STANZA_ENTRY, XmppStanzaEntry))
#define XMPP_STANZA_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_STANZA_ENTRY, XmppStanzaEntryClass))
#define XMPP_IS_STANZA_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_STANZA_ENTRY))
#define XMPP_IS_STANZA_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_STANZA_ENTRY))
#define XMPP_STANZA_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_STANZA_ENTRY, XmppStanzaEntryClass))

typedef struct _XmppStanzaEntry XmppStanzaEntry;
typedef struct _XmppStanzaEntryClass XmppStanzaEntryClass;

#define XMPP_TYPE_STANZA_NODE (xmpp_stanza_node_get_type ())
#define XMPP_STANZA_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_STANZA_NODE, XmppStanzaNode))
#define XMPP_STANZA_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_STANZA_NODE, XmppStanzaNodeClass))
#define XMPP_IS_STANZA_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_STANZA_NODE))
#define XMPP_IS_STANZA_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_STANZA_NODE))
#define XMPP_STANZA_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_STANZA_NODE, XmppStanzaNodeClass))

typedef struct _XmppStanzaNode XmppStanzaNode;
typedef struct _XmppStanzaNodeClass XmppStanzaNodeClass;

#define XMPP_TYPE_JID (xmpp_jid_get_type ())
#define XMPP_JID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_JID, XmppJid))
#define XMPP_JID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_JID, XmppJidClass))
#define XMPP_IS_JID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_JID))
#define XMPP_IS_JID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_JID))
#define XMPP_JID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_JID, XmppJidClass))

typedef struct _XmppJid XmppJid;
typedef struct _XmppJidClass XmppJidClass;

#define XMPP_TYPE_XMPP_LOG (xmpp_xmpp_log_get_type ())
#define XMPP_XMPP_LOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_XMPP_LOG, XmppXmppLog))
#define XMPP_XMPP_LOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_XMPP_LOG, XmppXmppLogClass))
#define XMPP_IS_XMPP_LOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_XMPP_LOG))
#define XMPP_IS_XMPP_LOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_XMPP_LOG))
#define XMPP_XMPP_LOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_XMPP_LOG, XmppXmppLogClass))

typedef struct _XmppXmppLog XmppXmppLog;
typedef struct _XmppXmppLogClass XmppXmppLogClass;

#define XMPP_TYPE_IO_XMPP_STREAM (xmpp_io_xmpp_stream_get_type ())
#define XMPP_IO_XMPP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_IO_XMPP_STREAM, XmppIoXmppStream))
#define XMPP_IO_XMPP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_IO_XMPP_STREAM, XmppIoXmppStreamClass))
#define XMPP_IS_IO_XMPP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_IO_XMPP_STREAM))
#define XMPP_IS_IO_XMPP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_IO_XMPP_STREAM))
#define XMPP_IO_XMPP_STREAM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_IO_XMPP_STREAM, XmppIoXmppStreamClass))

typedef struct _XmppIoXmppStream XmppIoXmppStream;
typedef struct _XmppIoXmppStreamClass XmppIoXmppStreamClass;
typedef struct _XmppIoXmppStreamPrivate XmppIoXmppStreamPrivate;

#define XMPP_TYPE_STANZA_READER (xmpp_stanza_reader_get_type ())
#define XMPP_STANZA_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_STANZA_READER, XmppStanzaReader))
#define XMPP_STANZA_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_STANZA_READER, XmppStanzaReaderClass))
#define XMPP_IS_STANZA_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_STANZA_READER))
#define XMPP_IS_STANZA_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_STANZA_READER))
#define XMPP_STANZA_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_STANZA_READER, XmppStanzaReaderClass))

typedef struct _XmppStanzaReader XmppStanzaReader;
typedef struct _XmppStanzaReaderClass XmppStanzaReaderClass;

#define XMPP_TYPE_STANZA_WRITER (xmpp_stanza_writer_get_type ())
#define XMPP_STANZA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_STANZA_WRITER, XmppStanzaWriter))
#define XMPP_STANZA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_STANZA_WRITER, XmppStanzaWriterClass))
#define XMPP_IS_STANZA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_STANZA_WRITER))
#define XMPP_IS_STANZA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_STANZA_WRITER))
#define XMPP_STANZA_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_STANZA_WRITER, XmppStanzaWriterClass))

typedef struct _XmppStanzaWriter XmppStanzaWriter;
typedef struct _XmppStanzaWriterClass XmppStanzaWriterClass;

#define XMPP_TYPE_WRITE_NODE_FUNC (xmpp_write_node_func_get_type ())
#define XMPP_WRITE_NODE_FUNC(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_WRITE_NODE_FUNC, XmppWriteNodeFunc))
#define XMPP_IS_WRITE_NODE_FUNC(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_WRITE_NODE_FUNC))
#define XMPP_WRITE_NODE_FUNC_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_TYPE_WRITE_NODE_FUNC, XmppWriteNodeFuncIface))

typedef struct _XmppWriteNodeFunc XmppWriteNodeFunc;
typedef struct _XmppWriteNodeFuncIface XmppWriteNodeFuncIface;

#define XMPP_TYPE_TLS_XMPP_STREAM (xmpp_tls_xmpp_stream_get_type ())
#define XMPP_TLS_XMPP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_TLS_XMPP_STREAM, XmppTlsXmppStream))
#define XMPP_TLS_XMPP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_TLS_XMPP_STREAM, XmppTlsXmppStreamClass))
#define XMPP_IS_TLS_XMPP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_TLS_XMPP_STREAM))
#define XMPP_IS_TLS_XMPP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_TLS_XMPP_STREAM))
#define XMPP_TLS_XMPP_STREAM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_TLS_XMPP_STREAM, XmppTlsXmppStreamClass))

typedef struct _XmppTlsXmppStream XmppTlsXmppStream;
typedef struct _XmppTlsXmppStreamClass XmppTlsXmppStreamClass;
typedef struct _XmppTlsXmppStreamPrivate XmppTlsXmppStreamPrivate;

#define XMPP_TYPE_DIRECT_TLS_XMPP_STREAM (xmpp_direct_tls_xmpp_stream_get_type ())
#define XMPP_DIRECT_TLS_XMPP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_DIRECT_TLS_XMPP_STREAM, XmppDirectTlsXmppStream))
#define XMPP_DIRECT_TLS_XMPP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_DIRECT_TLS_XMPP_STREAM, XmppDirectTlsXmppStreamClass))
#define XMPP_IS_DIRECT_TLS_XMPP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_DIRECT_TLS_XMPP_STREAM))
#define XMPP_IS_DIRECT_TLS_XMPP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_DIRECT_TLS_XMPP_STREAM))
#define XMPP_DIRECT_TLS_XMPP_STREAM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_DIRECT_TLS_XMPP_STREAM, XmppDirectTlsXmppStreamClass))

typedef struct _XmppDirectTlsXmppStream XmppDirectTlsXmppStream;
typedef struct _XmppDirectTlsXmppStreamClass XmppDirectTlsXmppStreamClass;
typedef struct _XmppDirectTlsXmppStreamPrivate XmppDirectTlsXmppStreamPrivate;

#define XMPP_TLS_XMPP_STREAM_TYPE_ON_INVALID_CERT_WRAPPER (xmpp_tls_xmpp_stream_on_invalid_cert_wrapper_get_type ())
#define XMPP_TLS_XMPP_STREAM_ON_INVALID_CERT_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TLS_XMPP_STREAM_TYPE_ON_INVALID_CERT_WRAPPER, XmppTlsXmppStreamOnInvalidCertWrapper))
#define XMPP_TLS_XMPP_STREAM_ON_INVALID_CERT_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TLS_XMPP_STREAM_TYPE_ON_INVALID_CERT_WRAPPER, XmppTlsXmppStreamOnInvalidCertWrapperClass))
#define XMPP_TLS_XMPP_STREAM_IS_ON_INVALID_CERT_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TLS_XMPP_STREAM_TYPE_ON_INVALID_CERT_WRAPPER))
#define XMPP_TLS_XMPP_STREAM_IS_ON_INVALID_CERT_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TLS_XMPP_STREAM_TYPE_ON_INVALID_CERT_WRAPPER))
#define XMPP_TLS_XMPP_STREAM_ON_INVALID_CERT_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TLS_XMPP_STREAM_TYPE_ON_INVALID_CERT_WRAPPER, XmppTlsXmppStreamOnInvalidCertWrapperClass))

typedef struct _XmppTlsXmppStreamOnInvalidCertWrapper XmppTlsXmppStreamOnInvalidCertWrapper;
typedef struct _XmppTlsXmppStreamOnInvalidCertWrapperClass XmppTlsXmppStreamOnInvalidCertWrapperClass;

#define XMPP_TYPE_FLAG_IDENTITY (xmpp_flag_identity_get_type ())
#define XMPP_FLAG_IDENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_FLAG_IDENTITY, XmppFlagIdentity))
#define XMPP_FLAG_IDENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_FLAG_IDENTITY, XmppFlagIdentityClass))
#define XMPP_IS_FLAG_IDENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_FLAG_IDENTITY))
#define XMPP_IS_FLAG_IDENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_FLAG_IDENTITY))
#define XMPP_FLAG_IDENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_FLAG_IDENTITY, XmppFlagIdentityClass))

typedef struct _XmppFlagIdentity XmppFlagIdentity;
typedef struct _XmppFlagIdentityClass XmppFlagIdentityClass;
typedef struct _XmppFlagIdentityPrivate XmppFlagIdentityPrivate;

#define XMPP_TYPE_XMPP_STREAM_FLAG (xmpp_xmpp_stream_flag_get_type ())
#define XMPP_XMPP_STREAM_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_XMPP_STREAM_FLAG, XmppXmppStreamFlag))
#define XMPP_XMPP_STREAM_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_XMPP_STREAM_FLAG, XmppXmppStreamFlagClass))
#define XMPP_IS_XMPP_STREAM_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_XMPP_STREAM_FLAG))
#define XMPP_IS_XMPP_STREAM_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_XMPP_STREAM_FLAG))
#define XMPP_XMPP_STREAM_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_XMPP_STREAM_FLAG, XmppXmppStreamFlagClass))

typedef struct _XmppXmppStreamFlag XmppXmppStreamFlag;
typedef struct _XmppXmppStreamFlagClass XmppXmppStreamFlagClass;
typedef struct _XmppXmppStreamFlagPrivate XmppXmppStreamFlagPrivate;

#define XMPP_TYPE_MODULE_IDENTITY (xmpp_module_identity_get_type ())
#define XMPP_MODULE_IDENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_MODULE_IDENTITY, XmppModuleIdentity))
#define XMPP_MODULE_IDENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_MODULE_IDENTITY, XmppModuleIdentityClass))
#define XMPP_IS_MODULE_IDENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_MODULE_IDENTITY))
#define XMPP_IS_MODULE_IDENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_MODULE_IDENTITY))
#define XMPP_MODULE_IDENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_MODULE_IDENTITY, XmppModuleIdentityClass))

typedef struct _XmppModuleIdentity XmppModuleIdentity;
typedef struct _XmppModuleIdentityClass XmppModuleIdentityClass;
typedef struct _XmppModuleIdentityPrivate XmppModuleIdentityPrivate;

#define XMPP_TYPE_XMPP_STREAM_MODULE (xmpp_xmpp_stream_module_get_type ())
#define XMPP_XMPP_STREAM_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_XMPP_STREAM_MODULE, XmppXmppStreamModule))
#define XMPP_XMPP_STREAM_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_XMPP_STREAM_MODULE, XmppXmppStreamModuleClass))
#define XMPP_IS_XMPP_STREAM_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_XMPP_STREAM_MODULE))
#define XMPP_IS_XMPP_STREAM_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_XMPP_STREAM_MODULE))
#define XMPP_XMPP_STREAM_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_XMPP_STREAM_MODULE, XmppXmppStreamModuleClass))

typedef struct _XmppXmppStreamModule XmppXmppStreamModule;
typedef struct _XmppXmppStreamModuleClass XmppXmppStreamModuleClass;
typedef struct _XmppXmppStreamModulePrivate XmppXmppStreamModulePrivate;

#define XMPP_TYPE_XMPP_STREAM_NEGOTIATION_MODULE (xmpp_xmpp_stream_negotiation_module_get_type ())
#define XMPP_XMPP_STREAM_NEGOTIATION_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_XMPP_STREAM_NEGOTIATION_MODULE, XmppXmppStreamNegotiationModule))
#define XMPP_XMPP_STREAM_NEGOTIATION_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_XMPP_STREAM_NEGOTIATION_MODULE, XmppXmppStreamNegotiationModuleClass))
#define XMPP_IS_XMPP_STREAM_NEGOTIATION_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_XMPP_STREAM_NEGOTIATION_MODULE))
#define XMPP_IS_XMPP_STREAM_NEGOTIATION_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_XMPP_STREAM_NEGOTIATION_MODULE))
#define XMPP_XMPP_STREAM_NEGOTIATION_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_XMPP_STREAM_NEGOTIATION_MODULE, XmppXmppStreamNegotiationModuleClass))

typedef struct _XmppXmppStreamNegotiationModule XmppXmppStreamNegotiationModule;
typedef struct _XmppXmppStreamNegotiationModuleClass XmppXmppStreamNegotiationModuleClass;
typedef struct _XmppXmppStreamNegotiationModulePrivate XmppXmppStreamNegotiationModulePrivate;

#define XMPP_TYPE_NAMESPACE_STATE (xmpp_namespace_state_get_type ())
#define XMPP_NAMESPACE_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_NAMESPACE_STATE, XmppNamespaceState))
#define XMPP_NAMESPACE_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_NAMESPACE_STATE, XmppNamespaceStateClass))
#define XMPP_IS_NAMESPACE_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_NAMESPACE_STATE))
#define XMPP_IS_NAMESPACE_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_NAMESPACE_STATE))
#define XMPP_NAMESPACE_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_NAMESPACE_STATE, XmppNamespaceStateClass))

typedef struct _XmppNamespaceState XmppNamespaceState;
typedef struct _XmppNamespaceStateClass XmppNamespaceStateClass;
typedef struct _XmppNamespaceStatePrivate XmppNamespaceStatePrivate;
typedef struct _XmppStanzaEntryPrivate XmppStanzaEntryPrivate;

#define XMPP_TYPE_STANZA_ATTRIBUTE (xmpp_stanza_attribute_get_type ())
#define XMPP_STANZA_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_STANZA_ATTRIBUTE, XmppStanzaAttribute))
#define XMPP_STANZA_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_STANZA_ATTRIBUTE, XmppStanzaAttributeClass))
#define XMPP_IS_STANZA_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_STANZA_ATTRIBUTE))
#define XMPP_IS_STANZA_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_STANZA_ATTRIBUTE))
#define XMPP_STANZA_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_STANZA_ATTRIBUTE, XmppStanzaAttributeClass))

typedef struct _XmppStanzaAttribute XmppStanzaAttribute;
typedef struct _XmppStanzaAttributeClass XmppStanzaAttributeClass;
typedef struct _XmppStanzaAttributePrivate XmppStanzaAttributePrivate;
typedef struct _XmppStanzaNodePrivate XmppStanzaNodePrivate;
typedef struct _XmppStanzaReaderPrivate XmppStanzaReaderPrivate;
typedef struct _XmppStanzaWriterPrivate XmppStanzaWriterPrivate;

#define XMPP_TYPE_SOURCE_FUNC_WRAPPER (xmpp_source_func_wrapper_get_type ())
#define XMPP_SOURCE_FUNC_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_SOURCE_FUNC_WRAPPER, XmppSourceFuncWrapper))
#define XMPP_SOURCE_FUNC_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_SOURCE_FUNC_WRAPPER, XmppSourceFuncWrapperClass))
#define XMPP_IS_SOURCE_FUNC_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_SOURCE_FUNC_WRAPPER))
#define XMPP_IS_SOURCE_FUNC_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_SOURCE_FUNC_WRAPPER))
#define XMPP_SOURCE_FUNC_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_SOURCE_FUNC_WRAPPER, XmppSourceFuncWrapperClass))

typedef struct _XmppSourceFuncWrapper XmppSourceFuncWrapper;
typedef struct _XmppSourceFuncWrapperClass XmppSourceFuncWrapperClass;
typedef struct _XmppSourceFuncWrapperPrivate XmppSourceFuncWrapperPrivate;

#define XMPP_TYPE_START_TLS_XMPP_STREAM (xmpp_start_tls_xmpp_stream_get_type ())
#define XMPP_START_TLS_XMPP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_START_TLS_XMPP_STREAM, XmppStartTlsXmppStream))
#define XMPP_START_TLS_XMPP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_START_TLS_XMPP_STREAM, XmppStartTlsXmppStreamClass))
#define XMPP_IS_START_TLS_XMPP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_START_TLS_XMPP_STREAM))
#define XMPP_IS_START_TLS_XMPP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_START_TLS_XMPP_STREAM))
#define XMPP_START_TLS_XMPP_STREAM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_START_TLS_XMPP_STREAM, XmppStartTlsXmppStreamClass))

typedef struct _XmppStartTlsXmppStream XmppStartTlsXmppStream;
typedef struct _XmppStartTlsXmppStreamClass XmppStartTlsXmppStreamClass;
typedef struct _XmppStartTlsXmppStreamPrivate XmppStartTlsXmppStreamPrivate;

#define XMPP_TYPE_XMPP_STREAM_RESULT (xmpp_xmpp_stream_result_get_type ())
#define XMPP_XMPP_STREAM_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_XMPP_STREAM_RESULT, XmppXmppStreamResult))
#define XMPP_XMPP_STREAM_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_XMPP_STREAM_RESULT, XmppXmppStreamResultClass))
#define XMPP_IS_XMPP_STREAM_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_XMPP_STREAM_RESULT))
#define XMPP_IS_XMPP_STREAM_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_XMPP_STREAM_RESULT))
#define XMPP_XMPP_STREAM_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_XMPP_STREAM_RESULT, XmppXmppStreamResultClass))

typedef struct _XmppXmppStreamResult XmppXmppStreamResult;
typedef struct _XmppXmppStreamResultClass XmppXmppStreamResultClass;
typedef struct _XmppXmppStreamResultPrivate XmppXmppStreamResultPrivate;
typedef gboolean (*XmppTlsXmppStreamOnInvalidCert) (GTlsCertificate* peer_cert, GTlsCertificateFlags errors, gpointer user_data);
typedef struct _XmppTlsXmppStreamOnInvalidCertWrapperPrivate XmppTlsXmppStreamOnInvalidCertWrapperPrivate;
typedef struct _XmppXmppLogPrivate XmppXmppLogPrivate;

#define XMPP_BIND_TYPE_MODULE (xmpp_bind_module_get_type ())
#define XMPP_BIND_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_BIND_TYPE_MODULE, XmppBindModule))
#define XMPP_BIND_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_BIND_TYPE_MODULE, XmppBindModuleClass))
#define XMPP_BIND_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_BIND_TYPE_MODULE))
#define XMPP_BIND_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_BIND_TYPE_MODULE))
#define XMPP_BIND_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_BIND_TYPE_MODULE, XmppBindModuleClass))

typedef struct _XmppBindModule XmppBindModule;
typedef struct _XmppBindModuleClass XmppBindModuleClass;
typedef struct _XmppBindModulePrivate XmppBindModulePrivate;

#define XMPP_TYPE_STANZA (xmpp_stanza_get_type ())
#define XMPP_STANZA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_STANZA, XmppStanza))
#define XMPP_STANZA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_STANZA, XmppStanzaClass))
#define XMPP_IS_STANZA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_STANZA))
#define XMPP_IS_STANZA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_STANZA))
#define XMPP_STANZA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_STANZA, XmppStanzaClass))

typedef struct _XmppStanza XmppStanza;
typedef struct _XmppStanzaClass XmppStanzaClass;

#define XMPP_IQ_TYPE_STANZA (xmpp_iq_stanza_get_type ())
#define XMPP_IQ_STANZA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_IQ_TYPE_STANZA, XmppIqStanza))
#define XMPP_IQ_STANZA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_IQ_TYPE_STANZA, XmppIqStanzaClass))
#define XMPP_IQ_IS_STANZA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_IQ_TYPE_STANZA))
#define XMPP_IQ_IS_STANZA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_IQ_TYPE_STANZA))
#define XMPP_IQ_STANZA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_IQ_TYPE_STANZA, XmppIqStanzaClass))

typedef struct _XmppIqStanza XmppIqStanza;
typedef struct _XmppIqStanzaClass XmppIqStanzaClass;

#define XMPP_BIND_TYPE_FLAG (xmpp_bind_flag_get_type ())
#define XMPP_BIND_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_BIND_TYPE_FLAG, XmppBindFlag))
#define XMPP_BIND_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_BIND_TYPE_FLAG, XmppBindFlagClass))
#define XMPP_BIND_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_BIND_TYPE_FLAG))
#define XMPP_BIND_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_BIND_TYPE_FLAG))
#define XMPP_BIND_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_BIND_TYPE_FLAG, XmppBindFlagClass))

typedef struct _XmppBindFlag XmppBindFlag;
typedef struct _XmppBindFlagClass XmppBindFlagClass;
typedef struct _XmppBindFlagPrivate XmppBindFlagPrivate;

#define XMPP_TYPE_BOOKMARKS_PROVIDER (xmpp_bookmarks_provider_get_type ())
#define XMPP_BOOKMARKS_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_BOOKMARKS_PROVIDER, XmppBookmarksProvider))
#define XMPP_IS_BOOKMARKS_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_BOOKMARKS_PROVIDER))
#define XMPP_BOOKMARKS_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_TYPE_BOOKMARKS_PROVIDER, XmppBookmarksProviderIface))

typedef struct _XmppBookmarksProvider XmppBookmarksProvider;
typedef struct _XmppBookmarksProviderIface XmppBookmarksProviderIface;

#define XMPP_TYPE_CONFERENCE (xmpp_conference_get_type ())
#define XMPP_CONFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_CONFERENCE, XmppConference))
#define XMPP_CONFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_CONFERENCE, XmppConferenceClass))
#define XMPP_IS_CONFERENCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_CONFERENCE))
#define XMPP_IS_CONFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_CONFERENCE))
#define XMPP_CONFERENCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_CONFERENCE, XmppConferenceClass))

typedef struct _XmppConference XmppConference;
typedef struct _XmppConferenceClass XmppConferenceClass;
typedef struct _XmppConferencePrivate XmppConferencePrivate;

#define XMPP_IQ_TYPE_MODULE (xmpp_iq_module_get_type ())
#define XMPP_IQ_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_IQ_TYPE_MODULE, XmppIqModule))
#define XMPP_IQ_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_IQ_TYPE_MODULE, XmppIqModuleClass))
#define XMPP_IQ_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_IQ_TYPE_MODULE))
#define XMPP_IQ_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_IQ_TYPE_MODULE))
#define XMPP_IQ_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_IQ_TYPE_MODULE, XmppIqModuleClass))

typedef struct _XmppIqModule XmppIqModule;
typedef struct _XmppIqModuleClass XmppIqModuleClass;
typedef struct _XmppIqModulePrivate XmppIqModulePrivate;
typedef void (*XmppIqModuleOnResult) (XmppXmppStream* stream, XmppIqStanza* iq, gpointer user_data);

#define XMPP_IQ_TYPE_HANDLER (xmpp_iq_handler_get_type ())
#define XMPP_IQ_HANDLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_IQ_TYPE_HANDLER, XmppIqHandler))
#define XMPP_IQ_IS_HANDLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_IQ_TYPE_HANDLER))
#define XMPP_IQ_HANDLER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_IQ_TYPE_HANDLER, XmppIqHandlerIface))

typedef struct _XmppIqHandler XmppIqHandler;
typedef struct _XmppIqHandlerIface XmppIqHandlerIface;
typedef struct _XmppStanzaPrivate XmppStanzaPrivate;
typedef struct _XmppIqStanzaPrivate XmppIqStanzaPrivate;

#define XMPP_TYPE_ERROR_STANZA (xmpp_error_stanza_get_type ())
#define XMPP_ERROR_STANZA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_ERROR_STANZA, XmppErrorStanza))
#define XMPP_ERROR_STANZA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_ERROR_STANZA, XmppErrorStanzaClass))
#define XMPP_IS_ERROR_STANZA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_ERROR_STANZA))
#define XMPP_IS_ERROR_STANZA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_ERROR_STANZA))
#define XMPP_ERROR_STANZA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_ERROR_STANZA, XmppErrorStanzaClass))

typedef struct _XmppErrorStanza XmppErrorStanza;
typedef struct _XmppErrorStanzaClass XmppErrorStanzaClass;
typedef struct _XmppJidPrivate XmppJidPrivate;

#define XMPP_TYPE_INVALID_JID_ERROR (xmpp_invalid_jid_error_get_type ())

#define XMPP_TYPE_MESSAGE_MODULE (xmpp_message_module_get_type ())
#define XMPP_MESSAGE_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_MESSAGE_MODULE, XmppMessageModule))
#define XMPP_MESSAGE_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_MESSAGE_MODULE, XmppMessageModuleClass))
#define XMPP_IS_MESSAGE_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_MESSAGE_MODULE))
#define XMPP_IS_MESSAGE_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_MESSAGE_MODULE))
#define XMPP_MESSAGE_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_MESSAGE_MODULE, XmppMessageModuleClass))

typedef struct _XmppMessageModule XmppMessageModule;
typedef struct _XmppMessageModuleClass XmppMessageModuleClass;
typedef struct _XmppMessageModulePrivate XmppMessageModulePrivate;

#define XMPP_TYPE_LISTENER_HOLDER (xmpp_listener_holder_get_type ())
#define XMPP_LISTENER_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_LISTENER_HOLDER, XmppListenerHolder))
#define XMPP_LISTENER_HOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_LISTENER_HOLDER, XmppListenerHolderClass))
#define XMPP_IS_LISTENER_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_LISTENER_HOLDER))
#define XMPP_IS_LISTENER_HOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_LISTENER_HOLDER))
#define XMPP_LISTENER_HOLDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_LISTENER_HOLDER, XmppListenerHolderClass))

typedef struct _XmppListenerHolder XmppListenerHolder;
typedef struct _XmppListenerHolderClass XmppListenerHolderClass;

#define XMPP_TYPE_STANZA_LISTENER_HOLDER (xmpp_stanza_listener_holder_get_type ())
#define XMPP_STANZA_LISTENER_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_STANZA_LISTENER_HOLDER, XmppStanzaListenerHolder))
#define XMPP_STANZA_LISTENER_HOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_STANZA_LISTENER_HOLDER, XmppStanzaListenerHolderClass))
#define XMPP_IS_STANZA_LISTENER_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_STANZA_LISTENER_HOLDER))
#define XMPP_IS_STANZA_LISTENER_HOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_STANZA_LISTENER_HOLDER))
#define XMPP_STANZA_LISTENER_HOLDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_STANZA_LISTENER_HOLDER, XmppStanzaListenerHolderClass))

typedef struct _XmppStanzaListenerHolder XmppStanzaListenerHolder;
typedef struct _XmppStanzaListenerHolderClass XmppStanzaListenerHolderClass;

#define XMPP_TYPE_MESSAGE_STANZA (xmpp_message_stanza_get_type ())
#define XMPP_MESSAGE_STANZA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_MESSAGE_STANZA, XmppMessageStanza))
#define XMPP_MESSAGE_STANZA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_MESSAGE_STANZA, XmppMessageStanzaClass))
#define XMPP_IS_MESSAGE_STANZA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_MESSAGE_STANZA))
#define XMPP_IS_MESSAGE_STANZA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_MESSAGE_STANZA))
#define XMPP_MESSAGE_STANZA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_MESSAGE_STANZA, XmppMessageStanzaClass))

typedef struct _XmppMessageStanza XmppMessageStanza;
typedef struct _XmppMessageStanzaClass XmppMessageStanzaClass;
typedef struct _XmppMessageStanzaPrivate XmppMessageStanzaPrivate;

#define XMPP_TYPE_MESSAGE_FLAG (xmpp_message_flag_get_type ())
#define XMPP_MESSAGE_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_MESSAGE_FLAG, XmppMessageFlag))
#define XMPP_MESSAGE_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_MESSAGE_FLAG, XmppMessageFlagClass))
#define XMPP_IS_MESSAGE_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_MESSAGE_FLAG))
#define XMPP_IS_MESSAGE_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_MESSAGE_FLAG))
#define XMPP_MESSAGE_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_MESSAGE_FLAG, XmppMessageFlagClass))

typedef struct _XmppMessageFlag XmppMessageFlag;
typedef struct _XmppMessageFlagClass XmppMessageFlagClass;
typedef struct _XmppMessageFlagPrivate XmppMessageFlagPrivate;

#define XMPP_PRESENCE_TYPE_FLAG (xmpp_presence_flag_get_type ())
#define XMPP_PRESENCE_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_PRESENCE_TYPE_FLAG, XmppPresenceFlag))
#define XMPP_PRESENCE_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_PRESENCE_TYPE_FLAG, XmppPresenceFlagClass))
#define XMPP_PRESENCE_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_PRESENCE_TYPE_FLAG))
#define XMPP_PRESENCE_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_PRESENCE_TYPE_FLAG))
#define XMPP_PRESENCE_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_PRESENCE_TYPE_FLAG, XmppPresenceFlagClass))

typedef struct _XmppPresenceFlag XmppPresenceFlag;
typedef struct _XmppPresenceFlagClass XmppPresenceFlagClass;
typedef struct _XmppPresenceFlagPrivate XmppPresenceFlagPrivate;

#define XMPP_PRESENCE_TYPE_STANZA (xmpp_presence_stanza_get_type ())
#define XMPP_PRESENCE_STANZA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_PRESENCE_TYPE_STANZA, XmppPresenceStanza))
#define XMPP_PRESENCE_STANZA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_PRESENCE_TYPE_STANZA, XmppPresenceStanzaClass))
#define XMPP_PRESENCE_IS_STANZA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_PRESENCE_TYPE_STANZA))
#define XMPP_PRESENCE_IS_STANZA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_PRESENCE_TYPE_STANZA))
#define XMPP_PRESENCE_STANZA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_PRESENCE_TYPE_STANZA, XmppPresenceStanzaClass))

typedef struct _XmppPresenceStanza XmppPresenceStanza;
typedef struct _XmppPresenceStanzaClass XmppPresenceStanzaClass;

#define XMPP_PRESENCE_TYPE_MODULE (xmpp_presence_module_get_type ())
#define XMPP_PRESENCE_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_PRESENCE_TYPE_MODULE, XmppPresenceModule))
#define XMPP_PRESENCE_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_PRESENCE_TYPE_MODULE, XmppPresenceModuleClass))
#define XMPP_PRESENCE_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_PRESENCE_TYPE_MODULE))
#define XMPP_PRESENCE_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_PRESENCE_TYPE_MODULE))
#define XMPP_PRESENCE_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_PRESENCE_TYPE_MODULE, XmppPresenceModuleClass))

typedef struct _XmppPresenceModule XmppPresenceModule;
typedef struct _XmppPresenceModuleClass XmppPresenceModuleClass;
typedef struct _XmppPresenceModulePrivate XmppPresenceModulePrivate;
typedef struct _XmppPresenceStanzaPrivate XmppPresenceStanzaPrivate;

#define XMPP_ROSTER_TYPE_FLAG (xmpp_roster_flag_get_type ())
#define XMPP_ROSTER_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_ROSTER_TYPE_FLAG, XmppRosterFlag))
#define XMPP_ROSTER_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_ROSTER_TYPE_FLAG, XmppRosterFlagClass))
#define XMPP_ROSTER_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_ROSTER_TYPE_FLAG))
#define XMPP_ROSTER_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_ROSTER_TYPE_FLAG))
#define XMPP_ROSTER_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_ROSTER_TYPE_FLAG, XmppRosterFlagClass))

typedef struct _XmppRosterFlag XmppRosterFlag;
typedef struct _XmppRosterFlagClass XmppRosterFlagClass;
typedef struct _XmppRosterFlagPrivate XmppRosterFlagPrivate;

#define XMPP_ROSTER_TYPE_ITEM (xmpp_roster_item_get_type ())
#define XMPP_ROSTER_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_ROSTER_TYPE_ITEM, XmppRosterItem))
#define XMPP_ROSTER_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_ROSTER_TYPE_ITEM, XmppRosterItemClass))
#define XMPP_ROSTER_IS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_ROSTER_TYPE_ITEM))
#define XMPP_ROSTER_IS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_ROSTER_TYPE_ITEM))
#define XMPP_ROSTER_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_ROSTER_TYPE_ITEM, XmppRosterItemClass))

typedef struct _XmppRosterItem XmppRosterItem;
typedef struct _XmppRosterItemClass XmppRosterItemClass;
typedef struct _XmppRosterItemPrivate XmppRosterItemPrivate;

#define XMPP_ROSTER_TYPE_MODULE (xmpp_roster_module_get_type ())
#define XMPP_ROSTER_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_ROSTER_TYPE_MODULE, XmppRosterModule))
#define XMPP_ROSTER_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_ROSTER_TYPE_MODULE, XmppRosterModuleClass))
#define XMPP_ROSTER_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_ROSTER_TYPE_MODULE))
#define XMPP_ROSTER_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_ROSTER_TYPE_MODULE))
#define XMPP_ROSTER_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_ROSTER_TYPE_MODULE, XmppRosterModuleClass))

typedef struct _XmppRosterModule XmppRosterModule;
typedef struct _XmppRosterModuleClass XmppRosterModuleClass;
typedef struct _XmppRosterModulePrivate XmppRosterModulePrivate;

#define XMPP_ROSTER_TYPE_VERSIONING_MODULE (xmpp_roster_versioning_module_get_type ())
#define XMPP_ROSTER_VERSIONING_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_ROSTER_TYPE_VERSIONING_MODULE, XmppRosterVersioningModule))
#define XMPP_ROSTER_VERSIONING_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_ROSTER_TYPE_VERSIONING_MODULE, XmppRosterVersioningModuleClass))
#define XMPP_ROSTER_IS_VERSIONING_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_ROSTER_TYPE_VERSIONING_MODULE))
#define XMPP_ROSTER_IS_VERSIONING_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_ROSTER_TYPE_VERSIONING_MODULE))
#define XMPP_ROSTER_VERSIONING_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_ROSTER_TYPE_VERSIONING_MODULE, XmppRosterVersioningModuleClass))

typedef struct _XmppRosterVersioningModule XmppRosterVersioningModule;
typedef struct _XmppRosterVersioningModuleClass XmppRosterVersioningModuleClass;
typedef struct _XmppRosterVersioningModulePrivate XmppRosterVersioningModulePrivate;

#define XMPP_ROSTER_TYPE_STORAGE (xmpp_roster_storage_get_type ())
#define XMPP_ROSTER_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_ROSTER_TYPE_STORAGE, XmppRosterStorage))
#define XMPP_ROSTER_IS_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_ROSTER_TYPE_STORAGE))
#define XMPP_ROSTER_STORAGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_ROSTER_TYPE_STORAGE, XmppRosterStorageIface))

typedef struct _XmppRosterStorage XmppRosterStorage;
typedef struct _XmppRosterStorageIface XmppRosterStorageIface;

#define XMPP_SASL_TYPE_FLAG (xmpp_sasl_flag_get_type ())
#define XMPP_SASL_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_SASL_TYPE_FLAG, XmppSaslFlag))
#define XMPP_SASL_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_SASL_TYPE_FLAG, XmppSaslFlagClass))
#define XMPP_SASL_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_SASL_TYPE_FLAG))
#define XMPP_SASL_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_SASL_TYPE_FLAG))
#define XMPP_SASL_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_SASL_TYPE_FLAG, XmppSaslFlagClass))

typedef struct _XmppSaslFlag XmppSaslFlag;
typedef struct _XmppSaslFlagClass XmppSaslFlagClass;
typedef struct _XmppSaslFlagPrivate XmppSaslFlagPrivate;

#define XMPP_SASL_TYPE_MODULE (xmpp_sasl_module_get_type ())
#define XMPP_SASL_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_SASL_TYPE_MODULE, XmppSaslModule))
#define XMPP_SASL_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_SASL_TYPE_MODULE, XmppSaslModuleClass))
#define XMPP_SASL_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_SASL_TYPE_MODULE))
#define XMPP_SASL_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_SASL_TYPE_MODULE))
#define XMPP_SASL_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_SASL_TYPE_MODULE, XmppSaslModuleClass))

typedef struct _XmppSaslModule XmppSaslModule;
typedef struct _XmppSaslModuleClass XmppSaslModuleClass;
typedef struct _XmppSaslModulePrivate XmppSaslModulePrivate;

#define XMPP_SESSION_TYPE_MODULE (xmpp_session_module_get_type ())
#define XMPP_SESSION_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_SESSION_TYPE_MODULE, XmppSessionModule))
#define XMPP_SESSION_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_SESSION_TYPE_MODULE, XmppSessionModuleClass))
#define XMPP_SESSION_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_SESSION_TYPE_MODULE))
#define XMPP_SESSION_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_SESSION_TYPE_MODULE))
#define XMPP_SESSION_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_SESSION_TYPE_MODULE, XmppSessionModuleClass))

typedef struct _XmppSessionModule XmppSessionModule;
typedef struct _XmppSessionModuleClass XmppSessionModuleClass;
typedef struct _XmppSessionModulePrivate XmppSessionModulePrivate;

#define XMPP_SESSION_TYPE_FLAG (xmpp_session_flag_get_type ())
#define XMPP_SESSION_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_SESSION_TYPE_FLAG, XmppSessionFlag))
#define XMPP_SESSION_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_SESSION_TYPE_FLAG, XmppSessionFlagClass))
#define XMPP_SESSION_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_SESSION_TYPE_FLAG))
#define XMPP_SESSION_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_SESSION_TYPE_FLAG))
#define XMPP_SESSION_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_SESSION_TYPE_FLAG, XmppSessionFlagClass))

typedef struct _XmppSessionFlag XmppSessionFlag;
typedef struct _XmppSessionFlagClass XmppSessionFlagClass;
typedef struct _XmppSessionFlagPrivate XmppSessionFlagPrivate;
typedef struct _XmppErrorStanzaPrivate XmppErrorStanzaPrivate;

#define XMPP_STREAM_ERROR_TYPE_MODULE (xmpp_stream_error_module_get_type ())
#define XMPP_STREAM_ERROR_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_STREAM_ERROR_TYPE_MODULE, XmppStreamErrorModule))
#define XMPP_STREAM_ERROR_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_STREAM_ERROR_TYPE_MODULE, XmppStreamErrorModuleClass))
#define XMPP_STREAM_ERROR_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_STREAM_ERROR_TYPE_MODULE))
#define XMPP_STREAM_ERROR_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_STREAM_ERROR_TYPE_MODULE))
#define XMPP_STREAM_ERROR_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_STREAM_ERROR_TYPE_MODULE, XmppStreamErrorModuleClass))

typedef struct _XmppStreamErrorModule XmppStreamErrorModule;
typedef struct _XmppStreamErrorModuleClass XmppStreamErrorModuleClass;
typedef struct _XmppStreamErrorModulePrivate XmppStreamErrorModulePrivate;

#define XMPP_STREAM_ERROR_TYPE_FLAG (xmpp_stream_error_flag_get_type ())
#define XMPP_STREAM_ERROR_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_STREAM_ERROR_TYPE_FLAG, XmppStreamErrorFlag))
#define XMPP_STREAM_ERROR_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_STREAM_ERROR_TYPE_FLAG, XmppStreamErrorFlagClass))
#define XMPP_STREAM_ERROR_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_STREAM_ERROR_TYPE_FLAG))
#define XMPP_STREAM_ERROR_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_STREAM_ERROR_TYPE_FLAG))
#define XMPP_STREAM_ERROR_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_STREAM_ERROR_TYPE_FLAG, XmppStreamErrorFlagClass))

typedef struct _XmppStreamErrorFlag XmppStreamErrorFlag;
typedef struct _XmppStreamErrorFlagClass XmppStreamErrorFlagClass;
typedef struct _XmppStreamErrorFlagPrivate XmppStreamErrorFlagPrivate;
typedef enum  {
	XMPP_STREAM_ERROR_FLAG_RECONNECT_UNKNOWN,
	XMPP_STREAM_ERROR_FLAG_RECONNECT_NOW,
	XMPP_STREAM_ERROR_FLAG_RECONNECT_LATER,
	XMPP_STREAM_ERROR_FLAG_RECONNECT_NEVER
} XmppStreamErrorFlagReconnect;

#define XMPP_STREAM_ERROR_FLAG_TYPE_RECONNECT (xmpp_stream_error_flag_reconnect_get_type ())

#define XMPP_TYPE_ORDERED_LISTENER (xmpp_ordered_listener_get_type ())
#define XMPP_ORDERED_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_ORDERED_LISTENER, XmppOrderedListener))
#define XMPP_ORDERED_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_ORDERED_LISTENER, XmppOrderedListenerClass))
#define XMPP_IS_ORDERED_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_ORDERED_LISTENER))
#define XMPP_IS_ORDERED_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_ORDERED_LISTENER))
#define XMPP_ORDERED_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_ORDERED_LISTENER, XmppOrderedListenerClass))

typedef struct _XmppOrderedListener XmppOrderedListener;
typedef struct _XmppOrderedListenerClass XmppOrderedListenerClass;
typedef struct _XmppOrderedListenerPrivate XmppOrderedListenerPrivate;

#define XMPP_TYPE_STANZA_LISTENER (xmpp_stanza_listener_get_type ())
#define XMPP_STANZA_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_TYPE_STANZA_LISTENER, XmppStanzaListener))
#define XMPP_STANZA_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_TYPE_STANZA_LISTENER, XmppStanzaListenerClass))
#define XMPP_IS_STANZA_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_TYPE_STANZA_LISTENER))
#define XMPP_IS_STANZA_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_TYPE_STANZA_LISTENER))
#define XMPP_STANZA_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_TYPE_STANZA_LISTENER, XmppStanzaListenerClass))

typedef struct _XmppStanzaListener XmppStanzaListener;
typedef struct _XmppStanzaListenerClass XmppStanzaListenerClass;
typedef struct _XmppStanzaListenerPrivate XmppStanzaListenerPrivate;
typedef struct _XmppListenerHolderPrivate XmppListenerHolderPrivate;
typedef struct _XmppStanzaListenerHolderPrivate XmppStanzaListenerHolderPrivate;

#define XMPP_XEP_DATA_FORMS_TYPE_DATA_FORM (xmpp_xep_data_forms_data_form_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_TYPE_DATA_FORM, XmppXepDataFormsDataForm))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_TYPE_DATA_FORM, XmppXepDataFormsDataFormClass))
#define XMPP_XEP_DATA_FORMS_IS_DATA_FORM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_TYPE_DATA_FORM))
#define XMPP_XEP_DATA_FORMS_IS_DATA_FORM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_TYPE_DATA_FORM))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_TYPE_DATA_FORM, XmppXepDataFormsDataFormClass))

typedef struct _XmppXepDataFormsDataForm XmppXepDataFormsDataForm;
typedef struct _XmppXepDataFormsDataFormClass XmppXepDataFormsDataFormClass;
typedef struct _XmppXepDataFormsDataFormPrivate XmppXepDataFormsDataFormPrivate;

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIELD (xmpp_xep_data_forms_data_form_field_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIELD, XmppXepDataFormsDataFormField))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIELD, XmppXepDataFormsDataFormFieldClass))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIELD, XmppXepDataFormsDataFormFieldClass))

typedef struct _XmppXepDataFormsDataFormField XmppXepDataFormsDataFormField;
typedef struct _XmppXepDataFormsDataFormFieldClass XmppXepDataFormsDataFormFieldClass;
typedef enum  {
	XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_BOOLEAN,
	XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIXED,
	XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_HIDDEN,
	XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_JID_MULTI,
	XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_SINGLE,
	XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_MULTI,
	XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_PRIVATE,
	XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_SINGLE
} XmppXepDataFormsDataFormType;

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TYPE (xmpp_xep_data_forms_data_form_type_get_type ())

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_OPTION (xmpp_xep_data_forms_data_form_option_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM_OPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_OPTION, XmppXepDataFormsDataFormOption))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_OPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_OPTION, XmppXepDataFormsDataFormOptionClass))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_OPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_OPTION))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_OPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_OPTION))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_OPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_OPTION, XmppXepDataFormsDataFormOptionClass))

typedef struct _XmppXepDataFormsDataFormOption XmppXepDataFormsDataFormOption;
typedef struct _XmppXepDataFormsDataFormOptionClass XmppXepDataFormsDataFormOptionClass;
typedef struct _XmppXepDataFormsDataFormOptionPrivate XmppXepDataFormsDataFormOptionPrivate;
typedef struct _XmppXepDataFormsDataFormFieldPrivate XmppXepDataFormsDataFormFieldPrivate;

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_BOOLEAN_FIELD (xmpp_xep_data_forms_data_form_boolean_field_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM_BOOLEAN_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_BOOLEAN_FIELD, XmppXepDataFormsDataFormBooleanField))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_BOOLEAN_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_BOOLEAN_FIELD, XmppXepDataFormsDataFormBooleanFieldClass))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_BOOLEAN_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_BOOLEAN_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_BOOLEAN_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_BOOLEAN_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_BOOLEAN_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_BOOLEAN_FIELD, XmppXepDataFormsDataFormBooleanFieldClass))

typedef struct _XmppXepDataFormsDataFormBooleanField XmppXepDataFormsDataFormBooleanField;
typedef struct _XmppXepDataFormsDataFormBooleanFieldClass XmppXepDataFormsDataFormBooleanFieldClass;
typedef struct _XmppXepDataFormsDataFormBooleanFieldPrivate XmppXepDataFormsDataFormBooleanFieldPrivate;

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIXED_FIELD (xmpp_xep_data_forms_data_form_fixed_field_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM_FIXED_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIXED_FIELD, XmppXepDataFormsDataFormFixedField))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_FIXED_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIXED_FIELD, XmppXepDataFormsDataFormFixedFieldClass))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_FIXED_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIXED_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_FIXED_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIXED_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_FIXED_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_FIXED_FIELD, XmppXepDataFormsDataFormFixedFieldClass))

typedef struct _XmppXepDataFormsDataFormFixedField XmppXepDataFormsDataFormFixedField;
typedef struct _XmppXepDataFormsDataFormFixedFieldClass XmppXepDataFormsDataFormFixedFieldClass;
typedef struct _XmppXepDataFormsDataFormFixedFieldPrivate XmppXepDataFormsDataFormFixedFieldPrivate;

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_HIDDEN_FIELD (xmpp_xep_data_forms_data_form_hidden_field_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM_HIDDEN_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_HIDDEN_FIELD, XmppXepDataFormsDataFormHiddenField))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_HIDDEN_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_HIDDEN_FIELD, XmppXepDataFormsDataFormHiddenFieldClass))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_HIDDEN_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_HIDDEN_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_HIDDEN_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_HIDDEN_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_HIDDEN_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_HIDDEN_FIELD, XmppXepDataFormsDataFormHiddenFieldClass))

typedef struct _XmppXepDataFormsDataFormHiddenField XmppXepDataFormsDataFormHiddenField;
typedef struct _XmppXepDataFormsDataFormHiddenFieldClass XmppXepDataFormsDataFormHiddenFieldClass;
typedef struct _XmppXepDataFormsDataFormHiddenFieldPrivate XmppXepDataFormsDataFormHiddenFieldPrivate;

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_JID_MULTI_FIELD (xmpp_xep_data_forms_data_form_jid_multi_field_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM_JID_MULTI_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_JID_MULTI_FIELD, XmppXepDataFormsDataFormJidMultiField))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_JID_MULTI_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_JID_MULTI_FIELD, XmppXepDataFormsDataFormJidMultiFieldClass))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_JID_MULTI_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_JID_MULTI_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_JID_MULTI_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_JID_MULTI_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_JID_MULTI_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_JID_MULTI_FIELD, XmppXepDataFormsDataFormJidMultiFieldClass))

typedef struct _XmppXepDataFormsDataFormJidMultiField XmppXepDataFormsDataFormJidMultiField;
typedef struct _XmppXepDataFormsDataFormJidMultiFieldClass XmppXepDataFormsDataFormJidMultiFieldClass;
typedef struct _XmppXepDataFormsDataFormJidMultiFieldPrivate XmppXepDataFormsDataFormJidMultiFieldPrivate;

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_SINGLE_FIELD (xmpp_xep_data_forms_data_form_list_single_field_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM_LIST_SINGLE_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_SINGLE_FIELD, XmppXepDataFormsDataFormListSingleField))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_LIST_SINGLE_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_SINGLE_FIELD, XmppXepDataFormsDataFormListSingleFieldClass))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_LIST_SINGLE_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_SINGLE_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_LIST_SINGLE_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_SINGLE_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_LIST_SINGLE_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_SINGLE_FIELD, XmppXepDataFormsDataFormListSingleFieldClass))

typedef struct _XmppXepDataFormsDataFormListSingleField XmppXepDataFormsDataFormListSingleField;
typedef struct _XmppXepDataFormsDataFormListSingleFieldClass XmppXepDataFormsDataFormListSingleFieldClass;
typedef struct _XmppXepDataFormsDataFormListSingleFieldPrivate XmppXepDataFormsDataFormListSingleFieldPrivate;

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_MULTI_FIELD (xmpp_xep_data_forms_data_form_list_multi_field_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM_LIST_MULTI_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_MULTI_FIELD, XmppXepDataFormsDataFormListMultiField))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_LIST_MULTI_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_MULTI_FIELD, XmppXepDataFormsDataFormListMultiFieldClass))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_LIST_MULTI_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_MULTI_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_LIST_MULTI_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_MULTI_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_LIST_MULTI_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_LIST_MULTI_FIELD, XmppXepDataFormsDataFormListMultiFieldClass))

typedef struct _XmppXepDataFormsDataFormListMultiField XmppXepDataFormsDataFormListMultiField;
typedef struct _XmppXepDataFormsDataFormListMultiFieldClass XmppXepDataFormsDataFormListMultiFieldClass;
typedef struct _XmppXepDataFormsDataFormListMultiFieldPrivate XmppXepDataFormsDataFormListMultiFieldPrivate;

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_PRIVATE_FIELD (xmpp_xep_data_forms_data_form_text_private_field_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM_TEXT_PRIVATE_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_PRIVATE_FIELD, XmppXepDataFormsDataFormTextPrivateField))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_TEXT_PRIVATE_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_PRIVATE_FIELD, XmppXepDataFormsDataFormTextPrivateFieldClass))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_TEXT_PRIVATE_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_PRIVATE_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_TEXT_PRIVATE_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_PRIVATE_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_TEXT_PRIVATE_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_PRIVATE_FIELD, XmppXepDataFormsDataFormTextPrivateFieldClass))

typedef struct _XmppXepDataFormsDataFormTextPrivateField XmppXepDataFormsDataFormTextPrivateField;
typedef struct _XmppXepDataFormsDataFormTextPrivateFieldClass XmppXepDataFormsDataFormTextPrivateFieldClass;
typedef struct _XmppXepDataFormsDataFormTextPrivateFieldPrivate XmppXepDataFormsDataFormTextPrivateFieldPrivate;

#define XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_SINGLE_FIELD (xmpp_xep_data_forms_data_form_text_single_field_get_type ())
#define XMPP_XEP_DATA_FORMS_DATA_FORM_TEXT_SINGLE_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_SINGLE_FIELD, XmppXepDataFormsDataFormTextSingleField))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_TEXT_SINGLE_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_SINGLE_FIELD, XmppXepDataFormsDataFormTextSingleFieldClass))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_TEXT_SINGLE_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_SINGLE_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_IS_TEXT_SINGLE_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_SINGLE_FIELD))
#define XMPP_XEP_DATA_FORMS_DATA_FORM_TEXT_SINGLE_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DATA_FORMS_DATA_FORM_TYPE_TEXT_SINGLE_FIELD, XmppXepDataFormsDataFormTextSingleFieldClass))

typedef struct _XmppXepDataFormsDataFormTextSingleField XmppXepDataFormsDataFormTextSingleField;
typedef struct _XmppXepDataFormsDataFormTextSingleFieldClass XmppXepDataFormsDataFormTextSingleFieldClass;
typedef struct _XmppXepDataFormsDataFormTextSingleFieldPrivate XmppXepDataFormsDataFormTextSingleFieldPrivate;

#define XMPP_XEP_SERVICE_DISCOVERY_TYPE_FLAG (xmpp_xep_service_discovery_flag_get_type ())
#define XMPP_XEP_SERVICE_DISCOVERY_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_FLAG, XmppXepServiceDiscoveryFlag))
#define XMPP_XEP_SERVICE_DISCOVERY_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_FLAG, XmppXepServiceDiscoveryFlagClass))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_FLAG))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_FLAG))
#define XMPP_XEP_SERVICE_DISCOVERY_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_FLAG, XmppXepServiceDiscoveryFlagClass))

typedef struct _XmppXepServiceDiscoveryFlag XmppXepServiceDiscoveryFlag;
typedef struct _XmppXepServiceDiscoveryFlagClass XmppXepServiceDiscoveryFlagClass;
typedef struct _XmppXepServiceDiscoveryFlagPrivate XmppXepServiceDiscoveryFlagPrivate;

#define XMPP_XEP_SERVICE_DISCOVERY_TYPE_IDENTITY (xmpp_xep_service_discovery_identity_get_type ())
#define XMPP_XEP_SERVICE_DISCOVERY_IDENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_IDENTITY, XmppXepServiceDiscoveryIdentity))
#define XMPP_XEP_SERVICE_DISCOVERY_IDENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_IDENTITY, XmppXepServiceDiscoveryIdentityClass))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_IDENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_IDENTITY))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_IDENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_IDENTITY))
#define XMPP_XEP_SERVICE_DISCOVERY_IDENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_IDENTITY, XmppXepServiceDiscoveryIdentityClass))

typedef struct _XmppXepServiceDiscoveryIdentity XmppXepServiceDiscoveryIdentity;
typedef struct _XmppXepServiceDiscoveryIdentityClass XmppXepServiceDiscoveryIdentityClass;
typedef struct _XmppXepServiceDiscoveryIdentityPrivate XmppXepServiceDiscoveryIdentityPrivate;

#define XMPP_XEP_SERVICE_DISCOVERY_TYPE_INFO_RESULT (xmpp_xep_service_discovery_info_result_get_type ())
#define XMPP_XEP_SERVICE_DISCOVERY_INFO_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_INFO_RESULT, XmppXepServiceDiscoveryInfoResult))
#define XMPP_XEP_SERVICE_DISCOVERY_INFO_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_INFO_RESULT, XmppXepServiceDiscoveryInfoResultClass))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_INFO_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_INFO_RESULT))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_INFO_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_INFO_RESULT))
#define XMPP_XEP_SERVICE_DISCOVERY_INFO_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_INFO_RESULT, XmppXepServiceDiscoveryInfoResultClass))

typedef struct _XmppXepServiceDiscoveryInfoResult XmppXepServiceDiscoveryInfoResult;
typedef struct _XmppXepServiceDiscoveryInfoResultClass XmppXepServiceDiscoveryInfoResultClass;
typedef struct _XmppXepServiceDiscoveryInfoResultPrivate XmppXepServiceDiscoveryInfoResultPrivate;

#define XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEM (xmpp_xep_service_discovery_item_get_type ())
#define XMPP_XEP_SERVICE_DISCOVERY_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEM, XmppXepServiceDiscoveryItem))
#define XMPP_XEP_SERVICE_DISCOVERY_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEM, XmppXepServiceDiscoveryItemClass))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEM))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEM))
#define XMPP_XEP_SERVICE_DISCOVERY_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEM, XmppXepServiceDiscoveryItemClass))

typedef struct _XmppXepServiceDiscoveryItem XmppXepServiceDiscoveryItem;
typedef struct _XmppXepServiceDiscoveryItemClass XmppXepServiceDiscoveryItemClass;
typedef struct _XmppXepServiceDiscoveryItemPrivate XmppXepServiceDiscoveryItemPrivate;

#define XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEMS_RESULT (xmpp_xep_service_discovery_items_result_get_type ())
#define XMPP_XEP_SERVICE_DISCOVERY_ITEMS_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEMS_RESULT, XmppXepServiceDiscoveryItemsResult))
#define XMPP_XEP_SERVICE_DISCOVERY_ITEMS_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEMS_RESULT, XmppXepServiceDiscoveryItemsResultClass))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_ITEMS_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEMS_RESULT))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_ITEMS_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEMS_RESULT))
#define XMPP_XEP_SERVICE_DISCOVERY_ITEMS_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_ITEMS_RESULT, XmppXepServiceDiscoveryItemsResultClass))

typedef struct _XmppXepServiceDiscoveryItemsResult XmppXepServiceDiscoveryItemsResult;
typedef struct _XmppXepServiceDiscoveryItemsResultClass XmppXepServiceDiscoveryItemsResultClass;
typedef struct _XmppXepServiceDiscoveryItemsResultPrivate XmppXepServiceDiscoveryItemsResultPrivate;

#define XMPP_XEP_SERVICE_DISCOVERY_TYPE_MODULE (xmpp_xep_service_discovery_module_get_type ())
#define XMPP_XEP_SERVICE_DISCOVERY_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_MODULE, XmppXepServiceDiscoveryModule))
#define XMPP_XEP_SERVICE_DISCOVERY_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_MODULE, XmppXepServiceDiscoveryModuleClass))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_MODULE))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_SERVICE_DISCOVERY_TYPE_MODULE))
#define XMPP_XEP_SERVICE_DISCOVERY_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_MODULE, XmppXepServiceDiscoveryModuleClass))

typedef struct _XmppXepServiceDiscoveryModule XmppXepServiceDiscoveryModule;
typedef struct _XmppXepServiceDiscoveryModuleClass XmppXepServiceDiscoveryModuleClass;
typedef struct _XmppXepServiceDiscoveryModulePrivate XmppXepServiceDiscoveryModulePrivate;

#define XMPP_XEP_SERVICE_DISCOVERY_TYPE_CAPS_CACHE (xmpp_xep_service_discovery_caps_cache_get_type ())
#define XMPP_XEP_SERVICE_DISCOVERY_CAPS_CACHE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_CAPS_CACHE, XmppXepServiceDiscoveryCapsCache))
#define XMPP_XEP_SERVICE_DISCOVERY_IS_CAPS_CACHE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_CAPS_CACHE))
#define XMPP_XEP_SERVICE_DISCOVERY_CAPS_CACHE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_SERVICE_DISCOVERY_TYPE_CAPS_CACHE, XmppXepServiceDiscoveryCapsCacheIface))

typedef struct _XmppXepServiceDiscoveryCapsCache XmppXepServiceDiscoveryCapsCache;
typedef struct _XmppXepServiceDiscoveryCapsCacheIface XmppXepServiceDiscoveryCapsCacheIface;

#define XMPP_XEP_MUC_TYPE_FLAG (xmpp_xep_muc_flag_get_type ())
#define XMPP_XEP_MUC_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MUC_TYPE_FLAG, XmppXepMucFlag))
#define XMPP_XEP_MUC_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MUC_TYPE_FLAG, XmppXepMucFlagClass))
#define XMPP_XEP_MUC_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MUC_TYPE_FLAG))
#define XMPP_XEP_MUC_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MUC_TYPE_FLAG))
#define XMPP_XEP_MUC_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MUC_TYPE_FLAG, XmppXepMucFlagClass))

typedef struct _XmppXepMucFlag XmppXepMucFlag;
typedef struct _XmppXepMucFlagClass XmppXepMucFlagClass;
typedef struct _XmppXepMucFlagPrivate XmppXepMucFlagPrivate;

#define XMPP_XEP_MUC_TYPE_JOIN_RESULT (xmpp_xep_muc_join_result_get_type ())
#define XMPP_XEP_MUC_JOIN_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MUC_TYPE_JOIN_RESULT, XmppXepMucJoinResult))
#define XMPP_XEP_MUC_JOIN_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MUC_TYPE_JOIN_RESULT, XmppXepMucJoinResultClass))
#define XMPP_XEP_MUC_IS_JOIN_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MUC_TYPE_JOIN_RESULT))
#define XMPP_XEP_MUC_IS_JOIN_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MUC_TYPE_JOIN_RESULT))
#define XMPP_XEP_MUC_JOIN_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MUC_TYPE_JOIN_RESULT, XmppXepMucJoinResultClass))

typedef struct _XmppXepMucJoinResult XmppXepMucJoinResult;
typedef struct _XmppXepMucJoinResultClass XmppXepMucJoinResultClass;
typedef enum  {
	XMPP_XEP_MUC_FEATURE_REGISTER,
	XMPP_XEP_MUC_FEATURE_ROOMCONFIG,
	XMPP_XEP_MUC_FEATURE_ROOMINFO,
	XMPP_XEP_MUC_FEATURE_HIDDEN,
	XMPP_XEP_MUC_FEATURE_MEMBERS_ONLY,
	XMPP_XEP_MUC_FEATURE_MODERATED,
	XMPP_XEP_MUC_FEATURE_NON_ANONYMOUS,
	XMPP_XEP_MUC_FEATURE_OPEN,
	XMPP_XEP_MUC_FEATURE_PASSWORD_PROTECTED,
	XMPP_XEP_MUC_FEATURE_PERSISTENT,
	XMPP_XEP_MUC_FEATURE_PUBLIC,
	XMPP_XEP_MUC_FEATURE_ROOMS,
	XMPP_XEP_MUC_FEATURE_SEMI_ANONYMOUS,
	XMPP_XEP_MUC_FEATURE_STABLE_ID,
	XMPP_XEP_MUC_FEATURE_TEMPORARY,
	XMPP_XEP_MUC_FEATURE_UNMODERATED,
	XMPP_XEP_MUC_FEATURE_UNSECURED
} XmppXepMucFeature;

#define XMPP_XEP_MUC_TYPE_FEATURE (xmpp_xep_muc_feature_get_type ())
typedef enum  {
	XMPP_XEP_MUC_AFFILIATION_NONE,
	XMPP_XEP_MUC_AFFILIATION_ADMIN,
	XMPP_XEP_MUC_AFFILIATION_MEMBER,
	XMPP_XEP_MUC_AFFILIATION_OUTCAST,
	XMPP_XEP_MUC_AFFILIATION_OWNER
} XmppXepMucAffiliation;

#define XMPP_XEP_MUC_TYPE_AFFILIATION (xmpp_xep_muc_affiliation_get_type ())
typedef enum  {
	XMPP_XEP_MUC_ROLE_NONE,
	XMPP_XEP_MUC_ROLE_MODERATOR,
	XMPP_XEP_MUC_ROLE_PARTICIPANT,
	XMPP_XEP_MUC_ROLE_VISITOR
} XmppXepMucRole;

#define XMPP_XEP_MUC_TYPE_ROLE (xmpp_xep_muc_role_get_type ())
typedef enum  {
	XMPP_XEP_MUC_MUC_ENTER_ERROR_PASSWORD_REQUIRED,
	XMPP_XEP_MUC_MUC_ENTER_ERROR_BANNED,
	XMPP_XEP_MUC_MUC_ENTER_ERROR_ROOM_DOESNT_EXIST,
	XMPP_XEP_MUC_MUC_ENTER_ERROR_CREATION_RESTRICTED,
	XMPP_XEP_MUC_MUC_ENTER_ERROR_USE_RESERVED_ROOMNICK,
	XMPP_XEP_MUC_MUC_ENTER_ERROR_NOT_IN_MEMBER_LIST,
	XMPP_XEP_MUC_MUC_ENTER_ERROR_NICK_CONFLICT,
	XMPP_XEP_MUC_MUC_ENTER_ERROR_OCCUPANT_LIMIT_REACHED
} XmppXepMucMucEnterError;

#define XMPP_XEP_MUC_TYPE_MUC_ENTER_ERROR (xmpp_xep_muc_muc_enter_error_get_type ())
typedef struct _XmppXepMucJoinResultPrivate XmppXepMucJoinResultPrivate;

#define XMPP_XEP_MUC_TYPE_MODULE (xmpp_xep_muc_module_get_type ())
#define XMPP_XEP_MUC_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MUC_TYPE_MODULE, XmppXepMucModule))
#define XMPP_XEP_MUC_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MUC_TYPE_MODULE, XmppXepMucModuleClass))
#define XMPP_XEP_MUC_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MUC_TYPE_MODULE))
#define XMPP_XEP_MUC_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MUC_TYPE_MODULE))
#define XMPP_XEP_MUC_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MUC_TYPE_MODULE, XmppXepMucModuleClass))

typedef struct _XmppXepMucModule XmppXepMucModule;
typedef struct _XmppXepMucModuleClass XmppXepMucModuleClass;
typedef struct _XmppXepMucModulePrivate XmppXepMucModulePrivate;

#define XMPP_XEP_MUC_TYPE_RECEIVED_PIPELINE_LISTENER (xmpp_xep_muc_received_pipeline_listener_get_type ())
#define XMPP_XEP_MUC_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MUC_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepMucReceivedPipelineListener))
#define XMPP_XEP_MUC_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MUC_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepMucReceivedPipelineListenerClass))
#define XMPP_XEP_MUC_IS_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MUC_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_XEP_MUC_IS_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MUC_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_XEP_MUC_RECEIVED_PIPELINE_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MUC_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepMucReceivedPipelineListenerClass))

typedef struct _XmppXepMucReceivedPipelineListener XmppXepMucReceivedPipelineListener;
typedef struct _XmppXepMucReceivedPipelineListenerClass XmppXepMucReceivedPipelineListenerClass;
typedef struct _XmppXepMucReceivedPipelineListenerPrivate XmppXepMucReceivedPipelineListenerPrivate;
typedef enum  {
	XMPP_XEP_MUC_STATUS_CODE_JID_VISIBLE = 100,
	XMPP_XEP_MUC_STATUS_CODE_AFFILIATION_CHANGED = 101,
	XMPP_XEP_MUC_STATUS_CODE_SHOWS_UNAVIABLE_MEMBERS = 102,
	XMPP_XEP_MUC_STATUS_CODE_SHOWS_UNAVIABLE_MEMBERS_NOT = 103,
	XMPP_XEP_MUC_STATUS_CODE_CONFIG_CHANGE_NON_PRIVACY = 104,
	XMPP_XEP_MUC_STATUS_CODE_SELF_PRESENCE = 110,
	XMPP_XEP_MUC_STATUS_CODE_LOGGING_ENABLED = 170,
	XMPP_XEP_MUC_STATUS_CODE_LOGGING_DISABLED = 171,
	XMPP_XEP_MUC_STATUS_CODE_NON_ANONYMOUS = 172,
	XMPP_XEP_MUC_STATUS_CODE_SEMI_ANONYMOUS = 173,
	XMPP_XEP_MUC_STATUS_CODE_NEW_ROOM_CREATED = 201,
	XMPP_XEP_MUC_STATUS_CODE_MODIFIED_NICK = 210,
	XMPP_XEP_MUC_STATUS_CODE_BANNED = 301,
	XMPP_XEP_MUC_STATUS_CODE_ROOM_NICKNAME = 303,
	XMPP_XEP_MUC_STATUS_CODE_KICKED = 307,
	XMPP_XEP_MUC_STATUS_CODE_REMOVED_AFFILIATION_CHANGE = 321,
	XMPP_XEP_MUC_STATUS_CODE_REMOVED_MEMBERS_ONLY = 322,
	XMPP_XEP_MUC_STATUS_CODE_REMOVED_SHUTDOWN = 332
} XmppXepMucStatusCode;

#define XMPP_XEP_MUC_TYPE_STATUS_CODE (xmpp_xep_muc_status_code_get_type ())

#define XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_MODULE (xmpp_xep_in_band_bytestreams_module_get_type ())
#define XMPP_XEP_IN_BAND_BYTESTREAMS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_MODULE, XmppXepInBandBytestreamsModule))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_MODULE, XmppXepInBandBytestreamsModuleClass))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_MODULE))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_MODULE))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_MODULE, XmppXepInBandBytestreamsModuleClass))

typedef struct _XmppXepInBandBytestreamsModule XmppXepInBandBytestreamsModule;
typedef struct _XmppXepInBandBytestreamsModuleClass XmppXepInBandBytestreamsModuleClass;
typedef struct _XmppXepInBandBytestreamsModulePrivate XmppXepInBandBytestreamsModulePrivate;

#define XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_CONNECTION (xmpp_xep_in_band_bytestreams_connection_get_type ())
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_CONNECTION, XmppXepInBandBytestreamsConnection))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_CONNECTION, XmppXepInBandBytestreamsConnectionClass))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_IS_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_CONNECTION))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_IS_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_CONNECTION))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_CONNECTION, XmppXepInBandBytestreamsConnectionClass))

typedef struct _XmppXepInBandBytestreamsConnection XmppXepInBandBytestreamsConnection;
typedef struct _XmppXepInBandBytestreamsConnectionClass XmppXepInBandBytestreamsConnectionClass;
typedef struct _XmppXepInBandBytestreamsConnectionPrivate XmppXepInBandBytestreamsConnectionPrivate;
typedef enum  {
	XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_STATE_WAITING_FOR_CONNECT,
	XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_STATE_CONNECTING,
	XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_STATE_CONNECTED,
	XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_STATE_DISCONNECTING,
	XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_STATE_DISCONNECTED,
	XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_STATE_ERROR
} XmppXepInBandBytestreamsConnectionState;

#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_STATE (xmpp_xep_in_band_bytestreams_connection_state_get_type ())

#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_INPUT (xmpp_xep_in_band_bytestreams_connection_input_get_type ())
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_INPUT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_INPUT, XmppXepInBandBytestreamsConnectionInput))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_INPUT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_INPUT, XmppXepInBandBytestreamsConnectionInputClass))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_IS_INPUT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_INPUT))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_IS_INPUT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_INPUT))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_INPUT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_INPUT, XmppXepInBandBytestreamsConnectionInputClass))

typedef struct _XmppXepInBandBytestreamsConnectionInput XmppXepInBandBytestreamsConnectionInput;
typedef struct _XmppXepInBandBytestreamsConnectionInputClass XmppXepInBandBytestreamsConnectionInputClass;
typedef struct _XmppXepInBandBytestreamsConnectionInputPrivate XmppXepInBandBytestreamsConnectionInputPrivate;

#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_OUTPUT (xmpp_xep_in_band_bytestreams_connection_output_get_type ())
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_OUTPUT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_OUTPUT, XmppXepInBandBytestreamsConnectionOutput))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_OUTPUT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_OUTPUT, XmppXepInBandBytestreamsConnectionOutputClass))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_IS_OUTPUT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_OUTPUT))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_IS_OUTPUT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_OUTPUT))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_OUTPUT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_CONNECTION_TYPE_OUTPUT, XmppXepInBandBytestreamsConnectionOutputClass))

typedef struct _XmppXepInBandBytestreamsConnectionOutput XmppXepInBandBytestreamsConnectionOutput;
typedef struct _XmppXepInBandBytestreamsConnectionOutputClass XmppXepInBandBytestreamsConnectionOutputClass;
typedef struct _XmppXepInBandBytestreamsConnectionOutputPrivate XmppXepInBandBytestreamsConnectionOutputPrivate;

#define XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_FLAG (xmpp_xep_in_band_bytestreams_flag_get_type ())
#define XMPP_XEP_IN_BAND_BYTESTREAMS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_FLAG, XmppXepInBandBytestreamsFlag))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_FLAG, XmppXepInBandBytestreamsFlagClass))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_FLAG))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_FLAG))
#define XMPP_XEP_IN_BAND_BYTESTREAMS_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_IN_BAND_BYTESTREAMS_TYPE_FLAG, XmppXepInBandBytestreamsFlagClass))

typedef struct _XmppXepInBandBytestreamsFlag XmppXepInBandBytestreamsFlag;
typedef struct _XmppXepInBandBytestreamsFlagClass XmppXepInBandBytestreamsFlagClass;
typedef struct _XmppXepInBandBytestreamsFlagPrivate XmppXepInBandBytestreamsFlagPrivate;

#define XMPP_XEP_BOOKMARKS_TYPE_MODULE (xmpp_xep_bookmarks_module_get_type ())
#define XMPP_XEP_BOOKMARKS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_BOOKMARKS_TYPE_MODULE, XmppXepBookmarksModule))
#define XMPP_XEP_BOOKMARKS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_BOOKMARKS_TYPE_MODULE, XmppXepBookmarksModuleClass))
#define XMPP_XEP_BOOKMARKS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_BOOKMARKS_TYPE_MODULE))
#define XMPP_XEP_BOOKMARKS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_BOOKMARKS_TYPE_MODULE))
#define XMPP_XEP_BOOKMARKS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_BOOKMARKS_TYPE_MODULE, XmppXepBookmarksModuleClass))

typedef struct _XmppXepBookmarksModule XmppXepBookmarksModule;
typedef struct _XmppXepBookmarksModuleClass XmppXepBookmarksModuleClass;
typedef struct _XmppXepBookmarksModulePrivate XmppXepBookmarksModulePrivate;

#define XMPP_XEP_BOOKMARKS_TYPE_BOOKMARKS1_CONFERENCE (xmpp_xep_bookmarks_bookmarks1_conference_get_type ())
#define XMPP_XEP_BOOKMARKS_BOOKMARKS1_CONFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_BOOKMARKS_TYPE_BOOKMARKS1_CONFERENCE, XmppXepBookmarksBookmarks1Conference))
#define XMPP_XEP_BOOKMARKS_BOOKMARKS1_CONFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_BOOKMARKS_TYPE_BOOKMARKS1_CONFERENCE, XmppXepBookmarksBookmarks1ConferenceClass))
#define XMPP_XEP_BOOKMARKS_IS_BOOKMARKS1_CONFERENCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_BOOKMARKS_TYPE_BOOKMARKS1_CONFERENCE))
#define XMPP_XEP_BOOKMARKS_IS_BOOKMARKS1_CONFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_BOOKMARKS_TYPE_BOOKMARKS1_CONFERENCE))
#define XMPP_XEP_BOOKMARKS_BOOKMARKS1_CONFERENCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_BOOKMARKS_TYPE_BOOKMARKS1_CONFERENCE, XmppXepBookmarksBookmarks1ConferenceClass))

typedef struct _XmppXepBookmarksBookmarks1Conference XmppXepBookmarksBookmarks1Conference;
typedef struct _XmppXepBookmarksBookmarks1ConferenceClass XmppXepBookmarksBookmarks1ConferenceClass;
typedef struct _XmppXepBookmarksBookmarks1ConferencePrivate XmppXepBookmarksBookmarks1ConferencePrivate;
typedef enum  {
	XMPP_XEP_MESSAGE_MARKUP_SPAN_TYPE_EMPHASIS,
	XMPP_XEP_MESSAGE_MARKUP_SPAN_TYPE_STRONG_EMPHASIS,
	XMPP_XEP_MESSAGE_MARKUP_SPAN_TYPE_DELETED
} XmppXepMessageMarkupSpanType;

#define XMPP_XEP_MESSAGE_MARKUP_TYPE_SPAN_TYPE (xmpp_xep_message_markup_span_type_get_type ())

#define XMPP_XEP_MESSAGE_MARKUP_TYPE_SPAN (xmpp_xep_message_markup_span_get_type ())
#define XMPP_XEP_MESSAGE_MARKUP_SPAN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MESSAGE_MARKUP_TYPE_SPAN, XmppXepMessageMarkupSpan))
#define XMPP_XEP_MESSAGE_MARKUP_SPAN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MESSAGE_MARKUP_TYPE_SPAN, XmppXepMessageMarkupSpanClass))
#define XMPP_XEP_MESSAGE_MARKUP_IS_SPAN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MESSAGE_MARKUP_TYPE_SPAN))
#define XMPP_XEP_MESSAGE_MARKUP_IS_SPAN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MESSAGE_MARKUP_TYPE_SPAN))
#define XMPP_XEP_MESSAGE_MARKUP_SPAN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MESSAGE_MARKUP_TYPE_SPAN, XmppXepMessageMarkupSpanClass))

typedef struct _XmppXepMessageMarkupSpan XmppXepMessageMarkupSpan;
typedef struct _XmppXepMessageMarkupSpanClass XmppXepMessageMarkupSpanClass;
typedef struct _XmppXepMessageMarkupSpanPrivate XmppXepMessageMarkupSpanPrivate;

#define XMPP_XEP_PRIVATE_XML_STORAGE_TYPE_MODULE (xmpp_xep_private_xml_storage_module_get_type ())
#define XMPP_XEP_PRIVATE_XML_STORAGE_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_PRIVATE_XML_STORAGE_TYPE_MODULE, XmppXepPrivateXmlStorageModule))
#define XMPP_XEP_PRIVATE_XML_STORAGE_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_PRIVATE_XML_STORAGE_TYPE_MODULE, XmppXepPrivateXmlStorageModuleClass))
#define XMPP_XEP_PRIVATE_XML_STORAGE_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_PRIVATE_XML_STORAGE_TYPE_MODULE))
#define XMPP_XEP_PRIVATE_XML_STORAGE_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_PRIVATE_XML_STORAGE_TYPE_MODULE))
#define XMPP_XEP_PRIVATE_XML_STORAGE_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_PRIVATE_XML_STORAGE_TYPE_MODULE, XmppXepPrivateXmlStorageModuleClass))

typedef struct _XmppXepPrivateXmlStorageModule XmppXepPrivateXmlStorageModule;
typedef struct _XmppXepPrivateXmlStorageModuleClass XmppXepPrivateXmlStorageModuleClass;
typedef struct _XmppXepPrivateXmlStorageModulePrivate XmppXepPrivateXmlStorageModulePrivate;

#define XMPP_XEP_VCARD_TYPE_MODULE (xmpp_xep_vcard_module_get_type ())
#define XMPP_XEP_VCARD_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_VCARD_TYPE_MODULE, XmppXepVCardModule))
#define XMPP_XEP_VCARD_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_VCARD_TYPE_MODULE, XmppXepVCardModuleClass))
#define XMPP_XEP_VCARD_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_VCARD_TYPE_MODULE))
#define XMPP_XEP_VCARD_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_VCARD_TYPE_MODULE))
#define XMPP_XEP_VCARD_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_VCARD_TYPE_MODULE, XmppXepVCardModuleClass))

typedef struct _XmppXepVCardModule XmppXepVCardModule;
typedef struct _XmppXepVCardModuleClass XmppXepVCardModuleClass;
typedef struct _XmppXepVCardModulePrivate XmppXepVCardModulePrivate;

#define XMPP_RESULT_SET_MANAGEMENT_TYPE_RESULT_SET_PARAMETERS (xmpp_result_set_management_result_set_parameters_get_type ())
#define XMPP_RESULT_SET_MANAGEMENT_RESULT_SET_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_RESULT_SET_MANAGEMENT_TYPE_RESULT_SET_PARAMETERS, XmppResultSetManagementResultSetParameters))
#define XMPP_RESULT_SET_MANAGEMENT_RESULT_SET_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_RESULT_SET_MANAGEMENT_TYPE_RESULT_SET_PARAMETERS, XmppResultSetManagementResultSetParametersClass))
#define XMPP_RESULT_SET_MANAGEMENT_IS_RESULT_SET_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_RESULT_SET_MANAGEMENT_TYPE_RESULT_SET_PARAMETERS))
#define XMPP_RESULT_SET_MANAGEMENT_IS_RESULT_SET_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_RESULT_SET_MANAGEMENT_TYPE_RESULT_SET_PARAMETERS))
#define XMPP_RESULT_SET_MANAGEMENT_RESULT_SET_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_RESULT_SET_MANAGEMENT_TYPE_RESULT_SET_PARAMETERS, XmppResultSetManagementResultSetParametersClass))

typedef struct _XmppResultSetManagementResultSetParameters XmppResultSetManagementResultSetParameters;
typedef struct _XmppResultSetManagementResultSetParametersClass XmppResultSetManagementResultSetParametersClass;
typedef struct _XmppResultSetManagementResultSetParametersPrivate XmppResultSetManagementResultSetParametersPrivate;

#define XMPP_XEP_PUBSUB_TYPE_MODULE (xmpp_xep_pubsub_module_get_type ())
#define XMPP_XEP_PUBSUB_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_PUBSUB_TYPE_MODULE, XmppXepPubsubModule))
#define XMPP_XEP_PUBSUB_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_PUBSUB_TYPE_MODULE, XmppXepPubsubModuleClass))
#define XMPP_XEP_PUBSUB_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_PUBSUB_TYPE_MODULE))
#define XMPP_XEP_PUBSUB_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_PUBSUB_TYPE_MODULE))
#define XMPP_XEP_PUBSUB_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_PUBSUB_TYPE_MODULE, XmppXepPubsubModuleClass))

typedef struct _XmppXepPubsubModule XmppXepPubsubModule;
typedef struct _XmppXepPubsubModuleClass XmppXepPubsubModuleClass;
typedef struct _XmppXepPubsubModulePrivate XmppXepPubsubModulePrivate;
typedef void (*XmppXepPubsubItemListenerDelegateResultFunc) (XmppXmppStream* stream, XmppJid* jid, const gchar* id, XmppStanzaNode* node, gpointer user_data);
typedef void (*XmppXepPubsubRetractListenerDelegateResultFunc) (XmppXmppStream* stream, XmppJid* jid, const gchar* id, gpointer user_data);
typedef void (*XmppXepPubsubDeleteListenerDelegateResultFunc) (XmppXmppStream* stream, XmppJid* jid, gpointer user_data);
typedef void (*XmppXepPubsubModuleOnResult) (XmppXmppStream* stream, XmppJid* jid, const gchar* id, XmppStanzaNode* node, gpointer user_data);

#define XMPP_XEP_PUBSUB_TYPE_PUBLISH_OPTIONS (xmpp_xep_pubsub_publish_options_get_type ())
#define XMPP_XEP_PUBSUB_PUBLISH_OPTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_PUBSUB_TYPE_PUBLISH_OPTIONS, XmppXepPubsubPublishOptions))
#define XMPP_XEP_PUBSUB_PUBLISH_OPTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_PUBSUB_TYPE_PUBLISH_OPTIONS, XmppXepPubsubPublishOptionsClass))
#define XMPP_XEP_PUBSUB_IS_PUBLISH_OPTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_PUBSUB_TYPE_PUBLISH_OPTIONS))
#define XMPP_XEP_PUBSUB_IS_PUBLISH_OPTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_PUBSUB_TYPE_PUBLISH_OPTIONS))
#define XMPP_XEP_PUBSUB_PUBLISH_OPTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_PUBSUB_TYPE_PUBLISH_OPTIONS, XmppXepPubsubPublishOptionsClass))

typedef struct _XmppXepPubsubPublishOptions XmppXepPubsubPublishOptions;
typedef struct _XmppXepPubsubPublishOptionsClass XmppXepPubsubPublishOptionsClass;
typedef struct _XmppXepPubsubPublishOptionsPrivate XmppXepPubsubPublishOptionsPrivate;

#define XMPP_XEP_PUBSUB_TYPE_ITEM_LISTENER_DELEGATE (xmpp_xep_pubsub_item_listener_delegate_get_type ())
#define XMPP_XEP_PUBSUB_ITEM_LISTENER_DELEGATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_PUBSUB_TYPE_ITEM_LISTENER_DELEGATE, XmppXepPubsubItemListenerDelegate))
#define XMPP_XEP_PUBSUB_ITEM_LISTENER_DELEGATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_PUBSUB_TYPE_ITEM_LISTENER_DELEGATE, XmppXepPubsubItemListenerDelegateClass))
#define XMPP_XEP_PUBSUB_IS_ITEM_LISTENER_DELEGATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_PUBSUB_TYPE_ITEM_LISTENER_DELEGATE))
#define XMPP_XEP_PUBSUB_IS_ITEM_LISTENER_DELEGATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_PUBSUB_TYPE_ITEM_LISTENER_DELEGATE))
#define XMPP_XEP_PUBSUB_ITEM_LISTENER_DELEGATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_PUBSUB_TYPE_ITEM_LISTENER_DELEGATE, XmppXepPubsubItemListenerDelegateClass))

typedef struct _XmppXepPubsubItemListenerDelegate XmppXepPubsubItemListenerDelegate;
typedef struct _XmppXepPubsubItemListenerDelegateClass XmppXepPubsubItemListenerDelegateClass;
typedef struct _XmppXepPubsubItemListenerDelegatePrivate XmppXepPubsubItemListenerDelegatePrivate;

#define XMPP_XEP_PUBSUB_TYPE_RETRACT_LISTENER_DELEGATE (xmpp_xep_pubsub_retract_listener_delegate_get_type ())
#define XMPP_XEP_PUBSUB_RETRACT_LISTENER_DELEGATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_PUBSUB_TYPE_RETRACT_LISTENER_DELEGATE, XmppXepPubsubRetractListenerDelegate))
#define XMPP_XEP_PUBSUB_RETRACT_LISTENER_DELEGATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_PUBSUB_TYPE_RETRACT_LISTENER_DELEGATE, XmppXepPubsubRetractListenerDelegateClass))
#define XMPP_XEP_PUBSUB_IS_RETRACT_LISTENER_DELEGATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_PUBSUB_TYPE_RETRACT_LISTENER_DELEGATE))
#define XMPP_XEP_PUBSUB_IS_RETRACT_LISTENER_DELEGATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_PUBSUB_TYPE_RETRACT_LISTENER_DELEGATE))
#define XMPP_XEP_PUBSUB_RETRACT_LISTENER_DELEGATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_PUBSUB_TYPE_RETRACT_LISTENER_DELEGATE, XmppXepPubsubRetractListenerDelegateClass))

typedef struct _XmppXepPubsubRetractListenerDelegate XmppXepPubsubRetractListenerDelegate;
typedef struct _XmppXepPubsubRetractListenerDelegateClass XmppXepPubsubRetractListenerDelegateClass;
typedef struct _XmppXepPubsubRetractListenerDelegatePrivate XmppXepPubsubRetractListenerDelegatePrivate;

#define XMPP_XEP_PUBSUB_TYPE_DELETE_LISTENER_DELEGATE (xmpp_xep_pubsub_delete_listener_delegate_get_type ())
#define XMPP_XEP_PUBSUB_DELETE_LISTENER_DELEGATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_PUBSUB_TYPE_DELETE_LISTENER_DELEGATE, XmppXepPubsubDeleteListenerDelegate))
#define XMPP_XEP_PUBSUB_DELETE_LISTENER_DELEGATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_PUBSUB_TYPE_DELETE_LISTENER_DELEGATE, XmppXepPubsubDeleteListenerDelegateClass))
#define XMPP_XEP_PUBSUB_IS_DELETE_LISTENER_DELEGATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_PUBSUB_TYPE_DELETE_LISTENER_DELEGATE))
#define XMPP_XEP_PUBSUB_IS_DELETE_LISTENER_DELEGATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_PUBSUB_TYPE_DELETE_LISTENER_DELEGATE))
#define XMPP_XEP_PUBSUB_DELETE_LISTENER_DELEGATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_PUBSUB_TYPE_DELETE_LISTENER_DELEGATE, XmppXepPubsubDeleteListenerDelegateClass))

typedef struct _XmppXepPubsubDeleteListenerDelegate XmppXepPubsubDeleteListenerDelegate;
typedef struct _XmppXepPubsubDeleteListenerDelegateClass XmppXepPubsubDeleteListenerDelegateClass;
typedef struct _XmppXepPubsubDeleteListenerDelegatePrivate XmppXepPubsubDeleteListenerDelegatePrivate;

#define XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_PROXY (xmpp_xep_socks5_bytestreams_proxy_get_type ())
#define XMPP_XEP_SOCKS5_BYTESTREAMS_PROXY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_PROXY, XmppXepSocks5BytestreamsProxy))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_PROXY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_PROXY, XmppXepSocks5BytestreamsProxyClass))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_IS_PROXY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_PROXY))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_IS_PROXY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_PROXY))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_PROXY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_PROXY, XmppXepSocks5BytestreamsProxyClass))

typedef struct _XmppXepSocks5BytestreamsProxy XmppXepSocks5BytestreamsProxy;
typedef struct _XmppXepSocks5BytestreamsProxyClass XmppXepSocks5BytestreamsProxyClass;
typedef struct _XmppXepSocks5BytestreamsProxyPrivate XmppXepSocks5BytestreamsProxyPrivate;
typedef GeeList* (*XmppXepSocks5BytestreamsGetLocalIpAddresses) (gpointer user_data);

#define XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_MODULE (xmpp_xep_socks5_bytestreams_module_get_type ())
#define XMPP_XEP_SOCKS5_BYTESTREAMS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_MODULE, XmppXepSocks5BytestreamsModule))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_MODULE, XmppXepSocks5BytestreamsModuleClass))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_MODULE))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_MODULE))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_MODULE, XmppXepSocks5BytestreamsModuleClass))

typedef struct _XmppXepSocks5BytestreamsModule XmppXepSocks5BytestreamsModule;
typedef struct _XmppXepSocks5BytestreamsModuleClass XmppXepSocks5BytestreamsModuleClass;
typedef struct _XmppXepSocks5BytestreamsModulePrivate XmppXepSocks5BytestreamsModulePrivate;

#define XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_FLAG (xmpp_xep_socks5_bytestreams_flag_get_type ())
#define XMPP_XEP_SOCKS5_BYTESTREAMS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_FLAG, XmppXepSocks5BytestreamsFlag))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_FLAG, XmppXepSocks5BytestreamsFlagClass))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_FLAG))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_FLAG))
#define XMPP_XEP_SOCKS5_BYTESTREAMS_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_SOCKS5_BYTESTREAMS_TYPE_FLAG, XmppXepSocks5BytestreamsFlagClass))

typedef struct _XmppXepSocks5BytestreamsFlag XmppXepSocks5BytestreamsFlag;
typedef struct _XmppXepSocks5BytestreamsFlagClass XmppXepSocks5BytestreamsFlagClass;
typedef struct _XmppXepSocks5BytestreamsFlagPrivate XmppXepSocks5BytestreamsFlagPrivate;

#define XMPP_XEP_IN_BAND_REGISTRATION_TYPE_MODULE (xmpp_xep_in_band_registration_module_get_type ())
#define XMPP_XEP_IN_BAND_REGISTRATION_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_IN_BAND_REGISTRATION_TYPE_MODULE, XmppXepInBandRegistrationModule))
#define XMPP_XEP_IN_BAND_REGISTRATION_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_IN_BAND_REGISTRATION_TYPE_MODULE, XmppXepInBandRegistrationModuleClass))
#define XMPP_XEP_IN_BAND_REGISTRATION_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_IN_BAND_REGISTRATION_TYPE_MODULE))
#define XMPP_XEP_IN_BAND_REGISTRATION_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_IN_BAND_REGISTRATION_TYPE_MODULE))
#define XMPP_XEP_IN_BAND_REGISTRATION_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_IN_BAND_REGISTRATION_TYPE_MODULE, XmppXepInBandRegistrationModuleClass))

typedef struct _XmppXepInBandRegistrationModule XmppXepInBandRegistrationModule;
typedef struct _XmppXepInBandRegistrationModuleClass XmppXepInBandRegistrationModuleClass;
typedef struct _XmppXepInBandRegistrationModulePrivate XmppXepInBandRegistrationModulePrivate;

#define XMPP_XEP_IN_BAND_REGISTRATION_TYPE_FORM (xmpp_xep_in_band_registration_form_get_type ())
#define XMPP_XEP_IN_BAND_REGISTRATION_FORM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_IN_BAND_REGISTRATION_TYPE_FORM, XmppXepInBandRegistrationForm))
#define XMPP_XEP_IN_BAND_REGISTRATION_FORM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_IN_BAND_REGISTRATION_TYPE_FORM, XmppXepInBandRegistrationFormClass))
#define XMPP_XEP_IN_BAND_REGISTRATION_IS_FORM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_IN_BAND_REGISTRATION_TYPE_FORM))
#define XMPP_XEP_IN_BAND_REGISTRATION_IS_FORM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_IN_BAND_REGISTRATION_TYPE_FORM))
#define XMPP_XEP_IN_BAND_REGISTRATION_FORM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_IN_BAND_REGISTRATION_TYPE_FORM, XmppXepInBandRegistrationFormClass))

typedef struct _XmppXepInBandRegistrationForm XmppXepInBandRegistrationForm;
typedef struct _XmppXepInBandRegistrationFormClass XmppXepInBandRegistrationFormClass;
typedef struct _XmppXepInBandRegistrationFormPrivate XmppXepInBandRegistrationFormPrivate;

#define XMPP_XEP_USER_AVATARS_TYPE_MODULE (xmpp_xep_user_avatars_module_get_type ())
#define XMPP_XEP_USER_AVATARS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_USER_AVATARS_TYPE_MODULE, XmppXepUserAvatarsModule))
#define XMPP_XEP_USER_AVATARS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_USER_AVATARS_TYPE_MODULE, XmppXepUserAvatarsModuleClass))
#define XMPP_XEP_USER_AVATARS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_USER_AVATARS_TYPE_MODULE))
#define XMPP_XEP_USER_AVATARS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_USER_AVATARS_TYPE_MODULE))
#define XMPP_XEP_USER_AVATARS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_USER_AVATARS_TYPE_MODULE, XmppXepUserAvatarsModuleClass))

typedef struct _XmppXepUserAvatarsModule XmppXepUserAvatarsModule;
typedef struct _XmppXepUserAvatarsModuleClass XmppXepUserAvatarsModuleClass;
typedef struct _XmppXepUserAvatarsModulePrivate XmppXepUserAvatarsModulePrivate;

#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_TYPE_MODULE (xmpp_xep_chat_state_notifications_module_get_type ())
#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_CHAT_STATE_NOTIFICATIONS_TYPE_MODULE, XmppXepChatStateNotificationsModule))
#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_CHAT_STATE_NOTIFICATIONS_TYPE_MODULE, XmppXepChatStateNotificationsModuleClass))
#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_CHAT_STATE_NOTIFICATIONS_TYPE_MODULE))
#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_CHAT_STATE_NOTIFICATIONS_TYPE_MODULE))
#define XMPP_XEP_CHAT_STATE_NOTIFICATIONS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_CHAT_STATE_NOTIFICATIONS_TYPE_MODULE, XmppXepChatStateNotificationsModuleClass))

typedef struct _XmppXepChatStateNotificationsModule XmppXepChatStateNotificationsModule;
typedef struct _XmppXepChatStateNotificationsModuleClass XmppXepChatStateNotificationsModuleClass;
typedef struct _XmppXepChatStateNotificationsModulePrivate XmppXepChatStateNotificationsModulePrivate;

#define XMPP_XEP_ENTITY_CAPABILITIES_TYPE_MODULE (xmpp_xep_entity_capabilities_module_get_type ())
#define XMPP_XEP_ENTITY_CAPABILITIES_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_ENTITY_CAPABILITIES_TYPE_MODULE, XmppXepEntityCapabilitiesModule))
#define XMPP_XEP_ENTITY_CAPABILITIES_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_ENTITY_CAPABILITIES_TYPE_MODULE, XmppXepEntityCapabilitiesModuleClass))
#define XMPP_XEP_ENTITY_CAPABILITIES_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_ENTITY_CAPABILITIES_TYPE_MODULE))
#define XMPP_XEP_ENTITY_CAPABILITIES_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_ENTITY_CAPABILITIES_TYPE_MODULE))
#define XMPP_XEP_ENTITY_CAPABILITIES_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_ENTITY_CAPABILITIES_TYPE_MODULE, XmppXepEntityCapabilitiesModuleClass))

typedef struct _XmppXepEntityCapabilitiesModule XmppXepEntityCapabilitiesModule;
typedef struct _XmppXepEntityCapabilitiesModuleClass XmppXepEntityCapabilitiesModuleClass;
typedef struct _XmppXepEntityCapabilitiesModulePrivate XmppXepEntityCapabilitiesModulePrivate;

#define XMPP_XEP_ENTITY_CAPABILITIES_TYPE_STORAGE (xmpp_xep_entity_capabilities_storage_get_type ())
#define XMPP_XEP_ENTITY_CAPABILITIES_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_ENTITY_CAPABILITIES_TYPE_STORAGE, XmppXepEntityCapabilitiesStorage))
#define XMPP_XEP_ENTITY_CAPABILITIES_IS_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_ENTITY_CAPABILITIES_TYPE_STORAGE))
#define XMPP_XEP_ENTITY_CAPABILITIES_STORAGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_ENTITY_CAPABILITIES_TYPE_STORAGE, XmppXepEntityCapabilitiesStorageIface))

typedef struct _XmppXepEntityCapabilitiesStorage XmppXepEntityCapabilitiesStorage;
typedef struct _XmppXepEntityCapabilitiesStorageIface XmppXepEntityCapabilitiesStorageIface;

#define XMPP_XEP_JINGLE_TYPE_COMPONENT_CONNECTION (xmpp_xep_jingle_component_connection_get_type ())
#define XMPP_XEP_JINGLE_COMPONENT_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_COMPONENT_CONNECTION, XmppXepJingleComponentConnection))
#define XMPP_XEP_JINGLE_COMPONENT_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_TYPE_COMPONENT_CONNECTION, XmppXepJingleComponentConnectionClass))
#define XMPP_XEP_JINGLE_IS_COMPONENT_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_COMPONENT_CONNECTION))
#define XMPP_XEP_JINGLE_IS_COMPONENT_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_TYPE_COMPONENT_CONNECTION))
#define XMPP_XEP_JINGLE_COMPONENT_CONNECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_TYPE_COMPONENT_CONNECTION, XmppXepJingleComponentConnectionClass))

typedef struct _XmppXepJingleComponentConnection XmppXepJingleComponentConnection;
typedef struct _XmppXepJingleComponentConnectionClass XmppXepJingleComponentConnectionClass;
typedef struct _XmppXepJingleComponentConnectionPrivate XmppXepJingleComponentConnectionPrivate;

#define XMPP_XEP_JINGLE_TYPE_DATAGRAM_CONNECTION (xmpp_xep_jingle_datagram_connection_get_type ())
#define XMPP_XEP_JINGLE_DATAGRAM_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_DATAGRAM_CONNECTION, XmppXepJingleDatagramConnection))
#define XMPP_XEP_JINGLE_DATAGRAM_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_TYPE_DATAGRAM_CONNECTION, XmppXepJingleDatagramConnectionClass))
#define XMPP_XEP_JINGLE_IS_DATAGRAM_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_DATAGRAM_CONNECTION))
#define XMPP_XEP_JINGLE_IS_DATAGRAM_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_TYPE_DATAGRAM_CONNECTION))
#define XMPP_XEP_JINGLE_DATAGRAM_CONNECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_TYPE_DATAGRAM_CONNECTION, XmppXepJingleDatagramConnectionClass))

typedef struct _XmppXepJingleDatagramConnection XmppXepJingleDatagramConnection;
typedef struct _XmppXepJingleDatagramConnectionClass XmppXepJingleDatagramConnectionClass;
typedef struct _XmppXepJingleDatagramConnectionPrivate XmppXepJingleDatagramConnectionPrivate;

#define XMPP_XEP_JINGLE_TYPE_STREAMING_CONNECTION (xmpp_xep_jingle_streaming_connection_get_type ())
#define XMPP_XEP_JINGLE_STREAMING_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_STREAMING_CONNECTION, XmppXepJingleStreamingConnection))
#define XMPP_XEP_JINGLE_STREAMING_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_TYPE_STREAMING_CONNECTION, XmppXepJingleStreamingConnectionClass))
#define XMPP_XEP_JINGLE_IS_STREAMING_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_STREAMING_CONNECTION))
#define XMPP_XEP_JINGLE_IS_STREAMING_CONNECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_TYPE_STREAMING_CONNECTION))
#define XMPP_XEP_JINGLE_STREAMING_CONNECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_TYPE_STREAMING_CONNECTION, XmppXepJingleStreamingConnectionClass))

typedef struct _XmppXepJingleStreamingConnection XmppXepJingleStreamingConnection;
typedef struct _XmppXepJingleStreamingConnectionClass XmppXepJingleStreamingConnectionClass;
typedef struct _XmppXepJingleStreamingConnectionPrivate XmppXepJingleStreamingConnectionPrivate;

#define XMPP_XEP_JINGLE_TYPE_CONTENT (xmpp_xep_jingle_content_get_type ())
#define XMPP_XEP_JINGLE_CONTENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT, XmppXepJingleContent))
#define XMPP_XEP_JINGLE_CONTENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_TYPE_CONTENT, XmppXepJingleContentClass))
#define XMPP_XEP_JINGLE_IS_CONTENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT))
#define XMPP_XEP_JINGLE_IS_CONTENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_TYPE_CONTENT))
#define XMPP_XEP_JINGLE_CONTENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT, XmppXepJingleContentClass))

typedef struct _XmppXepJingleContent XmppXepJingleContent;
typedef struct _XmppXepJingleContentClass XmppXepJingleContentClass;
typedef struct _XmppXepJingleContentPrivate XmppXepJingleContentPrivate;

#define XMPP_XEP_JINGLE_TYPE_CONTENT_TYPE (xmpp_xep_jingle_content_type_get_type ())
#define XMPP_XEP_JINGLE_CONTENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT_TYPE, XmppXepJingleContentType))
#define XMPP_XEP_JINGLE_IS_CONTENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT_TYPE))
#define XMPP_XEP_JINGLE_CONTENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT_TYPE, XmppXepJingleContentTypeIface))

typedef struct _XmppXepJingleContentType XmppXepJingleContentType;
typedef struct _XmppXepJingleContentTypeIface XmppXepJingleContentTypeIface;

#define XMPP_XEP_JINGLE_TYPE_CONTENT_PARAMETERS (xmpp_xep_jingle_content_parameters_get_type ())
#define XMPP_XEP_JINGLE_CONTENT_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT_PARAMETERS, XmppXepJingleContentParameters))
#define XMPP_XEP_JINGLE_IS_CONTENT_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT_PARAMETERS))
#define XMPP_XEP_JINGLE_CONTENT_PARAMETERS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT_PARAMETERS, XmppXepJingleContentParametersIface))

typedef struct _XmppXepJingleContentParameters XmppXepJingleContentParameters;
typedef struct _XmppXepJingleContentParametersIface XmppXepJingleContentParametersIface;

#define XMPP_XEP_JINGLE_TYPE_SESSION (xmpp_xep_jingle_session_get_type ())
#define XMPP_XEP_JINGLE_SESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_SESSION, XmppXepJingleSession))
#define XMPP_XEP_JINGLE_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_TYPE_SESSION, XmppXepJingleSessionClass))
#define XMPP_XEP_JINGLE_IS_SESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_SESSION))
#define XMPP_XEP_JINGLE_IS_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_TYPE_SESSION))
#define XMPP_XEP_JINGLE_SESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_TYPE_SESSION, XmppXepJingleSessionClass))

typedef struct _XmppXepJingleSession XmppXepJingleSession;
typedef struct _XmppXepJingleSessionClass XmppXepJingleSessionClass;

#define XMPP_XEP_JINGLE_TYPE_IQ_ERROR (xmpp_xep_jingle_iq_error_get_type ())
typedef enum  {
	XMPP_XEP_JINGLE_TRANSPORT_TYPE_DATAGRAM,
	XMPP_XEP_JINGLE_TRANSPORT_TYPE_STREAMING
} XmppXepJingleTransportType;

#define XMPP_XEP_JINGLE_TYPE_TRANSPORT_TYPE (xmpp_xep_jingle_transport_type_get_type ())

#define XMPP_XEP_JINGLE_TYPE_TRANSPORT (xmpp_xep_jingle_transport_get_type ())
#define XMPP_XEP_JINGLE_TRANSPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_TRANSPORT, XmppXepJingleTransport))
#define XMPP_XEP_JINGLE_IS_TRANSPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_TRANSPORT))
#define XMPP_XEP_JINGLE_TRANSPORT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_JINGLE_TYPE_TRANSPORT, XmppXepJingleTransportIface))

typedef struct _XmppXepJingleTransport XmppXepJingleTransport;
typedef struct _XmppXepJingleTransportIface XmppXepJingleTransportIface;

#define XMPP_XEP_JINGLE_TYPE_TRANSPORT_PARAMETERS (xmpp_xep_jingle_transport_parameters_get_type ())
#define XMPP_XEP_JINGLE_TRANSPORT_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_TRANSPORT_PARAMETERS, XmppXepJingleTransportParameters))
#define XMPP_XEP_JINGLE_IS_TRANSPORT_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_TRANSPORT_PARAMETERS))
#define XMPP_XEP_JINGLE_TRANSPORT_PARAMETERS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_JINGLE_TYPE_TRANSPORT_PARAMETERS, XmppXepJingleTransportParametersIface))

typedef struct _XmppXepJingleTransportParameters XmppXepJingleTransportParameters;
typedef struct _XmppXepJingleTransportParametersIface XmppXepJingleTransportParametersIface;

#define XMPP_XEP_JINGLE_TYPE_ERROR (xmpp_xep_jingle_error_get_type ())

#define XMPP_XEP_JINGLE_TYPE_SECURITY_PRECONDITION (xmpp_xep_jingle_security_precondition_get_type ())
#define XMPP_XEP_JINGLE_SECURITY_PRECONDITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_SECURITY_PRECONDITION, XmppXepJingleSecurityPrecondition))
#define XMPP_XEP_JINGLE_IS_SECURITY_PRECONDITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_SECURITY_PRECONDITION))
#define XMPP_XEP_JINGLE_SECURITY_PRECONDITION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_JINGLE_TYPE_SECURITY_PRECONDITION, XmppXepJingleSecurityPreconditionIface))

typedef struct _XmppXepJingleSecurityPrecondition XmppXepJingleSecurityPrecondition;
typedef struct _XmppXepJingleSecurityPreconditionIface XmppXepJingleSecurityPreconditionIface;

#define XMPP_XEP_JINGLE_TYPE_SECURITY_PARAMETERS (xmpp_xep_jingle_security_parameters_get_type ())
#define XMPP_XEP_JINGLE_SECURITY_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_SECURITY_PARAMETERS, XmppXepJingleSecurityParameters))
#define XMPP_XEP_JINGLE_IS_SECURITY_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_SECURITY_PARAMETERS))
#define XMPP_XEP_JINGLE_SECURITY_PARAMETERS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_JINGLE_TYPE_SECURITY_PARAMETERS, XmppXepJingleSecurityParametersIface))

typedef struct _XmppXepJingleSecurityParameters XmppXepJingleSecurityParameters;
typedef struct _XmppXepJingleSecurityParametersIface XmppXepJingleSecurityParametersIface;

#define XMPP_XEP_JINGLE_TYPE_CONTENT_ENCRYPTION (xmpp_xep_jingle_content_encryption_get_type ())
#define XMPP_XEP_JINGLE_CONTENT_ENCRYPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT_ENCRYPTION, XmppXepJingleContentEncryption))
#define XMPP_XEP_JINGLE_CONTENT_ENCRYPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_TYPE_CONTENT_ENCRYPTION, XmppXepJingleContentEncryptionClass))
#define XMPP_XEP_JINGLE_IS_CONTENT_ENCRYPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT_ENCRYPTION))
#define XMPP_XEP_JINGLE_IS_CONTENT_ENCRYPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_TYPE_CONTENT_ENCRYPTION))
#define XMPP_XEP_JINGLE_CONTENT_ENCRYPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_TYPE_CONTENT_ENCRYPTION, XmppXepJingleContentEncryptionClass))

typedef struct _XmppXepJingleContentEncryption XmppXepJingleContentEncryption;
typedef struct _XmppXepJingleContentEncryptionClass XmppXepJingleContentEncryptionClass;
typedef enum  {
	XMPP_XEP_JINGLE_CONTENT_STATE_PENDING,
	XMPP_XEP_JINGLE_CONTENT_STATE_WANTS_TO_BE_ACCEPTED,
	XMPP_XEP_JINGLE_CONTENT_STATE_ACCEPTED,
	XMPP_XEP_JINGLE_CONTENT_STATE_REPLACING_TRANSPORT,
	XMPP_XEP_JINGLE_CONTENT_STATE_WAITING_FOR_TRANSPORT_REPLACE
} XmppXepJingleContentState;

#define XMPP_XEP_JINGLE_CONTENT_TYPE_STATE (xmpp_xep_jingle_content_state_get_type ())
typedef enum  {
	XMPP_XEP_JINGLE_SENDERS_BOTH,
	XMPP_XEP_JINGLE_SENDERS_INITIATOR,
	XMPP_XEP_JINGLE_SENDERS_NONE,
	XMPP_XEP_JINGLE_SENDERS_RESPONDER
} XmppXepJingleSenders;

#define XMPP_XEP_JINGLE_TYPE_SENDERS (xmpp_xep_jingle_senders_get_type ())
typedef enum  {
	XMPP_XEP_JINGLE_ROLE_INITIATOR,
	XMPP_XEP_JINGLE_ROLE_RESPONDER
} XmppXepJingleRole;

#define XMPP_XEP_JINGLE_TYPE_ROLE (xmpp_xep_jingle_role_get_type ())
typedef struct _XmppXepJingleContentEncryptionPrivate XmppXepJingleContentEncryptionPrivate;

#define XMPP_XEP_JINGLE_TYPE_FLAG (xmpp_xep_jingle_flag_get_type ())
#define XMPP_XEP_JINGLE_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_FLAG, XmppXepJingleFlag))
#define XMPP_XEP_JINGLE_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_TYPE_FLAG, XmppXepJingleFlagClass))
#define XMPP_XEP_JINGLE_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_FLAG))
#define XMPP_XEP_JINGLE_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_TYPE_FLAG))
#define XMPP_XEP_JINGLE_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_TYPE_FLAG, XmppXepJingleFlagClass))

typedef struct _XmppXepJingleFlag XmppXepJingleFlag;
typedef struct _XmppXepJingleFlagClass XmppXepJingleFlagClass;
typedef struct _XmppXepJingleFlagPrivate XmppXepJingleFlagPrivate;

#define XMPP_XEP_JINGLE_TYPE_MODULE (xmpp_xep_jingle_module_get_type ())
#define XMPP_XEP_JINGLE_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_MODULE, XmppXepJingleModule))
#define XMPP_XEP_JINGLE_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_TYPE_MODULE, XmppXepJingleModuleClass))
#define XMPP_XEP_JINGLE_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_MODULE))
#define XMPP_XEP_JINGLE_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_TYPE_MODULE))
#define XMPP_XEP_JINGLE_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_TYPE_MODULE, XmppXepJingleModuleClass))

typedef struct _XmppXepJingleModule XmppXepJingleModule;
typedef struct _XmppXepJingleModuleClass XmppXepJingleModuleClass;
typedef struct _XmppXepJingleModulePrivate XmppXepJingleModulePrivate;

#define XMPP_XEP_JINGLE_TYPE_SESSION_INFO_NS (xmpp_xep_jingle_session_info_ns_get_type ())
#define XMPP_XEP_JINGLE_SESSION_INFO_NS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_TYPE_SESSION_INFO_NS, XmppXepJingleSessionInfoNs))
#define XMPP_XEP_JINGLE_IS_SESSION_INFO_NS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_TYPE_SESSION_INFO_NS))
#define XMPP_XEP_JINGLE_SESSION_INFO_NS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_JINGLE_TYPE_SESSION_INFO_NS, XmppXepJingleSessionInfoNsIface))

typedef struct _XmppXepJingleSessionInfoNs XmppXepJingleSessionInfoNs;
typedef struct _XmppXepJingleSessionInfoNsIface XmppXepJingleSessionInfoNsIface;
typedef void (*XmppXepJingleSessionTerminate) (XmppJid* to, const gchar* sid, XmppStanzaNode* reason, gpointer user_data);
typedef struct _XmppXepJingleSessionPrivate XmppXepJingleSessionPrivate;
typedef enum  {
	XMPP_XEP_JINGLE_SESSION_STATE_INITIATE_SENT,
	XMPP_XEP_JINGLE_SESSION_STATE_INITIATE_RECEIVED,
	XMPP_XEP_JINGLE_SESSION_STATE_ACTIVE,
	XMPP_XEP_JINGLE_SESSION_STATE_ENDED
} XmppXepJingleSessionState;

#define XMPP_XEP_JINGLE_SESSION_TYPE_STATE (xmpp_xep_jingle_session_state_get_type ())

#define XMPP_XEP_JINGLE_RTP_TYPE_PARAMETERS (xmpp_xep_jingle_rtp_parameters_get_type ())
#define XMPP_XEP_JINGLE_RTP_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RTP_TYPE_PARAMETERS, XmppXepJingleRtpParameters))
#define XMPP_XEP_JINGLE_RTP_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RTP_TYPE_PARAMETERS, XmppXepJingleRtpParametersClass))
#define XMPP_XEP_JINGLE_RTP_IS_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RTP_TYPE_PARAMETERS))
#define XMPP_XEP_JINGLE_RTP_IS_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RTP_TYPE_PARAMETERS))
#define XMPP_XEP_JINGLE_RTP_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RTP_TYPE_PARAMETERS, XmppXepJingleRtpParametersClass))

typedef struct _XmppXepJingleRtpParameters XmppXepJingleRtpParameters;
typedef struct _XmppXepJingleRtpParametersClass XmppXepJingleRtpParametersClass;
typedef struct _XmppXepJingleRtpParametersPrivate XmppXepJingleRtpParametersPrivate;

#define XMPP_XEP_JINGLE_RTP_TYPE_PAYLOAD_TYPE (xmpp_xep_jingle_rtp_payload_type_get_type ())
#define XMPP_XEP_JINGLE_RTP_PAYLOAD_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RTP_TYPE_PAYLOAD_TYPE, XmppXepJingleRtpPayloadType))
#define XMPP_XEP_JINGLE_RTP_PAYLOAD_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RTP_TYPE_PAYLOAD_TYPE, XmppXepJingleRtpPayloadTypeClass))
#define XMPP_XEP_JINGLE_RTP_IS_PAYLOAD_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RTP_TYPE_PAYLOAD_TYPE))
#define XMPP_XEP_JINGLE_RTP_IS_PAYLOAD_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RTP_TYPE_PAYLOAD_TYPE))
#define XMPP_XEP_JINGLE_RTP_PAYLOAD_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RTP_TYPE_PAYLOAD_TYPE, XmppXepJingleRtpPayloadTypeClass))

typedef struct _XmppXepJingleRtpPayloadType XmppXepJingleRtpPayloadType;
typedef struct _XmppXepJingleRtpPayloadTypeClass XmppXepJingleRtpPayloadTypeClass;

#define XMPP_XEP_JINGLE_RTP_TYPE_HEADER_EXTENSION (xmpp_xep_jingle_rtp_header_extension_get_type ())
#define XMPP_XEP_JINGLE_RTP_HEADER_EXTENSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RTP_TYPE_HEADER_EXTENSION, XmppXepJingleRtpHeaderExtension))
#define XMPP_XEP_JINGLE_RTP_HEADER_EXTENSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RTP_TYPE_HEADER_EXTENSION, XmppXepJingleRtpHeaderExtensionClass))
#define XMPP_XEP_JINGLE_RTP_IS_HEADER_EXTENSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RTP_TYPE_HEADER_EXTENSION))
#define XMPP_XEP_JINGLE_RTP_IS_HEADER_EXTENSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RTP_TYPE_HEADER_EXTENSION))
#define XMPP_XEP_JINGLE_RTP_HEADER_EXTENSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RTP_TYPE_HEADER_EXTENSION, XmppXepJingleRtpHeaderExtensionClass))

typedef struct _XmppXepJingleRtpHeaderExtension XmppXepJingleRtpHeaderExtension;
typedef struct _XmppXepJingleRtpHeaderExtensionClass XmppXepJingleRtpHeaderExtensionClass;

#define XMPP_XEP_JINGLE_RTP_TYPE_CRYPTO (xmpp_xep_jingle_rtp_crypto_get_type ())
#define XMPP_XEP_JINGLE_RTP_CRYPTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RTP_TYPE_CRYPTO, XmppXepJingleRtpCrypto))
#define XMPP_XEP_JINGLE_RTP_CRYPTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RTP_TYPE_CRYPTO, XmppXepJingleRtpCryptoClass))
#define XMPP_XEP_JINGLE_RTP_IS_CRYPTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RTP_TYPE_CRYPTO))
#define XMPP_XEP_JINGLE_RTP_IS_CRYPTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RTP_TYPE_CRYPTO))
#define XMPP_XEP_JINGLE_RTP_CRYPTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RTP_TYPE_CRYPTO, XmppXepJingleRtpCryptoClass))

typedef struct _XmppXepJingleRtpCrypto XmppXepJingleRtpCrypto;
typedef struct _XmppXepJingleRtpCryptoClass XmppXepJingleRtpCryptoClass;

#define XMPP_XEP_JINGLE_RTP_TYPE_MODULE (xmpp_xep_jingle_rtp_module_get_type ())
#define XMPP_XEP_JINGLE_RTP_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RTP_TYPE_MODULE, XmppXepJingleRtpModule))
#define XMPP_XEP_JINGLE_RTP_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RTP_TYPE_MODULE, XmppXepJingleRtpModuleClass))
#define XMPP_XEP_JINGLE_RTP_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RTP_TYPE_MODULE))
#define XMPP_XEP_JINGLE_RTP_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RTP_TYPE_MODULE))
#define XMPP_XEP_JINGLE_RTP_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RTP_TYPE_MODULE, XmppXepJingleRtpModuleClass))

typedef struct _XmppXepJingleRtpModule XmppXepJingleRtpModule;
typedef struct _XmppXepJingleRtpModuleClass XmppXepJingleRtpModuleClass;

#define XMPP_XEP_JINGLE_RTP_TYPE_STREAM (xmpp_xep_jingle_rtp_stream_get_type ())
#define XMPP_XEP_JINGLE_RTP_STREAM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RTP_TYPE_STREAM, XmppXepJingleRtpStream))
#define XMPP_XEP_JINGLE_RTP_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RTP_TYPE_STREAM, XmppXepJingleRtpStreamClass))
#define XMPP_XEP_JINGLE_RTP_IS_STREAM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RTP_TYPE_STREAM))
#define XMPP_XEP_JINGLE_RTP_IS_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RTP_TYPE_STREAM))
#define XMPP_XEP_JINGLE_RTP_STREAM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RTP_TYPE_STREAM, XmppXepJingleRtpStreamClass))

typedef struct _XmppXepJingleRtpStream XmppXepJingleRtpStream;
typedef struct _XmppXepJingleRtpStreamClass XmppXepJingleRtpStreamClass;
typedef struct _XmppXepJingleRtpHeaderExtensionPrivate XmppXepJingleRtpHeaderExtensionPrivate;

#define XMPP_XEP_JINGLE_RTP_TYPE_CONTENT_TYPE (xmpp_xep_jingle_rtp_content_type_get_type ())
#define XMPP_XEP_JINGLE_RTP_CONTENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RTP_TYPE_CONTENT_TYPE, XmppXepJingleRtpContentType))
#define XMPP_XEP_JINGLE_RTP_CONTENT_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RTP_TYPE_CONTENT_TYPE, XmppXepJingleRtpContentTypeClass))
#define XMPP_XEP_JINGLE_RTP_IS_CONTENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RTP_TYPE_CONTENT_TYPE))
#define XMPP_XEP_JINGLE_RTP_IS_CONTENT_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RTP_TYPE_CONTENT_TYPE))
#define XMPP_XEP_JINGLE_RTP_CONTENT_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RTP_TYPE_CONTENT_TYPE, XmppXepJingleRtpContentTypeClass))

typedef struct _XmppXepJingleRtpContentType XmppXepJingleRtpContentType;
typedef struct _XmppXepJingleRtpContentTypeClass XmppXepJingleRtpContentTypeClass;
typedef struct _XmppXepJingleRtpContentTypePrivate XmppXepJingleRtpContentTypePrivate;
typedef struct _XmppXepJingleRtpModulePrivate XmppXepJingleRtpModulePrivate;

#define XMPP_XEP_JINGLE_RTP_TYPE_SESSION_INFO_TYPE (xmpp_xep_jingle_rtp_session_info_type_get_type ())
#define XMPP_XEP_JINGLE_RTP_SESSION_INFO_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RTP_TYPE_SESSION_INFO_TYPE, XmppXepJingleRtpSessionInfoType))
#define XMPP_XEP_JINGLE_RTP_SESSION_INFO_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RTP_TYPE_SESSION_INFO_TYPE, XmppXepJingleRtpSessionInfoTypeClass))
#define XMPP_XEP_JINGLE_RTP_IS_SESSION_INFO_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RTP_TYPE_SESSION_INFO_TYPE))
#define XMPP_XEP_JINGLE_RTP_IS_SESSION_INFO_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RTP_TYPE_SESSION_INFO_TYPE))
#define XMPP_XEP_JINGLE_RTP_SESSION_INFO_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RTP_TYPE_SESSION_INFO_TYPE, XmppXepJingleRtpSessionInfoTypeClass))

typedef struct _XmppXepJingleRtpSessionInfoType XmppXepJingleRtpSessionInfoType;
typedef struct _XmppXepJingleRtpSessionInfoTypeClass XmppXepJingleRtpSessionInfoTypeClass;
typedef struct _XmppXepJingleRtpCryptoPrivate XmppXepJingleRtpCryptoPrivate;
typedef struct _XmppXepJingleRtpPayloadTypePrivate XmppXepJingleRtpPayloadTypePrivate;

#define XMPP_XEP_JINGLE_RTP_TYPE_RTCP_FEEDBACK (xmpp_xep_jingle_rtp_rtcp_feedback_get_type ())
#define XMPP_XEP_JINGLE_RTP_RTCP_FEEDBACK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RTP_TYPE_RTCP_FEEDBACK, XmppXepJingleRtpRtcpFeedback))
#define XMPP_XEP_JINGLE_RTP_RTCP_FEEDBACK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RTP_TYPE_RTCP_FEEDBACK, XmppXepJingleRtpRtcpFeedbackClass))
#define XMPP_XEP_JINGLE_RTP_IS_RTCP_FEEDBACK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RTP_TYPE_RTCP_FEEDBACK))
#define XMPP_XEP_JINGLE_RTP_IS_RTCP_FEEDBACK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RTP_TYPE_RTCP_FEEDBACK))
#define XMPP_XEP_JINGLE_RTP_RTCP_FEEDBACK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RTP_TYPE_RTCP_FEEDBACK, XmppXepJingleRtpRtcpFeedbackClass))

typedef struct _XmppXepJingleRtpRtcpFeedback XmppXepJingleRtpRtcpFeedback;
typedef struct _XmppXepJingleRtpRtcpFeedbackClass XmppXepJingleRtpRtcpFeedbackClass;
typedef struct _XmppXepJingleRtpRtcpFeedbackPrivate XmppXepJingleRtpRtcpFeedbackPrivate;
typedef enum  {
	XMPP_XEP_JINGLE_RTP_CALL_SESSION_INFO_ACTIVE,
	XMPP_XEP_JINGLE_RTP_CALL_SESSION_INFO_HOLD,
	XMPP_XEP_JINGLE_RTP_CALL_SESSION_INFO_UNHOLD,
	XMPP_XEP_JINGLE_RTP_CALL_SESSION_INFO_MUTE,
	XMPP_XEP_JINGLE_RTP_CALL_SESSION_INFO_UNMUTE,
	XMPP_XEP_JINGLE_RTP_CALL_SESSION_INFO_RINGING
} XmppXepJingleRtpCallSessionInfo;

#define XMPP_XEP_JINGLE_RTP_TYPE_CALL_SESSION_INFO (xmpp_xep_jingle_rtp_call_session_info_get_type ())
typedef struct _XmppXepJingleRtpSessionInfoTypePrivate XmppXepJingleRtpSessionInfoTypePrivate;
typedef struct _XmppXepJingleRtpStreamPrivate XmppXepJingleRtpStreamPrivate;

#define XMPP_XEP_JINGLE_ICE_UDP_TYPE_CANDIDATE (xmpp_xep_jingle_ice_udp_candidate_get_type ())
#define XMPP_XEP_JINGLE_ICE_UDP_CANDIDATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_ICE_UDP_TYPE_CANDIDATE, XmppXepJingleIceUdpCandidate))
#define XMPP_XEP_JINGLE_ICE_UDP_CANDIDATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_ICE_UDP_TYPE_CANDIDATE, XmppXepJingleIceUdpCandidateClass))
#define XMPP_XEP_JINGLE_ICE_UDP_IS_CANDIDATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_ICE_UDP_TYPE_CANDIDATE))
#define XMPP_XEP_JINGLE_ICE_UDP_IS_CANDIDATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_ICE_UDP_TYPE_CANDIDATE))
#define XMPP_XEP_JINGLE_ICE_UDP_CANDIDATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_ICE_UDP_TYPE_CANDIDATE, XmppXepJingleIceUdpCandidateClass))

typedef struct _XmppXepJingleIceUdpCandidate XmppXepJingleIceUdpCandidate;
typedef struct _XmppXepJingleIceUdpCandidateClass XmppXepJingleIceUdpCandidateClass;
typedef struct _XmppXepJingleIceUdpCandidatePrivate XmppXepJingleIceUdpCandidatePrivate;
typedef enum  {
	XMPP_XEP_JINGLE_ICE_UDP_CANDIDATE_TYPE_HOST,
	XMPP_XEP_JINGLE_ICE_UDP_CANDIDATE_TYPE_PRFLX,
	XMPP_XEP_JINGLE_ICE_UDP_CANDIDATE_TYPE_RELAY,
	XMPP_XEP_JINGLE_ICE_UDP_CANDIDATE_TYPE_SRFLX
} XmppXepJingleIceUdpCandidateType;

#define XMPP_XEP_JINGLE_ICE_UDP_CANDIDATE_TYPE_TYPE (xmpp_xep_jingle_ice_udp_candidate_type_get_type ())

#define XMPP_XEP_JINGLE_ICE_UDP_TYPE_MODULE (xmpp_xep_jingle_ice_udp_module_get_type ())
#define XMPP_XEP_JINGLE_ICE_UDP_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_ICE_UDP_TYPE_MODULE, XmppXepJingleIceUdpModule))
#define XMPP_XEP_JINGLE_ICE_UDP_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_ICE_UDP_TYPE_MODULE, XmppXepJingleIceUdpModuleClass))
#define XMPP_XEP_JINGLE_ICE_UDP_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_ICE_UDP_TYPE_MODULE))
#define XMPP_XEP_JINGLE_ICE_UDP_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_ICE_UDP_TYPE_MODULE))
#define XMPP_XEP_JINGLE_ICE_UDP_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_ICE_UDP_TYPE_MODULE, XmppXepJingleIceUdpModuleClass))

typedef struct _XmppXepJingleIceUdpModule XmppXepJingleIceUdpModule;
typedef struct _XmppXepJingleIceUdpModuleClass XmppXepJingleIceUdpModuleClass;
typedef struct _XmppXepJingleIceUdpModulePrivate XmppXepJingleIceUdpModulePrivate;

#define XMPP_XEP_JINGLE_ICE_UDP_TYPE_ICE_UDP_TRANSPORT_PARAMETERS (xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_get_type ())
#define XMPP_XEP_JINGLE_ICE_UDP_ICE_UDP_TRANSPORT_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_ICE_UDP_TYPE_ICE_UDP_TRANSPORT_PARAMETERS, XmppXepJingleIceUdpIceUdpTransportParameters))
#define XMPP_XEP_JINGLE_ICE_UDP_ICE_UDP_TRANSPORT_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_ICE_UDP_TYPE_ICE_UDP_TRANSPORT_PARAMETERS, XmppXepJingleIceUdpIceUdpTransportParametersClass))
#define XMPP_XEP_JINGLE_ICE_UDP_IS_ICE_UDP_TRANSPORT_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_ICE_UDP_TYPE_ICE_UDP_TRANSPORT_PARAMETERS))
#define XMPP_XEP_JINGLE_ICE_UDP_IS_ICE_UDP_TRANSPORT_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_ICE_UDP_TYPE_ICE_UDP_TRANSPORT_PARAMETERS))
#define XMPP_XEP_JINGLE_ICE_UDP_ICE_UDP_TRANSPORT_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_ICE_UDP_TYPE_ICE_UDP_TRANSPORT_PARAMETERS, XmppXepJingleIceUdpIceUdpTransportParametersClass))

typedef struct _XmppXepJingleIceUdpIceUdpTransportParameters XmppXepJingleIceUdpIceUdpTransportParameters;
typedef struct _XmppXepJingleIceUdpIceUdpTransportParametersClass XmppXepJingleIceUdpIceUdpTransportParametersClass;
typedef struct _XmppXepJingleIceUdpIceUdpTransportParametersPrivate XmppXepJingleIceUdpIceUdpTransportParametersPrivate;
typedef GeeList* (*XmppXepJingleRawUdpGetLocalIpAddresses) (gpointer user_data);

#define XMPP_XEP_JINGLE_RAW_UDP_TYPE_MODULE (xmpp_xep_jingle_raw_udp_module_get_type ())
#define XMPP_XEP_JINGLE_RAW_UDP_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RAW_UDP_TYPE_MODULE, XmppXepJingleRawUdpModule))
#define XMPP_XEP_JINGLE_RAW_UDP_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RAW_UDP_TYPE_MODULE, XmppXepJingleRawUdpModuleClass))
#define XMPP_XEP_JINGLE_RAW_UDP_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RAW_UDP_TYPE_MODULE))
#define XMPP_XEP_JINGLE_RAW_UDP_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RAW_UDP_TYPE_MODULE))
#define XMPP_XEP_JINGLE_RAW_UDP_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RAW_UDP_TYPE_MODULE, XmppXepJingleRawUdpModuleClass))

typedef struct _XmppXepJingleRawUdpModule XmppXepJingleRawUdpModule;
typedef struct _XmppXepJingleRawUdpModuleClass XmppXepJingleRawUdpModuleClass;
typedef struct _XmppXepJingleRawUdpModulePrivate XmppXepJingleRawUdpModulePrivate;

#define XMPP_XEP_JINGLE_RAW_UDP_TYPE_TRANSPORT_PARAMETERS (xmpp_xep_jingle_raw_udp_transport_parameters_get_type ())
#define XMPP_XEP_JINGLE_RAW_UDP_TRANSPORT_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RAW_UDP_TYPE_TRANSPORT_PARAMETERS, XmppXepJingleRawUdpTransportParameters))
#define XMPP_XEP_JINGLE_RAW_UDP_TRANSPORT_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RAW_UDP_TYPE_TRANSPORT_PARAMETERS, XmppXepJingleRawUdpTransportParametersClass))
#define XMPP_XEP_JINGLE_RAW_UDP_IS_TRANSPORT_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RAW_UDP_TYPE_TRANSPORT_PARAMETERS))
#define XMPP_XEP_JINGLE_RAW_UDP_IS_TRANSPORT_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RAW_UDP_TYPE_TRANSPORT_PARAMETERS))
#define XMPP_XEP_JINGLE_RAW_UDP_TRANSPORT_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RAW_UDP_TYPE_TRANSPORT_PARAMETERS, XmppXepJingleRawUdpTransportParametersClass))

typedef struct _XmppXepJingleRawUdpTransportParameters XmppXepJingleRawUdpTransportParameters;
typedef struct _XmppXepJingleRawUdpTransportParametersClass XmppXepJingleRawUdpTransportParametersClass;
typedef struct _XmppXepJingleRawUdpTransportParametersPrivate XmppXepJingleRawUdpTransportParametersPrivate;

#define XMPP_XEP_JINGLE_RAW_UDP_TYPE_CANDIDATE (xmpp_xep_jingle_raw_udp_candidate_get_type ())
#define XMPP_XEP_JINGLE_RAW_UDP_CANDIDATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_RAW_UDP_TYPE_CANDIDATE, XmppXepJingleRawUdpCandidate))
#define XMPP_XEP_JINGLE_RAW_UDP_CANDIDATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_RAW_UDP_TYPE_CANDIDATE, XmppXepJingleRawUdpCandidateClass))
#define XMPP_XEP_JINGLE_RAW_UDP_IS_CANDIDATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_RAW_UDP_TYPE_CANDIDATE))
#define XMPP_XEP_JINGLE_RAW_UDP_IS_CANDIDATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_RAW_UDP_TYPE_CANDIDATE))
#define XMPP_XEP_JINGLE_RAW_UDP_CANDIDATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_RAW_UDP_TYPE_CANDIDATE, XmppXepJingleRawUdpCandidateClass))

typedef struct _XmppXepJingleRawUdpCandidate XmppXepJingleRawUdpCandidate;
typedef struct _XmppXepJingleRawUdpCandidateClass XmppXepJingleRawUdpCandidateClass;
typedef struct _XmppXepJingleRawUdpCandidatePrivate XmppXepJingleRawUdpCandidatePrivate;

#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_MODULE (xmpp_xep_message_delivery_receipts_module_get_type ())
#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_MODULE, XmppXepMessageDeliveryReceiptsModule))
#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_MODULE, XmppXepMessageDeliveryReceiptsModuleClass))
#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_MODULE))
#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_MODULE))
#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_MODULE, XmppXepMessageDeliveryReceiptsModuleClass))

typedef struct _XmppXepMessageDeliveryReceiptsModule XmppXepMessageDeliveryReceiptsModule;
typedef struct _XmppXepMessageDeliveryReceiptsModuleClass XmppXepMessageDeliveryReceiptsModuleClass;
typedef struct _XmppXepMessageDeliveryReceiptsModulePrivate XmppXepMessageDeliveryReceiptsModulePrivate;

#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_SEND_PIPELINE_LISTENER (xmpp_xep_message_delivery_receipts_send_pipeline_listener_get_type ())
#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_SEND_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_SEND_PIPELINE_LISTENER, XmppXepMessageDeliveryReceiptsSendPipelineListener))
#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_SEND_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_SEND_PIPELINE_LISTENER, XmppXepMessageDeliveryReceiptsSendPipelineListenerClass))
#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_IS_SEND_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_SEND_PIPELINE_LISTENER))
#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_IS_SEND_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_SEND_PIPELINE_LISTENER))
#define XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_SEND_PIPELINE_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MESSAGE_DELIVERY_RECEIPTS_TYPE_SEND_PIPELINE_LISTENER, XmppXepMessageDeliveryReceiptsSendPipelineListenerClass))

typedef struct _XmppXepMessageDeliveryReceiptsSendPipelineListener XmppXepMessageDeliveryReceiptsSendPipelineListener;
typedef struct _XmppXepMessageDeliveryReceiptsSendPipelineListenerClass XmppXepMessageDeliveryReceiptsSendPipelineListenerClass;
typedef struct _XmppXepMessageDeliveryReceiptsSendPipelineListenerPrivate XmppXepMessageDeliveryReceiptsSendPipelineListenerPrivate;

#define XMPP_XEP_BLOCKING_COMMAND_TYPE_MODULE (xmpp_xep_blocking_command_module_get_type ())
#define XMPP_XEP_BLOCKING_COMMAND_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_BLOCKING_COMMAND_TYPE_MODULE, XmppXepBlockingCommandModule))
#define XMPP_XEP_BLOCKING_COMMAND_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_BLOCKING_COMMAND_TYPE_MODULE, XmppXepBlockingCommandModuleClass))
#define XMPP_XEP_BLOCKING_COMMAND_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_BLOCKING_COMMAND_TYPE_MODULE))
#define XMPP_XEP_BLOCKING_COMMAND_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_BLOCKING_COMMAND_TYPE_MODULE))
#define XMPP_XEP_BLOCKING_COMMAND_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_BLOCKING_COMMAND_TYPE_MODULE, XmppXepBlockingCommandModuleClass))

typedef struct _XmppXepBlockingCommandModule XmppXepBlockingCommandModule;
typedef struct _XmppXepBlockingCommandModuleClass XmppXepBlockingCommandModuleClass;
typedef struct _XmppXepBlockingCommandModulePrivate XmppXepBlockingCommandModulePrivate;

#define XMPP_XEP_BLOCKING_COMMAND_TYPE_FLAG (xmpp_xep_blocking_command_flag_get_type ())
#define XMPP_XEP_BLOCKING_COMMAND_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_BLOCKING_COMMAND_TYPE_FLAG, XmppXepBlockingCommandFlag))
#define XMPP_XEP_BLOCKING_COMMAND_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_BLOCKING_COMMAND_TYPE_FLAG, XmppXepBlockingCommandFlagClass))
#define XMPP_XEP_BLOCKING_COMMAND_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_BLOCKING_COMMAND_TYPE_FLAG))
#define XMPP_XEP_BLOCKING_COMMAND_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_BLOCKING_COMMAND_TYPE_FLAG))
#define XMPP_XEP_BLOCKING_COMMAND_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_BLOCKING_COMMAND_TYPE_FLAG, XmppXepBlockingCommandFlagClass))

typedef struct _XmppXepBlockingCommandFlag XmppXepBlockingCommandFlag;
typedef struct _XmppXepBlockingCommandFlagClass XmppXepBlockingCommandFlagClass;
typedef struct _XmppXepBlockingCommandFlagPrivate XmppXepBlockingCommandFlagPrivate;

#define XMPP_XEP_STREAM_MANAGEMENT_TYPE_MODULE (xmpp_xep_stream_management_module_get_type ())
#define XMPP_XEP_STREAM_MANAGEMENT_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_STREAM_MANAGEMENT_TYPE_MODULE, XmppXepStreamManagementModule))
#define XMPP_XEP_STREAM_MANAGEMENT_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_STREAM_MANAGEMENT_TYPE_MODULE, XmppXepStreamManagementModuleClass))
#define XMPP_XEP_STREAM_MANAGEMENT_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_STREAM_MANAGEMENT_TYPE_MODULE))
#define XMPP_XEP_STREAM_MANAGEMENT_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_STREAM_MANAGEMENT_TYPE_MODULE))
#define XMPP_XEP_STREAM_MANAGEMENT_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_STREAM_MANAGEMENT_TYPE_MODULE, XmppXepStreamManagementModuleClass))

typedef struct _XmppXepStreamManagementModule XmppXepStreamManagementModule;
typedef struct _XmppXepStreamManagementModuleClass XmppXepStreamManagementModuleClass;
typedef struct _XmppXepStreamManagementModulePrivate XmppXepStreamManagementModulePrivate;

#define XMPP_XEP_STREAM_MANAGEMENT_TYPE_FLAG (xmpp_xep_stream_management_flag_get_type ())
#define XMPP_XEP_STREAM_MANAGEMENT_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_STREAM_MANAGEMENT_TYPE_FLAG, XmppXepStreamManagementFlag))
#define XMPP_XEP_STREAM_MANAGEMENT_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_STREAM_MANAGEMENT_TYPE_FLAG, XmppXepStreamManagementFlagClass))
#define XMPP_XEP_STREAM_MANAGEMENT_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_STREAM_MANAGEMENT_TYPE_FLAG))
#define XMPP_XEP_STREAM_MANAGEMENT_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_STREAM_MANAGEMENT_TYPE_FLAG))
#define XMPP_XEP_STREAM_MANAGEMENT_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_STREAM_MANAGEMENT_TYPE_FLAG, XmppXepStreamManagementFlagClass))

typedef struct _XmppXepStreamManagementFlag XmppXepStreamManagementFlag;
typedef struct _XmppXepStreamManagementFlagClass XmppXepStreamManagementFlagClass;
typedef struct _XmppXepStreamManagementFlagPrivate XmppXepStreamManagementFlagPrivate;

#define XMPP_XEP_PING_TYPE_MODULE (xmpp_xep_ping_module_get_type ())
#define XMPP_XEP_PING_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_PING_TYPE_MODULE, XmppXepPingModule))
#define XMPP_XEP_PING_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_PING_TYPE_MODULE, XmppXepPingModuleClass))
#define XMPP_XEP_PING_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_PING_TYPE_MODULE))
#define XMPP_XEP_PING_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_PING_TYPE_MODULE))
#define XMPP_XEP_PING_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_PING_TYPE_MODULE, XmppXepPingModuleClass))

typedef struct _XmppXepPingModule XmppXepPingModule;
typedef struct _XmppXepPingModuleClass XmppXepPingModuleClass;
typedef struct _XmppXepPingModulePrivate XmppXepPingModulePrivate;

#define XMPP_XEP_DELAYED_DELIVERY_TYPE_MODULE (xmpp_xep_delayed_delivery_module_get_type ())
#define XMPP_XEP_DELAYED_DELIVERY_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DELAYED_DELIVERY_TYPE_MODULE, XmppXepDelayedDeliveryModule))
#define XMPP_XEP_DELAYED_DELIVERY_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DELAYED_DELIVERY_TYPE_MODULE, XmppXepDelayedDeliveryModuleClass))
#define XMPP_XEP_DELAYED_DELIVERY_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DELAYED_DELIVERY_TYPE_MODULE))
#define XMPP_XEP_DELAYED_DELIVERY_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DELAYED_DELIVERY_TYPE_MODULE))
#define XMPP_XEP_DELAYED_DELIVERY_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DELAYED_DELIVERY_TYPE_MODULE, XmppXepDelayedDeliveryModuleClass))

typedef struct _XmppXepDelayedDeliveryModule XmppXepDelayedDeliveryModule;
typedef struct _XmppXepDelayedDeliveryModuleClass XmppXepDelayedDeliveryModuleClass;
typedef struct _XmppXepDelayedDeliveryModulePrivate XmppXepDelayedDeliveryModulePrivate;

#define XMPP_XEP_DELAYED_DELIVERY_TYPE_RECEIVED_PIPELINE_LISTENER (xmpp_xep_delayed_delivery_received_pipeline_listener_get_type ())
#define XMPP_XEP_DELAYED_DELIVERY_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DELAYED_DELIVERY_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepDelayedDeliveryReceivedPipelineListener))
#define XMPP_XEP_DELAYED_DELIVERY_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DELAYED_DELIVERY_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepDelayedDeliveryReceivedPipelineListenerClass))
#define XMPP_XEP_DELAYED_DELIVERY_IS_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DELAYED_DELIVERY_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_XEP_DELAYED_DELIVERY_IS_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DELAYED_DELIVERY_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_XEP_DELAYED_DELIVERY_RECEIVED_PIPELINE_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DELAYED_DELIVERY_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepDelayedDeliveryReceivedPipelineListenerClass))

typedef struct _XmppXepDelayedDeliveryReceivedPipelineListener XmppXepDelayedDeliveryReceivedPipelineListener;
typedef struct _XmppXepDelayedDeliveryReceivedPipelineListenerClass XmppXepDelayedDeliveryReceivedPipelineListenerClass;
typedef struct _XmppXepDelayedDeliveryReceivedPipelineListenerPrivate XmppXepDelayedDeliveryReceivedPipelineListenerPrivate;

#define XMPP_XEP_DELAYED_DELIVERY_TYPE_MESSAGE_FLAG (xmpp_xep_delayed_delivery_message_flag_get_type ())
#define XMPP_XEP_DELAYED_DELIVERY_MESSAGE_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DELAYED_DELIVERY_TYPE_MESSAGE_FLAG, XmppXepDelayedDeliveryMessageFlag))
#define XMPP_XEP_DELAYED_DELIVERY_MESSAGE_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DELAYED_DELIVERY_TYPE_MESSAGE_FLAG, XmppXepDelayedDeliveryMessageFlagClass))
#define XMPP_XEP_DELAYED_DELIVERY_IS_MESSAGE_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DELAYED_DELIVERY_TYPE_MESSAGE_FLAG))
#define XMPP_XEP_DELAYED_DELIVERY_IS_MESSAGE_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DELAYED_DELIVERY_TYPE_MESSAGE_FLAG))
#define XMPP_XEP_DELAYED_DELIVERY_MESSAGE_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DELAYED_DELIVERY_TYPE_MESSAGE_FLAG, XmppXepDelayedDeliveryMessageFlagClass))

typedef struct _XmppXepDelayedDeliveryMessageFlag XmppXepDelayedDeliveryMessageFlag;
typedef struct _XmppXepDelayedDeliveryMessageFlagClass XmppXepDelayedDeliveryMessageFlagClass;
typedef struct _XmppXepDelayedDeliveryMessageFlagPrivate XmppXepDelayedDeliveryMessageFlagPrivate;

#define XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_TYPE_SERVICE (xmpp_xep_external_service_discovery_service_get_type ())
#define XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_TYPE_SERVICE, XmppXepExternalServiceDiscoveryService))
#define XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_TYPE_SERVICE, XmppXepExternalServiceDiscoveryServiceClass))
#define XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_IS_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_TYPE_SERVICE))
#define XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_IS_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_TYPE_SERVICE))
#define XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_EXTERNAL_SERVICE_DISCOVERY_TYPE_SERVICE, XmppXepExternalServiceDiscoveryServiceClass))

typedef struct _XmppXepExternalServiceDiscoveryService XmppXepExternalServiceDiscoveryService;
typedef struct _XmppXepExternalServiceDiscoveryServiceClass XmppXepExternalServiceDiscoveryServiceClass;
typedef struct _XmppXepExternalServiceDiscoveryServicePrivate XmppXepExternalServiceDiscoveryServicePrivate;

#define XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_MODULE (xmpp_xep_jingle_file_transfer_module_get_type ())
#define XMPP_XEP_JINGLE_FILE_TRANSFER_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_MODULE, XmppXepJingleFileTransferModule))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_MODULE, XmppXepJingleFileTransferModuleClass))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_MODULE))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_MODULE))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_MODULE, XmppXepJingleFileTransferModuleClass))

typedef struct _XmppXepJingleFileTransferModule XmppXepJingleFileTransferModule;
typedef struct _XmppXepJingleFileTransferModuleClass XmppXepJingleFileTransferModuleClass;
typedef struct _XmppXepJingleFileTransferModulePrivate XmppXepJingleFileTransferModulePrivate;

#define XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_SESSION_INFO_TYPE (xmpp_xep_jingle_file_transfer_session_info_type_get_type ())
#define XMPP_XEP_JINGLE_FILE_TRANSFER_SESSION_INFO_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_SESSION_INFO_TYPE, XmppXepJingleFileTransferSessionInfoType))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_SESSION_INFO_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_SESSION_INFO_TYPE, XmppXepJingleFileTransferSessionInfoTypeClass))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_IS_SESSION_INFO_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_SESSION_INFO_TYPE))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_IS_SESSION_INFO_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_SESSION_INFO_TYPE))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_SESSION_INFO_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_SESSION_INFO_TYPE, XmppXepJingleFileTransferSessionInfoTypeClass))

typedef struct _XmppXepJingleFileTransferSessionInfoType XmppXepJingleFileTransferSessionInfoType;
typedef struct _XmppXepJingleFileTransferSessionInfoTypeClass XmppXepJingleFileTransferSessionInfoTypeClass;
typedef struct _XmppXepJingleFileTransferSessionInfoTypePrivate XmppXepJingleFileTransferSessionInfoTypePrivate;

#define XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_PARAMETERS (xmpp_xep_jingle_file_transfer_parameters_get_type ())
#define XMPP_XEP_JINGLE_FILE_TRANSFER_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_PARAMETERS, XmppXepJingleFileTransferParameters))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_PARAMETERS, XmppXepJingleFileTransferParametersClass))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_IS_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_PARAMETERS))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_IS_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_PARAMETERS))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_PARAMETERS, XmppXepJingleFileTransferParametersClass))

typedef struct _XmppXepJingleFileTransferParameters XmppXepJingleFileTransferParameters;
typedef struct _XmppXepJingleFileTransferParametersClass XmppXepJingleFileTransferParametersClass;
typedef struct _XmppXepJingleFileTransferParametersPrivate XmppXepJingleFileTransferParametersPrivate;

#define XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_FILE_TRANSFER (xmpp_xep_jingle_file_transfer_file_transfer_get_type ())
#define XMPP_XEP_JINGLE_FILE_TRANSFER_FILE_TRANSFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_FILE_TRANSFER, XmppXepJingleFileTransferFileTransfer))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_FILE_TRANSFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_FILE_TRANSFER, XmppXepJingleFileTransferFileTransferClass))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_IS_FILE_TRANSFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_FILE_TRANSFER))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_IS_FILE_TRANSFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_FILE_TRANSFER))
#define XMPP_XEP_JINGLE_FILE_TRANSFER_FILE_TRANSFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_FILE_TRANSFER_TYPE_FILE_TRANSFER, XmppXepJingleFileTransferFileTransferClass))

typedef struct _XmppXepJingleFileTransferFileTransfer XmppXepJingleFileTransferFileTransfer;
typedef struct _XmppXepJingleFileTransferFileTransferClass XmppXepJingleFileTransferFileTransferClass;
typedef struct _XmppXepJingleFileTransferFileTransferPrivate XmppXepJingleFileTransferFileTransferPrivate;

#define XMPP_XEP_DIRECT_MUC_INVITATIONS_TYPE_MODULE (xmpp_xep_direct_muc_invitations_module_get_type ())
#define XMPP_XEP_DIRECT_MUC_INVITATIONS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_DIRECT_MUC_INVITATIONS_TYPE_MODULE, XmppXepDirectMucInvitationsModule))
#define XMPP_XEP_DIRECT_MUC_INVITATIONS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_DIRECT_MUC_INVITATIONS_TYPE_MODULE, XmppXepDirectMucInvitationsModuleClass))
#define XMPP_XEP_DIRECT_MUC_INVITATIONS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_DIRECT_MUC_INVITATIONS_TYPE_MODULE))
#define XMPP_XEP_DIRECT_MUC_INVITATIONS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_DIRECT_MUC_INVITATIONS_TYPE_MODULE))
#define XMPP_XEP_DIRECT_MUC_INVITATIONS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_DIRECT_MUC_INVITATIONS_TYPE_MODULE, XmppXepDirectMucInvitationsModuleClass))

typedef struct _XmppXepDirectMucInvitationsModule XmppXepDirectMucInvitationsModule;
typedef struct _XmppXepDirectMucInvitationsModuleClass XmppXepDirectMucInvitationsModuleClass;
typedef struct _XmppXepDirectMucInvitationsModulePrivate XmppXepDirectMucInvitationsModulePrivate;

#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_MODULE (xmpp_xep_jingle_socks5_bytestreams_module_get_type ())
#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_MODULE, XmppXepJingleSocks5BytestreamsModule))
#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_MODULE, XmppXepJingleSocks5BytestreamsModuleClass))
#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_MODULE))
#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_MODULE))
#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_MODULE, XmppXepJingleSocks5BytestreamsModuleClass))

typedef struct _XmppXepJingleSocks5BytestreamsModule XmppXepJingleSocks5BytestreamsModule;
typedef struct _XmppXepJingleSocks5BytestreamsModuleClass XmppXepJingleSocks5BytestreamsModuleClass;
typedef struct _XmppXepJingleSocks5BytestreamsModulePrivate XmppXepJingleSocks5BytestreamsModulePrivate;
typedef enum  {
	XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_CANDIDATE_TYPE_ASSISTED,
	XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_CANDIDATE_TYPE_DIRECT,
	XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_CANDIDATE_TYPE_PROXY,
	XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_CANDIDATE_TYPE_TUNNEL
} XmppXepJingleSocks5BytestreamsCandidateType;

#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_CANDIDATE_TYPE (xmpp_xep_jingle_socks5_bytestreams_candidate_type_get_type ())

#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_CANDIDATE (xmpp_xep_jingle_socks5_bytestreams_candidate_get_type ())
#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_CANDIDATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_CANDIDATE, XmppXepJingleSocks5BytestreamsCandidate))
#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_CANDIDATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_CANDIDATE, XmppXepJingleSocks5BytestreamsCandidateClass))
#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_IS_CANDIDATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_CANDIDATE))
#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_IS_CANDIDATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_CANDIDATE))
#define XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_CANDIDATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_SOCKS5_BYTESTREAMS_TYPE_CANDIDATE, XmppXepJingleSocks5BytestreamsCandidateClass))

typedef struct _XmppXepJingleSocks5BytestreamsCandidate XmppXepJingleSocks5BytestreamsCandidate;
typedef struct _XmppXepJingleSocks5BytestreamsCandidateClass XmppXepJingleSocks5BytestreamsCandidateClass;
typedef struct _XmppXepJingleSocks5BytestreamsCandidatePrivate XmppXepJingleSocks5BytestreamsCandidatePrivate;

#define XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_TYPE_MODULE (xmpp_xep_jingle_in_band_bytestreams_module_get_type ())
#define XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_TYPE_MODULE, XmppXepJingleInBandBytestreamsModule))
#define XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_TYPE_MODULE, XmppXepJingleInBandBytestreamsModuleClass))
#define XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_TYPE_MODULE))
#define XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_TYPE_MODULE))
#define XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_IN_BAND_BYTESTREAMS_TYPE_MODULE, XmppXepJingleInBandBytestreamsModuleClass))

typedef struct _XmppXepJingleInBandBytestreamsModule XmppXepJingleInBandBytestreamsModule;
typedef struct _XmppXepJingleInBandBytestreamsModuleClass XmppXepJingleInBandBytestreamsModuleClass;
typedef struct _XmppXepJingleInBandBytestreamsModulePrivate XmppXepJingleInBandBytestreamsModulePrivate;

#define XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_TYPE_THUMBNAIL (xmpp_xep_jingle_content_thumbnails_thumbnail_get_type ())
#define XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_THUMBNAIL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_TYPE_THUMBNAIL, XmppXepJingleContentThumbnailsThumbnail))
#define XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_THUMBNAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_TYPE_THUMBNAIL, XmppXepJingleContentThumbnailsThumbnailClass))
#define XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_IS_THUMBNAIL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_TYPE_THUMBNAIL))
#define XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_IS_THUMBNAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_TYPE_THUMBNAIL))
#define XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_THUMBNAIL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_CONTENT_THUMBNAILS_TYPE_THUMBNAIL, XmppXepJingleContentThumbnailsThumbnailClass))

typedef struct _XmppXepJingleContentThumbnailsThumbnail XmppXepJingleContentThumbnailsThumbnail;
typedef struct _XmppXepJingleContentThumbnailsThumbnailClass XmppXepJingleContentThumbnailsThumbnailClass;
typedef struct _XmppXepJingleContentThumbnailsThumbnailPrivate XmppXepJingleContentThumbnailsThumbnailPrivate;

#define XMPP_XEP_MUJI_TYPE_MODULE (xmpp_xep_muji_module_get_type ())
#define XMPP_XEP_MUJI_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MUJI_TYPE_MODULE, XmppXepMujiModule))
#define XMPP_XEP_MUJI_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MUJI_TYPE_MODULE, XmppXepMujiModuleClass))
#define XMPP_XEP_MUJI_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MUJI_TYPE_MODULE))
#define XMPP_XEP_MUJI_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MUJI_TYPE_MODULE))
#define XMPP_XEP_MUJI_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MUJI_TYPE_MODULE, XmppXepMujiModuleClass))

typedef struct _XmppXepMujiModule XmppXepMujiModule;
typedef struct _XmppXepMujiModuleClass XmppXepMujiModuleClass;
typedef struct _XmppXepMujiModulePrivate XmppXepMujiModulePrivate;

#define XMPP_XEP_MUJI_TYPE_GROUP_CALL (xmpp_xep_muji_group_call_get_type ())
#define XMPP_XEP_MUJI_GROUP_CALL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MUJI_TYPE_GROUP_CALL, XmppXepMujiGroupCall))
#define XMPP_XEP_MUJI_GROUP_CALL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MUJI_TYPE_GROUP_CALL, XmppXepMujiGroupCallClass))
#define XMPP_XEP_MUJI_IS_GROUP_CALL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MUJI_TYPE_GROUP_CALL))
#define XMPP_XEP_MUJI_IS_GROUP_CALL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MUJI_TYPE_GROUP_CALL))
#define XMPP_XEP_MUJI_GROUP_CALL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MUJI_TYPE_GROUP_CALL, XmppXepMujiGroupCallClass))

typedef struct _XmppXepMujiGroupCall XmppXepMujiGroupCall;
typedef struct _XmppXepMujiGroupCallClass XmppXepMujiGroupCallClass;
typedef struct _XmppXepMujiGroupCallPrivate XmppXepMujiGroupCallPrivate;

#define XMPP_XEP_MUJI_TYPE_FLAG (xmpp_xep_muji_flag_get_type ())
#define XMPP_XEP_MUJI_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MUJI_TYPE_FLAG, XmppXepMujiFlag))
#define XMPP_XEP_MUJI_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MUJI_TYPE_FLAG, XmppXepMujiFlagClass))
#define XMPP_XEP_MUJI_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MUJI_TYPE_FLAG))
#define XMPP_XEP_MUJI_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MUJI_TYPE_FLAG))
#define XMPP_XEP_MUJI_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MUJI_TYPE_FLAG, XmppXepMujiFlagClass))

typedef struct _XmppXepMujiFlag XmppXepMujiFlag;
typedef struct _XmppXepMujiFlagClass XmppXepMujiFlagClass;
typedef struct _XmppXepMujiFlagPrivate XmppXepMujiFlagPrivate;

#define XMPP_XEP_MESSAGE_CARBONS_TYPE_MODULE (xmpp_xep_message_carbons_module_get_type ())
#define XMPP_XEP_MESSAGE_CARBONS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MESSAGE_CARBONS_TYPE_MODULE, XmppXepMessageCarbonsModule))
#define XMPP_XEP_MESSAGE_CARBONS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MESSAGE_CARBONS_TYPE_MODULE, XmppXepMessageCarbonsModuleClass))
#define XMPP_XEP_MESSAGE_CARBONS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MESSAGE_CARBONS_TYPE_MODULE))
#define XMPP_XEP_MESSAGE_CARBONS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MESSAGE_CARBONS_TYPE_MODULE))
#define XMPP_XEP_MESSAGE_CARBONS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MESSAGE_CARBONS_TYPE_MODULE, XmppXepMessageCarbonsModuleClass))

typedef struct _XmppXepMessageCarbonsModule XmppXepMessageCarbonsModule;
typedef struct _XmppXepMessageCarbonsModuleClass XmppXepMessageCarbonsModuleClass;
typedef struct _XmppXepMessageCarbonsModulePrivate XmppXepMessageCarbonsModulePrivate;

#define XMPP_XEP_MESSAGE_CARBONS_TYPE_RECEIVED_PIPELINE_LISTENER (xmpp_xep_message_carbons_received_pipeline_listener_get_type ())
#define XMPP_XEP_MESSAGE_CARBONS_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MESSAGE_CARBONS_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepMessageCarbonsReceivedPipelineListener))
#define XMPP_XEP_MESSAGE_CARBONS_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MESSAGE_CARBONS_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepMessageCarbonsReceivedPipelineListenerClass))
#define XMPP_XEP_MESSAGE_CARBONS_IS_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MESSAGE_CARBONS_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_XEP_MESSAGE_CARBONS_IS_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MESSAGE_CARBONS_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_XEP_MESSAGE_CARBONS_RECEIVED_PIPELINE_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MESSAGE_CARBONS_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepMessageCarbonsReceivedPipelineListenerClass))

typedef struct _XmppXepMessageCarbonsReceivedPipelineListener XmppXepMessageCarbonsReceivedPipelineListener;
typedef struct _XmppXepMessageCarbonsReceivedPipelineListenerClass XmppXepMessageCarbonsReceivedPipelineListenerClass;
typedef struct _XmppXepMessageCarbonsReceivedPipelineListenerPrivate XmppXepMessageCarbonsReceivedPipelineListenerPrivate;

#define XMPP_XEP_MESSAGE_CARBONS_TYPE_MESSAGE_FLAG (xmpp_xep_message_carbons_message_flag_get_type ())
#define XMPP_XEP_MESSAGE_CARBONS_MESSAGE_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_MESSAGE_CARBONS_TYPE_MESSAGE_FLAG, XmppXepMessageCarbonsMessageFlag))
#define XMPP_XEP_MESSAGE_CARBONS_MESSAGE_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_MESSAGE_CARBONS_TYPE_MESSAGE_FLAG, XmppXepMessageCarbonsMessageFlagClass))
#define XMPP_XEP_MESSAGE_CARBONS_IS_MESSAGE_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_MESSAGE_CARBONS_TYPE_MESSAGE_FLAG))
#define XMPP_XEP_MESSAGE_CARBONS_IS_MESSAGE_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_MESSAGE_CARBONS_TYPE_MESSAGE_FLAG))
#define XMPP_XEP_MESSAGE_CARBONS_MESSAGE_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_MESSAGE_CARBONS_TYPE_MESSAGE_FLAG, XmppXepMessageCarbonsMessageFlagClass))

typedef struct _XmppXepMessageCarbonsMessageFlag XmppXepMessageCarbonsMessageFlag;
typedef struct _XmppXepMessageCarbonsMessageFlagClass XmppXepMessageCarbonsMessageFlagClass;
typedef struct _XmppXepMessageCarbonsMessageFlagPrivate XmppXepMessageCarbonsMessageFlagPrivate;

#define XMPP_XEP_COIN_TYPE_MODULE (xmpp_xep_coin_module_get_type ())
#define XMPP_XEP_COIN_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_COIN_TYPE_MODULE, XmppXepCoinModule))
#define XMPP_XEP_COIN_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_COIN_TYPE_MODULE, XmppXepCoinModuleClass))
#define XMPP_XEP_COIN_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_COIN_TYPE_MODULE))
#define XMPP_XEP_COIN_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_COIN_TYPE_MODULE))
#define XMPP_XEP_COIN_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_COIN_TYPE_MODULE, XmppXepCoinModuleClass))

typedef struct _XmppXepCoinModule XmppXepCoinModule;
typedef struct _XmppXepCoinModuleClass XmppXepCoinModuleClass;
typedef struct _XmppXepCoinModulePrivate XmppXepCoinModulePrivate;

#define XMPP_XEP_COIN_TYPE_CONFERENCE_INFO (xmpp_xep_coin_conference_info_get_type ())
#define XMPP_XEP_COIN_CONFERENCE_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_COIN_TYPE_CONFERENCE_INFO, XmppXepCoinConferenceInfo))
#define XMPP_XEP_COIN_CONFERENCE_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_COIN_TYPE_CONFERENCE_INFO, XmppXepCoinConferenceInfoClass))
#define XMPP_XEP_COIN_IS_CONFERENCE_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_COIN_TYPE_CONFERENCE_INFO))
#define XMPP_XEP_COIN_IS_CONFERENCE_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_COIN_TYPE_CONFERENCE_INFO))
#define XMPP_XEP_COIN_CONFERENCE_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_COIN_TYPE_CONFERENCE_INFO, XmppXepCoinConferenceInfoClass))

typedef struct _XmppXepCoinConferenceInfo XmppXepCoinConferenceInfo;
typedef struct _XmppXepCoinConferenceInfoClass XmppXepCoinConferenceInfoClass;
typedef struct _XmppXepCoinConferenceInfoPrivate XmppXepCoinConferenceInfoPrivate;

#define XMPP_XEP_COIN_TYPE_CONFERENCE_USER (xmpp_xep_coin_conference_user_get_type ())
#define XMPP_XEP_COIN_CONFERENCE_USER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_COIN_TYPE_CONFERENCE_USER, XmppXepCoinConferenceUser))
#define XMPP_XEP_COIN_CONFERENCE_USER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_COIN_TYPE_CONFERENCE_USER, XmppXepCoinConferenceUserClass))
#define XMPP_XEP_COIN_IS_CONFERENCE_USER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_COIN_TYPE_CONFERENCE_USER))
#define XMPP_XEP_COIN_IS_CONFERENCE_USER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_COIN_TYPE_CONFERENCE_USER))
#define XMPP_XEP_COIN_CONFERENCE_USER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_COIN_TYPE_CONFERENCE_USER, XmppXepCoinConferenceUserClass))

typedef struct _XmppXepCoinConferenceUser XmppXepCoinConferenceUser;
typedef struct _XmppXepCoinConferenceUserClass XmppXepCoinConferenceUserClass;
typedef struct _XmppXepCoinConferenceUserPrivate XmppXepCoinConferenceUserPrivate;

#define XMPP_XEP_COIN_TYPE_CONFERENCE_MEDIA (xmpp_xep_coin_conference_media_get_type ())
#define XMPP_XEP_COIN_CONFERENCE_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_COIN_TYPE_CONFERENCE_MEDIA, XmppXepCoinConferenceMedia))
#define XMPP_XEP_COIN_CONFERENCE_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_COIN_TYPE_CONFERENCE_MEDIA, XmppXepCoinConferenceMediaClass))
#define XMPP_XEP_COIN_IS_CONFERENCE_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_COIN_TYPE_CONFERENCE_MEDIA))
#define XMPP_XEP_COIN_IS_CONFERENCE_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_COIN_TYPE_CONFERENCE_MEDIA))
#define XMPP_XEP_COIN_CONFERENCE_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_COIN_TYPE_CONFERENCE_MEDIA, XmppXepCoinConferenceMediaClass))

typedef struct _XmppXepCoinConferenceMedia XmppXepCoinConferenceMedia;
typedef struct _XmppXepCoinConferenceMediaClass XmppXepCoinConferenceMediaClass;
typedef struct _XmppXepCoinConferenceMediaPrivate XmppXepCoinConferenceMediaPrivate;

#define XMPP_XEP_CRYPTOGRAPHIC_HASHES_TYPE_HASH (xmpp_xep_cryptographic_hashes_hash_get_type ())
#define XMPP_XEP_CRYPTOGRAPHIC_HASHES_HASH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_CRYPTOGRAPHIC_HASHES_TYPE_HASH, XmppXepCryptographicHashesHash))
#define XMPP_XEP_CRYPTOGRAPHIC_HASHES_HASH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_CRYPTOGRAPHIC_HASHES_TYPE_HASH, XmppXepCryptographicHashesHashClass))
#define XMPP_XEP_CRYPTOGRAPHIC_HASHES_IS_HASH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_CRYPTOGRAPHIC_HASHES_TYPE_HASH))
#define XMPP_XEP_CRYPTOGRAPHIC_HASHES_IS_HASH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_CRYPTOGRAPHIC_HASHES_TYPE_HASH))
#define XMPP_XEP_CRYPTOGRAPHIC_HASHES_HASH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_CRYPTOGRAPHIC_HASHES_TYPE_HASH, XmppXepCryptographicHashesHashClass))

typedef struct _XmppXepCryptographicHashesHash XmppXepCryptographicHashesHash;
typedef struct _XmppXepCryptographicHashesHashClass XmppXepCryptographicHashesHashClass;
typedef struct _XmppXepCryptographicHashesHashPrivate XmppXepCryptographicHashesHashPrivate;

#define XMPP_XEP_LAST_MESSAGE_CORRECTION_TYPE_MODULE (xmpp_xep_last_message_correction_module_get_type ())
#define XMPP_XEP_LAST_MESSAGE_CORRECTION_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_LAST_MESSAGE_CORRECTION_TYPE_MODULE, XmppXepLastMessageCorrectionModule))
#define XMPP_XEP_LAST_MESSAGE_CORRECTION_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_LAST_MESSAGE_CORRECTION_TYPE_MODULE, XmppXepLastMessageCorrectionModuleClass))
#define XMPP_XEP_LAST_MESSAGE_CORRECTION_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_LAST_MESSAGE_CORRECTION_TYPE_MODULE))
#define XMPP_XEP_LAST_MESSAGE_CORRECTION_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_LAST_MESSAGE_CORRECTION_TYPE_MODULE))
#define XMPP_XEP_LAST_MESSAGE_CORRECTION_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_LAST_MESSAGE_CORRECTION_TYPE_MODULE, XmppXepLastMessageCorrectionModuleClass))

typedef struct _XmppXepLastMessageCorrectionModule XmppXepLastMessageCorrectionModule;
typedef struct _XmppXepLastMessageCorrectionModuleClass XmppXepLastMessageCorrectionModuleClass;
typedef struct _XmppXepLastMessageCorrectionModulePrivate XmppXepLastMessageCorrectionModulePrivate;

#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_TYPE_MAM_QUERY_PARAMS (xmpp_message_archive_management_v2_mam_query_params_get_type ())
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_MAM_QUERY_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_TYPE_MAM_QUERY_PARAMS, XmppMessageArchiveManagementV2MamQueryParams))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_MAM_QUERY_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_TYPE_MAM_QUERY_PARAMS, XmppMessageArchiveManagementV2MamQueryParamsClass))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_IS_MAM_QUERY_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_TYPE_MAM_QUERY_PARAMS))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_IS_MAM_QUERY_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_TYPE_MAM_QUERY_PARAMS))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_MAM_QUERY_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_V2_TYPE_MAM_QUERY_PARAMS, XmppMessageArchiveManagementV2MamQueryParamsClass))

typedef struct _XmppMessageArchiveManagementV2MamQueryParams XmppMessageArchiveManagementV2MamQueryParams;
typedef struct _XmppMessageArchiveManagementV2MamQueryParamsClass XmppMessageArchiveManagementV2MamQueryParamsClass;
typedef struct _XmppMessageArchiveManagementV2MamQueryParamsPrivate XmppMessageArchiveManagementV2MamQueryParamsPrivate;

#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_QUERY_RESULT (xmpp_message_archive_management_query_result_get_type ())
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_QUERY_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_QUERY_RESULT, XmppMessageArchiveManagementQueryResult))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_QUERY_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_QUERY_RESULT, XmppMessageArchiveManagementQueryResultClass))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_IS_QUERY_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_QUERY_RESULT))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_IS_QUERY_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_QUERY_RESULT))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_QUERY_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_QUERY_RESULT, XmppMessageArchiveManagementQueryResultClass))

typedef struct _XmppMessageArchiveManagementQueryResult XmppMessageArchiveManagementQueryResult;
typedef struct _XmppMessageArchiveManagementQueryResultClass XmppMessageArchiveManagementQueryResultClass;
typedef struct _XmppMessageArchiveManagementQueryResultPrivate XmppMessageArchiveManagementQueryResultPrivate;

#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MODULE (xmpp_message_archive_management_module_get_type ())
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MODULE, XmppMessageArchiveManagementModule))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MODULE, XmppMessageArchiveManagementModuleClass))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MODULE))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MODULE))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MODULE, XmppMessageArchiveManagementModuleClass))

typedef struct _XmppMessageArchiveManagementModule XmppMessageArchiveManagementModule;
typedef struct _XmppMessageArchiveManagementModuleClass XmppMessageArchiveManagementModuleClass;
typedef struct _XmppMessageArchiveManagementModulePrivate XmppMessageArchiveManagementModulePrivate;

#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_RECEIVED_PIPELINE_LISTENER (xmpp_message_archive_management_received_pipeline_listener_get_type ())
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_RECEIVED_PIPELINE_LISTENER, XmppMessageArchiveManagementReceivedPipelineListener))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_RECEIVED_PIPELINE_LISTENER, XmppMessageArchiveManagementReceivedPipelineListenerClass))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_IS_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_IS_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_RECEIVED_PIPELINE_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_RECEIVED_PIPELINE_LISTENER, XmppMessageArchiveManagementReceivedPipelineListenerClass))

typedef struct _XmppMessageArchiveManagementReceivedPipelineListener XmppMessageArchiveManagementReceivedPipelineListener;
typedef struct _XmppMessageArchiveManagementReceivedPipelineListenerClass XmppMessageArchiveManagementReceivedPipelineListenerClass;
typedef struct _XmppMessageArchiveManagementReceivedPipelineListenerPrivate XmppMessageArchiveManagementReceivedPipelineListenerPrivate;

#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_FLAG (xmpp_message_archive_management_flag_get_type ())
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_FLAG, XmppMessageArchiveManagementFlag))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_FLAG, XmppMessageArchiveManagementFlagClass))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_FLAG))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_FLAG))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_FLAG, XmppMessageArchiveManagementFlagClass))

typedef struct _XmppMessageArchiveManagementFlag XmppMessageArchiveManagementFlag;
typedef struct _XmppMessageArchiveManagementFlagClass XmppMessageArchiveManagementFlagClass;
typedef struct _XmppMessageArchiveManagementFlagPrivate XmppMessageArchiveManagementFlagPrivate;

#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MESSAGE_FLAG (xmpp_message_archive_management_message_flag_get_type ())
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_MESSAGE_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MESSAGE_FLAG, XmppMessageArchiveManagementMessageFlag))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_MESSAGE_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MESSAGE_FLAG, XmppMessageArchiveManagementMessageFlagClass))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_IS_MESSAGE_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MESSAGE_FLAG))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_IS_MESSAGE_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MESSAGE_FLAG))
#define XMPP_MESSAGE_ARCHIVE_MANAGEMENT_MESSAGE_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_MESSAGE_ARCHIVE_MANAGEMENT_TYPE_MESSAGE_FLAG, XmppMessageArchiveManagementMessageFlagClass))

typedef struct _XmppMessageArchiveManagementMessageFlag XmppMessageArchiveManagementMessageFlag;
typedef struct _XmppMessageArchiveManagementMessageFlagClass XmppMessageArchiveManagementMessageFlagClass;
typedef struct _XmppMessageArchiveManagementMessageFlagPrivate XmppMessageArchiveManagementMessageFlagPrivate;

#define XMPP_XEP_CHAT_MARKERS_TYPE_MODULE (xmpp_xep_chat_markers_module_get_type ())
#define XMPP_XEP_CHAT_MARKERS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_CHAT_MARKERS_TYPE_MODULE, XmppXepChatMarkersModule))
#define XMPP_XEP_CHAT_MARKERS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_CHAT_MARKERS_TYPE_MODULE, XmppXepChatMarkersModuleClass))
#define XMPP_XEP_CHAT_MARKERS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_CHAT_MARKERS_TYPE_MODULE))
#define XMPP_XEP_CHAT_MARKERS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_CHAT_MARKERS_TYPE_MODULE))
#define XMPP_XEP_CHAT_MARKERS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_CHAT_MARKERS_TYPE_MODULE, XmppXepChatMarkersModuleClass))

typedef struct _XmppXepChatMarkersModule XmppXepChatMarkersModule;
typedef struct _XmppXepChatMarkersModuleClass XmppXepChatMarkersModuleClass;
typedef struct _XmppXepChatMarkersModulePrivate XmppXepChatMarkersModulePrivate;

#define XMPP_XEP_CHAT_MARKERS_TYPE_SEND_PIPELINE_LISTENER (xmpp_xep_chat_markers_send_pipeline_listener_get_type ())
#define XMPP_XEP_CHAT_MARKERS_SEND_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_CHAT_MARKERS_TYPE_SEND_PIPELINE_LISTENER, XmppXepChatMarkersSendPipelineListener))
#define XMPP_XEP_CHAT_MARKERS_SEND_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_CHAT_MARKERS_TYPE_SEND_PIPELINE_LISTENER, XmppXepChatMarkersSendPipelineListenerClass))
#define XMPP_XEP_CHAT_MARKERS_IS_SEND_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_CHAT_MARKERS_TYPE_SEND_PIPELINE_LISTENER))
#define XMPP_XEP_CHAT_MARKERS_IS_SEND_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_CHAT_MARKERS_TYPE_SEND_PIPELINE_LISTENER))
#define XMPP_XEP_CHAT_MARKERS_SEND_PIPELINE_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_CHAT_MARKERS_TYPE_SEND_PIPELINE_LISTENER, XmppXepChatMarkersSendPipelineListenerClass))

typedef struct _XmppXepChatMarkersSendPipelineListener XmppXepChatMarkersSendPipelineListener;
typedef struct _XmppXepChatMarkersSendPipelineListenerClass XmppXepChatMarkersSendPipelineListenerClass;
typedef struct _XmppXepChatMarkersSendPipelineListenerPrivate XmppXepChatMarkersSendPipelineListenerPrivate;

#define XMPP_XEP_JINGLE_MESSAGE_INITIATION_TYPE_MODULE (xmpp_xep_jingle_message_initiation_module_get_type ())
#define XMPP_XEP_JINGLE_MESSAGE_INITIATION_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JINGLE_MESSAGE_INITIATION_TYPE_MODULE, XmppXepJingleMessageInitiationModule))
#define XMPP_XEP_JINGLE_MESSAGE_INITIATION_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JINGLE_MESSAGE_INITIATION_TYPE_MODULE, XmppXepJingleMessageInitiationModuleClass))
#define XMPP_XEP_JINGLE_MESSAGE_INITIATION_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JINGLE_MESSAGE_INITIATION_TYPE_MODULE))
#define XMPP_XEP_JINGLE_MESSAGE_INITIATION_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JINGLE_MESSAGE_INITIATION_TYPE_MODULE))
#define XMPP_XEP_JINGLE_MESSAGE_INITIATION_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JINGLE_MESSAGE_INITIATION_TYPE_MODULE, XmppXepJingleMessageInitiationModuleClass))

typedef struct _XmppXepJingleMessageInitiationModule XmppXepJingleMessageInitiationModule;
typedef struct _XmppXepJingleMessageInitiationModuleClass XmppXepJingleMessageInitiationModuleClass;
typedef struct _XmppXepJingleMessageInitiationModulePrivate XmppXepJingleMessageInitiationModulePrivate;

#define XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_TYPE_MODULE (xmpp_xep_unique_stable_stanza_ids_module_get_type ())
#define XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_TYPE_MODULE, XmppXepUniqueStableStanzaIDsModule))
#define XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_TYPE_MODULE, XmppXepUniqueStableStanzaIDsModuleClass))
#define XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_TYPE_MODULE))
#define XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_TYPE_MODULE))
#define XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_UNIQUE_STABLE_STANZA_IDS_TYPE_MODULE, XmppXepUniqueStableStanzaIDsModuleClass))

typedef struct _XmppXepUniqueStableStanzaIDsModule XmppXepUniqueStableStanzaIDsModule;
typedef struct _XmppXepUniqueStableStanzaIDsModuleClass XmppXepUniqueStableStanzaIDsModuleClass;
typedef struct _XmppXepUniqueStableStanzaIDsModulePrivate XmppXepUniqueStableStanzaIDsModulePrivate;

#define XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_HTTP_FILE_TRANSFER_ERROR (xmpp_xep_http_file_upload_http_file_transfer_error_get_type ())

#define XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_MODULE (xmpp_xep_http_file_upload_module_get_type ())
#define XMPP_XEP_HTTP_FILE_UPLOAD_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_MODULE, XmppXepHttpFileUploadModule))
#define XMPP_XEP_HTTP_FILE_UPLOAD_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_MODULE, XmppXepHttpFileUploadModuleClass))
#define XMPP_XEP_HTTP_FILE_UPLOAD_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_MODULE))
#define XMPP_XEP_HTTP_FILE_UPLOAD_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_MODULE))
#define XMPP_XEP_HTTP_FILE_UPLOAD_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_MODULE, XmppXepHttpFileUploadModuleClass))

typedef struct _XmppXepHttpFileUploadModule XmppXepHttpFileUploadModule;
typedef struct _XmppXepHttpFileUploadModuleClass XmppXepHttpFileUploadModuleClass;
typedef struct _XmppXepHttpFileUploadModulePrivate XmppXepHttpFileUploadModulePrivate;

#define XMPP_XEP_HTTP_FILE_UPLOAD_MODULE_TYPE_SLOT_RESULT (xmpp_xep_http_file_upload_module_slot_result_get_type ())
typedef struct _XmppXepHttpFileUploadModuleSlotResult XmppXepHttpFileUploadModuleSlotResult;
typedef void (*XmppXepHttpFileUploadModuleOnSlotOk) (XmppXmppStream* stream, const gchar* url_get, const gchar* url_put, gpointer user_data);
typedef void (*XmppXepHttpFileUploadModuleOnError) (XmppXmppStream* stream, const gchar* _error_, gpointer user_data);

#define XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_RECEIVED_PIPELINE_LISTENER (xmpp_xep_http_file_upload_received_pipeline_listener_get_type ())
#define XMPP_XEP_HTTP_FILE_UPLOAD_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepHttpFileUploadReceivedPipelineListener))
#define XMPP_XEP_HTTP_FILE_UPLOAD_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepHttpFileUploadReceivedPipelineListenerClass))
#define XMPP_XEP_HTTP_FILE_UPLOAD_IS_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_XEP_HTTP_FILE_UPLOAD_IS_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_XEP_HTTP_FILE_UPLOAD_RECEIVED_PIPELINE_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepHttpFileUploadReceivedPipelineListenerClass))

typedef struct _XmppXepHttpFileUploadReceivedPipelineListener XmppXepHttpFileUploadReceivedPipelineListener;
typedef struct _XmppXepHttpFileUploadReceivedPipelineListenerClass XmppXepHttpFileUploadReceivedPipelineListenerClass;
typedef struct _XmppXepHttpFileUploadReceivedPipelineListenerPrivate XmppXepHttpFileUploadReceivedPipelineListenerPrivate;

#define XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_FLAG (xmpp_xep_http_file_upload_flag_get_type ())
#define XMPP_XEP_HTTP_FILE_UPLOAD_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_FLAG, XmppXepHttpFileUploadFlag))
#define XMPP_XEP_HTTP_FILE_UPLOAD_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_FLAG, XmppXepHttpFileUploadFlagClass))
#define XMPP_XEP_HTTP_FILE_UPLOAD_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_FLAG))
#define XMPP_XEP_HTTP_FILE_UPLOAD_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_FLAG))
#define XMPP_XEP_HTTP_FILE_UPLOAD_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_HTTP_FILE_UPLOAD_TYPE_FLAG, XmppXepHttpFileUploadFlagClass))

typedef struct _XmppXepHttpFileUploadFlag XmppXepHttpFileUploadFlag;
typedef struct _XmppXepHttpFileUploadFlagClass XmppXepHttpFileUploadFlagClass;
typedef struct _XmppXepHttpFileUploadFlagPrivate XmppXepHttpFileUploadFlagPrivate;

#define XMPP_XEP_OMEMO_TYPE_OMEMO_DECRYPTOR (xmpp_xep_omemo_omemo_decryptor_get_type ())
#define XMPP_XEP_OMEMO_OMEMO_DECRYPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_OMEMO_TYPE_OMEMO_DECRYPTOR, XmppXepOmemoOmemoDecryptor))
#define XMPP_XEP_OMEMO_OMEMO_DECRYPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_OMEMO_TYPE_OMEMO_DECRYPTOR, XmppXepOmemoOmemoDecryptorClass))
#define XMPP_XEP_OMEMO_IS_OMEMO_DECRYPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_OMEMO_TYPE_OMEMO_DECRYPTOR))
#define XMPP_XEP_OMEMO_IS_OMEMO_DECRYPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_OMEMO_TYPE_OMEMO_DECRYPTOR))
#define XMPP_XEP_OMEMO_OMEMO_DECRYPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_OMEMO_TYPE_OMEMO_DECRYPTOR, XmppXepOmemoOmemoDecryptorClass))

typedef struct _XmppXepOmemoOmemoDecryptor XmppXepOmemoOmemoDecryptor;
typedef struct _XmppXepOmemoOmemoDecryptorClass XmppXepOmemoOmemoDecryptorClass;
typedef struct _XmppXepOmemoOmemoDecryptorPrivate XmppXepOmemoOmemoDecryptorPrivate;

#define XMPP_XEP_OMEMO_TYPE_PARSED_DATA (xmpp_xep_omemo_parsed_data_get_type ())
#define XMPP_XEP_OMEMO_PARSED_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_OMEMO_TYPE_PARSED_DATA, XmppXepOmemoParsedData))
#define XMPP_XEP_OMEMO_PARSED_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_OMEMO_TYPE_PARSED_DATA, XmppXepOmemoParsedDataClass))
#define XMPP_XEP_OMEMO_IS_PARSED_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_OMEMO_TYPE_PARSED_DATA))
#define XMPP_XEP_OMEMO_IS_PARSED_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_OMEMO_TYPE_PARSED_DATA))
#define XMPP_XEP_OMEMO_PARSED_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_OMEMO_TYPE_PARSED_DATA, XmppXepOmemoParsedDataClass))

typedef struct _XmppXepOmemoParsedData XmppXepOmemoParsedData;
typedef struct _XmppXepOmemoParsedDataClass XmppXepOmemoParsedDataClass;
typedef struct _XmppXepOmemoParsedDataPrivate XmppXepOmemoParsedDataPrivate;

#define XMPP_XEP_OMEMO_TYPE_OMEMO_ENCRYPTOR (xmpp_xep_omemo_omemo_encryptor_get_type ())
#define XMPP_XEP_OMEMO_OMEMO_ENCRYPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_OMEMO_TYPE_OMEMO_ENCRYPTOR, XmppXepOmemoOmemoEncryptor))
#define XMPP_XEP_OMEMO_OMEMO_ENCRYPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_OMEMO_TYPE_OMEMO_ENCRYPTOR, XmppXepOmemoOmemoEncryptorClass))
#define XMPP_XEP_OMEMO_IS_OMEMO_ENCRYPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_OMEMO_TYPE_OMEMO_ENCRYPTOR))
#define XMPP_XEP_OMEMO_IS_OMEMO_ENCRYPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_OMEMO_TYPE_OMEMO_ENCRYPTOR))
#define XMPP_XEP_OMEMO_OMEMO_ENCRYPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_OMEMO_TYPE_OMEMO_ENCRYPTOR, XmppXepOmemoOmemoEncryptorClass))

typedef struct _XmppXepOmemoOmemoEncryptor XmppXepOmemoOmemoEncryptor;
typedef struct _XmppXepOmemoOmemoEncryptorClass XmppXepOmemoOmemoEncryptorClass;
typedef struct _XmppXepOmemoOmemoEncryptorPrivate XmppXepOmemoOmemoEncryptorPrivate;

#define XMPP_XEP_OMEMO_TYPE_ENCRYPTION_DATA (xmpp_xep_omemo_encryption_data_get_type ())
#define XMPP_XEP_OMEMO_ENCRYPTION_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_OMEMO_TYPE_ENCRYPTION_DATA, XmppXepOmemoEncryptionData))
#define XMPP_XEP_OMEMO_ENCRYPTION_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_OMEMO_TYPE_ENCRYPTION_DATA, XmppXepOmemoEncryptionDataClass))
#define XMPP_XEP_OMEMO_IS_ENCRYPTION_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_OMEMO_TYPE_ENCRYPTION_DATA))
#define XMPP_XEP_OMEMO_IS_ENCRYPTION_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_OMEMO_TYPE_ENCRYPTION_DATA))
#define XMPP_XEP_OMEMO_ENCRYPTION_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_OMEMO_TYPE_ENCRYPTION_DATA, XmppXepOmemoEncryptionDataClass))

typedef struct _XmppXepOmemoEncryptionData XmppXepOmemoEncryptionData;
typedef struct _XmppXepOmemoEncryptionDataClass XmppXepOmemoEncryptionDataClass;

#define XMPP_XEP_OMEMO_TYPE_ENCRYPTION_RESULT (xmpp_xep_omemo_encryption_result_get_type ())
#define XMPP_XEP_OMEMO_ENCRYPTION_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_OMEMO_TYPE_ENCRYPTION_RESULT, XmppXepOmemoEncryptionResult))
#define XMPP_XEP_OMEMO_ENCRYPTION_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_OMEMO_TYPE_ENCRYPTION_RESULT, XmppXepOmemoEncryptionResultClass))
#define XMPP_XEP_OMEMO_IS_ENCRYPTION_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_OMEMO_TYPE_ENCRYPTION_RESULT))
#define XMPP_XEP_OMEMO_IS_ENCRYPTION_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_OMEMO_TYPE_ENCRYPTION_RESULT))
#define XMPP_XEP_OMEMO_ENCRYPTION_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_OMEMO_TYPE_ENCRYPTION_RESULT, XmppXepOmemoEncryptionResultClass))

typedef struct _XmppXepOmemoEncryptionResult XmppXepOmemoEncryptionResult;
typedef struct _XmppXepOmemoEncryptionResultClass XmppXepOmemoEncryptionResultClass;
typedef struct _XmppXepOmemoEncryptionDataPrivate XmppXepOmemoEncryptionDataPrivate;
typedef struct _XmppXepOmemoEncryptionResultPrivate XmppXepOmemoEncryptionResultPrivate;

#define XMPP_XEP_OMEMO_TYPE_ENCRYPT_STATE (xmpp_xep_omemo_encrypt_state_get_type ())
#define XMPP_XEP_OMEMO_ENCRYPT_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_OMEMO_TYPE_ENCRYPT_STATE, XmppXepOmemoEncryptState))
#define XMPP_XEP_OMEMO_ENCRYPT_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_OMEMO_TYPE_ENCRYPT_STATE, XmppXepOmemoEncryptStateClass))
#define XMPP_XEP_OMEMO_IS_ENCRYPT_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_OMEMO_TYPE_ENCRYPT_STATE))
#define XMPP_XEP_OMEMO_IS_ENCRYPT_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_OMEMO_TYPE_ENCRYPT_STATE))
#define XMPP_XEP_OMEMO_ENCRYPT_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_OMEMO_TYPE_ENCRYPT_STATE, XmppXepOmemoEncryptStateClass))

typedef struct _XmppXepOmemoEncryptState XmppXepOmemoEncryptState;
typedef struct _XmppXepOmemoEncryptStateClass XmppXepOmemoEncryptStateClass;
typedef struct _XmppXepOmemoEncryptStatePrivate XmppXepOmemoEncryptStatePrivate;

#define XMPP_XEP_JET_TYPE_MODULE (xmpp_xep_jet_module_get_type ())
#define XMPP_XEP_JET_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JET_TYPE_MODULE, XmppXepJetModule))
#define XMPP_XEP_JET_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JET_TYPE_MODULE, XmppXepJetModuleClass))
#define XMPP_XEP_JET_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JET_TYPE_MODULE))
#define XMPP_XEP_JET_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JET_TYPE_MODULE))
#define XMPP_XEP_JET_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JET_TYPE_MODULE, XmppXepJetModuleClass))

typedef struct _XmppXepJetModule XmppXepJetModule;
typedef struct _XmppXepJetModuleClass XmppXepJetModuleClass;
typedef struct _XmppXepJetModulePrivate XmppXepJetModulePrivate;

#define XMPP_XEP_JET_TYPE_ENVELOP_ENCODING (xmpp_xep_jet_envelop_encoding_get_type ())
#define XMPP_XEP_JET_ENVELOP_ENCODING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JET_TYPE_ENVELOP_ENCODING, XmppXepJetEnvelopEncoding))
#define XMPP_XEP_JET_IS_ENVELOP_ENCODING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JET_TYPE_ENVELOP_ENCODING))
#define XMPP_XEP_JET_ENVELOP_ENCODING_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_JET_TYPE_ENVELOP_ENCODING, XmppXepJetEnvelopEncodingIface))

typedef struct _XmppXepJetEnvelopEncoding XmppXepJetEnvelopEncoding;
typedef struct _XmppXepJetEnvelopEncodingIface XmppXepJetEnvelopEncodingIface;

#define XMPP_XEP_JET_TYPE_TRANSPORT_SECRET (xmpp_xep_jet_transport_secret_get_type ())
#define XMPP_XEP_JET_TRANSPORT_SECRET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JET_TYPE_TRANSPORT_SECRET, XmppXepJetTransportSecret))
#define XMPP_XEP_JET_TRANSPORT_SECRET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JET_TYPE_TRANSPORT_SECRET, XmppXepJetTransportSecretClass))
#define XMPP_XEP_JET_IS_TRANSPORT_SECRET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JET_TYPE_TRANSPORT_SECRET))
#define XMPP_XEP_JET_IS_TRANSPORT_SECRET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JET_TYPE_TRANSPORT_SECRET))
#define XMPP_XEP_JET_TRANSPORT_SECRET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JET_TYPE_TRANSPORT_SECRET, XmppXepJetTransportSecretClass))

typedef struct _XmppXepJetTransportSecret XmppXepJetTransportSecret;
typedef struct _XmppXepJetTransportSecretClass XmppXepJetTransportSecretClass;

#define XMPP_XEP_JET_TYPE_SECURITY_PARAMETERS (xmpp_xep_jet_security_parameters_get_type ())
#define XMPP_XEP_JET_SECURITY_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JET_TYPE_SECURITY_PARAMETERS, XmppXepJetSecurityParameters))
#define XMPP_XEP_JET_SECURITY_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JET_TYPE_SECURITY_PARAMETERS, XmppXepJetSecurityParametersClass))
#define XMPP_XEP_JET_IS_SECURITY_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JET_TYPE_SECURITY_PARAMETERS))
#define XMPP_XEP_JET_IS_SECURITY_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JET_TYPE_SECURITY_PARAMETERS))
#define XMPP_XEP_JET_SECURITY_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JET_TYPE_SECURITY_PARAMETERS, XmppXepJetSecurityParametersClass))

typedef struct _XmppXepJetSecurityParameters XmppXepJetSecurityParameters;
typedef struct _XmppXepJetSecurityParametersClass XmppXepJetSecurityParametersClass;

#define XMPP_XEP_JET_TYPE_CIPHER (xmpp_xep_jet_cipher_get_type ())
#define XMPP_XEP_JET_CIPHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JET_TYPE_CIPHER, XmppXepJetCipher))
#define XMPP_XEP_JET_IS_CIPHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JET_TYPE_CIPHER))
#define XMPP_XEP_JET_CIPHER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_JET_TYPE_CIPHER, XmppXepJetCipherIface))

typedef struct _XmppXepJetCipher XmppXepJetCipher;
typedef struct _XmppXepJetCipherIface XmppXepJetCipherIface;

#define XMPP_XEP_JET_TYPE_OPTIONS (xmpp_xep_jet_options_get_type ())
#define XMPP_XEP_JET_OPTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_JET_TYPE_OPTIONS, XmppXepJetOptions))
#define XMPP_XEP_JET_OPTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_JET_TYPE_OPTIONS, XmppXepJetOptionsClass))
#define XMPP_XEP_JET_IS_OPTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_JET_TYPE_OPTIONS))
#define XMPP_XEP_JET_IS_OPTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_JET_TYPE_OPTIONS))
#define XMPP_XEP_JET_OPTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_JET_TYPE_OPTIONS, XmppXepJetOptionsClass))

typedef struct _XmppXepJetOptions XmppXepJetOptions;
typedef struct _XmppXepJetOptionsClass XmppXepJetOptionsClass;
typedef struct _XmppXepJetOptionsPrivate XmppXepJetOptionsPrivate;
typedef struct _XmppXepJetSecurityParametersPrivate XmppXepJetSecurityParametersPrivate;
typedef struct _XmppXepJetTransportSecretPrivate XmppXepJetTransportSecretPrivate;

#define XMPP_XEP_BOOKMARKS2_TYPE_MODULE (xmpp_xep_bookmarks2_module_get_type ())
#define XMPP_XEP_BOOKMARKS2_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_BOOKMARKS2_TYPE_MODULE, XmppXepBookmarks2Module))
#define XMPP_XEP_BOOKMARKS2_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_BOOKMARKS2_TYPE_MODULE, XmppXepBookmarks2ModuleClass))
#define XMPP_XEP_BOOKMARKS2_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_BOOKMARKS2_TYPE_MODULE))
#define XMPP_XEP_BOOKMARKS2_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_BOOKMARKS2_TYPE_MODULE))
#define XMPP_XEP_BOOKMARKS2_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_BOOKMARKS2_TYPE_MODULE, XmppXepBookmarks2ModuleClass))

typedef struct _XmppXepBookmarks2Module XmppXepBookmarks2Module;
typedef struct _XmppXepBookmarks2ModuleClass XmppXepBookmarks2ModuleClass;
typedef struct _XmppXepBookmarks2ModulePrivate XmppXepBookmarks2ModulePrivate;

#define XMPP_XEP_BOOKMARKS2_TYPE_FLAG (xmpp_xep_bookmarks2_flag_get_type ())
#define XMPP_XEP_BOOKMARKS2_FLAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_BOOKMARKS2_TYPE_FLAG, XmppXepBookmarks2Flag))
#define XMPP_XEP_BOOKMARKS2_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_BOOKMARKS2_TYPE_FLAG, XmppXepBookmarks2FlagClass))
#define XMPP_XEP_BOOKMARKS2_IS_FLAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_BOOKMARKS2_TYPE_FLAG))
#define XMPP_XEP_BOOKMARKS2_IS_FLAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_BOOKMARKS2_TYPE_FLAG))
#define XMPP_XEP_BOOKMARKS2_FLAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_BOOKMARKS2_TYPE_FLAG, XmppXepBookmarks2FlagClass))

typedef struct _XmppXepBookmarks2Flag XmppXepBookmarks2Flag;
typedef struct _XmppXepBookmarks2FlagClass XmppXepBookmarks2FlagClass;
typedef struct _XmppXepBookmarks2FlagPrivate XmppXepBookmarks2FlagPrivate;

#define XMPP_XEP_OCCUPANT_IDS_TYPE_MODULE (xmpp_xep_occupant_ids_module_get_type ())
#define XMPP_XEP_OCCUPANT_IDS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_OCCUPANT_IDS_TYPE_MODULE, XmppXepOccupantIdsModule))
#define XMPP_XEP_OCCUPANT_IDS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_OCCUPANT_IDS_TYPE_MODULE, XmppXepOccupantIdsModuleClass))
#define XMPP_XEP_OCCUPANT_IDS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_OCCUPANT_IDS_TYPE_MODULE))
#define XMPP_XEP_OCCUPANT_IDS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_OCCUPANT_IDS_TYPE_MODULE))
#define XMPP_XEP_OCCUPANT_IDS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_OCCUPANT_IDS_TYPE_MODULE, XmppXepOccupantIdsModuleClass))

typedef struct _XmppXepOccupantIdsModule XmppXepOccupantIdsModule;
typedef struct _XmppXepOccupantIdsModuleClass XmppXepOccupantIdsModuleClass;
typedef struct _XmppXepOccupantIdsModulePrivate XmppXepOccupantIdsModulePrivate;

#define XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK (xmpp_xep_fallback_indication_fallback_get_type ())
#define XMPP_XEP_FALLBACK_INDICATION_FALLBACK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK, XmppXepFallbackIndicationFallback))
#define XMPP_XEP_FALLBACK_INDICATION_FALLBACK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK, XmppXepFallbackIndicationFallbackClass))
#define XMPP_XEP_FALLBACK_INDICATION_IS_FALLBACK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK))
#define XMPP_XEP_FALLBACK_INDICATION_IS_FALLBACK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK))
#define XMPP_XEP_FALLBACK_INDICATION_FALLBACK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK, XmppXepFallbackIndicationFallbackClass))

typedef struct _XmppXepFallbackIndicationFallback XmppXepFallbackIndicationFallback;
typedef struct _XmppXepFallbackIndicationFallbackClass XmppXepFallbackIndicationFallbackClass;
typedef struct _XmppXepFallbackIndicationFallbackPrivate XmppXepFallbackIndicationFallbackPrivate;

#define XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK_LOCATION (xmpp_xep_fallback_indication_fallback_location_get_type ())
#define XMPP_XEP_FALLBACK_INDICATION_FALLBACK_LOCATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK_LOCATION, XmppXepFallbackIndicationFallbackLocation))
#define XMPP_XEP_FALLBACK_INDICATION_FALLBACK_LOCATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK_LOCATION, XmppXepFallbackIndicationFallbackLocationClass))
#define XMPP_XEP_FALLBACK_INDICATION_IS_FALLBACK_LOCATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK_LOCATION))
#define XMPP_XEP_FALLBACK_INDICATION_IS_FALLBACK_LOCATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK_LOCATION))
#define XMPP_XEP_FALLBACK_INDICATION_FALLBACK_LOCATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_FALLBACK_INDICATION_TYPE_FALLBACK_LOCATION, XmppXepFallbackIndicationFallbackLocationClass))

typedef struct _XmppXepFallbackIndicationFallbackLocation XmppXepFallbackIndicationFallbackLocation;
typedef struct _XmppXepFallbackIndicationFallbackLocationClass XmppXepFallbackIndicationFallbackLocationClass;
typedef struct _XmppXepFallbackIndicationFallbackLocationPrivate XmppXepFallbackIndicationFallbackLocationPrivate;

#define XMPP_XEP_REACTIONS_TYPE_MODULE (xmpp_xep_reactions_module_get_type ())
#define XMPP_XEP_REACTIONS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_REACTIONS_TYPE_MODULE, XmppXepReactionsModule))
#define XMPP_XEP_REACTIONS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_REACTIONS_TYPE_MODULE, XmppXepReactionsModuleClass))
#define XMPP_XEP_REACTIONS_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_REACTIONS_TYPE_MODULE))
#define XMPP_XEP_REACTIONS_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_REACTIONS_TYPE_MODULE))
#define XMPP_XEP_REACTIONS_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_REACTIONS_TYPE_MODULE, XmppXepReactionsModuleClass))

typedef struct _XmppXepReactionsModule XmppXepReactionsModule;
typedef struct _XmppXepReactionsModuleClass XmppXepReactionsModuleClass;
typedef struct _XmppXepReactionsModulePrivate XmppXepReactionsModulePrivate;

#define XMPP_XEP_REACTIONS_TYPE_RECEIVED_PIPELINE_LISTENER (xmpp_xep_reactions_received_pipeline_listener_get_type ())
#define XMPP_XEP_REACTIONS_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_REACTIONS_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepReactionsReceivedPipelineListener))
#define XMPP_XEP_REACTIONS_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_REACTIONS_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepReactionsReceivedPipelineListenerClass))
#define XMPP_XEP_REACTIONS_IS_RECEIVED_PIPELINE_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_REACTIONS_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_XEP_REACTIONS_IS_RECEIVED_PIPELINE_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_REACTIONS_TYPE_RECEIVED_PIPELINE_LISTENER))
#define XMPP_XEP_REACTIONS_RECEIVED_PIPELINE_LISTENER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_REACTIONS_TYPE_RECEIVED_PIPELINE_LISTENER, XmppXepReactionsReceivedPipelineListenerClass))

typedef struct _XmppXepReactionsReceivedPipelineListener XmppXepReactionsReceivedPipelineListener;
typedef struct _XmppXepReactionsReceivedPipelineListenerClass XmppXepReactionsReceivedPipelineListenerClass;
typedef struct _XmppXepReactionsReceivedPipelineListenerPrivate XmppXepReactionsReceivedPipelineListenerPrivate;

#define XMPP_XEP_FILE_METADATA_ELEMENT_TYPE_FILE_METADATA (xmpp_xep_file_metadata_element_file_metadata_get_type ())
#define XMPP_XEP_FILE_METADATA_ELEMENT_FILE_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_FILE_METADATA_ELEMENT_TYPE_FILE_METADATA, XmppXepFileMetadataElementFileMetadata))
#define XMPP_XEP_FILE_METADATA_ELEMENT_FILE_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_FILE_METADATA_ELEMENT_TYPE_FILE_METADATA, XmppXepFileMetadataElementFileMetadataClass))
#define XMPP_XEP_FILE_METADATA_ELEMENT_IS_FILE_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_FILE_METADATA_ELEMENT_TYPE_FILE_METADATA))
#define XMPP_XEP_FILE_METADATA_ELEMENT_IS_FILE_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_FILE_METADATA_ELEMENT_TYPE_FILE_METADATA))
#define XMPP_XEP_FILE_METADATA_ELEMENT_FILE_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_FILE_METADATA_ELEMENT_TYPE_FILE_METADATA, XmppXepFileMetadataElementFileMetadataClass))

typedef struct _XmppXepFileMetadataElementFileMetadata XmppXepFileMetadataElementFileMetadata;
typedef struct _XmppXepFileMetadataElementFileMetadataClass XmppXepFileMetadataElementFileMetadataClass;
typedef struct _XmppXepFileMetadataElementFileMetadataPrivate XmppXepFileMetadataElementFileMetadataPrivate;

#define XMPP_XEP_STATELESS_FILE_SHARING_TYPE_FILE_SHARE (xmpp_xep_stateless_file_sharing_file_share_get_type ())
#define XMPP_XEP_STATELESS_FILE_SHARING_FILE_SHARE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_FILE_SHARE, XmppXepStatelessFileSharingFileShare))
#define XMPP_XEP_STATELESS_FILE_SHARING_FILE_SHARE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_FILE_SHARE, XmppXepStatelessFileSharingFileShareClass))
#define XMPP_XEP_STATELESS_FILE_SHARING_IS_FILE_SHARE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_FILE_SHARE))
#define XMPP_XEP_STATELESS_FILE_SHARING_IS_FILE_SHARE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_FILE_SHARE))
#define XMPP_XEP_STATELESS_FILE_SHARING_FILE_SHARE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_FILE_SHARE, XmppXepStatelessFileSharingFileShareClass))

typedef struct _XmppXepStatelessFileSharingFileShare XmppXepStatelessFileSharingFileShare;
typedef struct _XmppXepStatelessFileSharingFileShareClass XmppXepStatelessFileSharingFileShareClass;

#define XMPP_XEP_STATELESS_FILE_SHARING_TYPE_SOURCE_ATTACHMENT (xmpp_xep_stateless_file_sharing_source_attachment_get_type ())
#define XMPP_XEP_STATELESS_FILE_SHARING_SOURCE_ATTACHMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_SOURCE_ATTACHMENT, XmppXepStatelessFileSharingSourceAttachment))
#define XMPP_XEP_STATELESS_FILE_SHARING_SOURCE_ATTACHMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_SOURCE_ATTACHMENT, XmppXepStatelessFileSharingSourceAttachmentClass))
#define XMPP_XEP_STATELESS_FILE_SHARING_IS_SOURCE_ATTACHMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_SOURCE_ATTACHMENT))
#define XMPP_XEP_STATELESS_FILE_SHARING_IS_SOURCE_ATTACHMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_SOURCE_ATTACHMENT))
#define XMPP_XEP_STATELESS_FILE_SHARING_SOURCE_ATTACHMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_SOURCE_ATTACHMENT, XmppXepStatelessFileSharingSourceAttachmentClass))

typedef struct _XmppXepStatelessFileSharingSourceAttachment XmppXepStatelessFileSharingSourceAttachment;
typedef struct _XmppXepStatelessFileSharingSourceAttachmentClass XmppXepStatelessFileSharingSourceAttachmentClass;

#define XMPP_XEP_STATELESS_FILE_SHARING_TYPE_SOURCE (xmpp_xep_stateless_file_sharing_source_get_type ())
#define XMPP_XEP_STATELESS_FILE_SHARING_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_SOURCE, XmppXepStatelessFileSharingSource))
#define XMPP_XEP_STATELESS_FILE_SHARING_IS_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_SOURCE))
#define XMPP_XEP_STATELESS_FILE_SHARING_SOURCE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_SOURCE, XmppXepStatelessFileSharingSourceIface))

typedef struct _XmppXepStatelessFileSharingSource XmppXepStatelessFileSharingSource;
typedef struct _XmppXepStatelessFileSharingSourceIface XmppXepStatelessFileSharingSourceIface;
typedef struct _XmppXepStatelessFileSharingFileSharePrivate XmppXepStatelessFileSharingFileSharePrivate;
typedef struct _XmppXepStatelessFileSharingSourceAttachmentPrivate XmppXepStatelessFileSharingSourceAttachmentPrivate;

#define XMPP_XEP_STATELESS_FILE_SHARING_TYPE_HTTP_SOURCE (xmpp_xep_stateless_file_sharing_http_source_get_type ())
#define XMPP_XEP_STATELESS_FILE_SHARING_HTTP_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_HTTP_SOURCE, XmppXepStatelessFileSharingHttpSource))
#define XMPP_XEP_STATELESS_FILE_SHARING_HTTP_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_HTTP_SOURCE, XmppXepStatelessFileSharingHttpSourceClass))
#define XMPP_XEP_STATELESS_FILE_SHARING_IS_HTTP_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_HTTP_SOURCE))
#define XMPP_XEP_STATELESS_FILE_SHARING_IS_HTTP_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_HTTP_SOURCE))
#define XMPP_XEP_STATELESS_FILE_SHARING_HTTP_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_STATELESS_FILE_SHARING_TYPE_HTTP_SOURCE, XmppXepStatelessFileSharingHttpSourceClass))

typedef struct _XmppXepStatelessFileSharingHttpSource XmppXepStatelessFileSharingHttpSource;
typedef struct _XmppXepStatelessFileSharingHttpSourceClass XmppXepStatelessFileSharingHttpSourceClass;
typedef struct _XmppXepStatelessFileSharingHttpSourcePrivate XmppXepStatelessFileSharingHttpSourcePrivate;

#define XMPP_XEP_REPLIES_TYPE_REPLY_TO (xmpp_xep_replies_reply_to_get_type ())
#define XMPP_XEP_REPLIES_REPLY_TO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_REPLIES_TYPE_REPLY_TO, XmppXepRepliesReplyTo))
#define XMPP_XEP_REPLIES_REPLY_TO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_REPLIES_TYPE_REPLY_TO, XmppXepRepliesReplyToClass))
#define XMPP_XEP_REPLIES_IS_REPLY_TO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_REPLIES_TYPE_REPLY_TO))
#define XMPP_XEP_REPLIES_IS_REPLY_TO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_REPLIES_TYPE_REPLY_TO))
#define XMPP_XEP_REPLIES_REPLY_TO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_REPLIES_TYPE_REPLY_TO, XmppXepRepliesReplyToClass))

typedef struct _XmppXepRepliesReplyTo XmppXepRepliesReplyTo;
typedef struct _XmppXepRepliesReplyToClass XmppXepRepliesReplyToClass;
typedef struct _XmppXepRepliesReplyToPrivate XmppXepRepliesReplyToPrivate;

#define XMPP_XEP_CALL_INVITES_TYPE_MODULE (xmpp_xep_call_invites_module_get_type ())
#define XMPP_XEP_CALL_INVITES_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_CALL_INVITES_TYPE_MODULE, XmppXepCallInvitesModule))
#define XMPP_XEP_CALL_INVITES_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), XMPP_XEP_CALL_INVITES_TYPE_MODULE, XmppXepCallInvitesModuleClass))
#define XMPP_XEP_CALL_INVITES_IS_MODULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_CALL_INVITES_TYPE_MODULE))
#define XMPP_XEP_CALL_INVITES_IS_MODULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XMPP_XEP_CALL_INVITES_TYPE_MODULE))
#define XMPP_XEP_CALL_INVITES_MODULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), XMPP_XEP_CALL_INVITES_TYPE_MODULE, XmppXepCallInvitesModuleClass))

typedef struct _XmppXepCallInvitesModule XmppXepCallInvitesModule;
typedef struct _XmppXepCallInvitesModuleClass XmppXepCallInvitesModuleClass;
typedef struct _XmppXepCallInvitesModulePrivate XmppXepCallInvitesModulePrivate;

#define XMPP_XEP_TYPE_PIXBUF_STORAGE (xmpp_xep_pixbuf_storage_get_type ())
#define XMPP_XEP_PIXBUF_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), XMPP_XEP_TYPE_PIXBUF_STORAGE, XmppXepPixbufStorage))
#define XMPP_XEP_IS_PIXBUF_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XMPP_XEP_TYPE_PIXBUF_STORAGE))
#define XMPP_XEP_PIXBUF_STORAGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), XMPP_XEP_TYPE_PIXBUF_STORAGE, XmppXepPixbufStorageIface))

typedef struct _XmppXepPixbufStorage XmppXepPixbufStorage;
typedef struct _XmppXepPixbufStorageIface XmppXepPixbufStorageIface;

struct _XmppXmppStream {
	GObject parent_instance;
	XmppXmppStreamPrivate * priv;
	XmppJid* remote_name;
	XmppXmppLog* log;
	gboolean non_negotiation_modules_attached;
	gboolean setup_needed;
	gboolean disconnected;
};

struct _XmppXmppStreamClass {
	GObjectClass parent_class;
	void (*connect) (XmppXmppStream* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_finish) (XmppXmppStream* self, GAsyncResult* _res_, GError** error);
	void (*disconnect) (XmppXmppStream* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*disconnect_finish) (XmppXmppStream* self, GAsyncResult* _res_, GError** error);
	void (*read) (XmppXmppStream* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	XmppStanzaNode* (*read_finish) (XmppXmppStream* self, GAsyncResult* _res_, GError** error);
	void (*write) (XmppXmppStream* self, XmppStanzaNode* node, gint io_priority) G_GNUC_DEPRECATED ;
	void (*write_async) (XmppXmppStream* self, XmppStanzaNode* node, gint io_priority, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_finish) (XmppXmppStream* self, GAsyncResult* _res_, GError** error);
	void (*setup) (XmppXmppStream* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*setup_finish) (XmppXmppStream* self, GAsyncResult* _res_, GError** error);
};

struct _XmppWriteNodeFuncIface {
	GTypeInterface parent_iface;
	void (*write_stanza) (XmppWriteNodeFunc* self, XmppXmppStream* stream, XmppStanzaNode* node, gint io_priority, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stanza_finish) (XmppWriteNodeFunc* self, GAsyncResult* _res_, GError** error);
};

struct _XmppIoXmppStream {
	XmppXmppStream parent_instance;
	XmppIoXmppStreamPrivate * priv;
	GCancellable* cancellable;
	XmppStanzaReader* reader;
	XmppStanzaWriter* writer;
	XmppWriteNodeFunc* write_obj;
};

struct _XmppIoXmppStreamClass {
	XmppXmppStreamClass parent_class;
};

struct _XmppTlsXmppStream {
	XmppIoXmppStream parent_instance;
	XmppTlsXmppStreamPrivate * priv;
	GTlsCertificateFlags* errors;
};

struct _XmppTlsXmppStreamClass {
	XmppIoXmppStreamClass parent_class;
};

struct _XmppDirectTlsXmppStream {
	XmppTlsXmppStream parent_instance;
	XmppDirectTlsXmppStreamPrivate * priv;
};

struct _XmppDirectTlsXmppStreamClass {
	XmppTlsXmppStreamClass parent_class;
};

struct _XmppFlagIdentity {
	GObject parent_instance;
	XmppFlagIdentityPrivate * priv;
};

struct _XmppFlagIdentityClass {
	GObjectClass parent_class;
};

struct _XmppXmppStreamFlag {
	GObject parent_instance;
	XmppXmppStreamFlagPrivate * priv;
};

struct _XmppXmppStreamFlagClass {
	GObjectClass parent_class;
	gchar* (*get_ns) (XmppXmppStreamFlag* self);
	gchar* (*get_id) (XmppXmppStreamFlag* self);
};

struct _XmppModuleIdentity {
	GObject parent_instance;
	XmppModuleIdentityPrivate * priv;
};

struct _XmppModuleIdentityClass {
	GObjectClass parent_class;
};

struct _XmppXmppStreamModule {
	GObject parent_instance;
	XmppXmppStreamModulePrivate * priv;
};

struct _XmppXmppStreamModuleClass {
	GObjectClass parent_class;
	void (*attach) (XmppXmppStreamModule* self, XmppXmppStream* stream);
	void (*detach) (XmppXmppStreamModule* self, XmppXmppStream* stream);
	gchar* (*get_ns) (XmppXmppStreamModule* self);
	gchar* (*get_id) (XmppXmppStreamModule* self);
};

struct _XmppXmppStreamNegotiationModule {
	XmppXmppStreamModule parent_instance;
	XmppXmppStreamNegotiationModulePrivate * priv;
};

struct _XmppXmppStreamNegotiationModuleClass {
	XmppXmppStreamModuleClass parent_class;
	gboolean (*mandatory_outstanding) (XmppXmppStreamNegotiationModule* self, XmppXmppStream* stream);
	gboolean (*negotiation_active) (XmppXmppStreamNegotiationModule* self, XmppXmppStream* stream);
};

struct _XmppNamespaceState {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppNamespaceStatePrivate * priv;
	gchar* current_ns_uri;
};

struct _XmppNamespaceStateClass {
	GTypeClass parent_class;
	void (*finalize) (XmppNamespaceState *self);
};

struct _XmppStanzaEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppStanzaEntryPrivate * priv;
	gchar* ns_uri;
	gchar* name;
	gchar* val;
};

struct _XmppStanzaEntryClass {
	GTypeClass parent_class;
	void (*finalize) (XmppStanzaEntry *self);
	const gchar* (*get_string_content) (XmppStanzaEntry* self);
	gchar* (*to_string) (XmppStanzaEntry* self, gint i);
};

struct _XmppStanzaAttribute {
	XmppStanzaEntry parent_instance;
	XmppStanzaAttributePrivate * priv;
};

struct _XmppStanzaAttributeClass {
	XmppStanzaEntryClass parent_class;
};

struct _XmppStanzaNode {
	XmppStanzaEntry parent_instance;
	XmppStanzaNodePrivate * priv;
	GeeList* sub_nodes;
	GeeList* attributes;
	gboolean has_nodes;
	gboolean pseudo;
};

struct _XmppStanzaNodeClass {
	XmppStanzaEntryClass parent_class;
};

struct _XmppStanzaReader {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppStanzaReaderPrivate * priv;
};

struct _XmppStanzaReaderClass {
	GTypeClass parent_class;
	void (*finalize) (XmppStanzaReader *self);
};

struct _XmppStanzaWriter {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppStanzaWriterPrivate * priv;
};

struct _XmppStanzaWriterClass {
	GTypeClass parent_class;
	void (*finalize) (XmppStanzaWriter *self);
};

struct _XmppSourceFuncWrapper {
	GObject parent_instance;
	XmppSourceFuncWrapperPrivate * priv;
	GSourceFunc sfun;
	gpointer sfun_target;
	GDestroyNotify sfun_target_destroy_notify;
};

struct _XmppSourceFuncWrapperClass {
	GObjectClass parent_class;
};

struct _XmppStartTlsXmppStream {
	XmppTlsXmppStream parent_instance;
	XmppStartTlsXmppStreamPrivate * priv;
};

struct _XmppStartTlsXmppStreamClass {
	XmppTlsXmppStreamClass parent_class;
};

struct _XmppXmppStreamResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXmppStreamResultPrivate * priv;
};

struct _XmppXmppStreamResultClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXmppStreamResult *self);
};

struct _XmppTlsXmppStreamOnInvalidCertWrapper {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppTlsXmppStreamOnInvalidCertWrapperPrivate * priv;
	XmppTlsXmppStreamOnInvalidCert func;
	gpointer func_target;
	GDestroyNotify func_target_destroy_notify;
};

struct _XmppTlsXmppStreamOnInvalidCertWrapperClass {
	GTypeClass parent_class;
	void (*finalize) (XmppTlsXmppStreamOnInvalidCertWrapper *self);
};

struct _XmppXmppLog {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXmppLogPrivate * priv;
};

struct _XmppXmppLogClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXmppLog *self);
	gboolean (*should_log_node) (XmppXmppLog* self, XmppStanzaNode* node);
	gboolean (*should_log_str) (XmppXmppLog* self, const gchar* str);
};

struct _XmppBindModule {
	XmppXmppStreamNegotiationModule parent_instance;
	XmppBindModulePrivate * priv;
};

struct _XmppBindModuleClass {
	XmppXmppStreamNegotiationModuleClass parent_class;
};

struct _XmppBindFlag {
	XmppXmppStreamFlag parent_instance;
	XmppBindFlagPrivate * priv;
	XmppJid* my_jid;
	gboolean finished;
};

struct _XmppBindFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppBookmarksProviderIface {
	GTypeInterface parent_iface;
	void (*get_conferences) (XmppBookmarksProvider* self, XmppXmppStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GeeSet* (*get_conferences_finish) (XmppBookmarksProvider* self, GAsyncResult* _res_);
	void (*add_conference) (XmppBookmarksProvider* self, XmppXmppStream* stream, XmppConference* conference, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*add_conference_finish) (XmppBookmarksProvider* self, GAsyncResult* _res_);
	void (*remove_conference) (XmppBookmarksProvider* self, XmppXmppStream* stream, XmppConference* conference, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*remove_conference_finish) (XmppBookmarksProvider* self, GAsyncResult* _res_);
	void (*replace_conference) (XmppBookmarksProvider* self, XmppXmppStream* stream, XmppJid* muc_jid, XmppConference* modified_conference, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*replace_conference_finish) (XmppBookmarksProvider* self, GAsyncResult* _res_);
};

struct _XmppConference {
	GObject parent_instance;
	XmppConferencePrivate * priv;
};

struct _XmppConferenceClass {
	GObjectClass parent_class;
	XmppJid* (*get_jid) (XmppConference* self);
	void (*set_jid) (XmppConference* self, XmppJid* value);
	gboolean (*get_autojoin) (XmppConference* self);
	void (*set_autojoin) (XmppConference* self, gboolean value);
	const gchar* (*get_nick) (XmppConference* self);
	void (*set_nick) (XmppConference* self, const gchar* value);
	const gchar* (*get_name) (XmppConference* self);
	void (*set_name) (XmppConference* self, const gchar* value);
	const gchar* (*get_password) (XmppConference* self);
	void (*set_password) (XmppConference* self, const gchar* value);
};

struct _XmppIqModule {
	XmppXmppStreamNegotiationModule parent_instance;
	XmppIqModulePrivate * priv;
};

struct _XmppIqModuleClass {
	XmppXmppStreamNegotiationModuleClass parent_class;
};

struct _XmppIqHandlerIface {
	GTypeInterface parent_iface;
	void (*on_iq_get) (XmppIqHandler* self, XmppXmppStream* stream, XmppIqStanza* iq, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*on_iq_get_finish) (XmppIqHandler* self, GAsyncResult* _res_);
	void (*on_iq_set) (XmppIqHandler* self, XmppXmppStream* stream, XmppIqStanza* iq, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*on_iq_set_finish) (XmppIqHandler* self, GAsyncResult* _res_);
};

struct _XmppStanza {
	GObject parent_instance;
	XmppStanzaPrivate * priv;
	XmppStanzaNode* stanza;
};

struct _XmppStanzaClass {
	GObjectClass parent_class;
	XmppJid* (*get_from) (XmppStanza* self);
	void (*set_from) (XmppStanza* self, XmppJid* value);
	const gchar* (*get_id) (XmppStanza* self);
	void (*set_id) (XmppStanza* self, const gchar* value);
	XmppJid* (*get_to) (XmppStanza* self);
	void (*set_to) (XmppStanza* self, XmppJid* value);
	const gchar* (*get_type_) (XmppStanza* self);
	void (*set_type_) (XmppStanza* self, const gchar* value);
};

struct _XmppIqStanza {
	XmppStanza parent_instance;
	XmppIqStanzaPrivate * priv;
};

struct _XmppIqStanzaClass {
	XmppStanzaClass parent_class;
};

struct _XmppJid {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppJidPrivate * priv;
	gchar* localpart;
	gchar* domainpart;
	gchar* resourcepart;
};

struct _XmppJidClass {
	GTypeClass parent_class;
	void (*finalize) (XmppJid *self);
};

typedef enum  {
	XMPP_INVALID_JID_ERROR_EMPTY_DOMAIN,
	XMPP_INVALID_JID_ERROR_EMPTY_RESOURCE,
	XMPP_INVALID_JID_ERROR_EMPTY_LOCAL,
	XMPP_INVALID_JID_ERROR_INVALID_CHAR,
	XMPP_INVALID_JID_ERROR_UNKNOWN
} XmppInvalidJidError;
#define XMPP_INVALID_JID_ERROR xmpp_invalid_jid_error_quark ()

struct _XmppMessageModule {
	XmppXmppStreamModule parent_instance;
	XmppMessageModulePrivate * priv;
	XmppStanzaListenerHolder* received_pipeline;
	XmppStanzaListenerHolder* send_pipeline;
};

struct _XmppMessageModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppMessageStanza {
	XmppStanza parent_instance;
	XmppMessageStanzaPrivate * priv;
	gboolean rerun_parsing;
};

struct _XmppMessageStanzaClass {
	XmppStanzaClass parent_class;
};

struct _XmppMessageFlag {
	GObject parent_instance;
	XmppMessageFlagPrivate * priv;
};

struct _XmppMessageFlagClass {
	GObjectClass parent_class;
	gchar* (*get_ns) (XmppMessageFlag* self);
	gchar* (*get_id) (XmppMessageFlag* self);
};

struct _XmppPresenceFlag {
	XmppXmppStreamFlag parent_instance;
	XmppPresenceFlagPrivate * priv;
};

struct _XmppPresenceFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppPresenceModule {
	XmppXmppStreamModule parent_instance;
	XmppPresenceModulePrivate * priv;
	gboolean available_resource;
};

struct _XmppPresenceModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppPresenceStanza {
	XmppStanza parent_instance;
	XmppPresenceStanzaPrivate * priv;
};

struct _XmppPresenceStanzaClass {
	XmppStanzaClass parent_class;
};

struct _XmppRosterFlag {
	XmppXmppStreamFlag parent_instance;
	XmppRosterFlagPrivate * priv;
	GeeHashMap* roster_items;
	gchar* iq_id;
};

struct _XmppRosterFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppRosterItem {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppRosterItemPrivate * priv;
	XmppStanzaNode* stanza_node;
};

struct _XmppRosterItemClass {
	GTypeClass parent_class;
	void (*finalize) (XmppRosterItem *self);
};

struct _XmppRosterModule {
	XmppXmppStreamModule parent_instance;
	XmppRosterModulePrivate * priv;
	gboolean interested_resource;
};

struct _XmppRosterModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppRosterVersioningModule {
	XmppXmppStreamModule parent_instance;
	XmppRosterVersioningModulePrivate * priv;
};

struct _XmppRosterVersioningModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppRosterStorageIface {
	GTypeInterface parent_iface;
	gchar* (*get_roster_version) (XmppRosterStorage* self);
	GeeCollection* (*get_roster) (XmppRosterStorage* self);
	void (*set_roster_version) (XmppRosterStorage* self, const gchar* version);
	void (*set_roster) (XmppRosterStorage* self, GeeCollection* items);
	void (*set_item) (XmppRosterStorage* self, XmppRosterItem* item);
	void (*remove_item) (XmppRosterStorage* self, XmppRosterItem* item);
};

struct _XmppSaslFlag {
	XmppXmppStreamFlag parent_instance;
	XmppSaslFlagPrivate * priv;
	gchar* mechanism;
	gchar* name;
	gchar* password;
	gchar* client_nonce;
	guint8* server_signature;
	gint server_signature_length1;
	gboolean finished;
};

struct _XmppSaslFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppSaslModule {
	XmppXmppStreamNegotiationModule parent_instance;
	XmppSaslModulePrivate * priv;
	gboolean use_full_name;
};

struct _XmppSaslModuleClass {
	XmppXmppStreamNegotiationModuleClass parent_class;
};

struct _XmppSessionModule {
	XmppXmppStreamNegotiationModule parent_instance;
	XmppSessionModulePrivate * priv;
};

struct _XmppSessionModuleClass {
	XmppXmppStreamNegotiationModuleClass parent_class;
};

struct _XmppSessionFlag {
	XmppXmppStreamFlag parent_instance;
	XmppSessionFlagPrivate * priv;
	gboolean finished;
};

struct _XmppSessionFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppErrorStanza {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppErrorStanzaPrivate * priv;
	XmppStanzaNode* error_node;
};

struct _XmppErrorStanzaClass {
	GTypeClass parent_class;
	void (*finalize) (XmppErrorStanza *self);
};

struct _XmppStreamErrorModule {
	XmppXmppStreamModule parent_instance;
	XmppStreamErrorModulePrivate * priv;
};

struct _XmppStreamErrorModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppStreamErrorFlag {
	XmppXmppStreamFlag parent_instance;
	XmppStreamErrorFlagPrivate * priv;
	gchar* error_type;
	XmppStreamErrorFlagReconnect reconnection_recomendation;
	gboolean resource_rejected;
};

struct _XmppStreamErrorFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppOrderedListener {
	GObject parent_instance;
	XmppOrderedListenerPrivate * priv;
};

struct _XmppOrderedListenerClass {
	GObjectClass parent_class;
	const gchar* (*get_action_group) (XmppOrderedListener* self);
	gchar** (*get_after_actions) (XmppOrderedListener* self, gint* result_length1);
};

struct _XmppStanzaListener {
	XmppOrderedListener parent_instance;
	XmppStanzaListenerPrivate * priv;
};

struct _XmppStanzaListenerClass {
	XmppOrderedListenerClass parent_class;
	void (*run) (XmppStanzaListener* self, XmppXmppStream* stream, gconstpointer stanza, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*run_finish) (XmppStanzaListener* self, GAsyncResult* _res_);
};

struct _XmppListenerHolder {
	GObject parent_instance;
	XmppListenerHolderPrivate * priv;
	GeeArrayList* listeners;
};

struct _XmppListenerHolderClass {
	GObjectClass parent_class;
};

struct _XmppStanzaListenerHolder {
	XmppListenerHolder parent_instance;
	XmppStanzaListenerHolderPrivate * priv;
};

struct _XmppStanzaListenerHolderClass {
	XmppListenerHolderClass parent_class;
};

struct _XmppXepDataFormsDataForm {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepDataFormsDataFormPrivate * priv;
	GeeList* fields;
	gchar* form_type;
	gchar* instructions;
	gchar* title;
};

struct _XmppXepDataFormsDataFormClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepDataFormsDataForm *self);
};

struct _XmppXepDataFormsDataFormOption {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepDataFormsDataFormOptionPrivate * priv;
};

struct _XmppXepDataFormsDataFormOptionClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepDataFormsDataFormOption *self);
};

struct _XmppXepDataFormsDataFormField {
	GObject parent_instance;
	XmppXepDataFormsDataFormFieldPrivate * priv;
};

struct _XmppXepDataFormsDataFormFieldClass {
	GObjectClass parent_class;
	XmppXepDataFormsDataFormType* (*get_type_) (XmppXepDataFormsDataFormField* self);
	void (*set_type_) (XmppXepDataFormsDataFormField* self, XmppXepDataFormsDataFormType* value);
};

struct _XmppXepDataFormsDataFormBooleanField {
	XmppXepDataFormsDataFormField parent_instance;
	XmppXepDataFormsDataFormBooleanFieldPrivate * priv;
};

struct _XmppXepDataFormsDataFormBooleanFieldClass {
	XmppXepDataFormsDataFormFieldClass parent_class;
};

struct _XmppXepDataFormsDataFormFixedField {
	XmppXepDataFormsDataFormField parent_instance;
	XmppXepDataFormsDataFormFixedFieldPrivate * priv;
};

struct _XmppXepDataFormsDataFormFixedFieldClass {
	XmppXepDataFormsDataFormFieldClass parent_class;
};

struct _XmppXepDataFormsDataFormHiddenField {
	XmppXepDataFormsDataFormField parent_instance;
	XmppXepDataFormsDataFormHiddenFieldPrivate * priv;
};

struct _XmppXepDataFormsDataFormHiddenFieldClass {
	XmppXepDataFormsDataFormFieldClass parent_class;
};

struct _XmppXepDataFormsDataFormJidMultiField {
	XmppXepDataFormsDataFormField parent_instance;
	XmppXepDataFormsDataFormJidMultiFieldPrivate * priv;
};

struct _XmppXepDataFormsDataFormJidMultiFieldClass {
	XmppXepDataFormsDataFormFieldClass parent_class;
};

struct _XmppXepDataFormsDataFormListSingleField {
	XmppXepDataFormsDataFormField parent_instance;
	XmppXepDataFormsDataFormListSingleFieldPrivate * priv;
};

struct _XmppXepDataFormsDataFormListSingleFieldClass {
	XmppXepDataFormsDataFormFieldClass parent_class;
};

struct _XmppXepDataFormsDataFormListMultiField {
	XmppXepDataFormsDataFormField parent_instance;
	XmppXepDataFormsDataFormListMultiFieldPrivate * priv;
};

struct _XmppXepDataFormsDataFormListMultiFieldClass {
	XmppXepDataFormsDataFormFieldClass parent_class;
};

struct _XmppXepDataFormsDataFormTextPrivateField {
	XmppXepDataFormsDataFormField parent_instance;
	XmppXepDataFormsDataFormTextPrivateFieldPrivate * priv;
};

struct _XmppXepDataFormsDataFormTextPrivateFieldClass {
	XmppXepDataFormsDataFormFieldClass parent_class;
};

struct _XmppXepDataFormsDataFormTextSingleField {
	XmppXepDataFormsDataFormField parent_instance;
	XmppXepDataFormsDataFormTextSingleFieldPrivate * priv;
};

struct _XmppXepDataFormsDataFormTextSingleFieldClass {
	XmppXepDataFormsDataFormFieldClass parent_class;
};

struct _XmppXepServiceDiscoveryFlag {
	XmppXmppStreamFlag parent_instance;
	XmppXepServiceDiscoveryFlagPrivate * priv;
};

struct _XmppXepServiceDiscoveryFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppXepServiceDiscoveryIdentity {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepServiceDiscoveryIdentityPrivate * priv;
};

struct _XmppXepServiceDiscoveryIdentityClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepServiceDiscoveryIdentity *self);
};

struct _XmppXepServiceDiscoveryInfoResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepServiceDiscoveryInfoResultPrivate * priv;
};

struct _XmppXepServiceDiscoveryInfoResultClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepServiceDiscoveryInfoResult *self);
};

struct _XmppXepServiceDiscoveryItem {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepServiceDiscoveryItemPrivate * priv;
	XmppJid* jid;
	gchar* name;
	gchar* node;
};

struct _XmppXepServiceDiscoveryItemClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepServiceDiscoveryItem *self);
};

struct _XmppXepServiceDiscoveryItemsResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepServiceDiscoveryItemsResultPrivate * priv;
};

struct _XmppXepServiceDiscoveryItemsResultClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepServiceDiscoveryItemsResult *self);
};

struct _XmppXepServiceDiscoveryCapsCacheIface {
	GTypeInterface parent_iface;
	void (*has_entity_feature) (XmppXepServiceDiscoveryCapsCache* self, XmppJid* jid, const gchar* feature, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*has_entity_feature_finish) (XmppXepServiceDiscoveryCapsCache* self, GAsyncResult* _res_);
	void (*get_entity_identities) (XmppXepServiceDiscoveryCapsCache* self, XmppJid* jid, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GeeSet* (*get_entity_identities_finish) (XmppXepServiceDiscoveryCapsCache* self, GAsyncResult* _res_);
};

struct _XmppXepServiceDiscoveryModule {
	XmppXmppStreamModule parent_instance;
	XmppXepServiceDiscoveryModulePrivate * priv;
	XmppXepServiceDiscoveryIdentity* own_identity;
	XmppXepServiceDiscoveryCapsCache* cache;
};

struct _XmppXepServiceDiscoveryModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepMucFlag {
	XmppXmppStreamFlag parent_instance;
	XmppXepMucFlagPrivate * priv;
	GeeHashMap* enter_futures;
};

struct _XmppXepMucFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppXepMucJoinResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepMucJoinResultPrivate * priv;
	XmppXepMucMucEnterError* muc_error;
	gchar* stanza_error;
	gchar* nick;
	gboolean newly_created;
};

struct _XmppXepMucJoinResultClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepMucJoinResult *self);
};

struct _XmppXepMucModule {
	XmppXmppStreamModule parent_instance;
	XmppXepMucModulePrivate * priv;
};

struct _XmppXepMucModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepMucReceivedPipelineListener {
	XmppStanzaListener parent_instance;
	XmppXepMucReceivedPipelineListenerPrivate * priv;
};

struct _XmppXepMucReceivedPipelineListenerClass {
	XmppStanzaListenerClass parent_class;
};

struct _XmppXepInBandBytestreamsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepInBandBytestreamsModulePrivate * priv;
};

struct _XmppXepInBandBytestreamsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepInBandBytestreamsConnection {
	GIOStream parent_instance;
	XmppXepInBandBytestreamsConnectionPrivate * priv;
	gint remote_seq;
};

struct _XmppXepInBandBytestreamsConnectionClass {
	GIOStreamClass parent_class;
};

struct _XmppXepInBandBytestreamsConnectionInput {
	GInputStream parent_instance;
	XmppXepInBandBytestreamsConnectionInputPrivate * priv;
};

struct _XmppXepInBandBytestreamsConnectionInputClass {
	GInputStreamClass parent_class;
};

struct _XmppXepInBandBytestreamsConnectionOutput {
	GOutputStream parent_instance;
	XmppXepInBandBytestreamsConnectionOutputPrivate * priv;
};

struct _XmppXepInBandBytestreamsConnectionOutputClass {
	GOutputStreamClass parent_class;
};

struct _XmppXepInBandBytestreamsFlag {
	XmppXmppStreamFlag parent_instance;
	XmppXepInBandBytestreamsFlagPrivate * priv;
};

struct _XmppXepInBandBytestreamsFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppXepBookmarksModule {
	XmppXmppStreamModule parent_instance;
	XmppXepBookmarksModulePrivate * priv;
};

struct _XmppXepBookmarksModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepBookmarksBookmarks1Conference {
	XmppConference parent_instance;
	XmppXepBookmarksBookmarks1ConferencePrivate * priv;
	XmppStanzaNode* stanza_node;
};

struct _XmppXepBookmarksBookmarks1ConferenceClass {
	XmppConferenceClass parent_class;
};

struct _XmppXepMessageMarkupSpan {
	GObject parent_instance;
	XmppXepMessageMarkupSpanPrivate * priv;
};

struct _XmppXepMessageMarkupSpanClass {
	GObjectClass parent_class;
};

struct _XmppXepPrivateXmlStorageModule {
	XmppXmppStreamModule parent_instance;
	XmppXepPrivateXmlStorageModulePrivate * priv;
};

struct _XmppXepPrivateXmlStorageModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepVCardModule {
	XmppXmppStreamModule parent_instance;
	XmppXepVCardModulePrivate * priv;
};

struct _XmppXepVCardModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppResultSetManagementResultSetParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppResultSetManagementResultSetParametersPrivate * priv;
};

struct _XmppResultSetManagementResultSetParametersClass {
	GTypeClass parent_class;
	void (*finalize) (XmppResultSetManagementResultSetParameters *self);
};

struct _XmppXepPubsubModule {
	XmppXmppStreamModule parent_instance;
	XmppXepPubsubModulePrivate * priv;
};

struct _XmppXepPubsubModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepPubsubPublishOptions {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepPubsubPublishOptionsPrivate * priv;
	GeeHashMap* settings;
};

struct _XmppXepPubsubPublishOptionsClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepPubsubPublishOptions *self);
};

struct _XmppXepPubsubItemListenerDelegate {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepPubsubItemListenerDelegatePrivate * priv;
};

struct _XmppXepPubsubItemListenerDelegateClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepPubsubItemListenerDelegate *self);
};

struct _XmppXepPubsubRetractListenerDelegate {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepPubsubRetractListenerDelegatePrivate * priv;
};

struct _XmppXepPubsubRetractListenerDelegateClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepPubsubRetractListenerDelegate *self);
};

struct _XmppXepPubsubDeleteListenerDelegate {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepPubsubDeleteListenerDelegatePrivate * priv;
};

struct _XmppXepPubsubDeleteListenerDelegateClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepPubsubDeleteListenerDelegate *self);
};

struct _XmppXepSocks5BytestreamsProxy {
	GObject parent_instance;
	XmppXepSocks5BytestreamsProxyPrivate * priv;
};

struct _XmppXepSocks5BytestreamsProxyClass {
	GObjectClass parent_class;
};

struct _XmppXepSocks5BytestreamsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepSocks5BytestreamsModulePrivate * priv;
};

struct _XmppXepSocks5BytestreamsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepSocks5BytestreamsFlag {
	XmppXmppStreamFlag parent_instance;
	XmppXepSocks5BytestreamsFlagPrivate * priv;
	GeeList* proxies;
};

struct _XmppXepSocks5BytestreamsFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppXepInBandRegistrationModule {
	XmppXmppStreamNegotiationModule parent_instance;
	XmppXepInBandRegistrationModulePrivate * priv;
};

struct _XmppXepInBandRegistrationModuleClass {
	XmppXmppStreamNegotiationModuleClass parent_class;
};

struct _XmppXepInBandRegistrationForm {
	XmppXepDataFormsDataForm parent_instance;
	XmppXepInBandRegistrationFormPrivate * priv;
	gchar* oob;
};

struct _XmppXepInBandRegistrationFormClass {
	XmppXepDataFormsDataFormClass parent_class;
};

struct _XmppXepUserAvatarsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepUserAvatarsModulePrivate * priv;
};

struct _XmppXepUserAvatarsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepChatStateNotificationsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepChatStateNotificationsModulePrivate * priv;
};

struct _XmppXepChatStateNotificationsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepEntityCapabilitiesModule {
	XmppXmppStreamModule parent_instance;
	XmppXepEntityCapabilitiesModulePrivate * priv;
};

struct _XmppXepEntityCapabilitiesModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepEntityCapabilitiesStorageIface {
	GTypeInterface parent_iface;
	void (*store_identities) (XmppXepEntityCapabilitiesStorage* self, const gchar* entity, GeeSet* identities);
	void (*store_features) (XmppXepEntityCapabilitiesStorage* self, const gchar* entity, GeeList* capabilities);
	XmppXepServiceDiscoveryIdentity* (*get_identities) (XmppXepEntityCapabilitiesStorage* self, const gchar* entity);
	GeeList* (*get_features) (XmppXepEntityCapabilitiesStorage* self, const gchar* entity);
};

struct _XmppXepJingleComponentConnection {
	GObject parent_instance;
	XmppXepJingleComponentConnectionPrivate * priv;
};

struct _XmppXepJingleComponentConnectionClass {
	GObjectClass parent_class;
	void (*terminate) (XmppXepJingleComponentConnection* self, gboolean we_terminated, const gchar* reason_name, const gchar* reason_text, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*terminate_finish) (XmppXepJingleComponentConnection* self, GAsyncResult* _res_);
};

struct _XmppXepJingleDatagramConnection {
	XmppXepJingleComponentConnection parent_instance;
	XmppXepJingleDatagramConnectionPrivate * priv;
};

struct _XmppXepJingleDatagramConnectionClass {
	XmppXepJingleComponentConnectionClass parent_class;
	void (*send_datagram) (XmppXepJingleDatagramConnection* self, GBytes* datagram);
};

struct _XmppXepJingleStreamingConnection {
	XmppXepJingleComponentConnection parent_instance;
	XmppXepJingleStreamingConnectionPrivate * priv;
	GeePromise* promise;
};

struct _XmppXepJingleStreamingConnectionClass {
	XmppXepJingleComponentConnectionClass parent_class;
};

struct _XmppXepJingleContentParametersIface {
	GTypeInterface parent_iface;
	void (*handle_proposed_content) (XmppXepJingleContentParameters* self, XmppXmppStream* stream, XmppXepJingleSession* session, XmppXepJingleContent* content, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*handle_proposed_content_finish) (XmppXepJingleContentParameters* self, GAsyncResult* _res_);
	void (*accept) (XmppXepJingleContentParameters* self, XmppXmppStream* stream, XmppXepJingleSession* session, XmppXepJingleContent* content);
	void (*handle_accept) (XmppXepJingleContentParameters* self, XmppXmppStream* stream, XmppXepJingleSession* session, XmppXepJingleContent* content, XmppStanzaNode* description_node);
	void (*terminate) (XmppXepJingleContentParameters* self, gboolean we_terminated, const gchar* reason_name, const gchar* reason_text);
	XmppStanzaNode* (*get_description_node) (XmppXepJingleContentParameters* self);
};

typedef enum  {
	XMPP_XEP_JINGLE_IQ_ERROR_BAD_REQUEST,
	XMPP_XEP_JINGLE_IQ_ERROR_NOT_ACCEPTABLE,
	XMPP_XEP_JINGLE_IQ_ERROR_NOT_IMPLEMENTED,
	XMPP_XEP_JINGLE_IQ_ERROR_UNSUPPORTED_INFO,
	XMPP_XEP_JINGLE_IQ_ERROR_OUT_OF_ORDER,
	XMPP_XEP_JINGLE_IQ_ERROR_RESOURCE_CONSTRAINT
} XmppXepJingleIqError;
#define XMPP_XEP_JINGLE_IQ_ERROR xmpp_xep_jingle_iq_error_quark ()

struct _XmppXepJingleContentTypeIface {
	GTypeInterface parent_iface;
	XmppXepJingleContentParameters* (*parse_content_parameters) (XmppXepJingleContentType* self, XmppStanzaNode* description, GError** error);
	const gchar* (*get_ns_uri) (XmppXepJingleContentType* self);
	XmppXepJingleTransportType (*get_required_transport_type) (XmppXepJingleContentType* self);
	guint8 (*get_required_components) (XmppXepJingleContentType* self);
};

struct _XmppXepJingleTransportParametersIface {
	GTypeInterface parent_iface;
	void (*set_content) (XmppXepJingleTransportParameters* self, XmppXepJingleContent* content);
	XmppStanzaNode* (*to_transport_stanza_node) (XmppXepJingleTransportParameters* self, const gchar* action_type);
	void (*handle_transport_accept) (XmppXepJingleTransportParameters* self, XmppStanzaNode* transport, GError** error);
	void (*handle_transport_info) (XmppXepJingleTransportParameters* self, XmppStanzaNode* transport, GError** error);
	void (*create_transport_connection) (XmppXepJingleTransportParameters* self, XmppXmppStream* stream, XmppXepJingleContent* content);
	const gchar* (*get_ns_uri) (XmppXepJingleTransportParameters* self);
	guint8 (*get_components) (XmppXepJingleTransportParameters* self);
};

typedef enum  {
	XMPP_XEP_JINGLE_ERROR_GENERAL,
	XMPP_XEP_JINGLE_ERROR_BAD_REQUEST,
	XMPP_XEP_JINGLE_ERROR_INVALID_PARAMETERS,
	XMPP_XEP_JINGLE_ERROR_UNSUPPORTED_TRANSPORT,
	XMPP_XEP_JINGLE_ERROR_UNSUPPORTED_SECURITY,
	XMPP_XEP_JINGLE_ERROR_NO_SHARED_PROTOCOLS,
	XMPP_XEP_JINGLE_ERROR_TRANSPORT_ERROR
} XmppXepJingleError;
#define XMPP_XEP_JINGLE_ERROR xmpp_xep_jingle_error_quark ()

struct _XmppXepJingleTransportIface {
	GTypeInterface parent_iface;
	void (*is_transport_available) (XmppXepJingleTransport* self, XmppXmppStream* stream, guint8 components, XmppJid* full_jid, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*is_transport_available_finish) (XmppXepJingleTransport* self, GAsyncResult* _res_);
	XmppXepJingleTransportParameters* (*create_transport_parameters) (XmppXepJingleTransport* self, XmppXmppStream* stream, guint8 components, XmppJid* local_full_jid, XmppJid* peer_full_jid, GError** error);
	XmppXepJingleTransportParameters* (*parse_transport_parameters) (XmppXepJingleTransport* self, XmppXmppStream* stream, guint8 components, XmppJid* local_full_jid, XmppJid* peer_full_jid, XmppStanzaNode* transport, GError** error);
	const gchar* (*get_ns_uri) (XmppXepJingleTransport* self);
	XmppXepJingleTransportType (*get_type_) (XmppXepJingleTransport* self);
	gint (*get_priority) (XmppXepJingleTransport* self);
};

struct _XmppXepJingleSecurityParametersIface {
	GTypeInterface parent_iface;
	gchar* (*security_ns_uri) (XmppXepJingleSecurityParameters* self);
	XmppStanzaNode* (*to_security_stanza_node) (XmppXepJingleSecurityParameters* self, XmppXmppStream* stream, XmppJid* local_full_jid, XmppJid* peer_full_jid);
	GIOStream* (*wrap_stream) (XmppXepJingleSecurityParameters* self, GIOStream* stream);
};

struct _XmppXepJingleSecurityPreconditionIface {
	GTypeInterface parent_iface;
	gchar* (*security_ns_uri) (XmppXepJingleSecurityPrecondition* self);
	XmppXepJingleSecurityParameters* (*create_security_parameters) (XmppXepJingleSecurityPrecondition* self, XmppXmppStream* stream, XmppJid* local_full_jid, XmppJid* peer_full_jid, GObject* options, GError** error);
	XmppXepJingleSecurityParameters* (*parse_security_parameters) (XmppXepJingleSecurityPrecondition* self, XmppXmppStream* stream, XmppJid* local_full_jid, XmppJid* peer_full_jid, XmppStanzaNode* security, GError** error);
};

struct _XmppXepJingleContent {
	GObject parent_instance;
	XmppXepJingleContentPrivate * priv;
	XmppXepJingleContentType* content_type;
	XmppXepJingleContentParameters* content_params;
	XmppXepJingleTransport* transport;
	XmppXepJingleTransportParameters* transport_params;
	XmppXepJingleSecurityPrecondition* security_precondition;
	XmppXepJingleSecurityParameters* security_params;
	XmppXepJingleSession* session;
	GeeMap* component_connections;
	GeeHashMap* encryptions;
};

struct _XmppXepJingleContentClass {
	GObjectClass parent_class;
};

struct _XmppXepJingleContentEncryption {
	GObject parent_instance;
	XmppXepJingleContentEncryptionPrivate * priv;
	gchar* encryption_ns;
	gchar* encryption_name;
	guint8* our_key;
	gint our_key_length1;
	guint8* peer_key;
	gint peer_key_length1;
};

struct _XmppXepJingleContentEncryptionClass {
	GObjectClass parent_class;
};

struct _XmppXepJingleFlag {
	XmppXmppStreamFlag parent_instance;
	XmppXepJingleFlagPrivate * priv;
	GeeHashMap* sessions;
	GeeHashMap* promises;
};

struct _XmppXepJingleFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppXepJingleModule {
	XmppXmppStreamModule parent_instance;
	XmppXepJingleModulePrivate * priv;
};

struct _XmppXepJingleModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepJingleSessionInfoNsIface {
	GTypeInterface parent_iface;
	void (*handle_content_session_info) (XmppXepJingleSessionInfoNs* self, XmppXmppStream* stream, XmppXepJingleSession* session, XmppStanzaNode* info, XmppIqStanza* iq, GError** error);
	const gchar* (*get_ns_uri) (XmppXepJingleSessionInfoNs* self);
};

struct _XmppXepJingleSession {
	GObject parent_instance;
	XmppXepJingleSessionPrivate * priv;
	GeeHashMap* contents_map;
	GeeList* contents;
};

struct _XmppXepJingleSessionClass {
	GObjectClass parent_class;
};

struct _XmppXepJingleRtpParameters {
	GObject parent_instance;
	XmppXepJingleRtpParametersPrivate * priv;
	GeeList* payload_types;
	GeeList* header_extensions;
	GeeList* remote_cryptos;
	XmppXepJingleRtpCrypto* local_crypto;
	XmppXepJingleRtpCrypto* remote_crypto;
};

struct _XmppXepJingleRtpParametersClass {
	GObjectClass parent_class;
};

struct _XmppXepJingleRtpHeaderExtension {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepJingleRtpHeaderExtensionPrivate * priv;
};

struct _XmppXepJingleRtpHeaderExtensionClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepJingleRtpHeaderExtension *self);
};

struct _XmppXepJingleRtpContentType {
	GObject parent_instance;
	XmppXepJingleRtpContentTypePrivate * priv;
};

struct _XmppXepJingleRtpContentTypeClass {
	GObjectClass parent_class;
};

struct _XmppXepJingleRtpModule {
	XmppXmppStreamModule parent_instance;
	XmppXepJingleRtpModulePrivate * priv;
	XmppXepJingleRtpSessionInfoType* session_info_type;
};

struct _XmppXepJingleRtpModuleClass {
	XmppXmppStreamModuleClass parent_class;
	void (*get_supported_payloads) (XmppXepJingleRtpModule* self, const gchar* media, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GeeList* (*get_supported_payloads_finish) (XmppXepJingleRtpModule* self, GAsyncResult* _res_);
	void (*is_payload_supported) (XmppXepJingleRtpModule* self, const gchar* media, XmppXepJingleRtpPayloadType* payload_type, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*is_payload_supported_finish) (XmppXepJingleRtpModule* self, GAsyncResult* _res_);
	void (*pick_payload_type) (XmppXepJingleRtpModule* self, const gchar* media, GeeList* payloads, GAsyncReadyCallback _callback_, gpointer _user_data_);
	XmppXepJingleRtpPayloadType* (*pick_payload_type_finish) (XmppXepJingleRtpModule* self, GAsyncResult* _res_);
	XmppXepJingleRtpCrypto* (*generate_local_crypto) (XmppXepJingleRtpModule* self);
	XmppXepJingleRtpCrypto* (*pick_remote_crypto) (XmppXepJingleRtpModule* self, GeeList* cryptos);
	XmppXepJingleRtpCrypto* (*pick_local_crypto) (XmppXepJingleRtpModule* self, XmppXepJingleRtpCrypto* remote);
	XmppXepJingleRtpStream* (*create_stream) (XmppXepJingleRtpModule* self, XmppXepJingleContent* content);
	gboolean (*is_header_extension_supported) (XmppXepJingleRtpModule* self, const gchar* media, XmppXepJingleRtpHeaderExtension* ext);
	GeeList* (*get_suggested_header_extensions) (XmppXepJingleRtpModule* self, const gchar* media);
	void (*close_stream) (XmppXepJingleRtpModule* self, XmppXepJingleRtpStream* stream);
};

struct _XmppXepJingleRtpCrypto {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepJingleRtpCryptoPrivate * priv;
};

struct _XmppXepJingleRtpCryptoClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepJingleRtpCrypto *self);
};

struct _XmppXepJingleRtpPayloadType {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepJingleRtpPayloadTypePrivate * priv;
	GeeMap* parameters;
	GeeList* rtcp_fbs;
};

struct _XmppXepJingleRtpPayloadTypeClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepJingleRtpPayloadType *self);
};

struct _XmppXepJingleRtpRtcpFeedback {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepJingleRtpRtcpFeedbackPrivate * priv;
};

struct _XmppXepJingleRtpRtcpFeedbackClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepJingleRtpRtcpFeedback *self);
};

struct _XmppXepJingleRtpSessionInfoType {
	GObject parent_instance;
	XmppXepJingleRtpSessionInfoTypePrivate * priv;
};

struct _XmppXepJingleRtpSessionInfoTypeClass {
	GObjectClass parent_class;
};

struct _XmppXepJingleRtpStream {
	GObject parent_instance;
	XmppXepJingleRtpStreamPrivate * priv;
};

struct _XmppXepJingleRtpStreamClass {
	GObjectClass parent_class;
	void (*on_recv_rtp_data) (XmppXepJingleRtpStream* self, GBytes* bytes);
	void (*on_recv_rtcp_data) (XmppXepJingleRtpStream* self, GBytes* bytes);
	void (*on_rtp_ready) (XmppXepJingleRtpStream* self);
	void (*on_rtcp_ready) (XmppXepJingleRtpStream* self);
	void (*create) (XmppXepJingleRtpStream* self);
	void (*destroy) (XmppXepJingleRtpStream* self);
};

struct _XmppXepJingleIceUdpCandidate {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepJingleIceUdpCandidatePrivate * priv;
	guint8 component;
	gchar* foundation;
	guint8 generation;
	gchar* id;
	gchar* ip;
	guint8 network;
	guint16 port;
	guint32 priority;
	gchar* protocol;
	gchar* rel_addr;
	guint16 rel_port;
	XmppXepJingleIceUdpCandidateType type_;
};

struct _XmppXepJingleIceUdpCandidateClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepJingleIceUdpCandidate *self);
};

struct _XmppXepJingleIceUdpModule {
	XmppXmppStreamModule parent_instance;
	XmppXepJingleIceUdpModulePrivate * priv;
};

struct _XmppXepJingleIceUdpModuleClass {
	XmppXmppStreamModuleClass parent_class;
	XmppXepJingleTransportParameters* (*create_transport_parameters) (XmppXepJingleIceUdpModule* self, XmppXmppStream* stream, guint8 components, XmppJid* local_full_jid, XmppJid* peer_full_jid, GError** error);
	XmppXepJingleTransportParameters* (*parse_transport_parameters) (XmppXepJingleIceUdpModule* self, XmppXmppStream* stream, guint8 components, XmppJid* local_full_jid, XmppJid* peer_full_jid, XmppStanzaNode* transport, GError** error);
};

struct _XmppXepJingleIceUdpIceUdpTransportParameters {
	GObject parent_instance;
	XmppXepJingleIceUdpIceUdpTransportParametersPrivate * priv;
	GeeConcurrentList* local_candidates;
	GeeConcurrentList* unsent_local_candidates;
	GeeList* remote_candidates;
	guint8* own_fingerprint;
	gint own_fingerprint_length1;
	gchar* own_setup;
	guint8* peer_fingerprint;
	gint peer_fingerprint_length1;
	gchar* peer_fp_algo;
	gchar* peer_setup;
	XmppXepJingleContent* content;
	gboolean use_raw;
};

struct _XmppXepJingleIceUdpIceUdpTransportParametersClass {
	GObjectClass parent_class;
	void (*handle_transport_accept) (XmppXepJingleIceUdpIceUdpTransportParameters* self, XmppStanzaNode* node, GError** error);
	void (*handle_transport_info) (XmppXepJingleIceUdpIceUdpTransportParameters* self, XmppStanzaNode* node, GError** error);
	void (*create_transport_connection) (XmppXepJingleIceUdpIceUdpTransportParameters* self, XmppXmppStream* stream, XmppXepJingleContent* content);
};

struct _XmppXepJingleRawUdpModule {
	XmppXmppStreamModule parent_instance;
	XmppXepJingleRawUdpModulePrivate * priv;
};

struct _XmppXepJingleRawUdpModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepJingleRawUdpTransportParameters {
	GObject parent_instance;
	XmppXepJingleRawUdpTransportParametersPrivate * priv;
	GeeList* remote_candidates;
	GeeList* own_candidates;
};

struct _XmppXepJingleRawUdpTransportParametersClass {
	GObjectClass parent_class;
};

struct _XmppXepJingleRawUdpCandidate {
	GObject parent_instance;
	XmppXepJingleRawUdpCandidatePrivate * priv;
};

struct _XmppXepJingleRawUdpCandidateClass {
	GObjectClass parent_class;
};

struct _XmppXepMessageDeliveryReceiptsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepMessageDeliveryReceiptsModulePrivate * priv;
};

struct _XmppXepMessageDeliveryReceiptsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepMessageDeliveryReceiptsSendPipelineListener {
	XmppStanzaListener parent_instance;
	XmppXepMessageDeliveryReceiptsSendPipelineListenerPrivate * priv;
};

struct _XmppXepMessageDeliveryReceiptsSendPipelineListenerClass {
	XmppStanzaListenerClass parent_class;
};

struct _XmppXepBlockingCommandModule {
	XmppXmppStreamModule parent_instance;
	XmppXepBlockingCommandModulePrivate * priv;
};

struct _XmppXepBlockingCommandModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepBlockingCommandFlag {
	XmppXmppStreamFlag parent_instance;
	XmppXepBlockingCommandFlagPrivate * priv;
	GeeList* blocklist;
};

struct _XmppXepBlockingCommandFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppXepStreamManagementModule {
	XmppXmppStreamNegotiationModule parent_instance;
	XmppXepStreamManagementModulePrivate * priv;
	gint h_inbound;
	gint h_outbound;
	GeeList* flags;
};

struct _XmppXepStreamManagementModuleClass {
	XmppXmppStreamNegotiationModuleClass parent_class;
};

struct _XmppXepStreamManagementFlag {
	XmppXmppStreamFlag parent_instance;
	XmppXepStreamManagementFlagPrivate * priv;
	gboolean finished;
	gboolean resumed;
};

struct _XmppXepStreamManagementFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppXepPingModule {
	XmppXmppStreamModule parent_instance;
	XmppXepPingModulePrivate * priv;
};

struct _XmppXepPingModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepDelayedDeliveryModule {
	XmppXmppStreamModule parent_instance;
	XmppXepDelayedDeliveryModulePrivate * priv;
};

struct _XmppXepDelayedDeliveryModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepDelayedDeliveryReceivedPipelineListener {
	XmppStanzaListener parent_instance;
	XmppXepDelayedDeliveryReceivedPipelineListenerPrivate * priv;
};

struct _XmppXepDelayedDeliveryReceivedPipelineListenerClass {
	XmppStanzaListenerClass parent_class;
};

struct _XmppXepDelayedDeliveryMessageFlag {
	XmppMessageFlag parent_instance;
	XmppXepDelayedDeliveryMessageFlagPrivate * priv;
};

struct _XmppXepDelayedDeliveryMessageFlagClass {
	XmppMessageFlagClass parent_class;
};

struct _XmppXepExternalServiceDiscoveryService {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepExternalServiceDiscoveryServicePrivate * priv;
};

struct _XmppXepExternalServiceDiscoveryServiceClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepExternalServiceDiscoveryService *self);
};

struct _XmppXepJingleFileTransferModule {
	XmppXmppStreamModule parent_instance;
	XmppXepJingleFileTransferModulePrivate * priv;
	XmppXepJingleFileTransferSessionInfoType* session_info_type;
};

struct _XmppXepJingleFileTransferModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepJingleFileTransferSessionInfoType {
	GObject parent_instance;
	XmppXepJingleFileTransferSessionInfoTypePrivate * priv;
};

struct _XmppXepJingleFileTransferSessionInfoTypeClass {
	GObjectClass parent_class;
};

struct _XmppXepJingleFileTransferParameters {
	GObject parent_instance;
	XmppXepJingleFileTransferParametersPrivate * priv;
};

struct _XmppXepJingleFileTransferParametersClass {
	GObjectClass parent_class;
};

struct _XmppXepJingleFileTransferFileTransfer {
	GObject parent_instance;
	XmppXepJingleFileTransferFileTransferPrivate * priv;
};

struct _XmppXepJingleFileTransferFileTransferClass {
	GObjectClass parent_class;
};

struct _XmppXepDirectMucInvitationsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepDirectMucInvitationsModulePrivate * priv;
};

struct _XmppXepDirectMucInvitationsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepJingleSocks5BytestreamsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepJingleSocks5BytestreamsModulePrivate * priv;
};

struct _XmppXepJingleSocks5BytestreamsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepJingleSocks5BytestreamsCandidate {
	XmppXepSocks5BytestreamsProxy parent_instance;
	XmppXepJingleSocks5BytestreamsCandidatePrivate * priv;
};

struct _XmppXepJingleSocks5BytestreamsCandidateClass {
	XmppXepSocks5BytestreamsProxyClass parent_class;
};

struct _XmppXepJingleInBandBytestreamsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepJingleInBandBytestreamsModulePrivate * priv;
};

struct _XmppXepJingleInBandBytestreamsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepJingleContentThumbnailsThumbnail {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepJingleContentThumbnailsThumbnailPrivate * priv;
	gchar* uri;
	gchar* media_type;
	gint width;
	gint height;
};

struct _XmppXepJingleContentThumbnailsThumbnailClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepJingleContentThumbnailsThumbnail *self);
};

struct _XmppXepMujiModule {
	XmppXmppStreamModule parent_instance;
	XmppXepMujiModulePrivate * priv;
};

struct _XmppXepMujiModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepMujiGroupCall {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepMujiGroupCallPrivate * priv;
	gchar* our_nick;
	XmppJid* muc_jid;
	GeeArrayList* peers_to_connect_to;
	GeeArrayList* peers;
	GeeHashMap* real_jids;
	GeeHashMap* waiting_for_finish_prepares;
	GeeHashMap* current_payload_intersection;
};

struct _XmppXepMujiGroupCallClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepMujiGroupCall *self);
};

struct _XmppXepMujiFlag {
	XmppXmppStreamFlag parent_instance;
	XmppXepMujiFlagPrivate * priv;
	GeeHashMap* calls;
};

struct _XmppXepMujiFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppXepMessageCarbonsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepMessageCarbonsModulePrivate * priv;
};

struct _XmppXepMessageCarbonsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepMessageCarbonsReceivedPipelineListener {
	XmppStanzaListener parent_instance;
	XmppXepMessageCarbonsReceivedPipelineListenerPrivate * priv;
};

struct _XmppXepMessageCarbonsReceivedPipelineListenerClass {
	XmppStanzaListenerClass parent_class;
};

struct _XmppXepMessageCarbonsMessageFlag {
	XmppMessageFlag parent_instance;
	XmppXepMessageCarbonsMessageFlagPrivate * priv;
};

struct _XmppXepMessageCarbonsMessageFlagClass {
	XmppMessageFlagClass parent_class;
};

struct _XmppXepCoinModule {
	XmppXmppStreamModule parent_instance;
	XmppXepCoinModulePrivate * priv;
};

struct _XmppXepCoinModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepCoinConferenceInfo {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepCoinConferenceInfoPrivate * priv;
	gint version;
	GeeHashMap* users;
};

struct _XmppXepCoinConferenceInfoClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepCoinConferenceInfo *self);
};

struct _XmppXepCoinConferenceUser {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepCoinConferenceUserPrivate * priv;
	XmppJid* jid;
	gchar* display_text;
	GeeHashMap* medias;
};

struct _XmppXepCoinConferenceUserClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepCoinConferenceUser *self);
};

struct _XmppXepCoinConferenceMedia {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepCoinConferenceMediaPrivate * priv;
	gchar* id;
	gchar* ty;
	gint src_id;
};

struct _XmppXepCoinConferenceMediaClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepCoinConferenceMedia *self);
};

struct _XmppXepCryptographicHashesHash {
	GObject parent_instance;
	XmppXepCryptographicHashesHashPrivate * priv;
	gchar* algo;
	gchar* val;
};

struct _XmppXepCryptographicHashesHashClass {
	GObjectClass parent_class;
};

struct _XmppXepLastMessageCorrectionModule {
	XmppXmppStreamModule parent_instance;
	XmppXepLastMessageCorrectionModulePrivate * priv;
};

struct _XmppXepLastMessageCorrectionModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppMessageArchiveManagementV2MamQueryParams {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppMessageArchiveManagementV2MamQueryParamsPrivate * priv;
	gboolean use_ns2_extended;
	gchar* query_id;
};

struct _XmppMessageArchiveManagementV2MamQueryParamsClass {
	GTypeClass parent_class;
	void (*finalize) (XmppMessageArchiveManagementV2MamQueryParams *self);
};

struct _XmppMessageArchiveManagementQueryResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppMessageArchiveManagementQueryResultPrivate * priv;
};

struct _XmppMessageArchiveManagementQueryResultClass {
	GTypeClass parent_class;
	void (*finalize) (XmppMessageArchiveManagementQueryResult *self);
};

struct _XmppMessageArchiveManagementModule {
	XmppXmppStreamModule parent_instance;
	XmppMessageArchiveManagementModulePrivate * priv;
};

struct _XmppMessageArchiveManagementModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppMessageArchiveManagementReceivedPipelineListener {
	XmppStanzaListener parent_instance;
	XmppMessageArchiveManagementReceivedPipelineListenerPrivate * priv;
};

struct _XmppMessageArchiveManagementReceivedPipelineListenerClass {
	XmppStanzaListenerClass parent_class;
};

struct _XmppMessageArchiveManagementFlag {
	XmppXmppStreamFlag parent_instance;
	XmppMessageArchiveManagementFlagPrivate * priv;
};

struct _XmppMessageArchiveManagementFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppMessageArchiveManagementMessageFlag {
	XmppMessageFlag parent_instance;
	XmppMessageArchiveManagementMessageFlagPrivate * priv;
};

struct _XmppMessageArchiveManagementMessageFlagClass {
	XmppMessageFlagClass parent_class;
};

struct _XmppXepChatMarkersModule {
	XmppXmppStreamModule parent_instance;
	XmppXepChatMarkersModulePrivate * priv;
};

struct _XmppXepChatMarkersModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepChatMarkersSendPipelineListener {
	XmppStanzaListener parent_instance;
	XmppXepChatMarkersSendPipelineListenerPrivate * priv;
};

struct _XmppXepChatMarkersSendPipelineListenerClass {
	XmppStanzaListenerClass parent_class;
};

struct _XmppXepJingleMessageInitiationModule {
	XmppXmppStreamModule parent_instance;
	XmppXepJingleMessageInitiationModulePrivate * priv;
};

struct _XmppXepJingleMessageInitiationModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepUniqueStableStanzaIDsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepUniqueStableStanzaIDsModulePrivate * priv;
};

struct _XmppXepUniqueStableStanzaIDsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

typedef enum  {
	XMPP_XEP_HTTP_FILE_UPLOAD_HTTP_FILE_TRANSFER_ERROR_SLOT_REQUEST
} XmppXepHttpFileUploadHttpFileTransferError;
#define XMPP_XEP_HTTP_FILE_UPLOAD_HTTP_FILE_TRANSFER_ERROR xmpp_xep_http_file_upload_http_file_transfer_error_quark ()

struct _XmppXepHttpFileUploadModule {
	XmppXmppStreamModule parent_instance;
	XmppXepHttpFileUploadModulePrivate * priv;
};

struct _XmppXepHttpFileUploadModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepHttpFileUploadModuleSlotResult {
	gchar* _url_get;
	gchar* _url_put;
	GeeHashMap* _headers;
};

struct _XmppXepHttpFileUploadReceivedPipelineListener {
	XmppStanzaListener parent_instance;
	XmppXepHttpFileUploadReceivedPipelineListenerPrivate * priv;
};

struct _XmppXepHttpFileUploadReceivedPipelineListenerClass {
	XmppStanzaListenerClass parent_class;
};

struct _XmppXepHttpFileUploadFlag {
	XmppXmppStreamFlag parent_instance;
	XmppXepHttpFileUploadFlagPrivate * priv;
	XmppJid* file_store_jid;
	gchar* ns_ver;
	gint* max_file_size;
};

struct _XmppXepHttpFileUploadFlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppXepOmemoOmemoDecryptor {
	XmppXmppStreamModule parent_instance;
	XmppXepOmemoOmemoDecryptorPrivate * priv;
};

struct _XmppXepOmemoOmemoDecryptorClass {
	XmppXmppStreamModuleClass parent_class;
	gchar* (*decrypt) (XmppXepOmemoOmemoDecryptor* self, guint8* ciphertext, gint ciphertext_length1, guint8* key, gint key_length1, guint8* iv, gint iv_length1, GError** error);
	guint8* (*decrypt_key) (XmppXepOmemoOmemoDecryptor* self, XmppXepOmemoParsedData* data, XmppJid* from_jid, gint* result_length1, GError** error);
	guint32 (*get_own_device_id) (XmppXepOmemoOmemoDecryptor* self);
};

struct _XmppXepOmemoParsedData {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepOmemoParsedDataPrivate * priv;
	gint sid;
	guint8* ciphertext;
	gint ciphertext_length1;
	guint8* iv;
	gint iv_length1;
	guchar* encrypted_key;
	gint encrypted_key_length1;
	gboolean is_prekey;
	GeeHashMap* our_potential_encrypted_keys;
};

struct _XmppXepOmemoParsedDataClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepOmemoParsedData *self);
};

struct _XmppXepOmemoOmemoEncryptor {
	XmppXmppStreamModule parent_instance;
	XmppXepOmemoOmemoEncryptorPrivate * priv;
};

struct _XmppXepOmemoOmemoEncryptorClass {
	XmppXmppStreamModuleClass parent_class;
	XmppXepOmemoEncryptionData* (*encrypt_plaintext) (XmppXepOmemoOmemoEncryptor* self, const gchar* plaintext, GError** error);
	void (*encrypt_key) (XmppXepOmemoOmemoEncryptor* self, XmppXepOmemoEncryptionData* encryption_data, XmppJid* jid, gint32 device_id, GError** error);
	XmppXepOmemoEncryptionResult* (*encrypt_key_to_recipient) (XmppXepOmemoOmemoEncryptor* self, XmppXmppStream* stream, XmppXepOmemoEncryptionData* enc_data, XmppJid* recipient, GError** error);
	guint32 (*get_own_device_id) (XmppXepOmemoOmemoEncryptor* self);
};

struct _XmppXepOmemoEncryptionData {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepOmemoEncryptionDataPrivate * priv;
	guint32 own_device_id;
	guint8* ciphertext;
	gint ciphertext_length1;
	guint8* keytag;
	gint keytag_length1;
	guint8* iv;
	gint iv_length1;
	GeeList* key_nodes;
};

struct _XmppXepOmemoEncryptionDataClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepOmemoEncryptionData *self);
};

struct _XmppXepOmemoEncryptionResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepOmemoEncryptionResultPrivate * priv;
};

struct _XmppXepOmemoEncryptionResultClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepOmemoEncryptionResult *self);
};

struct _XmppXepOmemoEncryptState {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepOmemoEncryptStatePrivate * priv;
};

struct _XmppXepOmemoEncryptStateClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepOmemoEncryptState *self);
};

struct _XmppXepJetModule {
	XmppXmppStreamModule parent_instance;
	XmppXepJetModulePrivate * priv;
};

struct _XmppXepJetModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepJetEnvelopEncodingIface {
	GTypeInterface parent_iface;
	gchar* (*get_type_uri) (XmppXepJetEnvelopEncoding* self);
	XmppXepJetTransportSecret* (*decode_envolop) (XmppXepJetEnvelopEncoding* self, XmppXmppStream* stream, XmppJid* local_full_jid, XmppJid* peer_full_jid, XmppStanzaNode* security, GError** error);
	void (*encode_envelop) (XmppXepJetEnvelopEncoding* self, XmppXmppStream* stream, XmppJid* local_full_jid, XmppJid* peer_full_jid, XmppXepJetSecurityParameters* security_params, XmppStanzaNode* security);
};

struct _XmppXepJetCipherIface {
	GTypeInterface parent_iface;
	gchar* (*get_cipher_uri) (XmppXepJetCipher* self);
	XmppXepJetTransportSecret* (*generate_random_secret) (XmppXepJetCipher* self);
	GInputStream* (*wrap_input_stream) (XmppXepJetCipher* self, GInputStream* input, XmppXepJetTransportSecret* secret);
	GOutputStream* (*wrap_output_stream) (XmppXepJetCipher* self, GOutputStream* output, XmppXepJetTransportSecret* secret);
};

struct _XmppXepJetOptions {
	GObject parent_instance;
	XmppXepJetOptionsPrivate * priv;
};

struct _XmppXepJetOptionsClass {
	GObjectClass parent_class;
};

struct _XmppXepJetSecurityParameters {
	GObject parent_instance;
	XmppXepJetSecurityParametersPrivate * priv;
};

struct _XmppXepJetSecurityParametersClass {
	GObjectClass parent_class;
};

struct _XmppXepJetTransportSecret {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepJetTransportSecretPrivate * priv;
};

struct _XmppXepJetTransportSecretClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepJetTransportSecret *self);
};

struct _XmppXepBookmarks2Module {
	XmppXmppStreamModule parent_instance;
	XmppXepBookmarks2ModulePrivate * priv;
};

struct _XmppXepBookmarks2ModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepBookmarks2Flag {
	XmppXmppStreamFlag parent_instance;
	XmppXepBookmarks2FlagPrivate * priv;
	GeeHashMap* conferences;
};

struct _XmppXepBookmarks2FlagClass {
	XmppXmppStreamFlagClass parent_class;
};

struct _XmppXepOccupantIdsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepOccupantIdsModulePrivate * priv;
};

struct _XmppXepOccupantIdsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepFallbackIndicationFallback {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepFallbackIndicationFallbackPrivate * priv;
	GeeList* locations;
};

struct _XmppXepFallbackIndicationFallbackClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepFallbackIndicationFallback *self);
};

struct _XmppXepFallbackIndicationFallbackLocation {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepFallbackIndicationFallbackLocationPrivate * priv;
};

struct _XmppXepFallbackIndicationFallbackLocationClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepFallbackIndicationFallbackLocation *self);
};

struct _XmppXepReactionsModule {
	XmppXmppStreamModule parent_instance;
	XmppXepReactionsModulePrivate * priv;
};

struct _XmppXepReactionsModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepReactionsReceivedPipelineListener {
	XmppStanzaListener parent_instance;
	XmppXepReactionsReceivedPipelineListenerPrivate * priv;
};

struct _XmppXepReactionsReceivedPipelineListenerClass {
	XmppStanzaListenerClass parent_class;
};

struct _XmppXepFileMetadataElementFileMetadata {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepFileMetadataElementFileMetadataPrivate * priv;
	GeeList* hashes;
	GeeList* thumbnails;
};

struct _XmppXepFileMetadataElementFileMetadataClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepFileMetadataElementFileMetadata *self);
};

struct _XmppXepStatelessFileSharingSourceIface {
	GTypeInterface parent_iface;
	gchar* (*type) (XmppXepStatelessFileSharingSource* self);
	XmppStanzaNode* (*to_stanza_node) (XmppXepStatelessFileSharingSource* self);
	gboolean (*equals) (XmppXepStatelessFileSharingSource* self, XmppXepStatelessFileSharingSource* source);
};

struct _XmppXepStatelessFileSharingFileShare {
	GObject parent_instance;
	XmppXepStatelessFileSharingFileSharePrivate * priv;
};

struct _XmppXepStatelessFileSharingFileShareClass {
	GObjectClass parent_class;
};

struct _XmppXepStatelessFileSharingSourceAttachment {
	GObject parent_instance;
	XmppXepStatelessFileSharingSourceAttachmentPrivate * priv;
};

struct _XmppXepStatelessFileSharingSourceAttachmentClass {
	GObjectClass parent_class;
};

struct _XmppXepStatelessFileSharingHttpSource {
	GObject parent_instance;
	XmppXepStatelessFileSharingHttpSourcePrivate * priv;
};

struct _XmppXepStatelessFileSharingHttpSourceClass {
	GObjectClass parent_class;
};

struct _XmppXepRepliesReplyTo {
	GTypeInstance parent_instance;
	volatile int ref_count;
	XmppXepRepliesReplyToPrivate * priv;
};

struct _XmppXepRepliesReplyToClass {
	GTypeClass parent_class;
	void (*finalize) (XmppXepRepliesReplyTo *self);
};

struct _XmppXepCallInvitesModule {
	XmppXmppStreamModule parent_instance;
	XmppXepCallInvitesModulePrivate * priv;
};

struct _XmppXepCallInvitesModuleClass {
	XmppXmppStreamModuleClass parent_class;
};

struct _XmppXepPixbufStorageIface {
	GTypeInterface parent_iface;
	void (*store) (XmppXepPixbufStorage* self, const gchar* id, GBytes* data);
	gboolean (*has_image) (XmppXepPixbufStorage* self, const gchar* id);
	void (*get_image) (XmppXepPixbufStorage* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*get_image_finish) (XmppXepPixbufStorage* self, GAsyncResult* _res_);
};

VALA_EXTERN GType xmpp_xmpp_stream_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXmppStream, g_object_unref)
VALA_EXTERN gpointer xmpp_stanza_entry_ref (gpointer instance);
VALA_EXTERN void xmpp_stanza_entry_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_param_spec_stanza_entry (const gchar* name,
                                          const gchar* nick,
                                          const gchar* blurb,
                                          GType object_type,
                                          GParamFlags flags);
VALA_EXTERN void xmpp_value_set_stanza_entry (GValue* value,
                                  gpointer v_object);
VALA_EXTERN void xmpp_value_take_stanza_entry (GValue* value,
                                   gpointer v_object);
VALA_EXTERN gpointer xmpp_value_get_stanza_entry (const GValue* value);
VALA_EXTERN GType xmpp_stanza_entry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStanzaEntry, xmpp_stanza_entry_unref)
VALA_EXTERN GType xmpp_stanza_node_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStanzaNode, xmpp_stanza_entry_unref)
VALA_EXTERN gpointer xmpp_jid_ref (gpointer instance);
VALA_EXTERN void xmpp_jid_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_param_spec_jid (const gchar* name,
                                 const gchar* nick,
                                 const gchar* blurb,
                                 GType object_type,
                                 GParamFlags flags);
VALA_EXTERN void xmpp_value_set_jid (GValue* value,
                         gpointer v_object);
VALA_EXTERN void xmpp_value_take_jid (GValue* value,
                          gpointer v_object);
VALA_EXTERN gpointer xmpp_value_get_jid (const GValue* value);
VALA_EXTERN GType xmpp_jid_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppJid, xmpp_jid_unref)
VALA_EXTERN gpointer xmpp_xmpp_log_ref (gpointer instance);
VALA_EXTERN void xmpp_xmpp_log_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_param_spec_xmpp_log (const gchar* name,
                                      const gchar* nick,
                                      const gchar* blurb,
                                      GType object_type,
                                      GParamFlags flags);
VALA_EXTERN void xmpp_value_set_xmpp_log (GValue* value,
                              gpointer v_object);
VALA_EXTERN void xmpp_value_take_xmpp_log (GValue* value,
                               gpointer v_object);
VALA_EXTERN gpointer xmpp_value_get_xmpp_log (const GValue* value);
VALA_EXTERN GType xmpp_xmpp_log_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXmppLog, xmpp_xmpp_log_unref)
VALA_EXTERN GType xmpp_io_xmpp_stream_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppIoXmppStream, g_object_unref)
VALA_EXTERN gpointer xmpp_stanza_reader_ref (gpointer instance);
VALA_EXTERN void xmpp_stanza_reader_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_param_spec_stanza_reader (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
VALA_EXTERN void xmpp_value_set_stanza_reader (GValue* value,
                                   gpointer v_object);
VALA_EXTERN void xmpp_value_take_stanza_reader (GValue* value,
                                    gpointer v_object);
VALA_EXTERN gpointer xmpp_value_get_stanza_reader (const GValue* value);
VALA_EXTERN GType xmpp_stanza_reader_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStanzaReader, xmpp_stanza_reader_unref)
VALA_EXTERN gpointer xmpp_stanza_writer_ref (gpointer instance);
VALA_EXTERN void xmpp_stanza_writer_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_param_spec_stanza_writer (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
VALA_EXTERN void xmpp_value_set_stanza_writer (GValue* value,
                                   gpointer v_object);
VALA_EXTERN void xmpp_value_take_stanza_writer (GValue* value,
                                    gpointer v_object);
VALA_EXTERN gpointer xmpp_value_get_stanza_writer (const GValue* value);
VALA_EXTERN GType xmpp_stanza_writer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStanzaWriter, xmpp_stanza_writer_unref)
VALA_EXTERN GType xmpp_write_node_func_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppWriteNodeFunc, g_object_unref)
VALA_EXTERN GType xmpp_tls_xmpp_stream_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppTlsXmppStream, g_object_unref)
VALA_EXTERN GType xmpp_direct_tls_xmpp_stream_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppDirectTlsXmppStream, g_object_unref)
VALA_EXTERN gpointer xmpp_tls_xmpp_stream_on_invalid_cert_wrapper_ref (gpointer instance);
VALA_EXTERN void xmpp_tls_xmpp_stream_on_invalid_cert_wrapper_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_tls_xmpp_stream_param_spec_on_invalid_cert_wrapper (const gchar* name,
                                                                     const gchar* nick,
                                                                     const gchar* blurb,
                                                                     GType object_type,
                                                                     GParamFlags flags);
VALA_EXTERN void xmpp_tls_xmpp_stream_value_set_on_invalid_cert_wrapper (GValue* value,
                                                             gpointer v_object);
VALA_EXTERN void xmpp_tls_xmpp_stream_value_take_on_invalid_cert_wrapper (GValue* value,
                                                              gpointer v_object);
VALA_EXTERN gpointer xmpp_tls_xmpp_stream_value_get_on_invalid_cert_wrapper (const GValue* value);
VALA_EXTERN GType xmpp_tls_xmpp_stream_on_invalid_cert_wrapper_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppTlsXmppStreamOnInvalidCertWrapper, xmpp_tls_xmpp_stream_on_invalid_cert_wrapper_unref)
VALA_EXTERN XmppDirectTlsXmppStream* xmpp_direct_tls_xmpp_stream_new (XmppJid* remote_name,
                                                          const gchar* host,
                                                          guint16 port,
                                                          XmppTlsXmppStreamOnInvalidCertWrapper* on_invalid_cert);
VALA_EXTERN XmppDirectTlsXmppStream* xmpp_direct_tls_xmpp_stream_construct (GType object_type,
                                                                XmppJid* remote_name,
                                                                const gchar* host,
                                                                guint16 port,
                                                                XmppTlsXmppStreamOnInvalidCertWrapper* on_invalid_cert);
VALA_EXTERN void xmpp_write_node_func_write_stanza (XmppWriteNodeFunc* self,
                                        XmppXmppStream* stream,
                                        XmppStanzaNode* node,
                                        gint io_priority,
                                        GCancellable* cancellable,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_);
VALA_EXTERN void xmpp_write_node_func_write_stanza_finish (XmppWriteNodeFunc* self,
                                               GAsyncResult* _res_,
                                               GError** error);
VALA_EXTERN XmppIoXmppStream* xmpp_io_xmpp_stream_construct (GType object_type,
                                                 XmppJid* remote_name,
                                                 GCancellable* cancellable);
VALA_EXTERN void xmpp_io_xmpp_stream_cancel (XmppIoXmppStream* self);
VALA_EXTERN void xmpp_io_xmpp_stream_reset_stream (XmppIoXmppStream* self,
                                       GIOStream* stream);
VALA_EXTERN GType xmpp_flag_identity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppFlagIdentity, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_flag_identity_new (GType t_type,
                                          GBoxedCopyFunc t_dup_func,
                                          GDestroyNotify t_destroy_func,
                                          const gchar* ns,
                                          const gchar* id);
VALA_EXTERN XmppFlagIdentity* xmpp_flag_identity_construct (GType object_type,
                                                GType t_type,
                                                GBoxedCopyFunc t_dup_func,
                                                GDestroyNotify t_destroy_func,
                                                const gchar* ns,
                                                const gchar* id);
VALA_EXTERN GType xmpp_xmpp_stream_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXmppStreamFlag, g_object_unref)
VALA_EXTERN gpointer xmpp_flag_identity_cast (XmppFlagIdentity* self,
                                  XmppXmppStreamFlag* flag);
VALA_EXTERN gboolean xmpp_flag_identity_matches (XmppFlagIdentity* self,
                                     XmppXmppStreamFlag* module);
VALA_EXTERN const gchar* xmpp_flag_identity_get_ns (XmppFlagIdentity* self);
VALA_EXTERN const gchar* xmpp_flag_identity_get_id (XmppFlagIdentity* self);
VALA_EXTERN gchar* xmpp_xmpp_stream_flag_get_ns (XmppXmppStreamFlag* self);
VALA_EXTERN gchar* xmpp_xmpp_stream_flag_get_id (XmppXmppStreamFlag* self);
VALA_EXTERN XmppXmppStreamFlag* xmpp_xmpp_stream_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_module_identity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppModuleIdentity, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_module_identity_new (GType t_type,
                                              GBoxedCopyFunc t_dup_func,
                                              GDestroyNotify t_destroy_func,
                                              const gchar* ns,
                                              const gchar* id);
VALA_EXTERN XmppModuleIdentity* xmpp_module_identity_construct (GType object_type,
                                                    GType t_type,
                                                    GBoxedCopyFunc t_dup_func,
                                                    GDestroyNotify t_destroy_func,
                                                    const gchar* ns,
                                                    const gchar* id);
VALA_EXTERN GType xmpp_xmpp_stream_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXmppStreamModule, g_object_unref)
VALA_EXTERN gpointer xmpp_module_identity_cast (XmppModuleIdentity* self,
                                    XmppXmppStreamModule* module);
VALA_EXTERN gboolean xmpp_module_identity_matches (XmppModuleIdentity* self,
                                       XmppXmppStreamModule* module);
VALA_EXTERN const gchar* xmpp_module_identity_get_ns (XmppModuleIdentity* self);
VALA_EXTERN const gchar* xmpp_module_identity_get_id (XmppModuleIdentity* self);
VALA_EXTERN void xmpp_xmpp_stream_module_attach (XmppXmppStreamModule* self,
                                     XmppXmppStream* stream);
VALA_EXTERN void xmpp_xmpp_stream_module_detach (XmppXmppStreamModule* self,
                                     XmppXmppStream* stream);
VALA_EXTERN gchar* xmpp_xmpp_stream_module_get_ns (XmppXmppStreamModule* self);
VALA_EXTERN gchar* xmpp_xmpp_stream_module_get_id (XmppXmppStreamModule* self);
VALA_EXTERN XmppXmppStreamModule* xmpp_xmpp_stream_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xmpp_stream_negotiation_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXmppStreamNegotiationModule, g_object_unref)
VALA_EXTERN gboolean xmpp_xmpp_stream_negotiation_module_mandatory_outstanding (XmppXmppStreamNegotiationModule* self,
                                                                    XmppXmppStream* stream);
VALA_EXTERN gboolean xmpp_xmpp_stream_negotiation_module_negotiation_active (XmppXmppStreamNegotiationModule* self,
                                                                 XmppXmppStream* stream);
VALA_EXTERN XmppXmppStreamNegotiationModule* xmpp_xmpp_stream_negotiation_module_construct (GType object_type);
VALA_EXTERN gpointer xmpp_namespace_state_ref (gpointer instance);
VALA_EXTERN void xmpp_namespace_state_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_param_spec_namespace_state (const gchar* name,
                                             const gchar* nick,
                                             const gchar* blurb,
                                             GType object_type,
                                             GParamFlags flags);
VALA_EXTERN void xmpp_value_set_namespace_state (GValue* value,
                                     gpointer v_object);
VALA_EXTERN void xmpp_value_take_namespace_state (GValue* value,
                                      gpointer v_object);
VALA_EXTERN gpointer xmpp_value_get_namespace_state (const GValue* value);
VALA_EXTERN GType xmpp_namespace_state_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppNamespaceState, xmpp_namespace_state_unref)
VALA_EXTERN XmppNamespaceState* xmpp_namespace_state_new (void);
VALA_EXTERN XmppNamespaceState* xmpp_namespace_state_construct (GType object_type);
VALA_EXTERN XmppNamespaceState* xmpp_namespace_state_new_for_stanza (void);
VALA_EXTERN XmppNamespaceState* xmpp_namespace_state_construct_for_stanza (GType object_type);
VALA_EXTERN XmppNamespaceState* xmpp_namespace_state_new_with_assoc (XmppNamespaceState* old,
                                                         const gchar* ns_uri,
                                                         const gchar* name);
VALA_EXTERN XmppNamespaceState* xmpp_namespace_state_construct_with_assoc (GType object_type,
                                                               XmppNamespaceState* old,
                                                               const gchar* ns_uri,
                                                               const gchar* name);
VALA_EXTERN XmppNamespaceState* xmpp_namespace_state_new_with_current (XmppNamespaceState* old,
                                                           const gchar* current_ns_uri);
VALA_EXTERN XmppNamespaceState* xmpp_namespace_state_construct_with_current (GType object_type,
                                                                 XmppNamespaceState* old,
                                                                 const gchar* current_ns_uri);
VALA_EXTERN void xmpp_namespace_state_add_assoc (XmppNamespaceState* self,
                                     const gchar* ns_uri,
                                     const gchar* name);
VALA_EXTERN void xmpp_namespace_state_set_current (XmppNamespaceState* self,
                                       const gchar* current_ns_uri);
VALA_EXTERN gchar* xmpp_namespace_state_find_name (XmppNamespaceState* self,
                                       const gchar* ns_uri,
                                       GError** error);
VALA_EXTERN gchar* xmpp_namespace_state_find_uri (XmppNamespaceState* self,
                                      const gchar* name,
                                      GError** error);
VALA_EXTERN XmppNamespaceState* xmpp_namespace_state_push (XmppNamespaceState* self);
VALA_EXTERN XmppNamespaceState* xmpp_namespace_state_pop (XmppNamespaceState* self);
VALA_EXTERN gchar* xmpp_namespace_state_to_string (XmppNamespaceState* self);
VALA_EXTERN GType xmpp_stanza_attribute_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStanzaAttribute, xmpp_stanza_entry_unref)
VALA_EXTERN XmppStanzaAttribute* xmpp_stanza_attribute_new_build (const gchar* ns_uri,
                                                      const gchar* name,
                                                      const gchar* val);
VALA_EXTERN XmppStanzaAttribute* xmpp_stanza_attribute_construct_build (GType object_type,
                                                            const gchar* ns_uri,
                                                            const gchar* name,
                                                            const gchar* val);
VALA_EXTERN gboolean xmpp_stanza_attribute_equals (XmppStanzaAttribute* self,
                                       XmppStanzaAttribute* other);
VALA_EXTERN gchar* xmpp_stanza_attribute_to_ansi_string (XmppStanzaAttribute* self,
                                             gboolean hide_ns);
VALA_EXTERN gchar* xmpp_stanza_attribute_to_xml (XmppStanzaAttribute* self,
                                     XmppNamespaceState* state_);
VALA_EXTERN gchar* xmpp_stanza_attribute_to_ansi_xml (XmppStanzaAttribute* self,
                                          XmppNamespaceState* state_);
VALA_EXTERN const gchar* xmpp_stanza_entry_get_string_content (XmppStanzaEntry* self);
VALA_EXTERN gchar* xmpp_stanza_entry_to_string (XmppStanzaEntry* self,
                                    gint i);
VALA_EXTERN XmppStanzaEntry* xmpp_stanza_entry_construct (GType object_type);
VALA_EXTERN gchar* xmpp_stanza_entry_get_encoded_val (XmppStanzaEntry* self);
VALA_EXTERN void xmpp_stanza_entry_set_encoded_val (XmppStanzaEntry* self,
                                        const gchar* value);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_new_build (const gchar* name,
                                            const gchar* ns_uri,
                                            GeeArrayList* nodes,
                                            GeeArrayList* attrs);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_construct_build (GType object_type,
                                                  const gchar* name,
                                                  const gchar* ns_uri,
                                                  GeeArrayList* nodes,
                                                  GeeArrayList* attrs);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_new_text (const gchar* text);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_construct_text (GType object_type,
                                                 const gchar* text);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_new_encoded_text (const gchar* text);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_construct_encoded_text (GType object_type,
                                                         const gchar* text);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_add_self_xmlns (XmppStanzaNode* self);
VALA_EXTERN const gchar* xmpp_stanza_node_get_attribute (XmppStanzaNode* self,
                                             const gchar* name,
                                             const gchar* ns_uri);
VALA_EXTERN gint xmpp_stanza_node_get_attribute_int (XmppStanzaNode* self,
                                         const gchar* name,
                                         gint def,
                                         const gchar* ns_uri);
VALA_EXTERN guint xmpp_stanza_node_get_attribute_uint (XmppStanzaNode* self,
                                           const gchar* name,
                                           guint def,
                                           const gchar* ns_uri);
VALA_EXTERN gboolean xmpp_stanza_node_get_attribute_bool (XmppStanzaNode* self,
                                              const gchar* name,
                                              gboolean def,
                                              const gchar* ns_uri);
VALA_EXTERN XmppStanzaAttribute* xmpp_stanza_node_get_attribute_raw (XmppStanzaNode* self,
                                                         const gchar* name,
                                                         const gchar* ns_uri);
VALA_EXTERN GeeList* xmpp_stanza_node_get_attributes_by_ns_uri (XmppStanzaNode* self,
                                                    const gchar* ns_uri);
VALA_EXTERN const gchar* xmpp_stanza_node_get_deep_attribute (XmppStanzaNode* self,
                                                  ...);
VALA_EXTERN XmppStanzaAttribute* xmpp_stanza_node_get_deep_attribute_ (XmppStanzaNode* self,
                                                           va_list l);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_get_subnode (XmppStanzaNode* self,
                                              const gchar* name,
                                              const gchar* ns_uri,
                                              gboolean recurse);
VALA_EXTERN GeeList* xmpp_stanza_node_get_subnodes (XmppStanzaNode* self,
                                        const gchar* name,
                                        const gchar* ns_uri,
                                        gboolean recurse);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_get_deep_subnode (XmppStanzaNode* self,
                                                   ...);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_get_deep_subnode_ (XmppStanzaNode* self,
                                                    va_list l);
VALA_EXTERN GeeList* xmpp_stanza_node_get_deep_subnodes (XmppStanzaNode* self,
                                             ...);
VALA_EXTERN GeeList* xmpp_stanza_node_get_deep_subnodes_ (XmppStanzaNode* self,
                                              va_list l);
VALA_EXTERN GeeList* xmpp_stanza_node_get_all_subnodes (XmppStanzaNode* self);
VALA_EXTERN GeeList* xmpp_stanza_node_get_deep_all_subnodes (XmppStanzaNode* self,
                                                 ...);
VALA_EXTERN void xmpp_stanza_node_add_attribute (XmppStanzaNode* self,
                                     XmppStanzaAttribute* attr);
VALA_EXTERN const gchar* xmpp_stanza_node_get_deep_string_content (XmppStanzaNode* self,
                                                       ...);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_put_attribute (XmppStanzaNode* self,
                                                const gchar* name,
                                                const gchar* val,
                                                const gchar* ns_uri);
VALA_EXTERN void xmpp_stanza_node_set_attribute (XmppStanzaNode* self,
                                     const gchar* name,
                                     const gchar* val,
                                     const gchar* ns_uri);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_node_put_node (XmppStanzaNode* self,
                                           XmppStanzaNode* node);
VALA_EXTERN gboolean xmpp_stanza_node_equals (XmppStanzaNode* self,
                                  XmppStanzaNode* other);
VALA_EXTERN gchar* xmpp_stanza_node_to_ansi_string (XmppStanzaNode* self,
                                        gboolean hide_ns,
                                        gint i);
VALA_EXTERN gchar* xmpp_stanza_node_to_xml (XmppStanzaNode* self,
                                XmppNamespaceState* state,
                                GError** error);
VALA_EXTERN XmppStanzaReader* xmpp_stanza_reader_new_for_buffer (guint8* buffer,
                                                     gint buffer_length1);
VALA_EXTERN XmppStanzaReader* xmpp_stanza_reader_construct_for_buffer (GType object_type,
                                                           guint8* buffer,
                                                           gint buffer_length1);
VALA_EXTERN XmppStanzaReader* xmpp_stanza_reader_new_for_string (const gchar* s);
VALA_EXTERN XmppStanzaReader* xmpp_stanza_reader_construct_for_string (GType object_type,
                                                           const gchar* s);
VALA_EXTERN XmppStanzaReader* xmpp_stanza_reader_new_for_stream (GInputStream* input,
                                                     GCancellable* cancellable);
VALA_EXTERN XmppStanzaReader* xmpp_stanza_reader_construct_for_stream (GType object_type,
                                                           GInputStream* input,
                                                           GCancellable* cancellable);
VALA_EXTERN void xmpp_stanza_reader_read_node_start (XmppStanzaReader* self,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_reader_read_node_start_finish (XmppStanzaReader* self,
                                                           GAsyncResult* _res_,
                                                           GError** error);
VALA_EXTERN void xmpp_stanza_reader_read_text_node (XmppStanzaReader* self,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_reader_read_text_node_finish (XmppStanzaReader* self,
                                                          GAsyncResult* _res_,
                                                          GError** error);
VALA_EXTERN void xmpp_stanza_reader_read_root_node (XmppStanzaReader* self,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_reader_read_root_node_finish (XmppStanzaReader* self,
                                                          GAsyncResult* _res_,
                                                          GError** error);
VALA_EXTERN void xmpp_stanza_reader_read_stanza_node (XmppStanzaReader* self,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_reader_read_stanza_node_finish (XmppStanzaReader* self,
                                                            GAsyncResult* _res_,
                                                            GError** error);
VALA_EXTERN void xmpp_stanza_reader_read_node (XmppStanzaReader* self,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
VALA_EXTERN XmppStanzaNode* xmpp_stanza_reader_read_node_finish (XmppStanzaReader* self,
                                                     GAsyncResult* _res_,
                                                     GError** error);
VALA_EXTERN XmppStanzaReader* xmpp_stanza_reader_new (void);
VALA_EXTERN XmppStanzaReader* xmpp_stanza_reader_construct (GType object_type);
VALA_EXTERN XmppStanzaWriter* xmpp_stanza_writer_new_for_stream (GOutputStream* output,
                                                     GCancellable* cancellable);
VALA_EXTERN XmppStanzaWriter* xmpp_stanza_writer_construct_for_stream (GType object_type,
                                                           GOutputStream* output,
                                                           GCancellable* cancellable);
VALA_EXTERN void xmpp_stanza_writer_write_node (XmppStanzaWriter* self,
                                    XmppStanzaNode* node,
                                    gint io_priority,
                                    GCancellable* cancellable,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN void xmpp_stanza_writer_write_node_finish (XmppStanzaWriter* self,
                                           GAsyncResult* _res_,
                                           GError** error);
VALA_EXTERN void xmpp_stanza_writer_write_nodes (XmppStanzaWriter* self,
                                     XmppStanzaNode* node1,
                                     XmppStanzaNode* node2,
                                     gint io_priority,
                                     GCancellable* cancellable,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
VALA_EXTERN void xmpp_stanza_writer_write_nodes_finish (XmppStanzaWriter* self,
                                            GAsyncResult* _res_,
                                            GError** error);
VALA_EXTERN void xmpp_stanza_writer_write (XmppStanzaWriter* self,
                               const gchar* s,
                               gint io_priority,
                               GCancellable* cancellable,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
VALA_EXTERN void xmpp_stanza_writer_write_finish (XmppStanzaWriter* self,
                                      GAsyncResult* _res_,
                                      GError** error);
VALA_EXTERN XmppStanzaWriter* xmpp_stanza_writer_new (void);
VALA_EXTERN XmppStanzaWriter* xmpp_stanza_writer_construct (GType object_type);
VALA_EXTERN GType xmpp_source_func_wrapper_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppSourceFuncWrapper, g_object_unref)
VALA_EXTERN XmppSourceFuncWrapper* xmpp_source_func_wrapper_new (GSourceFunc sfun,
                                                     gpointer sfun_target,
                                                     GDestroyNotify sfun_target_destroy_notify);
VALA_EXTERN XmppSourceFuncWrapper* xmpp_source_func_wrapper_construct (GType object_type,
                                                           GSourceFunc sfun,
                                                           gpointer sfun_target,
                                                           GDestroyNotify sfun_target_destroy_notify);
VALA_EXTERN GType xmpp_start_tls_xmpp_stream_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStartTlsXmppStream, g_object_unref)
VALA_EXTERN XmppStartTlsXmppStream* xmpp_start_tls_xmpp_stream_new (XmppJid* remote,
                                                        const gchar* host,
                                                        guint16 port,
                                                        XmppTlsXmppStreamOnInvalidCertWrapper* on_invalid_cert);
VALA_EXTERN XmppStartTlsXmppStream* xmpp_start_tls_xmpp_stream_construct (GType object_type,
                                                              XmppJid* remote,
                                                              const gchar* host,
                                                              guint16 port,
                                                              XmppTlsXmppStreamOnInvalidCertWrapper* on_invalid_cert);
VALA_EXTERN gpointer xmpp_xmpp_stream_result_ref (gpointer instance);
VALA_EXTERN void xmpp_xmpp_stream_result_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_param_spec_xmpp_stream_result (const gchar* name,
                                                const gchar* nick,
                                                const gchar* blurb,
                                                GType object_type,
                                                GParamFlags flags);
VALA_EXTERN void xmpp_value_set_xmpp_stream_result (GValue* value,
                                        gpointer v_object);
VALA_EXTERN void xmpp_value_take_xmpp_stream_result (GValue* value,
                                         gpointer v_object);
VALA_EXTERN gpointer xmpp_value_get_xmpp_stream_result (const GValue* value);
VALA_EXTERN GType xmpp_xmpp_stream_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXmppStreamResult, xmpp_xmpp_stream_result_unref)
VALA_EXTERN XmppXmppStreamResult* xmpp_xmpp_stream_result_new (void);
VALA_EXTERN XmppXmppStreamResult* xmpp_xmpp_stream_result_construct (GType object_type);
VALA_EXTERN XmppTlsXmppStream* xmpp_xmpp_stream_result_get_stream (XmppXmppStreamResult* self);
VALA_EXTERN void xmpp_xmpp_stream_result_set_stream (XmppXmppStreamResult* self,
                                         XmppTlsXmppStream* value);
VALA_EXTERN GTlsCertificateFlags* xmpp_xmpp_stream_result_get_tls_errors (XmppXmppStreamResult* self);
VALA_EXTERN void xmpp_xmpp_stream_result_set_tls_errors (XmppXmppStreamResult* self,
                                             GTlsCertificateFlags* value);
VALA_EXTERN GError* xmpp_xmpp_stream_result_get_io_error (XmppXmppStreamResult* self);
VALA_EXTERN void xmpp_xmpp_stream_result_set_io_error (XmppXmppStreamResult* self,
                                           GError* value);
VALA_EXTERN void xmpp_establish_stream (XmppJid* bare_jid,
                            GeeList* modules,
                            const gchar* log_options,
                            XmppTlsXmppStreamOnInvalidCert on_invalid_cert,
                            gpointer on_invalid_cert_target,
                            GDestroyNotify on_invalid_cert_target_destroy_notify,
                            GAsyncReadyCallback _callback_,
                            gpointer _user_data_);
VALA_EXTERN XmppXmppStreamResult* xmpp_establish_stream_finish (GAsyncResult* _res_);
VALA_EXTERN XmppTlsXmppStream* xmpp_tls_xmpp_stream_construct (GType object_type,
                                                   XmppJid* remote_name);
VALA_EXTERN gboolean xmpp_tls_xmpp_stream_on_invalid_certificate (XmppTlsXmppStream* self,
                                                      GTlsCertificate* peer_cert,
                                                      GTlsCertificateFlags errors);
VALA_EXTERN XmppTlsXmppStreamOnInvalidCertWrapper* xmpp_tls_xmpp_stream_on_invalid_cert_wrapper_new (XmppTlsXmppStreamOnInvalidCert func,
                                                                                         gpointer func_target,
                                                                                         GDestroyNotify func_target_destroy_notify);
VALA_EXTERN XmppTlsXmppStreamOnInvalidCertWrapper* xmpp_tls_xmpp_stream_on_invalid_cert_wrapper_construct (GType object_type,
                                                                                               XmppTlsXmppStreamOnInvalidCert func,
                                                                                               gpointer func_target,
                                                                                               GDestroyNotify func_target_destroy_notify);
VALA_EXTERN XmppXmppLog* xmpp_xmpp_log_new (const gchar* ident,
                                const gchar* desc);
VALA_EXTERN XmppXmppLog* xmpp_xmpp_log_construct (GType object_type,
                                      const gchar* ident,
                                      const gchar* desc);
VALA_EXTERN gboolean xmpp_xmpp_log_should_log_node (XmppXmppLog* self,
                                        XmppStanzaNode* node);
VALA_EXTERN gboolean xmpp_xmpp_log_should_log_str (XmppXmppLog* self,
                                       const gchar* str);
VALA_EXTERN void xmpp_xmpp_log_node (XmppXmppLog* self,
                         const gchar* what,
                         XmppStanzaNode* node,
                         XmppXmppStream* stream);
VALA_EXTERN void xmpp_xmpp_log_str (XmppXmppLog* self,
                        const gchar* what,
                        const gchar* str,
                        XmppXmppStream* stream);
VALA_EXTERN XmppXmppStream* xmpp_xmpp_stream_construct (GType object_type,
                                            XmppJid* remote_name);
VALA_EXTERN void xmpp_xmpp_stream_connect (XmppXmppStream* self,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
VALA_EXTERN void xmpp_xmpp_stream_connect_finish (XmppXmppStream* self,
                                      GAsyncResult* _res_,
                                      GError** error);
VALA_EXTERN void xmpp_xmpp_stream_disconnect (XmppXmppStream* self,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_);
VALA_EXTERN void xmpp_xmpp_stream_disconnect_finish (XmppXmppStream* self,
                                         GAsyncResult* _res_,
                                         GError** error);
VALA_EXTERN void xmpp_xmpp_stream_read (XmppXmppStream* self,
                            GAsyncReadyCallback _callback_,
                            gpointer _user_data_);
VALA_EXTERN XmppStanzaNode* xmpp_xmpp_stream_read_finish (XmppXmppStream* self,
                                              GAsyncResult* _res_,
                                              GError** error);
VALA_EXTERN void xmpp_xmpp_stream_write (XmppXmppStream* self,
                             XmppStanzaNode* node,
                             gint io_priority) G_GNUC_DEPRECATED ;
VALA_EXTERN void xmpp_xmpp_stream_write_async (XmppXmppStream* self,
                                   XmppStanzaNode* node,
                                   gint io_priority,
                                   GCancellable* cancellable,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
VALA_EXTERN void xmpp_xmpp_stream_write_finish (XmppXmppStream* self,
                                    GAsyncResult* _res_,
                                    GError** error);
VALA_EXTERN void xmpp_xmpp_stream_setup (XmppXmppStream* self,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_);
VALA_EXTERN void xmpp_xmpp_stream_setup_finish (XmppXmppStream* self,
                                    GAsyncResult* _res_,
                                    GError** error);
VALA_EXTERN void xmpp_xmpp_stream_require_setup (XmppXmppStream* self);
VALA_EXTERN gboolean xmpp_xmpp_stream_is_setup_needed (XmppXmppStream* self);
VALA_EXTERN void xmpp_xmpp_stream_add_flag (XmppXmppStream* self,
                                XmppXmppStreamFlag* flag);
VALA_EXTERN gboolean xmpp_xmpp_stream_has_flag (XmppXmppStream* self,
                                    GType t_type,
                                    GBoxedCopyFunc t_dup_func,
                                    GDestroyNotify t_destroy_func,
                                    XmppFlagIdentity* identity);
VALA_EXTERN gpointer xmpp_xmpp_stream_get_flag (XmppXmppStream* self,
                                    GType t_type,
                                    GBoxedCopyFunc t_dup_func,
                                    GDestroyNotify t_destroy_func,
                                    XmppFlagIdentity* identity);
VALA_EXTERN void xmpp_xmpp_stream_remove_flag (XmppXmppStream* self,
                                   XmppXmppStreamFlag* flag);
VALA_EXTERN XmppXmppStream* xmpp_xmpp_stream_add_module (XmppXmppStream* self,
                                             XmppXmppStreamModule* module);
VALA_EXTERN void xmpp_xmpp_stream_detach_modules (XmppXmppStream* self);
VALA_EXTERN gpointer xmpp_xmpp_stream_get_module (XmppXmppStream* self,
                                      GType t_type,
                                      GBoxedCopyFunc t_dup_func,
                                      GDestroyNotify t_destroy_func,
                                      XmppModuleIdentity* identity);
VALA_EXTERN void xmpp_xmpp_stream_loop (XmppXmppStream* self,
                            GAsyncReadyCallback _callback_,
                            gpointer _user_data_);
VALA_EXTERN void xmpp_xmpp_stream_loop_finish (XmppXmppStream* self,
                                   GAsyncResult* _res_,
                                   GError** error);
VALA_EXTERN gboolean xmpp_xmpp_stream_is_negotiation_active (XmppXmppStream* self);
VALA_EXTERN void xmpp_xmpp_stream_attach_negotation_modules (XmppXmppStream* self);
VALA_EXTERN GeeList* xmpp_xmpp_stream_get_flags (XmppXmppStream* self);
VALA_EXTERN GeeList* xmpp_xmpp_stream_get_modules (XmppXmppStream* self);
VALA_EXTERN XmppStanzaNode* xmpp_xmpp_stream_get_features (XmppXmppStream* self);
VALA_EXTERN gboolean xmpp_xmpp_stream_get_negotiation_complete (XmppXmppStream* self);
VALA_EXTERN void xmpp_xmpp_stream_set_negotiation_complete (XmppXmppStream* self,
                                                gboolean value);
VALA_EXTERN GType xmpp_bind_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppBindModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_bind_module_IDENTITY;
VALA_EXTERN XmppBindModule* xmpp_bind_module_new (const gchar* requested_resource);
VALA_EXTERN XmppBindModule* xmpp_bind_module_construct (GType object_type,
                                            const gchar* requested_resource);
VALA_EXTERN GType xmpp_stanza_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStanza, g_object_unref)
VALA_EXTERN GType xmpp_iq_stanza_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppIqStanza, g_object_unref)
VALA_EXTERN void xmpp_bind_module_iq_response_stanza (XmppBindModule* self,
                                          XmppXmppStream* stream,
                                          XmppIqStanza* iq);
VALA_EXTERN void xmpp_bind_module_received_features_node (XmppBindModule* self,
                                              XmppXmppStream* stream);
VALA_EXTERN const gchar* xmpp_bind_module_get_requested_resource (XmppBindModule* self);
VALA_EXTERN void xmpp_bind_module_set_requested_resource (XmppBindModule* self,
                                              const gchar* value);
VALA_EXTERN GType xmpp_bind_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppBindFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_bind_flag_IDENTITY;
VALA_EXTERN XmppJid* xmpp_bind_flag_get_my_jid (XmppXmppStream* stream);
VALA_EXTERN XmppBindFlag* xmpp_bind_flag_new (void);
VALA_EXTERN XmppBindFlag* xmpp_bind_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_conference_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppConference, g_object_unref)
VALA_EXTERN GType xmpp_bookmarks_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppBookmarksProvider, g_object_unref)
VALA_EXTERN void xmpp_bookmarks_provider_get_conferences (XmppBookmarksProvider* self,
                                              XmppXmppStream* stream,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
VALA_EXTERN GeeSet* xmpp_bookmarks_provider_get_conferences_finish (XmppBookmarksProvider* self,
                                                        GAsyncResult* _res_);
VALA_EXTERN void xmpp_bookmarks_provider_add_conference (XmppBookmarksProvider* self,
                                             XmppXmppStream* stream,
                                             XmppConference* conference,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
VALA_EXTERN void xmpp_bookmarks_provider_add_conference_finish (XmppBookmarksProvider* self,
                                                    GAsyncResult* _res_);
VALA_EXTERN void xmpp_bookmarks_provider_remove_conference (XmppBookmarksProvider* self,
                                                XmppXmppStream* stream,
                                                XmppConference* conference,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
VALA_EXTERN void xmpp_bookmarks_provider_remove_conference_finish (XmppBookmarksProvider* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN void xmpp_bookmarks_provider_replace_conference (XmppBookmarksProvider* self,
                                                 XmppXmppStream* stream,
                                                 XmppJid* muc_jid,
                                                 XmppConference* modified_conference,
                                                 GAsyncReadyCallback _callback_,
                                                 gpointer _user_data_);
VALA_EXTERN void xmpp_bookmarks_provider_replace_conference_finish (XmppBookmarksProvider* self,
                                                        GAsyncResult* _res_);
VALA_EXTERN gboolean xmpp_conference_equals (XmppConference* self,
                                 XmppConference* c);
VALA_EXTERN gboolean xmpp_conference_equals_func (XmppConference* a,
                                      XmppConference* b);
VALA_EXTERN guint xmpp_conference_hash_func (XmppConference* a);
VALA_EXTERN XmppConference* xmpp_conference_new (void);
VALA_EXTERN XmppConference* xmpp_conference_construct (GType object_type);
VALA_EXTERN XmppJid* xmpp_conference_get_jid (XmppConference* self);
VALA_EXTERN void xmpp_conference_set_jid (XmppConference* self,
                              XmppJid* value);
VALA_EXTERN gboolean xmpp_conference_get_autojoin (XmppConference* self);
VALA_EXTERN void xmpp_conference_set_autojoin (XmppConference* self,
                                   gboolean value);
VALA_EXTERN const gchar* xmpp_conference_get_nick (XmppConference* self);
VALA_EXTERN void xmpp_conference_set_nick (XmppConference* self,
                               const gchar* value);
VALA_EXTERN const gchar* xmpp_conference_get_name (XmppConference* self);
VALA_EXTERN void xmpp_conference_set_name (XmppConference* self,
                               const gchar* value);
VALA_EXTERN const gchar* xmpp_conference_get_password (XmppConference* self);
VALA_EXTERN void xmpp_conference_set_password (XmppConference* self,
                                   const gchar* value);
VALA_EXTERN GType xmpp_iq_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppIqModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_iq_module_IDENTITY;
VALA_EXTERN void xmpp_iq_module_send_iq_async (XmppIqModule* self,
                                   XmppXmppStream* stream,
                                   XmppIqStanza* iq,
                                   gint io_priority,
                                   GCancellable* cancellable,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
VALA_EXTERN XmppIqStanza* xmpp_iq_module_send_iq_finish (XmppIqModule* self,
                                             GAsyncResult* _res_,
                                             GError** error);
VALA_EXTERN void xmpp_iq_module_send_iq (XmppIqModule* self,
                             XmppXmppStream* stream,
                             XmppIqStanza* iq,
                             XmppIqModuleOnResult listener,
                             gpointer listener_target,
                             GDestroyNotify listener_target_destroy_notify,
                             gint io_priority);
VALA_EXTERN GType xmpp_iq_handler_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppIqHandler, g_object_unref)
VALA_EXTERN void xmpp_iq_module_register_for_namespace (XmppIqModule* self,
                                            const gchar* namespace,
                                            XmppIqHandler* module);
VALA_EXTERN void xmpp_iq_module_unregister_from_namespace (XmppIqModule* self,
                                               const gchar* namespace,
                                               XmppIqHandler* module);
VALA_EXTERN XmppIqModule* xmpp_iq_module_new (void);
VALA_EXTERN XmppIqModule* xmpp_iq_module_construct (GType object_type);
VALA_EXTERN void xmpp_iq_handler_on_iq_get (XmppIqHandler* self,
                                XmppXmppStream* stream,
                                XmppIqStanza* iq,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN void xmpp_iq_handler_on_iq_get_finish (XmppIqHandler* self,
                                       GAsyncResult* _res_);
VALA_EXTERN void xmpp_iq_handler_on_iq_set (XmppIqHandler* self,
                                XmppXmppStream* stream,
                                XmppIqStanza* iq,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN void xmpp_iq_handler_on_iq_set_finish (XmppIqHandler* self,
                                       GAsyncResult* _res_);
VALA_EXTERN XmppIqStanza* xmpp_iq_stanza_new_get (XmppStanzaNode* stanza_node,
                                      const gchar* id);
VALA_EXTERN XmppIqStanza* xmpp_iq_stanza_construct_get (GType object_type,
                                            XmppStanzaNode* stanza_node,
                                            const gchar* id);
VALA_EXTERN XmppIqStanza* xmpp_iq_stanza_new_result (XmppIqStanza* request,
                                         XmppStanzaNode* stanza_node);
VALA_EXTERN XmppIqStanza* xmpp_iq_stanza_construct_result (GType object_type,
                                               XmppIqStanza* request,
                                               XmppStanzaNode* stanza_node);
VALA_EXTERN XmppIqStanza* xmpp_iq_stanza_new_set (XmppStanzaNode* stanza_node,
                                      const gchar* id);
VALA_EXTERN XmppIqStanza* xmpp_iq_stanza_construct_set (GType object_type,
                                            XmppStanzaNode* stanza_node,
                                            const gchar* id);
VALA_EXTERN gpointer xmpp_error_stanza_ref (gpointer instance);
VALA_EXTERN void xmpp_error_stanza_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_param_spec_error_stanza (const gchar* name,
                                          const gchar* nick,
                                          const gchar* blurb,
                                          GType object_type,
                                          GParamFlags flags);
VALA_EXTERN void xmpp_value_set_error_stanza (GValue* value,
                                  gpointer v_object);
VALA_EXTERN void xmpp_value_take_error_stanza (GValue* value,
                                   gpointer v_object);
VALA_EXTERN gpointer xmpp_value_get_error_stanza (const GValue* value);
VALA_EXTERN GType xmpp_error_stanza_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppErrorStanza, xmpp_error_stanza_unref)
VALA_EXTERN XmppIqStanza* xmpp_iq_stanza_new_error (XmppIqStanza* request,
                                        XmppErrorStanza* error_stanza);
VALA_EXTERN XmppIqStanza* xmpp_iq_stanza_construct_error (GType object_type,
                                              XmppIqStanza* request,
                                              XmppErrorStanza* error_stanza);
VALA_EXTERN XmppIqStanza* xmpp_iq_stanza_new_from_stanza (XmppStanzaNode* stanza_node,
                                              XmppJid* my_jid);
VALA_EXTERN XmppIqStanza* xmpp_iq_stanza_construct_from_stanza (GType object_type,
                                                    XmppStanzaNode* stanza_node,
                                                    XmppJid* my_jid);
VALA_EXTERN GQuark xmpp_invalid_jid_error_quark (void);
VALA_EXTERN GType xmpp_invalid_jid_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppJid* xmpp_jid_new (const gchar* jid,
                       GError** error);
VALA_EXTERN XmppJid* xmpp_jid_construct (GType object_type,
                             const gchar* jid,
                             GError** error);
VALA_EXTERN XmppJid* xmpp_jid_new_components (const gchar* localpart,
                                  const gchar* domainpart,
                                  const gchar* resourcepart,
                                  GError** error);
VALA_EXTERN XmppJid* xmpp_jid_construct_components (GType object_type,
                                        const gchar* localpart,
                                        const gchar* domainpart,
                                        const gchar* resourcepart,
                                        GError** error);
VALA_EXTERN XmppJid* xmpp_jid_with_resource (XmppJid* self,
                                 const gchar* resourcepart,
                                 GError** error);
VALA_EXTERN gboolean xmpp_jid_is_domain (XmppJid* self);
VALA_EXTERN gboolean xmpp_jid_is_bare (XmppJid* self);
VALA_EXTERN gboolean xmpp_jid_is_full (XmppJid* self);
VALA_EXTERN gchar* xmpp_jid_to_string (XmppJid* self);
VALA_EXTERN gboolean xmpp_jid_equals_bare (XmppJid* self,
                               XmppJid* jid);
VALA_EXTERN gboolean xmpp_jid_equals (XmppJid* self,
                          XmppJid* jid);
VALA_EXTERN gboolean xmpp_jid_equals_bare_func (XmppJid* jid1,
                                    XmppJid* jid2);
VALA_EXTERN gboolean xmpp_jid_equals_func (XmppJid* jid1,
                               XmppJid* jid2);
VALA_EXTERN guint xmpp_jid_hash_bare_func (XmppJid* jid);
VALA_EXTERN guint xmpp_jid_hash_func (XmppJid* jid);
VALA_EXTERN XmppJid* xmpp_jid_get_bare_jid (XmppJid* self);
VALA_EXTERN XmppJid* xmpp_jid_get_domain_jid (XmppJid* self);
VALA_EXTERN GType xmpp_message_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppMessageModule, g_object_unref)
VALA_EXTERN GType xmpp_listener_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppListenerHolder, g_object_unref)
VALA_EXTERN GType xmpp_stanza_listener_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStanzaListenerHolder, g_object_unref)
VALA_EXTERN GType xmpp_message_stanza_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppMessageStanza, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_message_module_IDENTITY;
VALA_EXTERN void xmpp_message_module_send_message (XmppMessageModule* self,
                                       XmppXmppStream* stream,
                                       XmppMessageStanza* message,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN void xmpp_message_module_send_message_finish (XmppMessageModule* self,
                                              GAsyncResult* _res_,
                                              GError** error);
VALA_EXTERN void xmpp_message_module_received_message_stanza_async (XmppMessageModule* self,
                                                        XmppXmppStream* stream,
                                                        XmppStanzaNode* node,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
VALA_EXTERN void xmpp_message_module_received_message_stanza_finish (XmppMessageModule* self,
                                                         GAsyncResult* _res_);
VALA_EXTERN XmppMessageModule* xmpp_message_module_new (void);
VALA_EXTERN XmppMessageModule* xmpp_message_module_construct (GType object_type);
VALA_EXTERN XmppMessageStanza* xmpp_message_stanza_new (const gchar* id);
VALA_EXTERN XmppMessageStanza* xmpp_message_stanza_construct (GType object_type,
                                                  const gchar* id);
VALA_EXTERN XmppMessageStanza* xmpp_message_stanza_new_from_stanza (XmppStanzaNode* stanza_node,
                                                        XmppJid* my_jid);
VALA_EXTERN XmppMessageStanza* xmpp_message_stanza_construct_from_stanza (GType object_type,
                                                              XmppStanzaNode* stanza_node,
                                                              XmppJid* my_jid);
VALA_EXTERN GType xmpp_message_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppMessageFlag, g_object_unref)
VALA_EXTERN void xmpp_message_stanza_add_flag (XmppMessageStanza* self,
                                   XmppMessageFlag* flag);
VALA_EXTERN XmppMessageFlag* xmpp_message_stanza_get_flag (XmppMessageStanza* self,
                                               const gchar* ns,
                                               const gchar* id);
VALA_EXTERN const gchar* xmpp_message_stanza_get_body (XmppMessageStanza* self);
VALA_EXTERN void xmpp_message_stanza_set_body (XmppMessageStanza* self,
                                   const gchar* value);
VALA_EXTERN gchar* xmpp_message_flag_get_ns (XmppMessageFlag* self);
VALA_EXTERN gchar* xmpp_message_flag_get_id (XmppMessageFlag* self);
VALA_EXTERN XmppMessageFlag* xmpp_message_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_presence_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppPresenceFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_presence_flag_IDENTITY;
VALA_EXTERN GeeSet* xmpp_presence_flag_get_available_jids (XmppPresenceFlag* self);
VALA_EXTERN GeeList* xmpp_presence_flag_get_resources (XmppPresenceFlag* self,
                                           XmppJid* jid);
VALA_EXTERN GType xmpp_presence_stanza_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppPresenceStanza, g_object_unref)
VALA_EXTERN XmppPresenceStanza* xmpp_presence_flag_get_presence (XmppPresenceFlag* self,
                                                     XmppJid* full_jid);
VALA_EXTERN GeeList* xmpp_presence_flag_get_presences (XmppPresenceFlag* self,
                                           XmppJid* jid);
VALA_EXTERN void xmpp_presence_flag_add_presence (XmppPresenceFlag* self,
                                      XmppPresenceStanza* presence);
VALA_EXTERN void xmpp_presence_flag_remove_presence (XmppPresenceFlag* self,
                                         XmppJid* jid);
VALA_EXTERN XmppPresenceFlag* xmpp_presence_flag_new (void);
VALA_EXTERN XmppPresenceFlag* xmpp_presence_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_presence_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppPresenceModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_presence_module_IDENTITY;
VALA_EXTERN void xmpp_presence_module_request_subscription (XmppPresenceModule* self,
                                                XmppXmppStream* stream,
                                                XmppJid* bare_jid);
VALA_EXTERN void xmpp_presence_module_approve_subscription (XmppPresenceModule* self,
                                                XmppXmppStream* stream,
                                                XmppJid* bare_jid);
VALA_EXTERN void xmpp_presence_module_deny_subscription (XmppPresenceModule* self,
                                             XmppXmppStream* stream,
                                             XmppJid* bare_jid);
VALA_EXTERN void xmpp_presence_module_cancel_subscription (XmppPresenceModule* self,
                                               XmppXmppStream* stream,
                                               XmppJid* bare_jid);
VALA_EXTERN void xmpp_presence_module_unsubscribe (XmppPresenceModule* self,
                                       XmppXmppStream* stream,
                                       XmppJid* bare_jid);
VALA_EXTERN void xmpp_presence_module_send_presence (XmppPresenceModule* self,
                                         XmppXmppStream* stream,
                                         XmppPresenceStanza* presence);
VALA_EXTERN XmppPresenceModule* xmpp_presence_module_new (void);
VALA_EXTERN XmppPresenceModule* xmpp_presence_module_construct (GType object_type);
VALA_EXTERN XmppPresenceStanza* xmpp_presence_stanza_new (const gchar* id);
VALA_EXTERN XmppPresenceStanza* xmpp_presence_stanza_construct (GType object_type,
                                                    const gchar* id);
VALA_EXTERN XmppPresenceStanza* xmpp_presence_stanza_new_from_stanza (XmppStanzaNode* stanza_node,
                                                          XmppJid* my_jid);
VALA_EXTERN XmppPresenceStanza* xmpp_presence_stanza_construct_from_stanza (GType object_type,
                                                                XmppStanzaNode* stanza_node,
                                                                XmppJid* my_jid);
VALA_EXTERN gint xmpp_presence_stanza_get_priority (XmppPresenceStanza* self);
VALA_EXTERN void xmpp_presence_stanza_set_priority (XmppPresenceStanza* self,
                                        gint value);
VALA_EXTERN const gchar* xmpp_presence_stanza_get_status (XmppPresenceStanza* self);
VALA_EXTERN void xmpp_presence_stanza_set_status (XmppPresenceStanza* self,
                                      const gchar* value);
VALA_EXTERN const gchar* xmpp_presence_stanza_get_show (XmppPresenceStanza* self);
VALA_EXTERN void xmpp_presence_stanza_set_show (XmppPresenceStanza* self,
                                    const gchar* value);
VALA_EXTERN GType xmpp_roster_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppRosterFlag, g_object_unref)
VALA_EXTERN gpointer xmpp_roster_item_ref (gpointer instance);
VALA_EXTERN void xmpp_roster_item_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_roster_param_spec_item (const gchar* name,
                                         const gchar* nick,
                                         const gchar* blurb,
                                         GType object_type,
                                         GParamFlags flags);
VALA_EXTERN void xmpp_roster_value_set_item (GValue* value,
                                 gpointer v_object);
VALA_EXTERN void xmpp_roster_value_take_item (GValue* value,
                                  gpointer v_object);
VALA_EXTERN gpointer xmpp_roster_value_get_item (const GValue* value);
VALA_EXTERN GType xmpp_roster_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppRosterItem, xmpp_roster_item_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_roster_flag_IDENTITY;
VALA_EXTERN GeeCollection* xmpp_roster_flag_get_roster (XmppRosterFlag* self);
VALA_EXTERN XmppRosterItem* xmpp_roster_flag_get_item (XmppRosterFlag* self,
                                           XmppJid* jid);
VALA_EXTERN XmppRosterFlag* xmpp_roster_flag_new (void);
VALA_EXTERN XmppRosterFlag* xmpp_roster_flag_construct (GType object_type);
VALA_EXTERN XmppRosterItem* xmpp_roster_item_new (void);
VALA_EXTERN XmppRosterItem* xmpp_roster_item_construct (GType object_type);
VALA_EXTERN XmppRosterItem* xmpp_roster_item_new_from_stanza_node (XmppStanzaNode* stanza_node);
VALA_EXTERN XmppRosterItem* xmpp_roster_item_construct_from_stanza_node (GType object_type,
                                                             XmppStanzaNode* stanza_node);
VALA_EXTERN XmppJid* xmpp_roster_item_get_jid (XmppRosterItem* self);
VALA_EXTERN void xmpp_roster_item_set_jid (XmppRosterItem* self,
                               XmppJid* value);
VALA_EXTERN const gchar* xmpp_roster_item_get_name (XmppRosterItem* self);
VALA_EXTERN void xmpp_roster_item_set_name (XmppRosterItem* self,
                                const gchar* value);
VALA_EXTERN const gchar* xmpp_roster_item_get_subscription (XmppRosterItem* self);
VALA_EXTERN void xmpp_roster_item_set_subscription (XmppRosterItem* self,
                                        const gchar* value);
VALA_EXTERN const gchar* xmpp_roster_item_get_ask (XmppRosterItem* self);
VALA_EXTERN gboolean xmpp_roster_item_get_subscription_requested (XmppRosterItem* self);
VALA_EXTERN GType xmpp_roster_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppRosterModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_roster_module_IDENTITY;
VALA_EXTERN void xmpp_roster_module_add_jid (XmppRosterModule* self,
                                 XmppXmppStream* stream,
                                 XmppJid* jid,
                                 const gchar* handle);
VALA_EXTERN void xmpp_roster_module_remove_jid (XmppRosterModule* self,
                                    XmppXmppStream* stream,
                                    XmppJid* jid);
VALA_EXTERN void xmpp_roster_module_set_jid_handle (XmppRosterModule* self,
                                        XmppXmppStream* stream,
                                        XmppJid* jid,
                                        const gchar* handle);
VALA_EXTERN XmppRosterModule* xmpp_roster_module_new (void);
VALA_EXTERN XmppRosterModule* xmpp_roster_module_construct (GType object_type);
VALA_EXTERN GType xmpp_roster_versioning_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppRosterVersioningModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_roster_versioning_module_IDENTITY;
VALA_EXTERN GType xmpp_roster_storage_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppRosterStorage, g_object_unref)
VALA_EXTERN XmppRosterVersioningModule* xmpp_roster_versioning_module_new (XmppRosterStorage* storage);
VALA_EXTERN XmppRosterVersioningModule* xmpp_roster_versioning_module_construct (GType object_type,
                                                                     XmppRosterStorage* storage);
VALA_EXTERN gchar* xmpp_roster_storage_get_roster_version (XmppRosterStorage* self);
VALA_EXTERN GeeCollection* xmpp_roster_storage_get_roster (XmppRosterStorage* self);
VALA_EXTERN void xmpp_roster_storage_set_roster_version (XmppRosterStorage* self,
                                             const gchar* version);
VALA_EXTERN void xmpp_roster_storage_set_roster (XmppRosterStorage* self,
                                     GeeCollection* items);
VALA_EXTERN void xmpp_roster_storage_set_item (XmppRosterStorage* self,
                                   XmppRosterItem* item);
VALA_EXTERN void xmpp_roster_storage_remove_item (XmppRosterStorage* self,
                                      XmppRosterItem* item);
VALA_EXTERN GType xmpp_sasl_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppSaslFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_sasl_flag_IDENTITY;
VALA_EXTERN XmppSaslFlag* xmpp_sasl_flag_new (void);
VALA_EXTERN XmppSaslFlag* xmpp_sasl_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_sasl_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppSaslModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_sasl_module_IDENTITY;
VALA_EXTERN XmppSaslModule* xmpp_sasl_module_new (const gchar* name,
                                      const gchar* password);
VALA_EXTERN XmppSaslModule* xmpp_sasl_module_construct (GType object_type,
                                            const gchar* name,
                                            const gchar* password);
VALA_EXTERN void xmpp_sasl_module_received_nonza (XmppSaslModule* self,
                                      XmppXmppStream* stream,
                                      XmppStanzaNode* node);
VALA_EXTERN void xmpp_sasl_module_received_features_node (XmppSaslModule* self,
                                              XmppXmppStream* stream);
VALA_EXTERN const gchar* xmpp_sasl_module_get_name (XmppSaslModule* self);
VALA_EXTERN void xmpp_sasl_module_set_name (XmppSaslModule* self,
                                const gchar* value);
VALA_EXTERN const gchar* xmpp_sasl_module_get_password (XmppSaslModule* self);
VALA_EXTERN void xmpp_sasl_module_set_password (XmppSaslModule* self,
                                    const gchar* value);
VALA_EXTERN GType xmpp_session_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppSessionModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_session_module_IDENTITY;
VALA_EXTERN XmppSessionModule* xmpp_session_module_new (void);
VALA_EXTERN XmppSessionModule* xmpp_session_module_construct (GType object_type);
VALA_EXTERN GType xmpp_session_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppSessionFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_session_flag_IDENTITY;
VALA_EXTERN XmppSessionFlag* xmpp_session_flag_new (void);
VALA_EXTERN XmppSessionFlag* xmpp_session_flag_construct (GType object_type);
VALA_EXTERN XmppStanza* xmpp_stanza_new_incoming (XmppStanzaNode* stanza,
                                      XmppJid* my_jid);
VALA_EXTERN XmppStanza* xmpp_stanza_construct_incoming (GType object_type,
                                            XmppStanzaNode* stanza,
                                            XmppJid* my_jid);
VALA_EXTERN XmppStanza* xmpp_stanza_new_outgoing (XmppStanzaNode* stanza);
VALA_EXTERN XmppStanza* xmpp_stanza_construct_outgoing (GType object_type,
                                            XmppStanzaNode* stanza);
VALA_EXTERN gboolean xmpp_stanza_is_error (XmppStanza* self);
VALA_EXTERN XmppErrorStanza* xmpp_stanza_get_error (XmppStanza* self);
VALA_EXTERN XmppStanza* xmpp_stanza_new (void);
VALA_EXTERN XmppStanza* xmpp_stanza_construct (GType object_type);
VALA_EXTERN XmppJid* xmpp_stanza_get_from (XmppStanza* self);
VALA_EXTERN void xmpp_stanza_set_from (XmppStanza* self,
                           XmppJid* value);
VALA_EXTERN const gchar* xmpp_stanza_get_id (XmppStanza* self);
VALA_EXTERN void xmpp_stanza_set_id (XmppStanza* self,
                         const gchar* value);
VALA_EXTERN XmppJid* xmpp_stanza_get_to (XmppStanza* self);
VALA_EXTERN void xmpp_stanza_set_to (XmppStanza* self,
                         XmppJid* value);
VALA_EXTERN const gchar* xmpp_stanza_get_type_ (XmppStanza* self);
VALA_EXTERN void xmpp_stanza_set_type_ (XmppStanza* self,
                            const gchar* value);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_from_stanza (XmppStanzaNode* stanza);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_new_build (const gchar* type,
                                              const gchar* condition,
                                              const gchar* human_readable,
                                              XmppStanzaNode* application_condition);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_construct_build (GType object_type,
                                                    const gchar* type,
                                                    const gchar* condition,
                                                    const gchar* human_readable,
                                                    XmppStanzaNode* application_condition);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_new_bad_request (const gchar* human_readable);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_construct_bad_request (GType object_type,
                                                          const gchar* human_readable);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_new_feature_not_implemented (const gchar* human_readable);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_construct_feature_not_implemented (GType object_type,
                                                                      const gchar* human_readable);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_new_item_not_found (XmppStanzaNode* application_condition);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_construct_item_not_found (GType object_type,
                                                             XmppStanzaNode* application_condition);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_new_not_acceptable (const gchar* human_readable);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_construct_not_acceptable (GType object_type,
                                                             const gchar* human_readable);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_new_not_allowed (const gchar* human_readable);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_construct_not_allowed (GType object_type,
                                                          const gchar* human_readable);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_new_resource_constraint (const gchar* human_readable);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_construct_resource_constraint (GType object_type,
                                                                  const gchar* human_readable);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_new_service_unavailable (void);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_construct_service_unavailable (GType object_type);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_new (void);
VALA_EXTERN XmppErrorStanza* xmpp_error_stanza_construct (GType object_type);
VALA_EXTERN const gchar* xmpp_error_stanza_get_by (XmppErrorStanza* self);
VALA_EXTERN const gchar* xmpp_error_stanza_get_text (XmppErrorStanza* self);
VALA_EXTERN const gchar* xmpp_error_stanza_get_condition (XmppErrorStanza* self);
VALA_EXTERN const gchar* xmpp_error_stanza_get_type_ (XmppErrorStanza* self);
VALA_EXTERN GType xmpp_stream_error_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStreamErrorModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_stream_error_module_IDENTITY;
VALA_EXTERN void xmpp_stream_error_module_require (XmppXmppStream* stream);
VALA_EXTERN XmppStreamErrorModule* xmpp_stream_error_module_new (void);
VALA_EXTERN XmppStreamErrorModule* xmpp_stream_error_module_construct (GType object_type);
VALA_EXTERN GType xmpp_stream_error_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStreamErrorFlag, g_object_unref)
VALA_EXTERN GType xmpp_stream_error_flag_reconnect_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppFlagIdentity* xmpp_stream_error_flag_IDENTITY;
VALA_EXTERN XmppStreamErrorFlag* xmpp_stream_error_flag_new (void);
VALA_EXTERN XmppStreamErrorFlag* xmpp_stream_error_flag_construct (GType object_type);
VALA_EXTERN gchar* xmpp_random_uuid (void);
VALA_EXTERN GType xmpp_ordered_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppOrderedListener, g_object_unref)
VALA_EXTERN GType xmpp_stanza_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppStanzaListener, g_object_unref)
VALA_EXTERN void xmpp_stanza_listener_run (XmppStanzaListener* self,
                               XmppXmppStream* stream,
                               gconstpointer stanza,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
VALA_EXTERN gboolean xmpp_stanza_listener_run_finish (XmppStanzaListener* self,
                                          GAsyncResult* _res_);
VALA_EXTERN XmppStanzaListener* xmpp_stanza_listener_construct (GType object_type,
                                                    GType t_type,
                                                    GBoxedCopyFunc t_dup_func,
                                                    GDestroyNotify t_destroy_func);
VALA_EXTERN void xmpp_stanza_listener_holder_run (XmppStanzaListenerHolder* self,
                                      XmppXmppStream* stream,
                                      gconstpointer stanza,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_);
VALA_EXTERN gboolean xmpp_stanza_listener_holder_run_finish (XmppStanzaListenerHolder* self,
                                                 GAsyncResult* _res_);
VALA_EXTERN XmppStanzaListenerHolder* xmpp_stanza_listener_holder_new (GType t_type,
                                                           GBoxedCopyFunc t_dup_func,
                                                           GDestroyNotify t_destroy_func);
VALA_EXTERN XmppStanzaListenerHolder* xmpp_stanza_listener_holder_construct (GType object_type,
                                                                 GType t_type,
                                                                 GBoxedCopyFunc t_dup_func,
                                                                 GDestroyNotify t_destroy_func);
VALA_EXTERN XmppOrderedListener* xmpp_ordered_listener_construct (GType object_type);
VALA_EXTERN const gchar* xmpp_ordered_listener_get_action_group (XmppOrderedListener* self);
VALA_EXTERN gchar** xmpp_ordered_listener_get_after_actions (XmppOrderedListener* self,
                                                 gint* result_length1);
VALA_EXTERN void xmpp_listener_holder_connect (XmppListenerHolder* self,
                                   XmppOrderedListener* listener);
VALA_EXTERN void xmpp_listener_holder_disconnect (XmppListenerHolder* self,
                                      XmppOrderedListener* listener);
VALA_EXTERN XmppListenerHolder* xmpp_listener_holder_construct (GType object_type);
VALA_EXTERN gpointer xmpp_xep_data_forms_data_form_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_data_forms_data_form_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_data_forms_param_spec_data_form (const gchar* name,
                                                      const gchar* nick,
                                                      const gchar* blurb,
                                                      GType object_type,
                                                      GParamFlags flags);
VALA_EXTERN void xmpp_xep_data_forms_value_set_data_form (GValue* value,
                                              gpointer v_object);
VALA_EXTERN void xmpp_xep_data_forms_value_take_data_form (GValue* value,
                                               gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_data_forms_value_get_data_form (const GValue* value);
VALA_EXTERN GType xmpp_xep_data_forms_data_form_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataForm, xmpp_xep_data_forms_data_form_unref)
VALA_EXTERN GType xmpp_xep_data_forms_data_form_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataFormField, g_object_unref)
VALA_EXTERN GType xmpp_xep_data_forms_data_form_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppStanzaNode* xmpp_xep_data_forms_data_form_get_submit_node (XmppXepDataFormsDataForm* self);
VALA_EXTERN XmppXepDataFormsDataForm* xmpp_xep_data_forms_data_form_create_from_node (XmppStanzaNode* node);
VALA_EXTERN void xmpp_xep_data_forms_data_form_add_field (XmppXepDataFormsDataForm* self,
                                              XmppXepDataFormsDataFormField* field);
VALA_EXTERN XmppStanzaNode* xmpp_xep_data_forms_data_form_get_stanza_node (XmppXepDataFormsDataForm* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_set_stanza_node (XmppXepDataFormsDataForm* self,
                                                    XmppStanzaNode* value);
VALA_EXTERN gpointer xmpp_xep_data_forms_data_form_option_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_data_forms_data_form_option_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_data_forms_data_form_param_spec_option (const gchar* name,
                                                             const gchar* nick,
                                                             const gchar* blurb,
                                                             GType object_type,
                                                             GParamFlags flags);
VALA_EXTERN void xmpp_xep_data_forms_data_form_value_set_option (GValue* value,
                                                     gpointer v_object);
VALA_EXTERN void xmpp_xep_data_forms_data_form_value_take_option (GValue* value,
                                                      gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_data_forms_data_form_value_get_option (const GValue* value);
VALA_EXTERN GType xmpp_xep_data_forms_data_form_option_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataFormOption, xmpp_xep_data_forms_data_form_option_unref)
VALA_EXTERN XmppXepDataFormsDataFormOption* xmpp_xep_data_forms_data_form_option_new (const gchar* label,
                                                                          const gchar* value);
VALA_EXTERN XmppXepDataFormsDataFormOption* xmpp_xep_data_forms_data_form_option_construct (GType object_type,
                                                                                const gchar* label,
                                                                                const gchar* value);
VALA_EXTERN const gchar* xmpp_xep_data_forms_data_form_option_get_label (XmppXepDataFormsDataFormOption* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_option_set_label (XmppXepDataFormsDataFormOption* self,
                                                     const gchar* value);
VALA_EXTERN const gchar* xmpp_xep_data_forms_data_form_option_get_value (XmppXepDataFormsDataFormOption* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_option_set_value (XmppXepDataFormsDataFormOption* self,
                                                     const gchar* value);
VALA_EXTERN XmppXepDataFormsDataFormField* xmpp_xep_data_forms_data_form_field_new (void);
VALA_EXTERN XmppXepDataFormsDataFormField* xmpp_xep_data_forms_data_form_field_construct (GType object_type);
VALA_EXTERN XmppXepDataFormsDataFormField* xmpp_xep_data_forms_data_form_field_new_from_node (XmppStanzaNode* node);
VALA_EXTERN XmppXepDataFormsDataFormField* xmpp_xep_data_forms_data_form_field_construct_from_node (GType object_type,
                                                                                        XmppStanzaNode* node);
VALA_EXTERN gchar* xmpp_xep_data_forms_data_form_field_get_value_string (XmppXepDataFormsDataFormField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_field_set_value_string (XmppXepDataFormsDataFormField* self,
                                                           const gchar* val);
VALA_EXTERN XmppStanzaNode* xmpp_xep_data_forms_data_form_field_get_node (XmppXepDataFormsDataFormField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_field_set_node (XmppXepDataFormsDataFormField* self,
                                                   XmppStanzaNode* value);
VALA_EXTERN const gchar* xmpp_xep_data_forms_data_form_field_get_label (XmppXepDataFormsDataFormField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_field_set_label (XmppXepDataFormsDataFormField* self,
                                                    const gchar* value);
VALA_EXTERN XmppXepDataFormsDataFormType* xmpp_xep_data_forms_data_form_field_get_type_ (XmppXepDataFormsDataFormField* self);
VALA_EXTERN const gchar* xmpp_xep_data_forms_data_form_field_get_var (XmppXepDataFormsDataFormField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_field_set_var (XmppXepDataFormsDataFormField* self,
                                                  const gchar* value);
VALA_EXTERN GType xmpp_xep_data_forms_data_form_boolean_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataFormBooleanField, g_object_unref)
VALA_EXTERN XmppXepDataFormsDataFormBooleanField* xmpp_xep_data_forms_data_form_boolean_field_new (XmppStanzaNode* node);
VALA_EXTERN XmppXepDataFormsDataFormBooleanField* xmpp_xep_data_forms_data_form_boolean_field_construct (GType object_type,
                                                                                             XmppStanzaNode* node);
VALA_EXTERN gboolean xmpp_xep_data_forms_data_form_boolean_field_get_value (XmppXepDataFormsDataFormBooleanField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_boolean_field_set_value (XmppXepDataFormsDataFormBooleanField* self,
                                                            gboolean value);
VALA_EXTERN GType xmpp_xep_data_forms_data_form_fixed_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataFormFixedField, g_object_unref)
VALA_EXTERN XmppXepDataFormsDataFormFixedField* xmpp_xep_data_forms_data_form_fixed_field_new (XmppStanzaNode* node);
VALA_EXTERN XmppXepDataFormsDataFormFixedField* xmpp_xep_data_forms_data_form_fixed_field_construct (GType object_type,
                                                                                         XmppStanzaNode* node);
VALA_EXTERN gchar* xmpp_xep_data_forms_data_form_fixed_field_get_value (XmppXepDataFormsDataFormFixedField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_fixed_field_set_value (XmppXepDataFormsDataFormFixedField* self,
                                                          const gchar* value);
VALA_EXTERN GType xmpp_xep_data_forms_data_form_hidden_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataFormHiddenField, g_object_unref)
VALA_EXTERN XmppXepDataFormsDataFormHiddenField* xmpp_xep_data_forms_data_form_hidden_field_new (void);
VALA_EXTERN XmppXepDataFormsDataFormHiddenField* xmpp_xep_data_forms_data_form_hidden_field_construct (GType object_type);
VALA_EXTERN XmppXepDataFormsDataFormHiddenField* xmpp_xep_data_forms_data_form_hidden_field_new_from_node (XmppStanzaNode* node);
VALA_EXTERN XmppXepDataFormsDataFormHiddenField* xmpp_xep_data_forms_data_form_hidden_field_construct_from_node (GType object_type,
                                                                                                     XmppStanzaNode* node);
VALA_EXTERN GType xmpp_xep_data_forms_data_form_jid_multi_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataFormJidMultiField, g_object_unref)
VALA_EXTERN XmppXepDataFormsDataFormJidMultiField* xmpp_xep_data_forms_data_form_jid_multi_field_new (XmppStanzaNode* node);
VALA_EXTERN XmppXepDataFormsDataFormJidMultiField* xmpp_xep_data_forms_data_form_jid_multi_field_construct (GType object_type,
                                                                                                XmppStanzaNode* node);
VALA_EXTERN GeeList* xmpp_xep_data_forms_data_form_jid_multi_field_get_options (XmppXepDataFormsDataFormJidMultiField* self);
VALA_EXTERN GeeList* xmpp_xep_data_forms_data_form_jid_multi_field_get_value (XmppXepDataFormsDataFormJidMultiField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_jid_multi_field_set_value (XmppXepDataFormsDataFormJidMultiField* self,
                                                              GeeList* value);
VALA_EXTERN GType xmpp_xep_data_forms_data_form_list_single_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataFormListSingleField, g_object_unref)
VALA_EXTERN XmppXepDataFormsDataFormListSingleField* xmpp_xep_data_forms_data_form_list_single_field_new (XmppStanzaNode* node);
VALA_EXTERN XmppXepDataFormsDataFormListSingleField* xmpp_xep_data_forms_data_form_list_single_field_construct (GType object_type,
                                                                                                    XmppStanzaNode* node);
VALA_EXTERN GeeList* xmpp_xep_data_forms_data_form_list_single_field_get_options (XmppXepDataFormsDataFormListSingleField* self);
VALA_EXTERN gchar* xmpp_xep_data_forms_data_form_list_single_field_get_value (XmppXepDataFormsDataFormListSingleField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_list_single_field_set_value (XmppXepDataFormsDataFormListSingleField* self,
                                                                const gchar* value);
VALA_EXTERN GType xmpp_xep_data_forms_data_form_list_multi_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataFormListMultiField, g_object_unref)
VALA_EXTERN XmppXepDataFormsDataFormListMultiField* xmpp_xep_data_forms_data_form_list_multi_field_new (XmppStanzaNode* node);
VALA_EXTERN XmppXepDataFormsDataFormListMultiField* xmpp_xep_data_forms_data_form_list_multi_field_construct (GType object_type,
                                                                                                  XmppStanzaNode* node);
VALA_EXTERN GeeList* xmpp_xep_data_forms_data_form_list_multi_field_get_options (XmppXepDataFormsDataFormListMultiField* self);
VALA_EXTERN GeeList* xmpp_xep_data_forms_data_form_list_multi_field_get_value (XmppXepDataFormsDataFormListMultiField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_list_multi_field_set_value (XmppXepDataFormsDataFormListMultiField* self,
                                                               GeeList* value);
VALA_EXTERN GType xmpp_xep_data_forms_data_form_text_private_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataFormTextPrivateField, g_object_unref)
VALA_EXTERN XmppXepDataFormsDataFormTextPrivateField* xmpp_xep_data_forms_data_form_text_private_field_new (XmppStanzaNode* node);
VALA_EXTERN XmppXepDataFormsDataFormTextPrivateField* xmpp_xep_data_forms_data_form_text_private_field_construct (GType object_type,
                                                                                                      XmppStanzaNode* node);
VALA_EXTERN gchar* xmpp_xep_data_forms_data_form_text_private_field_get_value (XmppXepDataFormsDataFormTextPrivateField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_text_private_field_set_value (XmppXepDataFormsDataFormTextPrivateField* self,
                                                                 const gchar* value);
VALA_EXTERN GType xmpp_xep_data_forms_data_form_text_single_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDataFormsDataFormTextSingleField, g_object_unref)
VALA_EXTERN XmppXepDataFormsDataFormTextSingleField* xmpp_xep_data_forms_data_form_text_single_field_new (XmppStanzaNode* node);
VALA_EXTERN XmppXepDataFormsDataFormTextSingleField* xmpp_xep_data_forms_data_form_text_single_field_construct (GType object_type,
                                                                                                    XmppStanzaNode* node);
VALA_EXTERN gchar* xmpp_xep_data_forms_data_form_text_single_field_get_value (XmppXepDataFormsDataFormTextSingleField* self);
VALA_EXTERN void xmpp_xep_data_forms_data_form_text_single_field_set_value (XmppXepDataFormsDataFormTextSingleField* self,
                                                                const gchar* value);
VALA_EXTERN GType xmpp_xep_service_discovery_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepServiceDiscoveryFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_xep_service_discovery_flag_IDENTITY;
VALA_EXTERN void xmpp_xep_service_discovery_flag_add_own_feature (XmppXepServiceDiscoveryFlag* self,
                                                      const gchar* feature);
VALA_EXTERN void xmpp_xep_service_discovery_flag_remove_own_feature (XmppXepServiceDiscoveryFlag* self,
                                                         const gchar* feature);
VALA_EXTERN gpointer xmpp_xep_service_discovery_identity_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_service_discovery_identity_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_service_discovery_param_spec_identity (const gchar* name,
                                                            const gchar* nick,
                                                            const gchar* blurb,
                                                            GType object_type,
                                                            GParamFlags flags);
VALA_EXTERN void xmpp_xep_service_discovery_value_set_identity (GValue* value,
                                                    gpointer v_object);
VALA_EXTERN void xmpp_xep_service_discovery_value_take_identity (GValue* value,
                                                     gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_service_discovery_value_get_identity (const GValue* value);
VALA_EXTERN GType xmpp_xep_service_discovery_identity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepServiceDiscoveryIdentity, xmpp_xep_service_discovery_identity_unref)
VALA_EXTERN void xmpp_xep_service_discovery_flag_add_own_identity (XmppXepServiceDiscoveryFlag* self,
                                                       XmppXepServiceDiscoveryIdentity* identity);
VALA_EXTERN void xmpp_xep_service_discovery_flag_remove_own_identity (XmppXepServiceDiscoveryFlag* self,
                                                          XmppXepServiceDiscoveryIdentity* identity);
VALA_EXTERN XmppXepServiceDiscoveryFlag* xmpp_xep_service_discovery_flag_new (void);
VALA_EXTERN XmppXepServiceDiscoveryFlag* xmpp_xep_service_discovery_flag_construct (GType object_type);
VALA_EXTERN GeeList* xmpp_xep_service_discovery_flag_get_own_features (XmppXepServiceDiscoveryFlag* self);
VALA_EXTERN GeeSet* xmpp_xep_service_discovery_flag_get_own_identities (XmppXepServiceDiscoveryFlag* self);
VALA_EXTERN XmppXepServiceDiscoveryIdentity* xmpp_xep_service_discovery_identity_new (const gchar* category,
                                                                          const gchar* type,
                                                                          const gchar* name);
VALA_EXTERN XmppXepServiceDiscoveryIdentity* xmpp_xep_service_discovery_identity_construct (GType object_type,
                                                                                const gchar* category,
                                                                                const gchar* type,
                                                                                const gchar* name);
VALA_EXTERN guint xmpp_xep_service_discovery_identity_hash_func (XmppXepServiceDiscoveryIdentity* a);
VALA_EXTERN gboolean xmpp_xep_service_discovery_identity_equals_func (XmppXepServiceDiscoveryIdentity* a,
                                                          XmppXepServiceDiscoveryIdentity* b);
VALA_EXTERN const gchar* xmpp_xep_service_discovery_identity_get_category (XmppXepServiceDiscoveryIdentity* self);
VALA_EXTERN void xmpp_xep_service_discovery_identity_set_category (XmppXepServiceDiscoveryIdentity* self,
                                                       const gchar* value);
VALA_EXTERN const gchar* xmpp_xep_service_discovery_identity_get_type_ (XmppXepServiceDiscoveryIdentity* self);
VALA_EXTERN void xmpp_xep_service_discovery_identity_set_type_ (XmppXepServiceDiscoveryIdentity* self,
                                                    const gchar* value);
VALA_EXTERN const gchar* xmpp_xep_service_discovery_identity_get_name (XmppXepServiceDiscoveryIdentity* self);
VALA_EXTERN void xmpp_xep_service_discovery_identity_set_name (XmppXepServiceDiscoveryIdentity* self,
                                                   const gchar* value);
VALA_EXTERN gpointer xmpp_xep_service_discovery_info_result_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_service_discovery_info_result_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_service_discovery_param_spec_info_result (const gchar* name,
                                                               const gchar* nick,
                                                               const gchar* blurb,
                                                               GType object_type,
                                                               GParamFlags flags);
VALA_EXTERN void xmpp_xep_service_discovery_value_set_info_result (GValue* value,
                                                       gpointer v_object);
VALA_EXTERN void xmpp_xep_service_discovery_value_take_info_result (GValue* value,
                                                        gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_service_discovery_value_get_info_result (const GValue* value);
VALA_EXTERN GType xmpp_xep_service_discovery_info_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepServiceDiscoveryInfoResult, xmpp_xep_service_discovery_info_result_unref)
VALA_EXTERN XmppXepServiceDiscoveryInfoResult* xmpp_xep_service_discovery_info_result_new (XmppIqStanza* iq_request);
VALA_EXTERN XmppXepServiceDiscoveryInfoResult* xmpp_xep_service_discovery_info_result_construct (GType object_type,
                                                                                     XmppIqStanza* iq_request);
VALA_EXTERN XmppXepServiceDiscoveryInfoResult* xmpp_xep_service_discovery_info_result_create_from_iq (XmppIqStanza* iq);
VALA_EXTERN void xmpp_xep_service_discovery_info_result_add_feature (XmppXepServiceDiscoveryInfoResult* self,
                                                         const gchar* feature);
VALA_EXTERN void xmpp_xep_service_discovery_info_result_add_identity (XmppXepServiceDiscoveryInfoResult* self,
                                                          XmppXepServiceDiscoveryIdentity* identity);
VALA_EXTERN XmppIqStanza* xmpp_xep_service_discovery_info_result_get_iq (XmppXepServiceDiscoveryInfoResult* self);
VALA_EXTERN GeeList* xmpp_xep_service_discovery_info_result_get_features (XmppXepServiceDiscoveryInfoResult* self);
VALA_EXTERN void xmpp_xep_service_discovery_info_result_set_features (XmppXepServiceDiscoveryInfoResult* self,
                                                          GeeList* value);
VALA_EXTERN GeeSet* xmpp_xep_service_discovery_info_result_get_identities (XmppXepServiceDiscoveryInfoResult* self);
VALA_EXTERN void xmpp_xep_service_discovery_info_result_set_identities (XmppXepServiceDiscoveryInfoResult* self,
                                                            GeeSet* value);
VALA_EXTERN gpointer xmpp_xep_service_discovery_item_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_service_discovery_item_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_service_discovery_param_spec_item (const gchar* name,
                                                        const gchar* nick,
                                                        const gchar* blurb,
                                                        GType object_type,
                                                        GParamFlags flags);
VALA_EXTERN void xmpp_xep_service_discovery_value_set_item (GValue* value,
                                                gpointer v_object);
VALA_EXTERN void xmpp_xep_service_discovery_value_take_item (GValue* value,
                                                 gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_service_discovery_value_get_item (const GValue* value);
VALA_EXTERN GType xmpp_xep_service_discovery_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepServiceDiscoveryItem, xmpp_xep_service_discovery_item_unref)
VALA_EXTERN XmppXepServiceDiscoveryItem* xmpp_xep_service_discovery_item_new (XmppJid* jid,
                                                                  const gchar* name,
                                                                  const gchar* node);
VALA_EXTERN XmppXepServiceDiscoveryItem* xmpp_xep_service_discovery_item_construct (GType object_type,
                                                                        XmppJid* jid,
                                                                        const gchar* name,
                                                                        const gchar* node);
VALA_EXTERN gpointer xmpp_xep_service_discovery_items_result_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_service_discovery_items_result_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_service_discovery_param_spec_items_result (const gchar* name,
                                                                const gchar* nick,
                                                                const gchar* blurb,
                                                                GType object_type,
                                                                GParamFlags flags);
VALA_EXTERN void xmpp_xep_service_discovery_value_set_items_result (GValue* value,
                                                        gpointer v_object);
VALA_EXTERN void xmpp_xep_service_discovery_value_take_items_result (GValue* value,
                                                         gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_service_discovery_value_get_items_result (const GValue* value);
VALA_EXTERN GType xmpp_xep_service_discovery_items_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepServiceDiscoveryItemsResult, xmpp_xep_service_discovery_items_result_unref)
VALA_EXTERN XmppXepServiceDiscoveryItemsResult* xmpp_xep_service_discovery_items_result_create_from_iq (XmppIqStanza* iq);
VALA_EXTERN XmppXepServiceDiscoveryItemsResult* xmpp_xep_service_discovery_items_result_new (void);
VALA_EXTERN XmppXepServiceDiscoveryItemsResult* xmpp_xep_service_discovery_items_result_construct (GType object_type);
VALA_EXTERN XmppIqStanza* xmpp_xep_service_discovery_items_result_get_iq (XmppXepServiceDiscoveryItemsResult* self);
VALA_EXTERN GeeArrayList* xmpp_xep_service_discovery_items_result_get_items (XmppXepServiceDiscoveryItemsResult* self);
VALA_EXTERN GType xmpp_xep_service_discovery_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepServiceDiscoveryModule, g_object_unref)
VALA_EXTERN GType xmpp_xep_service_discovery_caps_cache_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepServiceDiscoveryCapsCache, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_service_discovery_module_IDENTITY;
VALA_EXTERN XmppXepServiceDiscoveryModule* xmpp_xep_service_discovery_module_new_with_identity (const gchar* category,
                                                                                    const gchar* type,
                                                                                    const gchar* name);
VALA_EXTERN XmppXepServiceDiscoveryModule* xmpp_xep_service_discovery_module_construct_with_identity (GType object_type,
                                                                                          const gchar* category,
                                                                                          const gchar* type,
                                                                                          const gchar* name);
VALA_EXTERN void xmpp_xep_service_discovery_module_add_feature (XmppXepServiceDiscoveryModule* self,
                                                    XmppXmppStream* stream,
                                                    const gchar* feature);
VALA_EXTERN void xmpp_xep_service_discovery_module_remove_feature (XmppXepServiceDiscoveryModule* self,
                                                       XmppXmppStream* stream,
                                                       const gchar* feature);
VALA_EXTERN void xmpp_xep_service_discovery_module_add_feature_notify (XmppXepServiceDiscoveryModule* self,
                                                           XmppXmppStream* stream,
                                                           const gchar* feature);
VALA_EXTERN void xmpp_xep_service_discovery_module_remove_feature_notify (XmppXepServiceDiscoveryModule* self,
                                                              XmppXmppStream* stream,
                                                              const gchar* feature);
VALA_EXTERN void xmpp_xep_service_discovery_module_has_entity_feature (XmppXepServiceDiscoveryModule* self,
                                                           XmppXmppStream* stream,
                                                           XmppJid* jid,
                                                           const gchar* feature,
                                                           GAsyncReadyCallback _callback_,
                                                           gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_service_discovery_module_has_entity_feature_finish (XmppXepServiceDiscoveryModule* self,
                                                                      GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_service_discovery_module_get_entity_identities (XmppXepServiceDiscoveryModule* self,
                                                              XmppXmppStream* stream,
                                                              XmppJid* jid,
                                                              GAsyncReadyCallback _callback_,
                                                              gpointer _user_data_);
VALA_EXTERN GeeSet* xmpp_xep_service_discovery_module_get_entity_identities_finish (XmppXepServiceDiscoveryModule* self,
                                                                        GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_service_discovery_module_request_info (XmppXepServiceDiscoveryModule* self,
                                                     XmppXmppStream* stream,
                                                     XmppJid* jid,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN XmppXepServiceDiscoveryInfoResult* xmpp_xep_service_discovery_module_request_info_finish (XmppXepServiceDiscoveryModule* self,
                                                                                          GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_service_discovery_module_request_items (XmppXepServiceDiscoveryModule* self,
                                                      XmppXmppStream* stream,
                                                      XmppJid* jid,
                                                      GAsyncReadyCallback _callback_,
                                                      gpointer _user_data_);
VALA_EXTERN XmppXepServiceDiscoveryItemsResult* xmpp_xep_service_discovery_module_request_items_finish (XmppXepServiceDiscoveryModule* self,
                                                                                            GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_service_discovery_module_require (XmppXmppStream* stream);
VALA_EXTERN XmppXepServiceDiscoveryModule* xmpp_xep_service_discovery_module_new (void);
VALA_EXTERN XmppXepServiceDiscoveryModule* xmpp_xep_service_discovery_module_construct (GType object_type);
VALA_EXTERN void xmpp_xep_service_discovery_caps_cache_has_entity_feature (XmppXepServiceDiscoveryCapsCache* self,
                                                               XmppJid* jid,
                                                               const gchar* feature,
                                                               GAsyncReadyCallback _callback_,
                                                               gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_service_discovery_caps_cache_has_entity_feature_finish (XmppXepServiceDiscoveryCapsCache* self,
                                                                          GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_service_discovery_caps_cache_get_entity_identities (XmppXepServiceDiscoveryCapsCache* self,
                                                                  XmppJid* jid,
                                                                  GAsyncReadyCallback _callback_,
                                                                  gpointer _user_data_);
VALA_EXTERN GeeSet* xmpp_xep_service_discovery_caps_cache_get_entity_identities_finish (XmppXepServiceDiscoveryCapsCache* self,
                                                                            GAsyncResult* _res_);
VALA_EXTERN GType xmpp_xep_muc_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMucFlag, g_object_unref)
VALA_EXTERN gpointer xmpp_xep_muc_join_result_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_muc_join_result_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_muc_param_spec_join_result (const gchar* name,
                                                 const gchar* nick,
                                                 const gchar* blurb,
                                                 GType object_type,
                                                 GParamFlags flags);
VALA_EXTERN void xmpp_xep_muc_value_set_join_result (GValue* value,
                                         gpointer v_object);
VALA_EXTERN void xmpp_xep_muc_value_take_join_result (GValue* value,
                                          gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_muc_value_get_join_result (const GValue* value);
VALA_EXTERN GType xmpp_xep_muc_join_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMucJoinResult, xmpp_xep_muc_join_result_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_xep_muc_flag_IDENTITY;
VALA_EXTERN gchar* xmpp_xep_muc_flag_get_room_name (XmppXepMucFlag* self,
                                        XmppJid* muc_jid);
VALA_EXTERN GType xmpp_xep_muc_feature_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gboolean xmpp_xep_muc_flag_has_room_feature (XmppXepMucFlag* self,
                                             XmppJid* muc_jid,
                                             XmppXepMucFeature feature);
VALA_EXTERN XmppJid* xmpp_xep_muc_flag_get_real_jid (XmppXepMucFlag* self,
                                         XmppJid* full_jid);
VALA_EXTERN XmppJid* xmpp_xep_muc_flag_get_occupant_jid (XmppXepMucFlag* self,
                                             XmppJid* real_jid,
                                             XmppJid* room);
VALA_EXTERN GeeList* xmpp_xep_muc_flag_get_offline_members (XmppXepMucFlag* self,
                                                XmppJid* muc_jid);
VALA_EXTERN GType xmpp_xep_muc_affiliation_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppXepMucAffiliation xmpp_xep_muc_flag_get_affiliation (XmppXepMucFlag* self,
                                                         XmppJid* muc_jid,
                                                         XmppJid* full_jid);
VALA_EXTERN GType xmpp_xep_muc_role_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppXepMucRole* xmpp_xep_muc_flag_get_occupant_role (XmppXepMucFlag* self,
                                                     XmppJid* full_jid);
VALA_EXTERN gchar* xmpp_xep_muc_flag_get_muc_nick (XmppXepMucFlag* self,
                                       XmppJid* muc_jid);
VALA_EXTERN void xmpp_xep_muc_flag_set_muc_nick (XmppXepMucFlag* self,
                                     XmppJid* muc_jid);
VALA_EXTERN gchar* xmpp_xep_muc_flag_get_enter_id (XmppXepMucFlag* self,
                                       XmppJid* muc_jid);
VALA_EXTERN gboolean xmpp_xep_muc_flag_is_muc (XmppXepMucFlag* self,
                                   XmppJid* jid);
VALA_EXTERN gboolean xmpp_xep_muc_flag_is_occupant (XmppXepMucFlag* self,
                                        XmppJid* jid);
VALA_EXTERN gboolean xmpp_xep_muc_flag_is_muc_enter_outstanding (XmppXepMucFlag* self);
VALA_EXTERN gchar* xmpp_xep_muc_flag_get_muc_subject (XmppXepMucFlag* self,
                                          XmppJid* muc_jid);
VALA_EXTERN XmppXepMucFlag* xmpp_xep_muc_flag_new (void);
VALA_EXTERN XmppXepMucFlag* xmpp_xep_muc_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_muc_muc_enter_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void xmpp_xep_muc_add_muc_pm_message_stanza_x_node (XmppMessageStanza* message_stanza);
VALA_EXTERN XmppXepMucJoinResult* xmpp_xep_muc_join_result_new (void);
VALA_EXTERN XmppXepMucJoinResult* xmpp_xep_muc_join_result_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_muc_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMucModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_muc_module_IDENTITY;
VALA_EXTERN XmppXepMucModule* xmpp_xep_muc_module_new (void);
VALA_EXTERN XmppXepMucModule* xmpp_xep_muc_module_construct (GType object_type);
VALA_EXTERN void xmpp_xep_muc_module_enter (XmppXepMucModule* self,
                                XmppXmppStream* stream,
                                XmppJid* bare_jid,
                                const gchar* nick,
                                const gchar* password,
                                GDateTime* history_since,
                                gboolean receive_history,
                                XmppStanzaNode* additional_node,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN XmppXepMucJoinResult* xmpp_xep_muc_module_enter_finish (XmppXepMucModule* self,
                                                        GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_muc_module_exit (XmppXepMucModule* self,
                               XmppXmppStream* stream,
                               XmppJid* jid);
VALA_EXTERN void xmpp_xep_muc_module_change_subject (XmppXepMucModule* self,
                                         XmppXmppStream* stream,
                                         XmppJid* jid,
                                         const gchar* subject);
VALA_EXTERN void xmpp_xep_muc_module_change_nick (XmppXepMucModule* self,
                                      XmppXmppStream* stream,
                                      XmppJid* jid,
                                      const gchar* new_nick);
VALA_EXTERN void xmpp_xep_muc_module_invite (XmppXepMucModule* self,
                                 XmppXmppStream* stream,
                                 XmppJid* to_muc,
                                 XmppJid* jid);
VALA_EXTERN void xmpp_xep_muc_module_request_voice (XmppXepMucModule* self,
                                        XmppXmppStream* stream,
                                        XmppJid* to_muc);
VALA_EXTERN void xmpp_xep_muc_module_kick (XmppXepMucModule* self,
                               XmppXmppStream* stream,
                               XmppJid* jid,
                               const gchar* nick);
VALA_EXTERN gboolean xmpp_xep_muc_module_kick_possible (XmppXepMucModule* self,
                                            XmppXmppStream* stream,
                                            XmppJid* occupant);
VALA_EXTERN void xmpp_xep_muc_module_change_role (XmppXepMucModule* self,
                                      XmppXmppStream* stream,
                                      XmppJid* jid,
                                      const gchar* nick,
                                      const gchar* new_role);
VALA_EXTERN void xmpp_xep_muc_module_change_affiliation (XmppXepMucModule* self,
                                             XmppXmppStream* stream,
                                             XmppJid* muc_jid,
                                             XmppJid* user_jid,
                                             const gchar* nick,
                                             const gchar* new_affiliation,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
VALA_EXTERN void xmpp_xep_muc_module_change_affiliation_finish (XmppXepMucModule* self,
                                                    GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_muc_module_get_config_form (XmppXepMucModule* self,
                                          XmppXmppStream* stream,
                                          XmppJid* jid,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN XmppXepDataFormsDataForm* xmpp_xep_muc_module_get_config_form_finish (XmppXepMucModule* self,
                                                                      GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_muc_module_set_config_form (XmppXepMucModule* self,
                                          XmppXmppStream* stream,
                                          XmppJid* jid,
                                          XmppXepDataFormsDataForm* data_form,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN void xmpp_xep_muc_module_set_config_form_finish (XmppXepMucModule* self,
                                                 GAsyncResult* _res_);
VALA_EXTERN GType xmpp_xep_muc_received_pipeline_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMucReceivedPipelineListener, g_object_unref)
VALA_EXTERN XmppXepMucReceivedPipelineListener* xmpp_xep_muc_received_pipeline_listener_new (XmppXepMucModule* outer);
VALA_EXTERN XmppXepMucReceivedPipelineListener* xmpp_xep_muc_received_pipeline_listener_construct (GType object_type,
                                                                                       XmppXepMucModule* outer);
VALA_EXTERN GType xmpp_xep_muc_status_code_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType xmpp_xep_in_band_bytestreams_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepInBandBytestreamsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_in_band_bytestreams_module_IDENTITY;
VALA_EXTERN XmppXepInBandBytestreamsModule* xmpp_xep_in_band_bytestreams_module_new (void);
VALA_EXTERN XmppXepInBandBytestreamsModule* xmpp_xep_in_band_bytestreams_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_in_band_bytestreams_connection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepInBandBytestreamsConnection, g_object_unref)
VALA_EXTERN GType xmpp_xep_in_band_bytestreams_connection_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_set_read_callback (XmppXepInBandBytestreamsConnection* self,
                                                                GSourceFunc callback,
                                                                gpointer callback_target,
                                                                GDestroyNotify callback_target_destroy_notify,
                                                                GCancellable* cancellable,
                                                                gint io_priority,
                                                                GError** error);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_set_write_callback (XmppXepInBandBytestreamsConnection* self,
                                                                 GSourceFunc callback,
                                                                 gpointer callback_target,
                                                                 GDestroyNotify callback_target_destroy_notify,
                                                                 GCancellable* cancellable,
                                                                 gint io_priority,
                                                                 GError** error);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_trigger_read_callback (XmppXepInBandBytestreamsConnection* self);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_trigger_write_callback (XmppXepInBandBytestreamsConnection* self);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_read_async (XmppXepInBandBytestreamsConnection* self,
                                                         guint8* buffer,
                                                         gint buffer_length1,
                                                         gint io_priority,
                                                         GCancellable* cancellable,
                                                         GAsyncReadyCallback _callback_,
                                                         gpointer _user_data_);
VALA_EXTERN gssize xmpp_xep_in_band_bytestreams_connection_read_finish (XmppXepInBandBytestreamsConnection* self,
                                                            GAsyncResult* _res_,
                                                            GError** error);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_write_async (XmppXepInBandBytestreamsConnection* self,
                                                          guint8* buffer,
                                                          gint buffer_length1,
                                                          gint io_priority,
                                                          GCancellable* cancellable,
                                                          GAsyncReadyCallback _callback_,
                                                          gpointer _user_data_);
VALA_EXTERN gssize xmpp_xep_in_band_bytestreams_connection_write_finish (XmppXepInBandBytestreamsConnection* self,
                                                             GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_close_read_async (XmppXepInBandBytestreamsConnection* self,
                                                               gint io_priority,
                                                               GCancellable* cancellable,
                                                               GAsyncReadyCallback _callback_,
                                                               gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_in_band_bytestreams_connection_close_read_finish (XmppXepInBandBytestreamsConnection* self,
                                                                    GAsyncResult* _res_,
                                                                    GError** error);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_close_write_async (XmppXepInBandBytestreamsConnection* self,
                                                                gint io_priority,
                                                                GCancellable* cancellable,
                                                                GAsyncReadyCallback _callback_,
                                                                gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_in_band_bytestreams_connection_close_write_finish (XmppXepInBandBytestreamsConnection* self,
                                                                     GAsyncResult* _res_,
                                                                     GError** error);
VALA_EXTERN XmppXepInBandBytestreamsConnection* xmpp_xep_in_band_bytestreams_connection_create (XmppXmppStream* stream,
                                                                                    XmppJid* receiver_full_jid,
                                                                                    const gchar* sid,
                                                                                    gint block_size,
                                                                                    gboolean initiate);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_handle_open (XmppXepInBandBytestreamsConnection* self,
                                                          XmppXmppStream* stream,
                                                          XmppStanzaNode* open,
                                                          XmppIqStanza* iq);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_handle_data (XmppXepInBandBytestreamsConnection* self,
                                                          XmppXmppStream* stream,
                                                          XmppStanzaNode* data,
                                                          XmppIqStanza* iq);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_connection_handle_close (XmppXepInBandBytestreamsConnection* self,
                                                           XmppXmppStream* stream,
                                                           XmppStanzaNode* close,
                                                           XmppIqStanza* iq);
VALA_EXTERN XmppXepInBandBytestreamsConnectionState xmpp_xep_in_band_bytestreams_connection_get_state (XmppXepInBandBytestreamsConnection* self);
VALA_EXTERN const gchar* xmpp_xep_in_band_bytestreams_connection_get_sid (XmppXepInBandBytestreamsConnection* self);
VALA_EXTERN GType xmpp_xep_in_band_bytestreams_connection_input_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepInBandBytestreamsConnectionInput, g_object_unref)
VALA_EXTERN XmppXepInBandBytestreamsConnectionInput* xmpp_xep_in_band_bytestreams_connection_input_new (XmppXepInBandBytestreamsConnection* connection);
VALA_EXTERN XmppXepInBandBytestreamsConnectionInput* xmpp_xep_in_band_bytestreams_connection_input_construct (GType object_type,
                                                                                                  XmppXepInBandBytestreamsConnection* connection);
VALA_EXTERN GType xmpp_xep_in_band_bytestreams_connection_output_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepInBandBytestreamsConnectionOutput, g_object_unref)
VALA_EXTERN XmppXepInBandBytestreamsConnectionOutput* xmpp_xep_in_band_bytestreams_connection_output_new (XmppXepInBandBytestreamsConnection* connection);
VALA_EXTERN XmppXepInBandBytestreamsConnectionOutput* xmpp_xep_in_band_bytestreams_connection_output_construct (GType object_type,
                                                                                                    XmppXepInBandBytestreamsConnection* connection);
VALA_EXTERN GType xmpp_xep_in_band_bytestreams_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepInBandBytestreamsFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_xep_in_band_bytestreams_flag_IDENTITY;
VALA_EXTERN void xmpp_xep_in_band_bytestreams_flag_add_connection (XmppXepInBandBytestreamsFlag* self,
                                                       XmppXepInBandBytestreamsConnection* conn);
VALA_EXTERN XmppXepInBandBytestreamsConnection* xmpp_xep_in_band_bytestreams_flag_get_connection (XmppXepInBandBytestreamsFlag* self,
                                                                                      const gchar* sid);
VALA_EXTERN void xmpp_xep_in_band_bytestreams_flag_remove_connection (XmppXepInBandBytestreamsFlag* self,
                                                          XmppXepInBandBytestreamsConnection* conn);
VALA_EXTERN XmppXepInBandBytestreamsFlag* xmpp_xep_in_band_bytestreams_flag_new (void);
VALA_EXTERN XmppXepInBandBytestreamsFlag* xmpp_xep_in_band_bytestreams_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_bookmarks_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepBookmarksModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_bookmarks_module_IDENTITY;
VALA_EXTERN XmppXepBookmarksModule* xmpp_xep_bookmarks_module_new (void);
VALA_EXTERN XmppXepBookmarksModule* xmpp_xep_bookmarks_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_bookmarks_bookmarks1_conference_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepBookmarksBookmarks1Conference, g_object_unref)
VALA_EXTERN XmppXepBookmarksBookmarks1Conference* xmpp_xep_bookmarks_bookmarks1_conference_new (XmppJid* jid);
VALA_EXTERN XmppXepBookmarksBookmarks1Conference* xmpp_xep_bookmarks_bookmarks1_conference_construct (GType object_type,
                                                                                          XmppJid* jid);
VALA_EXTERN XmppConference* xmpp_xep_bookmarks_bookmarks1_conference_create_from_stanza_node (XmppStanzaNode* stanza_node);
VALA_EXTERN GType xmpp_xep_message_markup_span_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType xmpp_xep_message_markup_span_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMessageMarkupSpan, g_object_unref)
VALA_EXTERN XmppXepMessageMarkupSpan* xmpp_xep_message_markup_span_new (void);
VALA_EXTERN XmppXepMessageMarkupSpan* xmpp_xep_message_markup_span_construct (GType object_type);
VALA_EXTERN GeeList* xmpp_xep_message_markup_span_get_types (XmppXepMessageMarkupSpan* self);
VALA_EXTERN void xmpp_xep_message_markup_span_set_types (XmppXepMessageMarkupSpan* self,
                                             GeeList* value);
VALA_EXTERN gint xmpp_xep_message_markup_span_get_start_char (XmppXepMessageMarkupSpan* self);
VALA_EXTERN void xmpp_xep_message_markup_span_set_start_char (XmppXepMessageMarkupSpan* self,
                                                  gint value);
VALA_EXTERN gint xmpp_xep_message_markup_span_get_end_char (XmppXepMessageMarkupSpan* self);
VALA_EXTERN void xmpp_xep_message_markup_span_set_end_char (XmppXepMessageMarkupSpan* self,
                                                gint value);
VALA_EXTERN GeeList* xmpp_xep_message_markup_get_spans (XmppMessageStanza* stanza);
VALA_EXTERN void xmpp_xep_message_markup_add_spans (XmppMessageStanza* stanza,
                                        GeeList* spans);
VALA_EXTERN gchar* xmpp_xep_message_markup_span_type_to_str (XmppXepMessageMarkupSpanType span_type);
VALA_EXTERN XmppXepMessageMarkupSpanType xmpp_xep_message_markup_str_to_span_type (const gchar* span_str);
VALA_EXTERN GType xmpp_xep_private_xml_storage_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepPrivateXmlStorageModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_private_xml_storage_module_IDENTITY;
VALA_EXTERN void xmpp_xep_private_xml_storage_module_store (XmppXepPrivateXmlStorageModule* self,
                                                XmppXmppStream* stream,
                                                XmppStanzaNode* node,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
VALA_EXTERN void xmpp_xep_private_xml_storage_module_store_finish (XmppXepPrivateXmlStorageModule* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_private_xml_storage_module_retrieve (XmppXepPrivateXmlStorageModule* self,
                                                   XmppXmppStream* stream,
                                                   XmppStanzaNode* node,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_);
VALA_EXTERN XmppStanzaNode* xmpp_xep_private_xml_storage_module_retrieve_finish (XmppXepPrivateXmlStorageModule* self,
                                                                     GAsyncResult* _res_);
VALA_EXTERN XmppXepPrivateXmlStorageModule* xmpp_xep_private_xml_storage_module_new (void);
VALA_EXTERN XmppXepPrivateXmlStorageModule* xmpp_xep_private_xml_storage_module_construct (GType object_type);
VALA_EXTERN void xmpp_xep_vcard_fetch_image (XmppXmppStream* stream,
                                 XmppJid* jid,
                                 const gchar* hash,
                                 GAsyncReadyCallback _callback_,
                                 gpointer _user_data_);
VALA_EXTERN GBytes* xmpp_xep_vcard_fetch_image_finish (GAsyncResult* _res_);
VALA_EXTERN GType xmpp_xep_vcard_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepVCardModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_vcard_module_IDENTITY;
VALA_EXTERN XmppXepVCardModule* xmpp_xep_vcard_module_new (void);
VALA_EXTERN XmppXepVCardModule* xmpp_xep_vcard_module_construct (GType object_type);
VALA_EXTERN gpointer xmpp_result_set_management_result_set_parameters_ref (gpointer instance);
VALA_EXTERN void xmpp_result_set_management_result_set_parameters_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_result_set_management_param_spec_result_set_parameters (const gchar* name,
                                                                         const gchar* nick,
                                                                         const gchar* blurb,
                                                                         GType object_type,
                                                                         GParamFlags flags);
VALA_EXTERN void xmpp_result_set_management_value_set_result_set_parameters (GValue* value,
                                                                 gpointer v_object);
VALA_EXTERN void xmpp_result_set_management_value_take_result_set_parameters (GValue* value,
                                                                  gpointer v_object);
VALA_EXTERN gpointer xmpp_result_set_management_value_get_result_set_parameters (const GValue* value);
VALA_EXTERN GType xmpp_result_set_management_result_set_parameters_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppResultSetManagementResultSetParameters, xmpp_result_set_management_result_set_parameters_unref)
VALA_EXTERN XmppResultSetManagementResultSetParameters* xmpp_result_set_management_result_set_parameters_new (void);
VALA_EXTERN XmppResultSetManagementResultSetParameters* xmpp_result_set_management_result_set_parameters_construct (GType object_type);
VALA_EXTERN XmppStanzaNode* xmpp_result_set_management_create_set_rsm_node_before (const gchar* before_id);
VALA_EXTERN XmppStanzaNode* xmpp_result_set_management_create_set_rsm_node_after (const gchar* after_id);
VALA_EXTERN GType xmpp_xep_pubsub_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepPubsubModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_pubsub_module_IDENTITY;
VALA_EXTERN void xmpp_xep_pubsub_module_add_filtered_notification (XmppXepPubsubModule* self,
                                                       XmppXmppStream* stream,
                                                       const gchar* node,
                                                       XmppXepPubsubItemListenerDelegateResultFunc item_listener,
                                                       gpointer item_listener_target,
                                                       GDestroyNotify item_listener_target_destroy_notify,
                                                       XmppXepPubsubRetractListenerDelegateResultFunc retract_listener,
                                                       gpointer retract_listener_target,
                                                       GDestroyNotify retract_listener_target_destroy_notify,
                                                       XmppXepPubsubDeleteListenerDelegateResultFunc delete_listener,
                                                       gpointer delete_listener_target,
                                                       GDestroyNotify delete_listener_target_destroy_notify);
VALA_EXTERN void xmpp_xep_pubsub_module_remove_filtered_notification (XmppXepPubsubModule* self,
                                                          XmppXmppStream* stream,
                                                          const gchar* node);
VALA_EXTERN void xmpp_xep_pubsub_module_request_all (XmppXepPubsubModule* self,
                                         XmppXmppStream* stream,
                                         XmppJid* jid,
                                         const gchar* node,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
VALA_EXTERN GeeList* xmpp_xep_pubsub_module_request_all_finish (XmppXepPubsubModule* self,
                                                    GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_pubsub_module_request (XmppXepPubsubModule* self,
                                     XmppXmppStream* stream,
                                     XmppJid* jid,
                                     const gchar* node,
                                     XmppXepPubsubModuleOnResult listener,
                                     gpointer listener_target,
                                     GDestroyNotify listener_target_destroy_notify);
VALA_EXTERN gpointer xmpp_xep_pubsub_publish_options_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_pubsub_publish_options_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_pubsub_param_spec_publish_options (const gchar* name,
                                                        const gchar* nick,
                                                        const gchar* blurb,
                                                        GType object_type,
                                                        GParamFlags flags);
VALA_EXTERN void xmpp_xep_pubsub_value_set_publish_options (GValue* value,
                                                gpointer v_object);
VALA_EXTERN void xmpp_xep_pubsub_value_take_publish_options (GValue* value,
                                                 gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_pubsub_value_get_publish_options (const GValue* value);
VALA_EXTERN GType xmpp_xep_pubsub_publish_options_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepPubsubPublishOptions, xmpp_xep_pubsub_publish_options_unref)
VALA_EXTERN void xmpp_xep_pubsub_module_publish (XmppXepPubsubModule* self,
                                     XmppXmppStream* stream,
                                     XmppJid* jid,
                                     const gchar* node_id,
                                     const gchar* item_id,
                                     XmppStanzaNode* content,
                                     XmppXepPubsubPublishOptions* publish_options,
                                     gboolean try_reconfiguring,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_pubsub_module_publish_finish (XmppXepPubsubModule* self,
                                                GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_pubsub_module_retract_item (XmppXepPubsubModule* self,
                                          XmppXmppStream* stream,
                                          XmppJid* jid,
                                          const gchar* node_id,
                                          const gchar* item_id,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_pubsub_module_retract_item_finish (XmppXepPubsubModule* self,
                                                     GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_pubsub_module_delete_node (XmppXepPubsubModule* self,
                                         XmppXmppStream* stream,
                                         XmppJid* jid,
                                         const gchar* node_id);
VALA_EXTERN void xmpp_xep_pubsub_module_request_node_config (XmppXepPubsubModule* self,
                                                 XmppXmppStream* stream,
                                                 XmppJid* jid,
                                                 const gchar* node_id,
                                                 GAsyncReadyCallback _callback_,
                                                 gpointer _user_data_);
VALA_EXTERN XmppXepDataFormsDataForm* xmpp_xep_pubsub_module_request_node_config_finish (XmppXepPubsubModule* self,
                                                                             GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_pubsub_module_submit_node_config (XmppXepPubsubModule* self,
                                                XmppXmppStream* stream,
                                                XmppXepDataFormsDataForm* data_form,
                                                const gchar* node_id,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_pubsub_module_submit_node_config_finish (XmppXepPubsubModule* self,
                                                           GAsyncResult* _res_);
VALA_EXTERN XmppXepPubsubModule* xmpp_xep_pubsub_module_new (void);
VALA_EXTERN XmppXepPubsubModule* xmpp_xep_pubsub_module_construct (GType object_type);
VALA_EXTERN XmppXepPubsubPublishOptions* xmpp_xep_pubsub_publish_options_set_persist_items (XmppXepPubsubPublishOptions* self,
                                                                                gboolean persist);
VALA_EXTERN XmppXepPubsubPublishOptions* xmpp_xep_pubsub_publish_options_set_max_items (XmppXepPubsubPublishOptions* self,
                                                                            const gchar* max);
VALA_EXTERN XmppXepPubsubPublishOptions* xmpp_xep_pubsub_publish_options_set_send_last_published_item (XmppXepPubsubPublishOptions* self,
                                                                                           const gchar* send);
VALA_EXTERN XmppXepPubsubPublishOptions* xmpp_xep_pubsub_publish_options_set_access_model (XmppXepPubsubPublishOptions* self,
                                                                               const gchar* model);
VALA_EXTERN XmppXepPubsubPublishOptions* xmpp_xep_pubsub_publish_options_new (void);
VALA_EXTERN XmppXepPubsubPublishOptions* xmpp_xep_pubsub_publish_options_construct (GType object_type);
VALA_EXTERN gpointer xmpp_xep_pubsub_item_listener_delegate_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_pubsub_item_listener_delegate_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_pubsub_param_spec_item_listener_delegate (const gchar* name,
                                                               const gchar* nick,
                                                               const gchar* blurb,
                                                               GType object_type,
                                                               GParamFlags flags);
VALA_EXTERN void xmpp_xep_pubsub_value_set_item_listener_delegate (GValue* value,
                                                       gpointer v_object);
VALA_EXTERN void xmpp_xep_pubsub_value_take_item_listener_delegate (GValue* value,
                                                        gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_pubsub_value_get_item_listener_delegate (const GValue* value);
VALA_EXTERN GType xmpp_xep_pubsub_item_listener_delegate_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepPubsubItemListenerDelegate, xmpp_xep_pubsub_item_listener_delegate_unref)
VALA_EXTERN XmppXepPubsubItemListenerDelegate* xmpp_xep_pubsub_item_listener_delegate_new (XmppXepPubsubItemListenerDelegateResultFunc on_result,
                                                                               gpointer on_result_target,
                                                                               GDestroyNotify on_result_target_destroy_notify);
VALA_EXTERN XmppXepPubsubItemListenerDelegate* xmpp_xep_pubsub_item_listener_delegate_construct (GType object_type,
                                                                                     XmppXepPubsubItemListenerDelegateResultFunc on_result,
                                                                                     gpointer on_result_target,
                                                                                     GDestroyNotify on_result_target_destroy_notify);
VALA_EXTERN XmppXepPubsubItemListenerDelegateResultFunc xmpp_xep_pubsub_item_listener_delegate_get_on_result (XmppXepPubsubItemListenerDelegate* self,
                                                                                                  gpointer* result_target);
VALA_EXTERN gpointer xmpp_xep_pubsub_retract_listener_delegate_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_pubsub_retract_listener_delegate_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_pubsub_param_spec_retract_listener_delegate (const gchar* name,
                                                                  const gchar* nick,
                                                                  const gchar* blurb,
                                                                  GType object_type,
                                                                  GParamFlags flags);
VALA_EXTERN void xmpp_xep_pubsub_value_set_retract_listener_delegate (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN void xmpp_xep_pubsub_value_take_retract_listener_delegate (GValue* value,
                                                           gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_pubsub_value_get_retract_listener_delegate (const GValue* value);
VALA_EXTERN GType xmpp_xep_pubsub_retract_listener_delegate_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepPubsubRetractListenerDelegate, xmpp_xep_pubsub_retract_listener_delegate_unref)
VALA_EXTERN XmppXepPubsubRetractListenerDelegate* xmpp_xep_pubsub_retract_listener_delegate_new (XmppXepPubsubRetractListenerDelegateResultFunc on_result,
                                                                                     gpointer on_result_target,
                                                                                     GDestroyNotify on_result_target_destroy_notify);
VALA_EXTERN XmppXepPubsubRetractListenerDelegate* xmpp_xep_pubsub_retract_listener_delegate_construct (GType object_type,
                                                                                           XmppXepPubsubRetractListenerDelegateResultFunc on_result,
                                                                                           gpointer on_result_target,
                                                                                           GDestroyNotify on_result_target_destroy_notify);
VALA_EXTERN XmppXepPubsubRetractListenerDelegateResultFunc xmpp_xep_pubsub_retract_listener_delegate_get_on_result (XmppXepPubsubRetractListenerDelegate* self,
                                                                                                        gpointer* result_target);
VALA_EXTERN gpointer xmpp_xep_pubsub_delete_listener_delegate_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_pubsub_delete_listener_delegate_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_pubsub_param_spec_delete_listener_delegate (const gchar* name,
                                                                 const gchar* nick,
                                                                 const gchar* blurb,
                                                                 GType object_type,
                                                                 GParamFlags flags);
VALA_EXTERN void xmpp_xep_pubsub_value_set_delete_listener_delegate (GValue* value,
                                                         gpointer v_object);
VALA_EXTERN void xmpp_xep_pubsub_value_take_delete_listener_delegate (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_pubsub_value_get_delete_listener_delegate (const GValue* value);
VALA_EXTERN GType xmpp_xep_pubsub_delete_listener_delegate_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepPubsubDeleteListenerDelegate, xmpp_xep_pubsub_delete_listener_delegate_unref)
VALA_EXTERN XmppXepPubsubDeleteListenerDelegate* xmpp_xep_pubsub_delete_listener_delegate_new (XmppXepPubsubDeleteListenerDelegateResultFunc on_result,
                                                                                   gpointer on_result_target,
                                                                                   GDestroyNotify on_result_target_destroy_notify);
VALA_EXTERN XmppXepPubsubDeleteListenerDelegate* xmpp_xep_pubsub_delete_listener_delegate_construct (GType object_type,
                                                                                         XmppXepPubsubDeleteListenerDelegateResultFunc on_result,
                                                                                         gpointer on_result_target,
                                                                                         GDestroyNotify on_result_target_destroy_notify);
VALA_EXTERN XmppXepPubsubDeleteListenerDelegateResultFunc xmpp_xep_pubsub_delete_listener_delegate_get_on_result (XmppXepPubsubDeleteListenerDelegate* self,
                                                                                                      gpointer* result_target);
VALA_EXTERN GType xmpp_xep_socks5_bytestreams_proxy_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepSocks5BytestreamsProxy, g_object_unref)
VALA_EXTERN XmppXepSocks5BytestreamsProxy* xmpp_xep_socks5_bytestreams_proxy_new (const gchar* host,
                                                                      XmppJid* jid,
                                                                      gint port);
VALA_EXTERN XmppXepSocks5BytestreamsProxy* xmpp_xep_socks5_bytestreams_proxy_construct (GType object_type,
                                                                            const gchar* host,
                                                                            XmppJid* jid,
                                                                            gint port);
VALA_EXTERN const gchar* xmpp_xep_socks5_bytestreams_proxy_get_host (XmppXepSocks5BytestreamsProxy* self);
VALA_EXTERN XmppJid* xmpp_xep_socks5_bytestreams_proxy_get_jid (XmppXepSocks5BytestreamsProxy* self);
VALA_EXTERN gint xmpp_xep_socks5_bytestreams_proxy_get_port (XmppXepSocks5BytestreamsProxy* self);
VALA_EXTERN GType xmpp_xep_socks5_bytestreams_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepSocks5BytestreamsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_socks5_bytestreams_module_IDENTITY;
VALA_EXTERN GeeList* xmpp_xep_socks5_bytestreams_module_get_proxies (XmppXepSocks5BytestreamsModule* self,
                                                         XmppXmppStream* stream);
VALA_EXTERN void xmpp_xep_socks5_bytestreams_module_set_local_ip_address_handler (XmppXepSocks5BytestreamsModule* self,
                                                                      XmppXepSocks5BytestreamsGetLocalIpAddresses get_local_ip_addresses,
                                                                      gpointer get_local_ip_addresses_target,
                                                                      GDestroyNotify get_local_ip_addresses_target_destroy_notify);
VALA_EXTERN GeeList* xmpp_xep_socks5_bytestreams_module_get_local_ip_addresses (XmppXepSocks5BytestreamsModule* self);
VALA_EXTERN XmppXepSocks5BytestreamsModule* xmpp_xep_socks5_bytestreams_module_new (void);
VALA_EXTERN XmppXepSocks5BytestreamsModule* xmpp_xep_socks5_bytestreams_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_socks5_bytestreams_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepSocks5BytestreamsFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_xep_socks5_bytestreams_flag_IDENTITY;
VALA_EXTERN XmppXepSocks5BytestreamsFlag* xmpp_xep_socks5_bytestreams_flag_new (void);
VALA_EXTERN XmppXepSocks5BytestreamsFlag* xmpp_xep_socks5_bytestreams_flag_construct (GType object_type);
VALA_EXTERN void xmpp_xep_out_of_band_data_add_url_to_message (XmppMessageStanza* message,
                                                   const gchar* url,
                                                   const gchar* desc);
VALA_EXTERN gchar* xmpp_xep_out_of_band_data_get_url_from_message (XmppMessageStanza* message);
VALA_EXTERN GType xmpp_xep_in_band_registration_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepInBandRegistrationModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_in_band_registration_module_IDENTITY;
VALA_EXTERN void xmpp_xep_in_band_registration_module_get_from_server (XmppXepInBandRegistrationModule* self,
                                                           XmppXmppStream* stream,
                                                           XmppJid* jid,
                                                           GAsyncReadyCallback _callback_,
                                                           gpointer _user_data_);
VALA_EXTERN GType xmpp_xep_in_band_registration_form_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepInBandRegistrationForm, xmpp_xep_data_forms_data_form_unref)
VALA_EXTERN XmppXepInBandRegistrationForm* xmpp_xep_in_band_registration_module_get_from_server_finish (XmppXepInBandRegistrationModule* self,
                                                                                            GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_in_band_registration_module_submit_to_server (XmppXepInBandRegistrationModule* self,
                                                            XmppXmppStream* stream,
                                                            XmppJid* jid,
                                                            XmppXepInBandRegistrationForm* form,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
VALA_EXTERN gchar* xmpp_xep_in_band_registration_module_submit_to_server_finish (XmppXepInBandRegistrationModule* self,
                                                                     GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_in_band_registration_module_change_password (XmppXepInBandRegistrationModule* self,
                                                           XmppXmppStream* stream,
                                                           XmppJid* jid,
                                                           const gchar* new_pw,
                                                           GAsyncReadyCallback _callback_,
                                                           gpointer _user_data_);
VALA_EXTERN XmppErrorStanza* xmpp_xep_in_band_registration_module_change_password_finish (XmppXepInBandRegistrationModule* self,
                                                                              GAsyncResult* _res_);
VALA_EXTERN XmppXepInBandRegistrationModule* xmpp_xep_in_band_registration_module_new (void);
VALA_EXTERN XmppXepInBandRegistrationModule* xmpp_xep_in_band_registration_module_construct (GType object_type);
VALA_EXTERN XmppXepInBandRegistrationForm* xmpp_xep_in_band_registration_form_new (void);
VALA_EXTERN XmppXepInBandRegistrationForm* xmpp_xep_in_band_registration_form_construct (GType object_type);
VALA_EXTERN GDateTime* xmpp_xep_date_time_profiles_parse_string (const gchar* time_string);
VALA_EXTERN gchar* xmpp_xep_date_time_profiles_to_datetime (GDateTime* time);
VALA_EXTERN void xmpp_xep_user_avatars_publish_png (XmppXmppStream* stream,
                                        guint8* image,
                                        gint image_length1,
                                        gint width,
                                        gint height);
VALA_EXTERN void xmpp_xep_user_avatars_unset_avatar (XmppXmppStream* stream);
VALA_EXTERN void xmpp_xep_user_avatars_fetch_image (XmppXmppStream* stream,
                                        XmppJid* jid,
                                        const gchar* hash,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_);
VALA_EXTERN GBytes* xmpp_xep_user_avatars_fetch_image_finish (GAsyncResult* _res_);
VALA_EXTERN GType xmpp_xep_user_avatars_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepUserAvatarsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_user_avatars_module_IDENTITY;
VALA_EXTERN void xmpp_xep_user_avatars_module_on_pupsub_item (XmppXepUserAvatarsModule* self,
                                                  XmppXmppStream* stream,
                                                  XmppJid* jid,
                                                  const gchar* hash,
                                                  XmppStanzaNode* node);
VALA_EXTERN void xmpp_xep_user_avatars_module_on_pubsub_delete (XmppXepUserAvatarsModule* self,
                                                    XmppXmppStream* stream,
                                                    XmppJid* jid);
VALA_EXTERN XmppXepUserAvatarsModule* xmpp_xep_user_avatars_module_new (void);
VALA_EXTERN XmppXepUserAvatarsModule* xmpp_xep_user_avatars_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_chat_state_notifications_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepChatStateNotificationsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_chat_state_notifications_module_IDENTITY;
VALA_EXTERN void xmpp_xep_chat_state_notifications_module_send_state (XmppXepChatStateNotificationsModule* self,
                                                          XmppXmppStream* stream,
                                                          XmppJid* jid,
                                                          const gchar* message_type,
                                                          const gchar* state);
VALA_EXTERN XmppXepChatStateNotificationsModule* xmpp_xep_chat_state_notifications_module_new (void);
VALA_EXTERN XmppXepChatStateNotificationsModule* xmpp_xep_chat_state_notifications_module_construct (GType object_type);
VALA_EXTERN void xmpp_xep_chat_state_notifications_add_state_to_message (XmppMessageStanza* message,
                                                             const gchar* state);
VALA_EXTERN gchar* xmpp_xep_http_scheme_for_url_data_get_url (XmppStanzaNode* node);
VALA_EXTERN XmppStanzaNode* xmpp_xep_http_scheme_for_url_data_to_stanza_node (const gchar* url);
VALA_EXTERN gchar* xmpp_xep_entity_capabilities_get_caps_hash (XmppPresenceStanza* presence);
VALA_EXTERN gchar* xmpp_xep_entity_capabilities_get_server_caps_hash (XmppXmppStream* stream);
VALA_EXTERN GType xmpp_xep_entity_capabilities_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepEntityCapabilitiesModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_entity_capabilities_module_IDENTITY;
VALA_EXTERN GType xmpp_xep_entity_capabilities_storage_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepEntityCapabilitiesStorage, g_object_unref)
VALA_EXTERN XmppXepEntityCapabilitiesModule* xmpp_xep_entity_capabilities_module_new (XmppXepEntityCapabilitiesStorage* storage);
VALA_EXTERN XmppXepEntityCapabilitiesModule* xmpp_xep_entity_capabilities_module_construct (GType object_type,
                                                                                XmppXepEntityCapabilitiesStorage* storage);
VALA_EXTERN gchar* xmpp_xep_entity_capabilities_module_compute_hash_for_info_result (XmppXepServiceDiscoveryInfoResult* info_result);
VALA_EXTERN gchar* xmpp_xep_entity_capabilities_module_compute_hash (GeeSet* identities_set,
                                                         GeeList* features,
                                                         GeeList* data_forms);
VALA_EXTERN void xmpp_xep_entity_capabilities_storage_store_identities (XmppXepEntityCapabilitiesStorage* self,
                                                            const gchar* entity,
                                                            GeeSet* identities);
VALA_EXTERN void xmpp_xep_entity_capabilities_storage_store_features (XmppXepEntityCapabilitiesStorage* self,
                                                          const gchar* entity,
                                                          GeeList* capabilities);
VALA_EXTERN XmppXepServiceDiscoveryIdentity* xmpp_xep_entity_capabilities_storage_get_identities (XmppXepEntityCapabilitiesStorage* self,
                                                                                      const gchar* entity);
VALA_EXTERN GeeList* xmpp_xep_entity_capabilities_storage_get_features (XmppXepEntityCapabilitiesStorage* self,
                                                            const gchar* entity);
VALA_EXTERN GType xmpp_xep_jingle_component_connection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleComponentConnection, g_object_unref)
VALA_EXTERN void xmpp_xep_jingle_component_connection_terminate (XmppXepJingleComponentConnection* self,
                                                     gboolean we_terminated,
                                                     const gchar* reason_name,
                                                     const gchar* reason_text,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN void xmpp_xep_jingle_component_connection_terminate_finish (XmppXepJingleComponentConnection* self,
                                                            GAsyncResult* _res_);
VALA_EXTERN XmppXepJingleComponentConnection* xmpp_xep_jingle_component_connection_construct (GType object_type);
VALA_EXTERN guint8 xmpp_xep_jingle_component_connection_get_component_id (XmppXepJingleComponentConnection* self);
VALA_EXTERN void xmpp_xep_jingle_component_connection_set_component_id (XmppXepJingleComponentConnection* self,
                                                            guint8 value);
VALA_EXTERN gulong xmpp_xep_jingle_component_connection_get_bytes_sent (XmppXepJingleComponentConnection* self);
VALA_EXTERN void xmpp_xep_jingle_component_connection_set_bytes_sent (XmppXepJingleComponentConnection* self,
                                                          gulong value);
VALA_EXTERN gulong xmpp_xep_jingle_component_connection_get_bytes_received (XmppXepJingleComponentConnection* self);
VALA_EXTERN void xmpp_xep_jingle_component_connection_set_bytes_received (XmppXepJingleComponentConnection* self,
                                                              gulong value);
VALA_EXTERN GType xmpp_xep_jingle_datagram_connection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleDatagramConnection, g_object_unref)
VALA_EXTERN void xmpp_xep_jingle_datagram_connection_send_datagram (XmppXepJingleDatagramConnection* self,
                                                        GBytes* datagram);
VALA_EXTERN XmppXepJingleDatagramConnection* xmpp_xep_jingle_datagram_connection_construct (GType object_type);
VALA_EXTERN gboolean xmpp_xep_jingle_datagram_connection_get_ready (XmppXepJingleDatagramConnection* self);
VALA_EXTERN void xmpp_xep_jingle_datagram_connection_set_ready (XmppXepJingleDatagramConnection* self,
                                                    gboolean value);
VALA_EXTERN GType xmpp_xep_jingle_streaming_connection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleStreamingConnection, g_object_unref)
VALA_EXTERN void xmpp_xep_jingle_streaming_connection_set_stream (XmppXepJingleStreamingConnection* self,
                                                      GIOStream* stream,
                                                      GAsyncReadyCallback _callback_,
                                                      gpointer _user_data_);
VALA_EXTERN void xmpp_xep_jingle_streaming_connection_set_stream_finish (XmppXepJingleStreamingConnection* self,
                                                             GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_jingle_streaming_connection_set_error (XmppXepJingleStreamingConnection* self,
                                                     GError* e);
VALA_EXTERN XmppXepJingleStreamingConnection* xmpp_xep_jingle_streaming_connection_new (void);
VALA_EXTERN XmppXepJingleStreamingConnection* xmpp_xep_jingle_streaming_connection_construct (GType object_type);
VALA_EXTERN GeeFuture* xmpp_xep_jingle_streaming_connection_get_stream (XmppXepJingleStreamingConnection* self);
VALA_EXTERN GType xmpp_xep_jingle_content_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleContent, g_object_unref)
VALA_EXTERN GType xmpp_xep_jingle_session_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleSession, g_object_unref)
VALA_EXTERN GType xmpp_xep_jingle_content_parameters_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleContentParameters, g_object_unref)
VALA_EXTERN GQuark xmpp_xep_jingle_iq_error_quark (void);
VALA_EXTERN GType xmpp_xep_jingle_iq_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType xmpp_xep_jingle_transport_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType xmpp_xep_jingle_content_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleContentType, g_object_unref)
VALA_EXTERN GType xmpp_xep_jingle_transport_parameters_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleTransportParameters, g_object_unref)
VALA_EXTERN GQuark xmpp_xep_jingle_error_quark (void);
VALA_EXTERN GType xmpp_xep_jingle_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType xmpp_xep_jingle_transport_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleTransport, g_object_unref)
VALA_EXTERN GType xmpp_xep_jingle_security_parameters_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleSecurityParameters, g_object_unref)
VALA_EXTERN GType xmpp_xep_jingle_security_precondition_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleSecurityPrecondition, g_object_unref)
VALA_EXTERN GType xmpp_xep_jingle_content_encryption_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleContentEncryption, g_object_unref)
VALA_EXTERN GType xmpp_xep_jingle_content_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType xmpp_xep_jingle_senders_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppXepJingleContent* xmpp_xep_jingle_content_new_initiate_sent (const gchar* content_name,
                                                                 XmppXepJingleSenders senders,
                                                                 XmppXepJingleContentType* content_type,
                                                                 XmppXepJingleContentParameters* content_params,
                                                                 XmppXepJingleTransport* transport,
                                                                 XmppXepJingleTransportParameters* transport_params,
                                                                 XmppXepJingleSecurityPrecondition* security_precondition,
                                                                 XmppXepJingleSecurityParameters* security_params,
                                                                 XmppJid* local_full_jid,
                                                                 XmppJid* peer_full_jid);
VALA_EXTERN XmppXepJingleContent* xmpp_xep_jingle_content_construct_initiate_sent (GType object_type,
                                                                       const gchar* content_name,
                                                                       XmppXepJingleSenders senders,
                                                                       XmppXepJingleContentType* content_type,
                                                                       XmppXepJingleContentParameters* content_params,
                                                                       XmppXepJingleTransport* transport,
                                                                       XmppXepJingleTransportParameters* transport_params,
                                                                       XmppXepJingleSecurityPrecondition* security_precondition,
                                                                       XmppXepJingleSecurityParameters* security_params,
                                                                       XmppJid* local_full_jid,
                                                                       XmppJid* peer_full_jid);
VALA_EXTERN XmppXepJingleContent* xmpp_xep_jingle_content_new_initiate_received (const gchar* content_name,
                                                                     XmppXepJingleSenders senders,
                                                                     XmppXepJingleContentType* content_type,
                                                                     XmppXepJingleContentParameters* content_params,
                                                                     XmppXepJingleTransport* transport,
                                                                     XmppXepJingleTransportParameters* transport_params,
                                                                     XmppXepJingleSecurityPrecondition* security_precondition,
                                                                     XmppXepJingleSecurityParameters* security_params,
                                                                     XmppJid* local_full_jid,
                                                                     XmppJid* peer_full_jid,
                                                                     GError** error);
VALA_EXTERN XmppXepJingleContent* xmpp_xep_jingle_content_construct_initiate_received (GType object_type,
                                                                           const gchar* content_name,
                                                                           XmppXepJingleSenders senders,
                                                                           XmppXepJingleContentType* content_type,
                                                                           XmppXepJingleContentParameters* content_params,
                                                                           XmppXepJingleTransport* transport,
                                                                           XmppXepJingleTransportParameters* transport_params,
                                                                           XmppXepJingleSecurityPrecondition* security_precondition,
                                                                           XmppXepJingleSecurityParameters* security_params,
                                                                           XmppJid* local_full_jid,
                                                                           XmppJid* peer_full_jid,
                                                                           GError** error);
VALA_EXTERN void xmpp_xep_jingle_content_set_session (XmppXepJingleContent* self,
                                          XmppXepJingleSession* session);
VALA_EXTERN void xmpp_xep_jingle_content_accept (XmppXepJingleContent* self);
VALA_EXTERN void xmpp_xep_jingle_content_reject (XmppXepJingleContent* self);
VALA_EXTERN void xmpp_xep_jingle_content_terminate (XmppXepJingleContent* self,
                                        gboolean we_terminated,
                                        const gchar* reason_name,
                                        const gchar* reason_text);
VALA_EXTERN void xmpp_xep_jingle_content_modify (XmppXepJingleContent* self,
                                     XmppXepJingleSenders new_sender);
VALA_EXTERN void xmpp_xep_jingle_content_accept_content_modify (XmppXepJingleContent* self,
                                                    XmppXepJingleSenders senders);
VALA_EXTERN void xmpp_xep_jingle_content_select_new_transport (XmppXepJingleContent* self,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_);
VALA_EXTERN void xmpp_xep_jingle_content_select_new_transport_finish (XmppXepJingleContent* self,
                                                          GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_jingle_content_handle_transport_accept (XmppXepJingleContent* self,
                                                      XmppXmppStream* stream,
                                                      XmppStanzaNode* transport_node,
                                                      XmppStanzaNode* jingle,
                                                      XmppIqStanza* iq,
                                                      GError** error);
VALA_EXTERN void xmpp_xep_jingle_content_handle_transport_reject (XmppXepJingleContent* self,
                                                      XmppXmppStream* stream,
                                                      XmppStanzaNode* jingle,
                                                      XmppIqStanza* iq,
                                                      GError** error);
VALA_EXTERN void xmpp_xep_jingle_content_handle_transport_replace (XmppXepJingleContent* self,
                                                       XmppXmppStream* stream,
                                                       XmppStanzaNode* transport_node,
                                                       XmppStanzaNode* jingle,
                                                       XmppIqStanza* iq,
                                                       GError** error);
VALA_EXTERN void xmpp_xep_jingle_content_handle_transport_info (XmppXepJingleContent* self,
                                                    XmppXmppStream* stream,
                                                    XmppStanzaNode* transport,
                                                    XmppStanzaNode* jingle,
                                                    XmppIqStanza* iq,
                                                    GError** error);
VALA_EXTERN void xmpp_xep_jingle_content_on_description_info (XmppXepJingleContent* self,
                                                  XmppXmppStream* stream,
                                                  XmppStanzaNode* description,
                                                  XmppStanzaNode* jinglq,
                                                  XmppIqStanza* iq,
                                                  GError** error);
VALA_EXTERN void xmpp_xep_jingle_content_set_transport_connection (XmppXepJingleContent* self,
                                                       XmppXepJingleComponentConnection* conn,
                                                       guint8 component);
VALA_EXTERN XmppXepJingleComponentConnection* xmpp_xep_jingle_content_get_transport_connection (XmppXepJingleContent* self,
                                                                                    guint8 component);
VALA_EXTERN void xmpp_xep_jingle_content_send_transport_info (XmppXepJingleContent* self,
                                                  XmppStanzaNode* transport);
VALA_EXTERN XmppXepJingleContent* xmpp_xep_jingle_content_new (void);
VALA_EXTERN XmppXepJingleContent* xmpp_xep_jingle_content_construct (GType object_type);
VALA_EXTERN XmppXepJingleContentState xmpp_xep_jingle_content_get_state (XmppXepJingleContent* self);
VALA_EXTERN void xmpp_xep_jingle_content_set_state (XmppXepJingleContent* self,
                                        XmppXepJingleContentState value);
VALA_EXTERN GType xmpp_xep_jingle_role_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppXepJingleRole xmpp_xep_jingle_content_get_role (XmppXepJingleContent* self);
VALA_EXTERN XmppJid* xmpp_xep_jingle_content_get_local_full_jid (XmppXepJingleContent* self);
VALA_EXTERN XmppJid* xmpp_xep_jingle_content_get_peer_full_jid (XmppXepJingleContent* self);
VALA_EXTERN XmppXepJingleRole xmpp_xep_jingle_content_get_content_creator (XmppXepJingleContent* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_content_get_content_name (XmppXepJingleContent* self);
VALA_EXTERN XmppXepJingleSenders xmpp_xep_jingle_content_get_senders (XmppXepJingleContent* self);
VALA_EXTERN XmppXepJingleContentEncryption* xmpp_xep_jingle_content_encryption_new (const gchar* encryption_ns,
                                                                        const gchar* encryption_name,
                                                                        guint8* our_key,
                                                                        gint our_key_length1,
                                                                        guint8* peer_key,
                                                                        gint peer_key_length1);
VALA_EXTERN XmppXepJingleContentEncryption* xmpp_xep_jingle_content_encryption_construct (GType object_type,
                                                                              const gchar* encryption_ns,
                                                                              const gchar* encryption_name,
                                                                              guint8* our_key,
                                                                              gint our_key_length1,
                                                                              guint8* peer_key,
                                                                              gint peer_key_length1);
VALA_EXTERN XmppXepJingleContentParameters* xmpp_xep_jingle_content_type_parse_content_parameters (XmppXepJingleContentType* self,
                                                                                       XmppStanzaNode* description,
                                                                                       GError** error);
VALA_EXTERN const gchar* xmpp_xep_jingle_content_type_get_ns_uri (XmppXepJingleContentType* self);
VALA_EXTERN XmppXepJingleTransportType xmpp_xep_jingle_content_type_get_required_transport_type (XmppXepJingleContentType* self);
VALA_EXTERN guint8 xmpp_xep_jingle_content_type_get_required_components (XmppXepJingleContentType* self);
VALA_EXTERN void xmpp_xep_jingle_content_parameters_handle_proposed_content (XmppXepJingleContentParameters* self,
                                                                 XmppXmppStream* stream,
                                                                 XmppXepJingleSession* session,
                                                                 XmppXepJingleContent* content,
                                                                 GAsyncReadyCallback _callback_,
                                                                 gpointer _user_data_);
VALA_EXTERN void xmpp_xep_jingle_content_parameters_handle_proposed_content_finish (XmppXepJingleContentParameters* self,
                                                                        GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_jingle_content_parameters_accept (XmppXepJingleContentParameters* self,
                                                XmppXmppStream* stream,
                                                XmppXepJingleSession* session,
                                                XmppXepJingleContent* content);
VALA_EXTERN void xmpp_xep_jingle_content_parameters_handle_accept (XmppXepJingleContentParameters* self,
                                                       XmppXmppStream* stream,
                                                       XmppXepJingleSession* session,
                                                       XmppXepJingleContent* content,
                                                       XmppStanzaNode* description_node);
VALA_EXTERN void xmpp_xep_jingle_content_parameters_terminate (XmppXepJingleContentParameters* self,
                                                   gboolean we_terminated,
                                                   const gchar* reason_name,
                                                   const gchar* reason_text);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_content_parameters_get_description_node (XmppXepJingleContentParameters* self);
VALA_EXTERN gchar* xmpp_xep_jingle_security_precondition_security_ns_uri (XmppXepJingleSecurityPrecondition* self);
VALA_EXTERN XmppXepJingleSecurityParameters* xmpp_xep_jingle_security_precondition_create_security_parameters (XmppXepJingleSecurityPrecondition* self,
                                                                                                   XmppXmppStream* stream,
                                                                                                   XmppJid* local_full_jid,
                                                                                                   XmppJid* peer_full_jid,
                                                                                                   GObject* options,
                                                                                                   GError** error);
VALA_EXTERN XmppXepJingleSecurityParameters* xmpp_xep_jingle_security_precondition_parse_security_parameters (XmppXepJingleSecurityPrecondition* self,
                                                                                                  XmppXmppStream* stream,
                                                                                                  XmppJid* local_full_jid,
                                                                                                  XmppJid* peer_full_jid,
                                                                                                  XmppStanzaNode* security,
                                                                                                  GError** error);
VALA_EXTERN gchar* xmpp_xep_jingle_security_parameters_security_ns_uri (XmppXepJingleSecurityParameters* self);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_security_parameters_to_security_stanza_node (XmppXepJingleSecurityParameters* self,
                                                                             XmppXmppStream* stream,
                                                                             XmppJid* local_full_jid,
                                                                             XmppJid* peer_full_jid);
VALA_EXTERN GIOStream* xmpp_xep_jingle_security_parameters_wrap_stream (XmppXepJingleSecurityParameters* self,
                                                            GIOStream* stream);
VALA_EXTERN void xmpp_xep_jingle_transport_is_transport_available (XmppXepJingleTransport* self,
                                                       XmppXmppStream* stream,
                                                       guint8 components,
                                                       XmppJid* full_jid,
                                                       GAsyncReadyCallback _callback_,
                                                       gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_jingle_transport_is_transport_available_finish (XmppXepJingleTransport* self,
                                                                  GAsyncResult* _res_);
VALA_EXTERN XmppXepJingleTransportParameters* xmpp_xep_jingle_transport_create_transport_parameters (XmppXepJingleTransport* self,
                                                                                         XmppXmppStream* stream,
                                                                                         guint8 components,
                                                                                         XmppJid* local_full_jid,
                                                                                         XmppJid* peer_full_jid,
                                                                                         GError** error);
VALA_EXTERN XmppXepJingleTransportParameters* xmpp_xep_jingle_transport_parse_transport_parameters (XmppXepJingleTransport* self,
                                                                                        XmppXmppStream* stream,
                                                                                        guint8 components,
                                                                                        XmppJid* local_full_jid,
                                                                                        XmppJid* peer_full_jid,
                                                                                        XmppStanzaNode* transport,
                                                                                        GError** error);
VALA_EXTERN const gchar* xmpp_xep_jingle_transport_get_ns_uri (XmppXepJingleTransport* self);
VALA_EXTERN XmppXepJingleTransportType xmpp_xep_jingle_transport_get_type_ (XmppXepJingleTransport* self);
VALA_EXTERN gint xmpp_xep_jingle_transport_get_priority (XmppXepJingleTransport* self);
VALA_EXTERN void xmpp_xep_jingle_transport_parameters_set_content (XmppXepJingleTransportParameters* self,
                                                       XmppXepJingleContent* content);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_transport_parameters_to_transport_stanza_node (XmppXepJingleTransportParameters* self,
                                                                               const gchar* action_type);
VALA_EXTERN void xmpp_xep_jingle_transport_parameters_handle_transport_accept (XmppXepJingleTransportParameters* self,
                                                                   XmppStanzaNode* transport,
                                                                   GError** error);
VALA_EXTERN void xmpp_xep_jingle_transport_parameters_handle_transport_info (XmppXepJingleTransportParameters* self,
                                                                 XmppStanzaNode* transport,
                                                                 GError** error);
VALA_EXTERN void xmpp_xep_jingle_transport_parameters_create_transport_connection (XmppXepJingleTransportParameters* self,
                                                                       XmppXmppStream* stream,
                                                                       XmppXepJingleContent* content);
VALA_EXTERN const gchar* xmpp_xep_jingle_transport_parameters_get_ns_uri (XmppXepJingleTransportParameters* self);
VALA_EXTERN guint8 xmpp_xep_jingle_transport_parameters_get_components (XmppXepJingleTransportParameters* self);
VALA_EXTERN GType xmpp_xep_jingle_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_xep_jingle_flag_IDENTITY;
VALA_EXTERN void xmpp_xep_jingle_flag_pre_add_session (XmppXepJingleFlag* self,
                                           const gchar* sid);
VALA_EXTERN void xmpp_xep_jingle_flag_add_session (XmppXepJingleFlag* self,
                                       XmppXepJingleSession* session);
VALA_EXTERN void xmpp_xep_jingle_flag_get_session (XmppXepJingleFlag* self,
                                       const gchar* sid,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN XmppXepJingleSession* xmpp_xep_jingle_flag_get_session_finish (XmppXepJingleFlag* self,
                                                               GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_jingle_flag_remove_session (XmppXepJingleFlag* self,
                                          const gchar* sid);
VALA_EXTERN XmppXepJingleFlag* xmpp_xep_jingle_flag_new (void);
VALA_EXTERN XmppXepJingleFlag* xmpp_xep_jingle_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_jingle_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_jingle_module_IDENTITY;
VALA_EXTERN void xmpp_xep_jingle_module_register_content_type (XmppXepJingleModule* self,
                                                   XmppXepJingleContentType* content_type);
VALA_EXTERN GType xmpp_xep_jingle_session_info_ns_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleSessionInfoNs, g_object_unref)
VALA_EXTERN void xmpp_xep_jingle_module_register_session_info_type (XmppXepJingleModule* self,
                                                        XmppXepJingleSessionInfoNs* info_ns);
VALA_EXTERN XmppXepJingleContentType* xmpp_xep_jingle_module_get_content_type (XmppXepJingleModule* self,
                                                                   const gchar* ns_uri);
VALA_EXTERN XmppXepJingleSessionInfoNs* xmpp_xep_jingle_module_get_session_info_type (XmppXepJingleModule* self,
                                                                          const gchar* ns_uri);
VALA_EXTERN void xmpp_xep_jingle_module_register_transport (XmppXepJingleModule* self,
                                                XmppXepJingleTransport* transport);
VALA_EXTERN XmppXepJingleTransport* xmpp_xep_jingle_module_get_transport (XmppXepJingleModule* self,
                                                              const gchar* ns_uri);
VALA_EXTERN void xmpp_xep_jingle_module_select_transport (XmppXepJingleModule* self,
                                              XmppXmppStream* stream,
                                              XmppXepJingleTransportType type,
                                              guint8 components,
                                              XmppJid* receiver_full_jid,
                                              GeeSet* blacklist,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
VALA_EXTERN XmppXepJingleTransport* xmpp_xep_jingle_module_select_transport_finish (XmppXepJingleModule* self,
                                                                        GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_jingle_module_register_security_precondition (XmppXepJingleModule* self,
                                                            XmppXepJingleSecurityPrecondition* precondition);
VALA_EXTERN XmppXepJingleSecurityPrecondition* xmpp_xep_jingle_module_get_security_precondition (XmppXepJingleModule* self,
                                                                                     const gchar* ns_uri);
VALA_EXTERN void xmpp_xep_jingle_module_is_available (XmppXepJingleModule* self,
                                          XmppXmppStream* stream,
                                          XmppXepJingleTransportType type,
                                          guint8 components,
                                          XmppJid* full_jid,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_jingle_module_is_available_finish (XmppXepJingleModule* self,
                                                     GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_jingle_module_create_session (XmppXepJingleModule* self,
                                            XmppXmppStream* stream,
                                            GeeList* contents,
                                            XmppJid* receiver_full_jid,
                                            const gchar* sid,
                                            XmppJid* muji_room,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
VALA_EXTERN XmppXepJingleSession* xmpp_xep_jingle_module_create_session_finish (XmppXepJingleModule* self,
                                                                    GAsyncResult* _res_,
                                                                    GError** error);
VALA_EXTERN void xmpp_xep_jingle_module_handle_session_initiate (XmppXepJingleModule* self,
                                                     XmppXmppStream* stream,
                                                     const gchar* sid,
                                                     XmppStanzaNode* jingle,
                                                     XmppIqStanza* iq,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN void xmpp_xep_jingle_module_handle_session_initiate_finish (XmppXepJingleModule* self,
                                                            GAsyncResult* _res_,
                                                            GError** error);
VALA_EXTERN void xmpp_xep_jingle_module_handle_iq_set (XmppXepJingleModule* self,
                                           XmppXmppStream* stream,
                                           XmppIqStanza* iq,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
VALA_EXTERN void xmpp_xep_jingle_module_handle_iq_set_finish (XmppXepJingleModule* self,
                                                  GAsyncResult* _res_,
                                                  GError** error);
VALA_EXTERN XmppXepJingleModule* xmpp_xep_jingle_module_new (void);
VALA_EXTERN XmppXepJingleModule* xmpp_xep_jingle_module_construct (GType object_type);
VALA_EXTERN gchar* xmpp_xep_jingle_senders_to_string (XmppXepJingleSenders self);
VALA_EXTERN XmppXepJingleSenders xmpp_xep_jingle_senders_parse (const gchar* senders,
                                                    GError** error);
VALA_EXTERN gchar* xmpp_xep_jingle_role_to_string (XmppXepJingleRole self);
VALA_EXTERN XmppXepJingleRole xmpp_xep_jingle_role_parse (const gchar* role,
                                              GError** error);
VALA_EXTERN GType xmpp_xep_jingle_session_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppXepJingleSession* xmpp_xep_jingle_session_new_initiate_sent (XmppXmppStream* stream,
                                                                 const gchar* sid,
                                                                 XmppJid* local_full_jid,
                                                                 XmppJid* peer_full_jid);
VALA_EXTERN XmppXepJingleSession* xmpp_xep_jingle_session_construct_initiate_sent (GType object_type,
                                                                       XmppXmppStream* stream,
                                                                       const gchar* sid,
                                                                       XmppJid* local_full_jid,
                                                                       XmppJid* peer_full_jid);
VALA_EXTERN XmppXepJingleSession* xmpp_xep_jingle_session_new_initiate_received (XmppXmppStream* stream,
                                                                     const gchar* sid,
                                                                     XmppJid* local_full_jid,
                                                                     XmppJid* peer_full_jid);
VALA_EXTERN XmppXepJingleSession* xmpp_xep_jingle_session_construct_initiate_received (GType object_type,
                                                                           XmppXmppStream* stream,
                                                                           const gchar* sid,
                                                                           XmppJid* local_full_jid,
                                                                           XmppJid* peer_full_jid);
VALA_EXTERN void xmpp_xep_jingle_session_handle_iq_set (XmppXepJingleSession* self,
                                            const gchar* action,
                                            XmppStanzaNode* jingle,
                                            XmppIqStanza* iq,
                                            GError** error);
VALA_EXTERN void xmpp_xep_jingle_session_add_content (XmppXepJingleSession* self,
                                          XmppXepJingleContent* content,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN void xmpp_xep_jingle_session_add_content_finish (XmppXepJingleSession* self,
                                                 GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_jingle_session_set_application_error (XmppXepJingleSession* self,
                                                    XmppStanzaNode* application_reason);
VALA_EXTERN void xmpp_xep_jingle_session_terminate (XmppXepJingleSession* self,
                                        const gchar* reason_name,
                                        const gchar* reason_text,
                                        const gchar* local_reason);
VALA_EXTERN gboolean xmpp_xep_jingle_session_senders_include_us (XmppXepJingleSession* self,
                                                     XmppXepJingleSenders senders);
VALA_EXTERN gboolean xmpp_xep_jingle_session_senders_include_counterpart (XmppXepJingleSession* self,
                                                              XmppXepJingleSenders senders);
VALA_EXTERN XmppXepJingleSession* xmpp_xep_jingle_session_new (void);
VALA_EXTERN XmppXepJingleSession* xmpp_xep_jingle_session_construct (GType object_type);
VALA_EXTERN XmppXmppStream* xmpp_xep_jingle_session_get_stream (XmppXepJingleSession* self);
VALA_EXTERN void xmpp_xep_jingle_session_set_stream (XmppXepJingleSession* self,
                                         XmppXmppStream* value);
VALA_EXTERN XmppXepJingleSessionState xmpp_xep_jingle_session_get_state (XmppXepJingleSession* self);
VALA_EXTERN void xmpp_xep_jingle_session_set_state (XmppXepJingleSession* self,
                                        XmppXepJingleSessionState value);
VALA_EXTERN const gchar* xmpp_xep_jingle_session_get_sid (XmppXepJingleSession* self);
VALA_EXTERN XmppJid* xmpp_xep_jingle_session_get_local_full_jid (XmppXepJingleSession* self);
VALA_EXTERN XmppJid* xmpp_xep_jingle_session_get_peer_full_jid (XmppXepJingleSession* self);
VALA_EXTERN gboolean xmpp_xep_jingle_session_get_we_initiated (XmppXepJingleSession* self);
VALA_EXTERN XmppXepJingleSecurityParameters* xmpp_xep_jingle_session_get_security (XmppXepJingleSession* self);
VALA_EXTERN XmppJid* xmpp_xep_jingle_session_get_muji_room (XmppXepJingleSession* self);
VALA_EXTERN void xmpp_xep_jingle_session_set_muji_room (XmppXepJingleSession* self,
                                            XmppJid* value);
VALA_EXTERN void xmpp_xep_jingle_session_info_ns_handle_content_session_info (XmppXepJingleSessionInfoNs* self,
                                                                  XmppXmppStream* stream,
                                                                  XmppXepJingleSession* session,
                                                                  XmppStanzaNode* info,
                                                                  XmppIqStanza* iq,
                                                                  GError** error);
VALA_EXTERN const gchar* xmpp_xep_jingle_session_info_ns_get_ns_uri (XmppXepJingleSessionInfoNs* self);
VALA_EXTERN GType xmpp_xep_jingle_rtp_parameters_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRtpParameters, g_object_unref)
VALA_EXTERN gpointer xmpp_xep_jingle_rtp_payload_type_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_jingle_rtp_payload_type_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_jingle_rtp_param_spec_payload_type (const gchar* name,
                                                         const gchar* nick,
                                                         const gchar* blurb,
                                                         GType object_type,
                                                         GParamFlags flags);
VALA_EXTERN void xmpp_xep_jingle_rtp_value_set_payload_type (GValue* value,
                                                 gpointer v_object);
VALA_EXTERN void xmpp_xep_jingle_rtp_value_take_payload_type (GValue* value,
                                                  gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_jingle_rtp_value_get_payload_type (const GValue* value);
VALA_EXTERN GType xmpp_xep_jingle_rtp_payload_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRtpPayloadType, xmpp_xep_jingle_rtp_payload_type_unref)
VALA_EXTERN gpointer xmpp_xep_jingle_rtp_header_extension_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_jingle_rtp_header_extension_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_jingle_rtp_param_spec_header_extension (const gchar* name,
                                                             const gchar* nick,
                                                             const gchar* blurb,
                                                             GType object_type,
                                                             GParamFlags flags);
VALA_EXTERN void xmpp_xep_jingle_rtp_value_set_header_extension (GValue* value,
                                                     gpointer v_object);
VALA_EXTERN void xmpp_xep_jingle_rtp_value_take_header_extension (GValue* value,
                                                      gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_jingle_rtp_value_get_header_extension (const GValue* value);
VALA_EXTERN GType xmpp_xep_jingle_rtp_header_extension_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRtpHeaderExtension, xmpp_xep_jingle_rtp_header_extension_unref)
VALA_EXTERN gpointer xmpp_xep_jingle_rtp_crypto_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_jingle_rtp_crypto_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_jingle_rtp_param_spec_crypto (const gchar* name,
                                                   const gchar* nick,
                                                   const gchar* blurb,
                                                   GType object_type,
                                                   GParamFlags flags);
VALA_EXTERN void xmpp_xep_jingle_rtp_value_set_crypto (GValue* value,
                                           gpointer v_object);
VALA_EXTERN void xmpp_xep_jingle_rtp_value_take_crypto (GValue* value,
                                            gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_jingle_rtp_value_get_crypto (const GValue* value);
VALA_EXTERN GType xmpp_xep_jingle_rtp_crypto_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRtpCrypto, xmpp_xep_jingle_rtp_crypto_unref)
VALA_EXTERN GType xmpp_xep_jingle_rtp_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRtpModule, g_object_unref)
VALA_EXTERN XmppXepJingleRtpParameters* xmpp_xep_jingle_rtp_parameters_new (XmppXepJingleRtpModule* parent,
                                                                const gchar* media,
                                                                GeeList* payload_types,
                                                                const gchar* ssrc,
                                                                gboolean rtcp_mux,
                                                                const gchar* bandwidth,
                                                                const gchar* bandwidth_type,
                                                                gboolean encryption_required,
                                                                XmppXepJingleRtpCrypto* local_crypto);
VALA_EXTERN XmppXepJingleRtpParameters* xmpp_xep_jingle_rtp_parameters_construct (GType object_type,
                                                                      XmppXepJingleRtpModule* parent,
                                                                      const gchar* media,
                                                                      GeeList* payload_types,
                                                                      const gchar* ssrc,
                                                                      gboolean rtcp_mux,
                                                                      const gchar* bandwidth,
                                                                      const gchar* bandwidth_type,
                                                                      gboolean encryption_required,
                                                                      XmppXepJingleRtpCrypto* local_crypto);
VALA_EXTERN XmppXepJingleRtpParameters* xmpp_xep_jingle_rtp_parameters_new_from_node (XmppXepJingleRtpModule* parent,
                                                                          XmppStanzaNode* node,
                                                                          GError** error);
VALA_EXTERN XmppXepJingleRtpParameters* xmpp_xep_jingle_rtp_parameters_construct_from_node (GType object_type,
                                                                                XmppXepJingleRtpModule* parent,
                                                                                XmppStanzaNode* node,
                                                                                GError** error);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_parameters_get_media (XmppXepJingleRtpParameters* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_parameters_get_ssrc (XmppXepJingleRtpParameters* self);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_parameters_get_rtcp_mux (XmppXepJingleRtpParameters* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_parameters_get_bandwidth (XmppXepJingleRtpParameters* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_parameters_get_bandwidth_type (XmppXepJingleRtpParameters* self);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_parameters_get_encryption_required (XmppXepJingleRtpParameters* self);
VALA_EXTERN XmppXepJingleRtpPayloadType* xmpp_xep_jingle_rtp_parameters_get_agreed_payload_type (XmppXepJingleRtpParameters* self);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_parameters_get_rtp_ready (XmppXepJingleRtpParameters* self);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_parameters_get_rtcp_ready (XmppXepJingleRtpParameters* self);
VALA_EXTERN GType xmpp_xep_jingle_rtp_stream_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRtpStream, g_object_unref)
VALA_EXTERN XmppXepJingleRtpStream* xmpp_xep_jingle_rtp_parameters_get_stream (XmppXepJingleRtpParameters* self);
VALA_EXTERN XmppXepJingleRtpHeaderExtension* xmpp_xep_jingle_rtp_header_extension_new (guint8 id,
                                                                           const gchar* uri);
VALA_EXTERN XmppXepJingleRtpHeaderExtension* xmpp_xep_jingle_rtp_header_extension_construct (GType object_type,
                                                                                 guint8 id,
                                                                                 const gchar* uri);
VALA_EXTERN XmppXepJingleRtpHeaderExtension* xmpp_xep_jingle_rtp_header_extension_parse (XmppStanzaNode* node);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_rtp_header_extension_to_xml (XmppXepJingleRtpHeaderExtension* self);
VALA_EXTERN guint8 xmpp_xep_jingle_rtp_header_extension_get_id (XmppXepJingleRtpHeaderExtension* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_header_extension_get_uri (XmppXepJingleRtpHeaderExtension* self);
VALA_EXTERN GType xmpp_xep_jingle_rtp_content_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRtpContentType, g_object_unref)
VALA_EXTERN XmppXepJingleRtpContentType* xmpp_xep_jingle_rtp_content_type_new (XmppXepJingleRtpModule* module);
VALA_EXTERN XmppXepJingleRtpContentType* xmpp_xep_jingle_rtp_content_type_construct (GType object_type,
                                                                         XmppXepJingleRtpModule* module);
VALA_EXTERN XmppXepJingleContentParameters* xmpp_xep_jingle_rtp_content_type_create_content_parameters (XmppXepJingleRtpContentType* self,
                                                                                            GObject* object,
                                                                                            GError** error);
VALA_EXTERN GType xmpp_xep_jingle_rtp_session_info_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRtpSessionInfoType, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_jingle_rtp_module_IDENTITY;
VALA_EXTERN XmppXepJingleRtpModule* xmpp_xep_jingle_rtp_module_construct (GType object_type);
VALA_EXTERN void xmpp_xep_jingle_rtp_module_get_supported_payloads (XmppXepJingleRtpModule* self,
                                                        const gchar* media,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
VALA_EXTERN GeeList* xmpp_xep_jingle_rtp_module_get_supported_payloads_finish (XmppXepJingleRtpModule* self,
                                                                   GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_jingle_rtp_module_is_payload_supported (XmppXepJingleRtpModule* self,
                                                      const gchar* media,
                                                      XmppXepJingleRtpPayloadType* payload_type,
                                                      GAsyncReadyCallback _callback_,
                                                      gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_module_is_payload_supported_finish (XmppXepJingleRtpModule* self,
                                                                 GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_jingle_rtp_module_pick_payload_type (XmppXepJingleRtpModule* self,
                                                   const gchar* media,
                                                   GeeList* payloads,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_);
VALA_EXTERN XmppXepJingleRtpPayloadType* xmpp_xep_jingle_rtp_module_pick_payload_type_finish (XmppXepJingleRtpModule* self,
                                                                                  GAsyncResult* _res_);
VALA_EXTERN XmppXepJingleRtpCrypto* xmpp_xep_jingle_rtp_module_generate_local_crypto (XmppXepJingleRtpModule* self);
VALA_EXTERN XmppXepJingleRtpCrypto* xmpp_xep_jingle_rtp_module_pick_remote_crypto (XmppXepJingleRtpModule* self,
                                                                       GeeList* cryptos);
VALA_EXTERN XmppXepJingleRtpCrypto* xmpp_xep_jingle_rtp_module_pick_local_crypto (XmppXepJingleRtpModule* self,
                                                                      XmppXepJingleRtpCrypto* remote);
VALA_EXTERN XmppXepJingleRtpStream* xmpp_xep_jingle_rtp_module_create_stream (XmppXepJingleRtpModule* self,
                                                                  XmppXepJingleContent* content);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_module_is_header_extension_supported (XmppXepJingleRtpModule* self,
                                                                   const gchar* media,
                                                                   XmppXepJingleRtpHeaderExtension* ext);
VALA_EXTERN GeeList* xmpp_xep_jingle_rtp_module_get_suggested_header_extensions (XmppXepJingleRtpModule* self,
                                                                     const gchar* media);
VALA_EXTERN void xmpp_xep_jingle_rtp_module_close_stream (XmppXepJingleRtpModule* self,
                                              XmppXepJingleRtpStream* stream);
VALA_EXTERN void xmpp_xep_jingle_rtp_module_start_call (XmppXepJingleRtpModule* self,
                                            XmppXmppStream* stream,
                                            XmppJid* receiver_full_jid,
                                            gboolean video,
                                            const gchar* sid,
                                            XmppJid* muji_room,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
VALA_EXTERN XmppXepJingleSession* xmpp_xep_jingle_rtp_module_start_call_finish (XmppXepJingleRtpModule* self,
                                                                    GAsyncResult* _res_,
                                                                    GError** error);
VALA_EXTERN void xmpp_xep_jingle_rtp_module_add_outgoing_video_content (XmppXepJingleRtpModule* self,
                                                            XmppXmppStream* stream,
                                                            XmppXepJingleSession* session,
                                                            XmppJid* muji_muc,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
VALA_EXTERN XmppXepJingleContent* xmpp_xep_jingle_rtp_module_add_outgoing_video_content_finish (XmppXepJingleRtpModule* self,
                                                                                    GAsyncResult* _res_,
                                                                                    GError** error);
VALA_EXTERN void xmpp_xep_jingle_rtp_module_is_available (XmppXepJingleRtpModule* self,
                                              XmppXmppStream* stream,
                                              XmppJid* full_jid,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_module_is_available_finish (XmppXepJingleRtpModule* self,
                                                         GAsyncResult* _res_);
VALA_EXTERN XmppXepJingleRtpCrypto* xmpp_xep_jingle_rtp_crypto_create (const gchar* crypto_suite,
                                                           guint8* key_and_salt,
                                                           gint key_and_salt_length1,
                                                           const gchar* session_params,
                                                           const gchar* tag);
VALA_EXTERN XmppXepJingleRtpCrypto* xmpp_xep_jingle_rtp_crypto_rekey (XmppXepJingleRtpCrypto* self,
                                                          guint8* key_and_salt,
                                                          gint key_and_salt_length1);
VALA_EXTERN XmppXepJingleRtpCrypto* xmpp_xep_jingle_rtp_crypto_parse (XmppStanzaNode* node);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_rtp_crypto_to_xml (XmppXepJingleRtpCrypto* self);
VALA_EXTERN XmppXepJingleRtpCrypto* xmpp_xep_jingle_rtp_crypto_new (void);
VALA_EXTERN XmppXepJingleRtpCrypto* xmpp_xep_jingle_rtp_crypto_construct (GType object_type);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_crypto_get_crypto_suite (XmppXepJingleRtpCrypto* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_crypto_get_key_params (XmppXepJingleRtpCrypto* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_crypto_get_session_params (XmppXepJingleRtpCrypto* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_crypto_get_tag (XmppXepJingleRtpCrypto* self);
VALA_EXTERN guint8* xmpp_xep_jingle_rtp_crypto_get_key_and_salt (XmppXepJingleRtpCrypto* self,
                                                     gint* result_length1);
VALA_EXTERN gchar* xmpp_xep_jingle_rtp_crypto_get_lifetime (XmppXepJingleRtpCrypto* self);
VALA_EXTERN gint xmpp_xep_jingle_rtp_crypto_get_mki (XmppXepJingleRtpCrypto* self);
VALA_EXTERN gint xmpp_xep_jingle_rtp_crypto_get_mki_length (XmppXepJingleRtpCrypto* self);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_crypto_get_is_valid (XmppXepJingleRtpCrypto* self);
VALA_EXTERN guint8* xmpp_xep_jingle_rtp_crypto_get_key (XmppXepJingleRtpCrypto* self,
                                            gint* result_length1);
VALA_EXTERN guint8* xmpp_xep_jingle_rtp_crypto_get_salt (XmppXepJingleRtpCrypto* self,
                                             gint* result_length1);
VALA_EXTERN gpointer xmpp_xep_jingle_rtp_rtcp_feedback_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_jingle_rtp_rtcp_feedback_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_jingle_rtp_param_spec_rtcp_feedback (const gchar* name,
                                                          const gchar* nick,
                                                          const gchar* blurb,
                                                          GType object_type,
                                                          GParamFlags flags);
VALA_EXTERN void xmpp_xep_jingle_rtp_value_set_rtcp_feedback (GValue* value,
                                                  gpointer v_object);
VALA_EXTERN void xmpp_xep_jingle_rtp_value_take_rtcp_feedback (GValue* value,
                                                   gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_jingle_rtp_value_get_rtcp_feedback (const GValue* value);
VALA_EXTERN GType xmpp_xep_jingle_rtp_rtcp_feedback_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRtpRtcpFeedback, xmpp_xep_jingle_rtp_rtcp_feedback_unref)
VALA_EXTERN XmppXepJingleRtpPayloadType* xmpp_xep_jingle_rtp_payload_type_parse (XmppStanzaNode* node);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_rtp_payload_type_to_xml (XmppXepJingleRtpPayloadType* self);
VALA_EXTERN XmppXepJingleRtpPayloadType* xmpp_xep_jingle_rtp_payload_type_clone (XmppXepJingleRtpPayloadType* self);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_payload_type_equals_func (XmppXepJingleRtpPayloadType* a,
                                                       XmppXepJingleRtpPayloadType* b);
VALA_EXTERN guint xmpp_xep_jingle_rtp_payload_type_hash_func (XmppXepJingleRtpPayloadType* payload_type);
VALA_EXTERN XmppXepJingleRtpPayloadType* xmpp_xep_jingle_rtp_payload_type_new (void);
VALA_EXTERN XmppXepJingleRtpPayloadType* xmpp_xep_jingle_rtp_payload_type_construct (GType object_type);
VALA_EXTERN guint8 xmpp_xep_jingle_rtp_payload_type_get_id (XmppXepJingleRtpPayloadType* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_payload_type_set_id (XmppXepJingleRtpPayloadType* self,
                                              guint8 value);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_payload_type_get_name (XmppXepJingleRtpPayloadType* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_payload_type_set_name (XmppXepJingleRtpPayloadType* self,
                                                const gchar* value);
VALA_EXTERN guint8 xmpp_xep_jingle_rtp_payload_type_get_channels (XmppXepJingleRtpPayloadType* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_payload_type_set_channels (XmppXepJingleRtpPayloadType* self,
                                                    guint8 value);
VALA_EXTERN guint32 xmpp_xep_jingle_rtp_payload_type_get_clockrate (XmppXepJingleRtpPayloadType* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_payload_type_set_clockrate (XmppXepJingleRtpPayloadType* self,
                                                     guint32 value);
VALA_EXTERN guint32 xmpp_xep_jingle_rtp_payload_type_get_maxptime (XmppXepJingleRtpPayloadType* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_payload_type_set_maxptime (XmppXepJingleRtpPayloadType* self,
                                                    guint32 value);
VALA_EXTERN guint32 xmpp_xep_jingle_rtp_payload_type_get_ptime (XmppXepJingleRtpPayloadType* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_payload_type_set_ptime (XmppXepJingleRtpPayloadType* self,
                                                 guint32 value);
VALA_EXTERN XmppXepJingleRtpRtcpFeedback* xmpp_xep_jingle_rtp_rtcp_feedback_new (const gchar* type,
                                                                     const gchar* subtype);
VALA_EXTERN XmppXepJingleRtpRtcpFeedback* xmpp_xep_jingle_rtp_rtcp_feedback_construct (GType object_type,
                                                                           const gchar* type,
                                                                           const gchar* subtype);
VALA_EXTERN XmppXepJingleRtpRtcpFeedback* xmpp_xep_jingle_rtp_rtcp_feedback_parse (XmppStanzaNode* node);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_rtp_rtcp_feedback_to_xml (XmppXepJingleRtpRtcpFeedback* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_rtcp_feedback_get_type_ (XmppXepJingleRtpRtcpFeedback* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_rtcp_feedback_get_subtype (XmppXepJingleRtpRtcpFeedback* self);
VALA_EXTERN GType xmpp_xep_jingle_rtp_call_session_info_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void xmpp_xep_jingle_rtp_session_info_type_send_mute (XmppXepJingleRtpSessionInfoType* self,
                                                      XmppXepJingleSession* session,
                                                      gboolean mute,
                                                      const gchar* media);
VALA_EXTERN void xmpp_xep_jingle_rtp_session_info_type_send_ringing (XmppXepJingleRtpSessionInfoType* self,
                                                         XmppXepJingleSession* session);
VALA_EXTERN XmppXepJingleRtpSessionInfoType* xmpp_xep_jingle_rtp_session_info_type_new (void);
VALA_EXTERN XmppXepJingleRtpSessionInfoType* xmpp_xep_jingle_rtp_session_info_type_construct (GType object_type);
VALA_EXTERN XmppXepJingleRtpStream* xmpp_xep_jingle_rtp_stream_construct (GType object_type,
                                                              XmppXepJingleContent* content);
VALA_EXTERN void xmpp_xep_jingle_rtp_stream_on_recv_rtp_data (XmppXepJingleRtpStream* self,
                                                  GBytes* bytes);
VALA_EXTERN void xmpp_xep_jingle_rtp_stream_on_recv_rtcp_data (XmppXepJingleRtpStream* self,
                                                   GBytes* bytes);
VALA_EXTERN void xmpp_xep_jingle_rtp_stream_on_rtp_ready (XmppXepJingleRtpStream* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_stream_on_rtcp_ready (XmppXepJingleRtpStream* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_stream_create (XmppXepJingleRtpStream* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_stream_destroy (XmppXepJingleRtpStream* self);
VALA_EXTERN gchar* xmpp_xep_jingle_rtp_stream_to_string (XmppXepJingleRtpStream* self);
VALA_EXTERN XmppXepJingleContent* xmpp_xep_jingle_rtp_stream_get_content (XmppXepJingleRtpStream* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_stream_set_content (XmppXepJingleRtpStream* self,
                                             XmppXepJingleContent* value);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_stream_get_name (XmppXepJingleRtpStream* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_rtp_stream_get_media (XmppXepJingleRtpStream* self);
VALA_EXTERN XmppXepJingleRtpPayloadType* xmpp_xep_jingle_rtp_stream_get_payload_type (XmppXepJingleRtpStream* self);
VALA_EXTERN XmppXepJingleRtpCrypto* xmpp_xep_jingle_rtp_stream_get_local_crypto (XmppXepJingleRtpStream* self);
VALA_EXTERN XmppXepJingleRtpCrypto* xmpp_xep_jingle_rtp_stream_get_remote_crypto (XmppXepJingleRtpStream* self);
VALA_EXTERN GeeList* xmpp_xep_jingle_rtp_stream_get_header_extensions (XmppXepJingleRtpStream* self);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_stream_get_sending (XmppXepJingleRtpStream* self);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_stream_get_receiving (XmppXepJingleRtpStream* self);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_stream_get_rtcp_mux (XmppXepJingleRtpStream* self);
VALA_EXTERN gboolean xmpp_xep_jingle_rtp_stream_get_remb_enabled (XmppXepJingleRtpStream* self);
VALA_EXTERN guint xmpp_xep_jingle_rtp_stream_get_target_receive_bitrate (XmppXepJingleRtpStream* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_stream_set_target_receive_bitrate (XmppXepJingleRtpStream* self,
                                                            guint value);
VALA_EXTERN guint xmpp_xep_jingle_rtp_stream_get_target_send_bitrate (XmppXepJingleRtpStream* self);
VALA_EXTERN void xmpp_xep_jingle_rtp_stream_set_target_send_bitrate (XmppXepJingleRtpStream* self,
                                                         guint value);
VALA_EXTERN gpointer xmpp_xep_jingle_ice_udp_candidate_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_jingle_ice_udp_candidate_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_jingle_ice_udp_param_spec_candidate (const gchar* name,
                                                          const gchar* nick,
                                                          const gchar* blurb,
                                                          GType object_type,
                                                          GParamFlags flags);
VALA_EXTERN void xmpp_xep_jingle_ice_udp_value_set_candidate (GValue* value,
                                                  gpointer v_object);
VALA_EXTERN void xmpp_xep_jingle_ice_udp_value_take_candidate (GValue* value,
                                                   gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_jingle_ice_udp_value_get_candidate (const GValue* value);
VALA_EXTERN GType xmpp_xep_jingle_ice_udp_candidate_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleIceUdpCandidate, xmpp_xep_jingle_ice_udp_candidate_unref)
VALA_EXTERN GType xmpp_xep_jingle_ice_udp_candidate_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppXepJingleIceUdpCandidateType xmpp_xep_jingle_ice_udp_candidate_type_parse (const gchar* str,
                                                                               GError** error);
VALA_EXTERN gchar* xmpp_xep_jingle_ice_udp_candidate_type_to_string (XmppXepJingleIceUdpCandidateType self);
VALA_EXTERN XmppXepJingleIceUdpCandidate* xmpp_xep_jingle_ice_udp_candidate_parse (XmppStanzaNode* node,
                                                                       GError** error);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_ice_udp_candidate_to_xml (XmppXepJingleIceUdpCandidate* self);
VALA_EXTERN gboolean xmpp_xep_jingle_ice_udp_candidate_equals (XmppXepJingleIceUdpCandidate* self,
                                                   XmppXepJingleIceUdpCandidate* c);
VALA_EXTERN gboolean xmpp_xep_jingle_ice_udp_candidate_equals_func (XmppXepJingleIceUdpCandidate* c1,
                                                        XmppXepJingleIceUdpCandidate* c2);
VALA_EXTERN XmppXepJingleIceUdpCandidate* xmpp_xep_jingle_ice_udp_candidate_new (void);
VALA_EXTERN XmppXepJingleIceUdpCandidate* xmpp_xep_jingle_ice_udp_candidate_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_jingle_ice_udp_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleIceUdpModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_jingle_ice_udp_module_IDENTITY;
VALA_EXTERN XmppXepJingleTransportParameters* xmpp_xep_jingle_ice_udp_module_create_transport_parameters (XmppXepJingleIceUdpModule* self,
                                                                                              XmppXmppStream* stream,
                                                                                              guint8 components,
                                                                                              XmppJid* local_full_jid,
                                                                                              XmppJid* peer_full_jid,
                                                                                              GError** error);
VALA_EXTERN XmppXepJingleTransportParameters* xmpp_xep_jingle_ice_udp_module_parse_transport_parameters (XmppXepJingleIceUdpModule* self,
                                                                                             XmppXmppStream* stream,
                                                                                             guint8 components,
                                                                                             XmppJid* local_full_jid,
                                                                                             XmppJid* peer_full_jid,
                                                                                             XmppStanzaNode* transport,
                                                                                             GError** error);
VALA_EXTERN XmppXepJingleIceUdpModule* xmpp_xep_jingle_ice_udp_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleIceUdpIceUdpTransportParameters, g_object_unref)
VALA_EXTERN XmppXepJingleIceUdpIceUdpTransportParameters* xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_construct (GType object_type,
                                                                                                              guint8 components,
                                                                                                              XmppJid* local_full_jid,
                                                                                                              XmppJid* peer_full_jid,
                                                                                                              XmppStanzaNode* node);
VALA_EXTERN void xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_init (XmppXepJingleIceUdpIceUdpTransportParameters* self,
                                                                const gchar* ufrag,
                                                                const gchar* pwd);
VALA_EXTERN void xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_unset_content (XmppXepJingleIceUdpIceUdpTransportParameters* self);
VALA_EXTERN void xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_handle_transport_accept (XmppXepJingleIceUdpIceUdpTransportParameters* self,
                                                                                   XmppStanzaNode* node,
                                                                                   GError** error);
VALA_EXTERN void xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_handle_transport_info (XmppXepJingleIceUdpIceUdpTransportParameters* self,
                                                                                 XmppStanzaNode* node,
                                                                                 GError** error);
VALA_EXTERN void xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_create_transport_connection (XmppXepJingleIceUdpIceUdpTransportParameters* self,
                                                                                       XmppXmppStream* stream,
                                                                                       XmppXepJingleContent* content);
VALA_EXTERN void xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_add_local_candidate_threadsafe (XmppXepJingleIceUdpIceUdpTransportParameters* self,
                                                                                          XmppXepJingleIceUdpCandidate* candidate);
VALA_EXTERN const gchar* xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_get_remote_pwd (XmppXepJingleIceUdpIceUdpTransportParameters* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_get_remote_ufrag (XmppXepJingleIceUdpIceUdpTransportParameters* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_get_local_pwd (XmppXepJingleIceUdpIceUdpTransportParameters* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_get_local_ufrag (XmppXepJingleIceUdpIceUdpTransportParameters* self);
VALA_EXTERN XmppJid* xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_get_local_full_jid (XmppXepJingleIceUdpIceUdpTransportParameters* self);
VALA_EXTERN XmppJid* xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_get_peer_full_jid (XmppXepJingleIceUdpIceUdpTransportParameters* self);
VALA_EXTERN gboolean xmpp_xep_jingle_ice_udp_ice_udp_transport_parameters_get_incoming (XmppXepJingleIceUdpIceUdpTransportParameters* self);
VALA_EXTERN GType xmpp_xep_jingle_raw_udp_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRawUdpModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_jingle_raw_udp_module_IDENTITY;
VALA_EXTERN void xmpp_xep_jingle_raw_udp_module_set_local_ip_address_handler (XmppXepJingleRawUdpModule* self,
                                                                  XmppXepJingleRawUdpGetLocalIpAddresses get_local_ip_addresses,
                                                                  gpointer get_local_ip_addresses_target,
                                                                  GDestroyNotify get_local_ip_addresses_target_destroy_notify);
VALA_EXTERN GeeList* xmpp_xep_jingle_raw_udp_module_get_local_ip_addresses (XmppXepJingleRawUdpModule* self);
VALA_EXTERN XmppXepJingleRawUdpModule* xmpp_xep_jingle_raw_udp_module_new (void);
VALA_EXTERN XmppXepJingleRawUdpModule* xmpp_xep_jingle_raw_udp_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_jingle_raw_udp_transport_parameters_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRawUdpTransportParameters, g_object_unref)
VALA_EXTERN GType xmpp_xep_jingle_raw_udp_candidate_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleRawUdpCandidate, g_object_unref)
VALA_EXTERN XmppXepJingleRawUdpTransportParameters* xmpp_xep_jingle_raw_udp_transport_parameters_new (guint8 components,
                                                                                          XmppStanzaNode* node);
VALA_EXTERN XmppXepJingleRawUdpTransportParameters* xmpp_xep_jingle_raw_udp_transport_parameters_construct (GType object_type,
                                                                                                guint8 components,
                                                                                                XmppStanzaNode* node);
VALA_EXTERN XmppXepJingleRawUdpCandidate* xmpp_xep_jingle_raw_udp_candidate_new (void);
VALA_EXTERN XmppXepJingleRawUdpCandidate* xmpp_xep_jingle_raw_udp_candidate_construct (GType object_type);
VALA_EXTERN gint xmpp_xep_jingle_raw_udp_candidate_get_component (XmppXepJingleRawUdpCandidate* self);
VALA_EXTERN void xmpp_xep_jingle_raw_udp_candidate_set_component (XmppXepJingleRawUdpCandidate* self,
                                                      gint value);
VALA_EXTERN gint xmpp_xep_jingle_raw_udp_candidate_get_generation (XmppXepJingleRawUdpCandidate* self);
VALA_EXTERN void xmpp_xep_jingle_raw_udp_candidate_set_generation (XmppXepJingleRawUdpCandidate* self,
                                                       gint value);
VALA_EXTERN const gchar* xmpp_xep_jingle_raw_udp_candidate_get_id (XmppXepJingleRawUdpCandidate* self);
VALA_EXTERN void xmpp_xep_jingle_raw_udp_candidate_set_id (XmppXepJingleRawUdpCandidate* self,
                                               const gchar* value);
VALA_EXTERN GInetAddress* xmpp_xep_jingle_raw_udp_candidate_get_ip (XmppXepJingleRawUdpCandidate* self);
VALA_EXTERN void xmpp_xep_jingle_raw_udp_candidate_set_ip (XmppXepJingleRawUdpCandidate* self,
                                               GInetAddress* value);
VALA_EXTERN guint xmpp_xep_jingle_raw_udp_candidate_get_port (XmppXepJingleRawUdpCandidate* self);
VALA_EXTERN void xmpp_xep_jingle_raw_udp_candidate_set_port (XmppXepJingleRawUdpCandidate* self,
                                                 guint value);
VALA_EXTERN GType xmpp_xep_message_delivery_receipts_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMessageDeliveryReceiptsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_message_delivery_receipts_module_IDENTITY;
VALA_EXTERN void xmpp_xep_message_delivery_receipts_module_send_received (XmppXepMessageDeliveryReceiptsModule* self,
                                                              XmppXmppStream* stream,
                                                              XmppJid* from,
                                                              const gchar* message_id);
VALA_EXTERN gboolean xmpp_xep_message_delivery_receipts_module_requests_receipt (XmppMessageStanza* message);
VALA_EXTERN XmppXepMessageDeliveryReceiptsModule* xmpp_xep_message_delivery_receipts_module_new (void);
VALA_EXTERN XmppXepMessageDeliveryReceiptsModule* xmpp_xep_message_delivery_receipts_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_message_delivery_receipts_send_pipeline_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMessageDeliveryReceiptsSendPipelineListener, g_object_unref)
VALA_EXTERN XmppXepMessageDeliveryReceiptsSendPipelineListener* xmpp_xep_message_delivery_receipts_send_pipeline_listener_new (void);
VALA_EXTERN XmppXepMessageDeliveryReceiptsSendPipelineListener* xmpp_xep_message_delivery_receipts_send_pipeline_listener_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_blocking_command_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepBlockingCommandModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_blocking_command_module_IDENTITY;
VALA_EXTERN gboolean xmpp_xep_blocking_command_module_is_blocked (XmppXepBlockingCommandModule* self,
                                                      XmppXmppStream* stream,
                                                      const gchar* jid);
VALA_EXTERN gboolean xmpp_xep_blocking_command_module_block (XmppXepBlockingCommandModule* self,
                                                 XmppXmppStream* stream,
                                                 gchar** jids,
                                                 gint jids_length1);
VALA_EXTERN gboolean xmpp_xep_blocking_command_module_unblock (XmppXepBlockingCommandModule* self,
                                                   XmppXmppStream* stream,
                                                   gchar** jids,
                                                   gint jids_length1);
VALA_EXTERN void xmpp_xep_blocking_command_module_unblock_all (XmppXepBlockingCommandModule* self,
                                                   XmppXmppStream* stream);
VALA_EXTERN gboolean xmpp_xep_blocking_command_module_is_supported (XmppXepBlockingCommandModule* self,
                                                        XmppXmppStream* stream);
VALA_EXTERN XmppXepBlockingCommandModule* xmpp_xep_blocking_command_module_new (void);
VALA_EXTERN XmppXepBlockingCommandModule* xmpp_xep_blocking_command_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_blocking_command_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepBlockingCommandFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_xep_blocking_command_flag_IDENTITY;
VALA_EXTERN XmppXepBlockingCommandFlag* xmpp_xep_blocking_command_flag_new (void);
VALA_EXTERN XmppXepBlockingCommandFlag* xmpp_xep_blocking_command_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_stream_management_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepStreamManagementModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_stream_management_module_IDENTITY;
VALA_EXTERN void xmpp_xep_stream_management_module_require (XmppXmppStream* stream);
VALA_EXTERN XmppXepStreamManagementModule* xmpp_xep_stream_management_module_new (void);
VALA_EXTERN XmppXepStreamManagementModule* xmpp_xep_stream_management_module_construct (GType object_type);
VALA_EXTERN const gchar* xmpp_xep_stream_management_module_get_session_id (XmppXepStreamManagementModule* self);
VALA_EXTERN void xmpp_xep_stream_management_module_set_session_id (XmppXepStreamManagementModule* self,
                                                       const gchar* value);
VALA_EXTERN GType xmpp_xep_stream_management_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepStreamManagementFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_xep_stream_management_flag_IDENTITY;
VALA_EXTERN XmppXepStreamManagementFlag* xmpp_xep_stream_management_flag_new (void);
VALA_EXTERN XmppXepStreamManagementFlag* xmpp_xep_stream_management_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_ping_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepPingModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_ping_module_IDENTITY;
VALA_EXTERN void xmpp_xep_ping_module_send_ping (XmppXepPingModule* self,
                                     XmppXmppStream* stream,
                                     XmppJid* jid,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
VALA_EXTERN XmppIqStanza* xmpp_xep_ping_module_send_ping_finish (XmppXepPingModule* self,
                                                     GAsyncResult* _res_);
VALA_EXTERN XmppXepPingModule* xmpp_xep_ping_module_new (void);
VALA_EXTERN XmppXepPingModule* xmpp_xep_ping_module_construct (GType object_type);
VALA_EXTERN GDateTime* xmpp_xep_delayed_delivery_get_time_for_node (XmppStanzaNode* node);
VALA_EXTERN GDateTime* xmpp_xep_delayed_delivery_get_time_for_message (XmppMessageStanza* message,
                                                           XmppJid* jid);
VALA_EXTERN GType xmpp_xep_delayed_delivery_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDelayedDeliveryModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_delayed_delivery_module_IDENTITY;
VALA_EXTERN void xmpp_xep_delayed_delivery_module_set_message_delay (XmppMessageStanza* message,
                                                         GDateTime* datetime);
VALA_EXTERN XmppXepDelayedDeliveryModule* xmpp_xep_delayed_delivery_module_new (void);
VALA_EXTERN XmppXepDelayedDeliveryModule* xmpp_xep_delayed_delivery_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_delayed_delivery_received_pipeline_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDelayedDeliveryReceivedPipelineListener, g_object_unref)
VALA_EXTERN XmppXepDelayedDeliveryReceivedPipelineListener* xmpp_xep_delayed_delivery_received_pipeline_listener_new (void);
VALA_EXTERN XmppXepDelayedDeliveryReceivedPipelineListener* xmpp_xep_delayed_delivery_received_pipeline_listener_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_delayed_delivery_message_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDelayedDeliveryMessageFlag, g_object_unref)
VALA_EXTERN XmppXepDelayedDeliveryMessageFlag* xmpp_xep_delayed_delivery_message_flag_new (GDateTime* datetime);
VALA_EXTERN XmppXepDelayedDeliveryMessageFlag* xmpp_xep_delayed_delivery_message_flag_construct (GType object_type,
                                                                                     GDateTime* datetime);
VALA_EXTERN XmppXepDelayedDeliveryMessageFlag* xmpp_xep_delayed_delivery_message_flag_get_flag (XmppMessageStanza* message);
VALA_EXTERN GDateTime* xmpp_xep_delayed_delivery_message_flag_get_datetime (XmppXepDelayedDeliveryMessageFlag* self);
VALA_EXTERN void xmpp_xep_external_service_discovery_request_services (XmppXmppStream* stream,
                                                           GAsyncReadyCallback _callback_,
                                                           gpointer _user_data_);
VALA_EXTERN gpointer xmpp_xep_external_service_discovery_service_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_external_service_discovery_service_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_external_service_discovery_param_spec_service (const gchar* name,
                                                                    const gchar* nick,
                                                                    const gchar* blurb,
                                                                    GType object_type,
                                                                    GParamFlags flags);
VALA_EXTERN void xmpp_xep_external_service_discovery_value_set_service (GValue* value,
                                                            gpointer v_object);
VALA_EXTERN void xmpp_xep_external_service_discovery_value_take_service (GValue* value,
                                                             gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_external_service_discovery_value_get_service (const GValue* value);
VALA_EXTERN GType xmpp_xep_external_service_discovery_service_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepExternalServiceDiscoveryService, xmpp_xep_external_service_discovery_service_unref)
VALA_EXTERN GeeList* xmpp_xep_external_service_discovery_request_services_finish (GAsyncResult* _res_);
VALA_EXTERN XmppXepExternalServiceDiscoveryService* xmpp_xep_external_service_discovery_service_new (void);
VALA_EXTERN XmppXepExternalServiceDiscoveryService* xmpp_xep_external_service_discovery_service_construct (GType object_type);
VALA_EXTERN const gchar* xmpp_xep_external_service_discovery_service_get_host (XmppXepExternalServiceDiscoveryService* self);
VALA_EXTERN void xmpp_xep_external_service_discovery_service_set_host (XmppXepExternalServiceDiscoveryService* self,
                                                           const gchar* value);
VALA_EXTERN guint xmpp_xep_external_service_discovery_service_get_port (XmppXepExternalServiceDiscoveryService* self);
VALA_EXTERN void xmpp_xep_external_service_discovery_service_set_port (XmppXepExternalServiceDiscoveryService* self,
                                                           guint value);
VALA_EXTERN const gchar* xmpp_xep_external_service_discovery_service_get_ty (XmppXepExternalServiceDiscoveryService* self);
VALA_EXTERN void xmpp_xep_external_service_discovery_service_set_ty (XmppXepExternalServiceDiscoveryService* self,
                                                         const gchar* value);
VALA_EXTERN const gchar* xmpp_xep_external_service_discovery_service_get_username (XmppXepExternalServiceDiscoveryService* self);
VALA_EXTERN void xmpp_xep_external_service_discovery_service_set_username (XmppXepExternalServiceDiscoveryService* self,
                                                               const gchar* value);
VALA_EXTERN const gchar* xmpp_xep_external_service_discovery_service_get_password (XmppXepExternalServiceDiscoveryService* self);
VALA_EXTERN void xmpp_xep_external_service_discovery_service_set_password (XmppXepExternalServiceDiscoveryService* self,
                                                               const gchar* value);
VALA_EXTERN GDateTime* xmpp_xep_external_service_discovery_service_get_expires (XmppXepExternalServiceDiscoveryService* self);
VALA_EXTERN void xmpp_xep_external_service_discovery_service_set_expires (XmppXepExternalServiceDiscoveryService* self,
                                                              GDateTime* value);
VALA_EXTERN const gchar* xmpp_xep_external_service_discovery_service_get_transport (XmppXepExternalServiceDiscoveryService* self);
VALA_EXTERN void xmpp_xep_external_service_discovery_service_set_transport (XmppXepExternalServiceDiscoveryService* self,
                                                                const gchar* value);
VALA_EXTERN const gchar* xmpp_xep_external_service_discovery_service_get_name (XmppXepExternalServiceDiscoveryService* self);
VALA_EXTERN void xmpp_xep_external_service_discovery_service_set_name (XmppXepExternalServiceDiscoveryService* self,
                                                           const gchar* value);
VALA_EXTERN gboolean xmpp_xep_external_service_discovery_service_get_restricted (XmppXepExternalServiceDiscoveryService* self);
VALA_EXTERN void xmpp_xep_external_service_discovery_service_set_restricted (XmppXepExternalServiceDiscoveryService* self,
                                                                 gboolean value);
VALA_EXTERN GType xmpp_xep_jingle_file_transfer_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleFileTransferModule, g_object_unref)
VALA_EXTERN GType xmpp_xep_jingle_file_transfer_session_info_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleFileTransferSessionInfoType, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_jingle_file_transfer_module_IDENTITY;
VALA_EXTERN XmppXepJingleContentParameters* xmpp_xep_jingle_file_transfer_module_create_content_parameters (XmppXepJingleFileTransferModule* self,
                                                                                                GObject* object,
                                                                                                GError** error);
VALA_EXTERN void xmpp_xep_jingle_file_transfer_module_is_available (XmppXepJingleFileTransferModule* self,
                                                        XmppXmppStream* stream,
                                                        XmppJid* full_jid,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_jingle_file_transfer_module_is_available_finish (XmppXepJingleFileTransferModule* self,
                                                                   GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_jingle_file_transfer_module_offer_file_stream (XmppXepJingleFileTransferModule* self,
                                                             XmppXmppStream* stream,
                                                             XmppJid* receiver_full_jid,
                                                             GInputStream* input_stream,
                                                             const gchar* basename,
                                                             gint64 size,
                                                             const gchar* precondition_name,
                                                             GObject* precondition_options,
                                                             GAsyncReadyCallback _callback_,
                                                             gpointer _user_data_);
VALA_EXTERN void xmpp_xep_jingle_file_transfer_module_offer_file_stream_finish (XmppXepJingleFileTransferModule* self,
                                                                    GAsyncResult* _res_,
                                                                    GError** error);
VALA_EXTERN XmppXepJingleFileTransferModule* xmpp_xep_jingle_file_transfer_module_new (void);
VALA_EXTERN XmppXepJingleFileTransferModule* xmpp_xep_jingle_file_transfer_module_construct (GType object_type);
VALA_EXTERN XmppXepJingleFileTransferSessionInfoType* xmpp_xep_jingle_file_transfer_session_info_type_new (void);
VALA_EXTERN XmppXepJingleFileTransferSessionInfoType* xmpp_xep_jingle_file_transfer_session_info_type_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_jingle_file_transfer_parameters_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleFileTransferParameters, g_object_unref)
VALA_EXTERN XmppXepJingleFileTransferParameters* xmpp_xep_jingle_file_transfer_parameters_new (XmppXepJingleFileTransferModule* parent,
                                                                                   XmppStanzaNode* original_description,
                                                                                   const gchar* media_type,
                                                                                   const gchar* name,
                                                                                   gint64 size);
VALA_EXTERN XmppXepJingleFileTransferParameters* xmpp_xep_jingle_file_transfer_parameters_construct (GType object_type,
                                                                                         XmppXepJingleFileTransferModule* parent,
                                                                                         XmppStanzaNode* original_description,
                                                                                         const gchar* media_type,
                                                                                         const gchar* name,
                                                                                         gint64 size);
VALA_EXTERN XmppXepJingleFileTransferParameters* xmpp_xep_jingle_file_transfer_parameters_parse (XmppXepJingleFileTransferModule* parent,
                                                                                     XmppStanzaNode* description,
                                                                                     GError** error);
VALA_EXTERN void xmpp_xep_jingle_file_transfer_parameters_modify (XmppXepJingleFileTransferParameters* self,
                                                      XmppXmppStream* stream,
                                                      XmppXepJingleSession* session,
                                                      XmppXepJingleContent* content,
                                                      XmppXepJingleSenders senders);
VALA_EXTERN const gchar* xmpp_xep_jingle_file_transfer_parameters_get_name (XmppXepJingleFileTransferParameters* self);
VALA_EXTERN gint64 xmpp_xep_jingle_file_transfer_parameters_get_size (XmppXepJingleFileTransferParameters* self);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_file_transfer_parameters_get_original_description (XmppXepJingleFileTransferParameters* self);
VALA_EXTERN GType xmpp_xep_jingle_file_transfer_file_transfer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleFileTransferFileTransfer, g_object_unref)
VALA_EXTERN XmppXepJingleFileTransferFileTransfer* xmpp_xep_jingle_file_transfer_file_transfer_new (XmppXepJingleSession* session,
                                                                                        XmppXepJingleContent* content,
                                                                                        XmppXepJingleFileTransferParameters* parameters);
VALA_EXTERN XmppXepJingleFileTransferFileTransfer* xmpp_xep_jingle_file_transfer_file_transfer_construct (GType object_type,
                                                                                              XmppXepJingleSession* session,
                                                                                              XmppXepJingleContent* content,
                                                                                              XmppXepJingleFileTransferParameters* parameters);
VALA_EXTERN void xmpp_xep_jingle_file_transfer_file_transfer_accept (XmppXepJingleFileTransferFileTransfer* self,
                                                         XmppXmppStream* stream,
                                                         GAsyncReadyCallback _callback_,
                                                         gpointer _user_data_);
VALA_EXTERN void xmpp_xep_jingle_file_transfer_file_transfer_accept_finish (XmppXepJingleFileTransferFileTransfer* self,
                                                                GAsyncResult* _res_,
                                                                GError** error);
VALA_EXTERN void xmpp_xep_jingle_file_transfer_file_transfer_reject (XmppXepJingleFileTransferFileTransfer* self,
                                                         XmppXmppStream* stream);
VALA_EXTERN XmppJid* xmpp_xep_jingle_file_transfer_file_transfer_get_peer (XmppXepJingleFileTransferFileTransfer* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_file_transfer_file_transfer_get_file_name (XmppXepJingleFileTransferFileTransfer* self);
VALA_EXTERN gint64 xmpp_xep_jingle_file_transfer_file_transfer_get_size (XmppXepJingleFileTransferFileTransfer* self);
VALA_EXTERN XmppXepJingleSecurityParameters* xmpp_xep_jingle_file_transfer_file_transfer_get_security (XmppXepJingleFileTransferFileTransfer* self);
VALA_EXTERN GInputStream* xmpp_xep_jingle_file_transfer_file_transfer_get_stream (XmppXepJingleFileTransferFileTransfer* self);
VALA_EXTERN GType xmpp_xep_direct_muc_invitations_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepDirectMucInvitationsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_direct_muc_invitations_module_IDENTITY;
VALA_EXTERN void xmpp_xep_direct_muc_invitations_module_invite (XmppXepDirectMucInvitationsModule* self,
                                                    XmppXmppStream* stream,
                                                    XmppJid* to_muc,
                                                    XmppJid* jid);
VALA_EXTERN XmppXepDirectMucInvitationsModule* xmpp_xep_direct_muc_invitations_module_new (void);
VALA_EXTERN XmppXepDirectMucInvitationsModule* xmpp_xep_direct_muc_invitations_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_jingle_socks5_bytestreams_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleSocks5BytestreamsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_jingle_socks5_bytestreams_module_IDENTITY;
VALA_EXTERN XmppXepJingleSocks5BytestreamsModule* xmpp_xep_jingle_socks5_bytestreams_module_new (void);
VALA_EXTERN XmppXepJingleSocks5BytestreamsModule* xmpp_xep_jingle_socks5_bytestreams_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_jingle_socks5_bytestreams_candidate_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppXepJingleSocks5BytestreamsCandidateType xmpp_xep_jingle_socks5_bytestreams_candidate_type_parse (const gchar* type,
                                                                                                     GError** error);
VALA_EXTERN gchar* xmpp_xep_jingle_socks5_bytestreams_candidate_type_to_string (XmppXepJingleSocks5BytestreamsCandidateType self);
VALA_EXTERN gint xmpp_xep_jingle_socks5_bytestreams_candidate_type_type_preference (XmppXepJingleSocks5BytestreamsCandidateType self);
VALA_EXTERN GType xmpp_xep_jingle_socks5_bytestreams_candidate_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleSocks5BytestreamsCandidate, g_object_unref)
VALA_EXTERN XmppXepJingleSocks5BytestreamsCandidate* xmpp_xep_jingle_socks5_bytestreams_candidate_new_build (const gchar* cid,
                                                                                                 const gchar* host,
                                                                                                 XmppJid* jid,
                                                                                                 gint port,
                                                                                                 gint local_priority,
                                                                                                 XmppXepJingleSocks5BytestreamsCandidateType type);
VALA_EXTERN XmppXepJingleSocks5BytestreamsCandidate* xmpp_xep_jingle_socks5_bytestreams_candidate_construct_build (GType object_type,
                                                                                                       const gchar* cid,
                                                                                                       const gchar* host,
                                                                                                       XmppJid* jid,
                                                                                                       gint port,
                                                                                                       gint local_priority,
                                                                                                       XmppXepJingleSocks5BytestreamsCandidateType type);
VALA_EXTERN XmppXepJingleSocks5BytestreamsCandidate* xmpp_xep_jingle_socks5_bytestreams_candidate_new_proxy (const gchar* cid,
                                                                                                 XmppXepSocks5BytestreamsProxy* proxy,
                                                                                                 gint local_priority);
VALA_EXTERN XmppXepJingleSocks5BytestreamsCandidate* xmpp_xep_jingle_socks5_bytestreams_candidate_construct_proxy (GType object_type,
                                                                                                       const gchar* cid,
                                                                                                       XmppXepSocks5BytestreamsProxy* proxy,
                                                                                                       gint local_priority);
VALA_EXTERN XmppXepJingleSocks5BytestreamsCandidate* xmpp_xep_jingle_socks5_bytestreams_candidate_parse (XmppStanzaNode* candidate,
                                                                                             GError** error);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_socks5_bytestreams_candidate_to_xml (XmppXepJingleSocks5BytestreamsCandidate* self);
VALA_EXTERN const gchar* xmpp_xep_jingle_socks5_bytestreams_candidate_get_cid (XmppXepJingleSocks5BytestreamsCandidate* self);
VALA_EXTERN gint xmpp_xep_jingle_socks5_bytestreams_candidate_get_priority (XmppXepJingleSocks5BytestreamsCandidate* self);
VALA_EXTERN XmppXepJingleSocks5BytestreamsCandidateType xmpp_xep_jingle_socks5_bytestreams_candidate_get_type_ (XmppXepJingleSocks5BytestreamsCandidate* self);
VALA_EXTERN GType xmpp_xep_jingle_in_band_bytestreams_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleInBandBytestreamsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_jingle_in_band_bytestreams_module_IDENTITY;
VALA_EXTERN XmppXepJingleInBandBytestreamsModule* xmpp_xep_jingle_in_band_bytestreams_module_new (void);
VALA_EXTERN XmppXepJingleInBandBytestreamsModule* xmpp_xep_jingle_in_band_bytestreams_module_construct (GType object_type);
VALA_EXTERN gpointer xmpp_xep_jingle_content_thumbnails_thumbnail_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_jingle_content_thumbnails_thumbnail_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_jingle_content_thumbnails_param_spec_thumbnail (const gchar* name,
                                                                     const gchar* nick,
                                                                     const gchar* blurb,
                                                                     GType object_type,
                                                                     GParamFlags flags);
VALA_EXTERN void xmpp_xep_jingle_content_thumbnails_value_set_thumbnail (GValue* value,
                                                             gpointer v_object);
VALA_EXTERN void xmpp_xep_jingle_content_thumbnails_value_take_thumbnail (GValue* value,
                                                              gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_jingle_content_thumbnails_value_get_thumbnail (const GValue* value);
VALA_EXTERN GType xmpp_xep_jingle_content_thumbnails_thumbnail_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleContentThumbnailsThumbnail, xmpp_xep_jingle_content_thumbnails_thumbnail_unref)
VALA_EXTERN GeeList* xmpp_xep_jingle_content_thumbnails_get_thumbnails (XmppStanzaNode* node);
VALA_EXTERN XmppStanzaNode* xmpp_xep_jingle_content_thumbnails_thumbnail_to_stanza_node (XmppXepJingleContentThumbnailsThumbnail* self);
VALA_EXTERN XmppXepJingleContentThumbnailsThumbnail* xmpp_xep_jingle_content_thumbnails_thumbnail_from_stanza_node (XmppStanzaNode* node);
VALA_EXTERN XmppXepJingleContentThumbnailsThumbnail* xmpp_xep_jingle_content_thumbnails_thumbnail_new (void);
VALA_EXTERN XmppXepJingleContentThumbnailsThumbnail* xmpp_xep_jingle_content_thumbnails_thumbnail_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_muji_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMujiModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_muji_module_IDENTITY;
VALA_EXTERN void xmpp_xep_muji_module_join_call (XmppXepMujiModule* self,
                                     XmppXmppStream* stream,
                                     XmppJid* muc_jid,
                                     gboolean video,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
VALA_EXTERN gpointer xmpp_xep_muji_group_call_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_muji_group_call_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_muji_param_spec_group_call (const gchar* name,
                                                 const gchar* nick,
                                                 const gchar* blurb,
                                                 GType object_type,
                                                 GParamFlags flags);
VALA_EXTERN void xmpp_xep_muji_value_set_group_call (GValue* value,
                                         gpointer v_object);
VALA_EXTERN void xmpp_xep_muji_value_take_group_call (GValue* value,
                                          gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_muji_value_get_group_call (const GValue* value);
VALA_EXTERN GType xmpp_xep_muji_group_call_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMujiGroupCall, xmpp_xep_muji_group_call_unref)
VALA_EXTERN XmppXepMujiGroupCall* xmpp_xep_muji_module_join_call_finish (XmppXepMujiModule* self,
                                                             GAsyncResult* _res_);
VALA_EXTERN XmppXepMujiModule* xmpp_xep_muji_module_new (void);
VALA_EXTERN XmppXepMujiModule* xmpp_xep_muji_module_construct (GType object_type);
VALA_EXTERN XmppXepMujiGroupCall* xmpp_xep_muji_group_call_new (XmppJid* muc_jid);
VALA_EXTERN XmppXepMujiGroupCall* xmpp_xep_muji_group_call_construct (GType object_type,
                                                          XmppJid* muc_jid);
VALA_EXTERN void xmpp_xep_muji_group_call_leave (XmppXepMujiGroupCall* self,
                                     XmppXmppStream* stream);
VALA_EXTERN GType xmpp_xep_muji_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMujiFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_xep_muji_flag_IDENTITY;
VALA_EXTERN XmppXepMujiFlag* xmpp_xep_muji_flag_new (void);
VALA_EXTERN XmppXepMujiFlag* xmpp_xep_muji_flag_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_message_carbons_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMessageCarbonsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_message_carbons_module_IDENTITY;
VALA_EXTERN void xmpp_xep_message_carbons_module_enable (XmppXepMessageCarbonsModule* self,
                                             XmppXmppStream* stream,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
VALA_EXTERN void xmpp_xep_message_carbons_module_enable_finish (XmppXepMessageCarbonsModule* self,
                                                    GAsyncResult* _res_);
VALA_EXTERN void xmpp_xep_message_carbons_module_disable (XmppXepMessageCarbonsModule* self,
                                              XmppXmppStream* stream,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
VALA_EXTERN void xmpp_xep_message_carbons_module_disable_finish (XmppXepMessageCarbonsModule* self,
                                                     GAsyncResult* _res_);
VALA_EXTERN XmppXepMessageCarbonsModule* xmpp_xep_message_carbons_module_new (void);
VALA_EXTERN XmppXepMessageCarbonsModule* xmpp_xep_message_carbons_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_message_carbons_received_pipeline_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMessageCarbonsReceivedPipelineListener, g_object_unref)
VALA_EXTERN XmppXepMessageCarbonsReceivedPipelineListener* xmpp_xep_message_carbons_received_pipeline_listener_new (void);
VALA_EXTERN XmppXepMessageCarbonsReceivedPipelineListener* xmpp_xep_message_carbons_received_pipeline_listener_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_message_carbons_message_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepMessageCarbonsMessageFlag, g_object_unref)
VALA_EXTERN XmppXepMessageCarbonsMessageFlag* xmpp_xep_message_carbons_message_flag_new (const gchar* type);
VALA_EXTERN XmppXepMessageCarbonsMessageFlag* xmpp_xep_message_carbons_message_flag_construct (GType object_type,
                                                                                   const gchar* type);
VALA_EXTERN XmppXepMessageCarbonsMessageFlag* xmpp_xep_message_carbons_message_flag_get_flag (XmppMessageStanza* message);
VALA_EXTERN GType xmpp_xep_coin_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepCoinModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_coin_module_IDENTITY;
VALA_EXTERN XmppXepCoinModule* xmpp_xep_coin_module_new (void);
VALA_EXTERN XmppXepCoinModule* xmpp_xep_coin_module_construct (GType object_type);
VALA_EXTERN gpointer xmpp_xep_coin_conference_info_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_coin_conference_info_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_coin_param_spec_conference_info (const gchar* name,
                                                      const gchar* nick,
                                                      const gchar* blurb,
                                                      GType object_type,
                                                      GParamFlags flags);
VALA_EXTERN void xmpp_xep_coin_value_set_conference_info (GValue* value,
                                              gpointer v_object);
VALA_EXTERN void xmpp_xep_coin_value_take_conference_info (GValue* value,
                                               gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_coin_value_get_conference_info (const GValue* value);
VALA_EXTERN GType xmpp_xep_coin_conference_info_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepCoinConferenceInfo, xmpp_xep_coin_conference_info_unref)
VALA_EXTERN XmppXepCoinConferenceInfo* xmpp_xep_coin_parse_node (XmppStanzaNode* conference_node,
                                                     XmppXepCoinConferenceInfo* previous_conference_info);
VALA_EXTERN gpointer xmpp_xep_coin_conference_user_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_coin_conference_user_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_coin_param_spec_conference_user (const gchar* name,
                                                      const gchar* nick,
                                                      const gchar* blurb,
                                                      GType object_type,
                                                      GParamFlags flags);
VALA_EXTERN void xmpp_xep_coin_value_set_conference_user (GValue* value,
                                              gpointer v_object);
VALA_EXTERN void xmpp_xep_coin_value_take_conference_user (GValue* value,
                                               gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_coin_value_get_conference_user (const GValue* value);
VALA_EXTERN GType xmpp_xep_coin_conference_user_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepCoinConferenceUser, xmpp_xep_coin_conference_user_unref)
VALA_EXTERN XmppStanzaNode* xmpp_xep_coin_conference_info_to_xml (XmppXepCoinConferenceInfo* self);
VALA_EXTERN XmppXepCoinConferenceInfo* xmpp_xep_coin_conference_info_new (void);
VALA_EXTERN XmppXepCoinConferenceInfo* xmpp_xep_coin_conference_info_construct (GType object_type);
VALA_EXTERN gpointer xmpp_xep_coin_conference_media_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_coin_conference_media_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_coin_param_spec_conference_media (const gchar* name,
                                                       const gchar* nick,
                                                       const gchar* blurb,
                                                       GType object_type,
                                                       GParamFlags flags);
VALA_EXTERN void xmpp_xep_coin_value_set_conference_media (GValue* value,
                                               gpointer v_object);
VALA_EXTERN void xmpp_xep_coin_value_take_conference_media (GValue* value,
                                                gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_coin_value_get_conference_media (const GValue* value);
VALA_EXTERN GType xmpp_xep_coin_conference_media_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepCoinConferenceMedia, xmpp_xep_coin_conference_media_unref)
VALA_EXTERN XmppStanzaNode* xmpp_xep_coin_conference_user_to_xml (XmppXepCoinConferenceUser* self);
VALA_EXTERN XmppXepCoinConferenceUser* xmpp_xep_coin_conference_user_new (void);
VALA_EXTERN XmppXepCoinConferenceUser* xmpp_xep_coin_conference_user_construct (GType object_type);
VALA_EXTERN XmppStanzaNode* xmpp_xep_coin_conference_media_to_xml (XmppXepCoinConferenceMedia* self);
VALA_EXTERN XmppXepCoinConferenceMedia* xmpp_xep_coin_conference_media_new (void);
VALA_EXTERN XmppXepCoinConferenceMedia* xmpp_xep_coin_conference_media_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_cryptographic_hashes_hash_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepCryptographicHashesHash, g_object_unref)
VALA_EXTERN GeeList* xmpp_xep_cryptographic_hashes_get_hashes (XmppStanzaNode* node);
VALA_EXTERN GeeList* xmpp_xep_cryptographic_hashes_get_supported_hashes (GeeList* hashes);
VALA_EXTERN gboolean xmpp_xep_cryptographic_hashes_has_supported_hashes (GeeList* hashes);
VALA_EXTERN XmppXepCryptographicHashesHash* xmpp_xep_cryptographic_hashes_hash_new_with_checksum (GChecksumType checksum_type,
                                                                                      const gchar* hash);
VALA_EXTERN XmppXepCryptographicHashesHash* xmpp_xep_cryptographic_hashes_hash_construct_with_checksum (GType object_type,
                                                                                            GChecksumType checksum_type,
                                                                                            const gchar* hash);
VALA_EXTERN XmppXepCryptographicHashesHash* xmpp_xep_cryptographic_hashes_hash_new_compute (GChecksumType type,
                                                                                guint8* data,
                                                                                gint data_length1);
VALA_EXTERN XmppXepCryptographicHashesHash* xmpp_xep_cryptographic_hashes_hash_construct_compute (GType object_type,
                                                                                      GChecksumType type,
                                                                                      guint8* data,
                                                                                      gint data_length1);
VALA_EXTERN XmppStanzaNode* xmpp_xep_cryptographic_hashes_hash_to_stanza_node (XmppXepCryptographicHashesHash* self);
VALA_EXTERN XmppXepCryptographicHashesHash* xmpp_xep_cryptographic_hashes_hash_new_from_stanza_node (XmppStanzaNode* node);
VALA_EXTERN XmppXepCryptographicHashesHash* xmpp_xep_cryptographic_hashes_hash_construct_from_stanza_node (GType object_type,
                                                                                               XmppStanzaNode* node);
VALA_EXTERN XmppXepCryptographicHashesHash* xmpp_xep_cryptographic_hashes_hash_new (void);
VALA_EXTERN XmppXepCryptographicHashesHash* xmpp_xep_cryptographic_hashes_hash_construct (GType object_type);
VALA_EXTERN gchar* xmpp_xep_cryptographic_hashes_hash_type_to_string (GChecksumType type);
VALA_EXTERN GChecksumType* xmpp_xep_cryptographic_hashes_hash_string_to_type (const gchar* hash);
VALA_EXTERN void xmpp_xep_last_message_correction_set_replace_id (XmppMessageStanza* message,
                                                      const gchar* replace_id);
VALA_EXTERN gchar* xmpp_xep_last_message_correction_get_replace_id (XmppMessageStanza* message);
VALA_EXTERN GType xmpp_xep_last_message_correction_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepLastMessageCorrectionModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_last_message_correction_module_IDENTITY;
VALA_EXTERN XmppXepLastMessageCorrectionModule* xmpp_xep_last_message_correction_module_new (void);
VALA_EXTERN XmppXepLastMessageCorrectionModule* xmpp_xep_last_message_correction_module_construct (GType object_type);
VALA_EXTERN gpointer xmpp_message_archive_management_v2_mam_query_params_ref (gpointer instance);
VALA_EXTERN void xmpp_message_archive_management_v2_mam_query_params_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_message_archive_management_v2_param_spec_mam_query_params (const gchar* name,
                                                                            const gchar* nick,
                                                                            const gchar* blurb,
                                                                            GType object_type,
                                                                            GParamFlags flags);
VALA_EXTERN void xmpp_message_archive_management_v2_value_set_mam_query_params (GValue* value,
                                                                    gpointer v_object);
VALA_EXTERN void xmpp_message_archive_management_v2_value_take_mam_query_params (GValue* value,
                                                                     gpointer v_object);
VALA_EXTERN gpointer xmpp_message_archive_management_v2_value_get_mam_query_params (const GValue* value);
VALA_EXTERN GType xmpp_message_archive_management_v2_mam_query_params_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppMessageArchiveManagementV2MamQueryParams, xmpp_message_archive_management_v2_mam_query_params_unref)
VALA_EXTERN XmppMessageArchiveManagementV2MamQueryParams* xmpp_message_archive_management_v2_mam_query_params_new_query_latest (XmppJid* mam_server,
                                                                                                                    GDateTime* latest_known_time,
                                                                                                                    const gchar* latest_known_id);
VALA_EXTERN XmppMessageArchiveManagementV2MamQueryParams* xmpp_message_archive_management_v2_mam_query_params_construct_query_latest (GType object_type,
                                                                                                                          XmppJid* mam_server,
                                                                                                                          GDateTime* latest_known_time,
                                                                                                                          const gchar* latest_known_id);
VALA_EXTERN XmppMessageArchiveManagementV2MamQueryParams* xmpp_message_archive_management_v2_mam_query_params_new_query_between (XmppJid* mam_server,
                                                                                                                     GDateTime* earliest_time,
                                                                                                                     const gchar* earliest_id,
                                                                                                                     GDateTime* latest_time,
                                                                                                                     const gchar* latest_id);
VALA_EXTERN XmppMessageArchiveManagementV2MamQueryParams* xmpp_message_archive_management_v2_mam_query_params_construct_query_between (GType object_type,
                                                                                                                           XmppJid* mam_server,
                                                                                                                           GDateTime* earliest_time,
                                                                                                                           const gchar* earliest_id,
                                                                                                                           GDateTime* latest_time,
                                                                                                                           const gchar* latest_id);
VALA_EXTERN XmppMessageArchiveManagementV2MamQueryParams* xmpp_message_archive_management_v2_mam_query_params_new_query_before (XmppJid* mam_server,
                                                                                                                    GDateTime* earliest_time,
                                                                                                                    const gchar* earliest_id);
VALA_EXTERN XmppMessageArchiveManagementV2MamQueryParams* xmpp_message_archive_management_v2_mam_query_params_construct_query_before (GType object_type,
                                                                                                                          XmppJid* mam_server,
                                                                                                                          GDateTime* earliest_time,
                                                                                                                          const gchar* earliest_id);
VALA_EXTERN XmppMessageArchiveManagementV2MamQueryParams* xmpp_message_archive_management_v2_mam_query_params_new (void);
VALA_EXTERN XmppMessageArchiveManagementV2MamQueryParams* xmpp_message_archive_management_v2_mam_query_params_construct (GType object_type);
VALA_EXTERN XmppJid* xmpp_message_archive_management_v2_mam_query_params_get_mam_server (XmppMessageArchiveManagementV2MamQueryParams* self);
VALA_EXTERN void xmpp_message_archive_management_v2_mam_query_params_set_mam_server (XmppMessageArchiveManagementV2MamQueryParams* self,
                                                                         XmppJid* value);
VALA_EXTERN XmppJid* xmpp_message_archive_management_v2_mam_query_params_get_with (XmppMessageArchiveManagementV2MamQueryParams* self);
VALA_EXTERN void xmpp_message_archive_management_v2_mam_query_params_set_with (XmppMessageArchiveManagementV2MamQueryParams* self,
                                                                   XmppJid* value);
VALA_EXTERN GDateTime* xmpp_message_archive_management_v2_mam_query_params_get_start (XmppMessageArchiveManagementV2MamQueryParams* self);
VALA_EXTERN void xmpp_message_archive_management_v2_mam_query_params_set_start (XmppMessageArchiveManagementV2MamQueryParams* self,
                                                                    GDateTime* value);
VALA_EXTERN GDateTime* xmpp_message_archive_management_v2_mam_query_params_get_end (XmppMessageArchiveManagementV2MamQueryParams* self);
VALA_EXTERN void xmpp_message_archive_management_v2_mam_query_params_set_end (XmppMessageArchiveManagementV2MamQueryParams* self,
                                                                  GDateTime* value);
VALA_EXTERN const gchar* xmpp_message_archive_management_v2_mam_query_params_get_start_id (XmppMessageArchiveManagementV2MamQueryParams* self);
VALA_EXTERN void xmpp_message_archive_management_v2_mam_query_params_set_start_id (XmppMessageArchiveManagementV2MamQueryParams* self,
                                                                       const gchar* value);
VALA_EXTERN const gchar* xmpp_message_archive_management_v2_mam_query_params_get_end_id (XmppMessageArchiveManagementV2MamQueryParams* self);
VALA_EXTERN void xmpp_message_archive_management_v2_mam_query_params_set_end_id (XmppMessageArchiveManagementV2MamQueryParams* self,
                                                                     const gchar* value);
VALA_EXTERN void xmpp_message_archive_management_v2_query_archive (XmppXmppStream* stream,
                                                       XmppMessageArchiveManagementV2MamQueryParams* mam_params,
                                                       GCancellable* cancellable,
                                                       GAsyncReadyCallback _callback_,
                                                       gpointer _user_data_);
VALA_EXTERN gpointer xmpp_message_archive_management_query_result_ref (gpointer instance);
VALA_EXTERN void xmpp_message_archive_management_query_result_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_message_archive_management_param_spec_query_result (const gchar* name,
                                                                     const gchar* nick,
                                                                     const gchar* blurb,
                                                                     GType object_type,
                                                                     GParamFlags flags);
VALA_EXTERN void xmpp_message_archive_management_value_set_query_result (GValue* value,
                                                             gpointer v_object);
VALA_EXTERN void xmpp_message_archive_management_value_take_query_result (GValue* value,
                                                              gpointer v_object);
VALA_EXTERN gpointer xmpp_message_archive_management_value_get_query_result (const GValue* value);
VALA_EXTERN GType xmpp_message_archive_management_query_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppMessageArchiveManagementQueryResult, xmpp_message_archive_management_query_result_unref)
VALA_EXTERN XmppMessageArchiveManagementQueryResult* xmpp_message_archive_management_v2_query_archive_finish (GAsyncResult* _res_);
VALA_EXTERN void xmpp_message_archive_management_v2_page_through_results (XmppXmppStream* stream,
                                                              XmppMessageArchiveManagementV2MamQueryParams* mam_params,
                                                              XmppMessageArchiveManagementQueryResult* prev_result,
                                                              GCancellable* cancellable,
                                                              GAsyncReadyCallback _callback_,
                                                              gpointer _user_data_);
VALA_EXTERN XmppMessageArchiveManagementQueryResult* xmpp_message_archive_management_v2_page_through_results_finish (GAsyncResult* _res_);
VALA_EXTERN XmppMessageArchiveManagementQueryResult* xmpp_message_archive_management_query_result_new (void);
VALA_EXTERN XmppMessageArchiveManagementQueryResult* xmpp_message_archive_management_query_result_construct (GType object_type);
VALA_EXTERN gboolean xmpp_message_archive_management_query_result_get_error (XmppMessageArchiveManagementQueryResult* self);
VALA_EXTERN void xmpp_message_archive_management_query_result_set_error (XmppMessageArchiveManagementQueryResult* self,
                                                             gboolean value);
VALA_EXTERN gboolean xmpp_message_archive_management_query_result_get_malformed (XmppMessageArchiveManagementQueryResult* self);
VALA_EXTERN void xmpp_message_archive_management_query_result_set_malformed (XmppMessageArchiveManagementQueryResult* self,
                                                                 gboolean value);
VALA_EXTERN gboolean xmpp_message_archive_management_query_result_get_complete (XmppMessageArchiveManagementQueryResult* self);
VALA_EXTERN void xmpp_message_archive_management_query_result_set_complete (XmppMessageArchiveManagementQueryResult* self,
                                                                gboolean value);
VALA_EXTERN const gchar* xmpp_message_archive_management_query_result_get_first (XmppMessageArchiveManagementQueryResult* self);
VALA_EXTERN void xmpp_message_archive_management_query_result_set_first (XmppMessageArchiveManagementQueryResult* self,
                                                             const gchar* value);
VALA_EXTERN const gchar* xmpp_message_archive_management_query_result_get_last (XmppMessageArchiveManagementQueryResult* self);
VALA_EXTERN void xmpp_message_archive_management_query_result_set_last (XmppMessageArchiveManagementQueryResult* self,
                                                            const gchar* value);
VALA_EXTERN GType xmpp_message_archive_management_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppMessageArchiveManagementModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_message_archive_management_module_IDENTITY;
VALA_EXTERN XmppMessageArchiveManagementModule* xmpp_message_archive_management_module_new (void);
VALA_EXTERN XmppMessageArchiveManagementModule* xmpp_message_archive_management_module_construct (GType object_type);
VALA_EXTERN GType xmpp_message_archive_management_received_pipeline_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppMessageArchiveManagementReceivedPipelineListener, g_object_unref)
VALA_EXTERN XmppMessageArchiveManagementReceivedPipelineListener* xmpp_message_archive_management_received_pipeline_listener_new (void);
VALA_EXTERN XmppMessageArchiveManagementReceivedPipelineListener* xmpp_message_archive_management_received_pipeline_listener_construct (GType object_type);
VALA_EXTERN GType xmpp_message_archive_management_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppMessageArchiveManagementFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_message_archive_management_flag_IDENTITY;
VALA_EXTERN XmppMessageArchiveManagementFlag* xmpp_message_archive_management_flag_get_flag (XmppXmppStream* stream);
VALA_EXTERN XmppMessageArchiveManagementFlag* xmpp_message_archive_management_flag_new (void);
VALA_EXTERN XmppMessageArchiveManagementFlag* xmpp_message_archive_management_flag_construct (GType object_type);
VALA_EXTERN gboolean xmpp_message_archive_management_flag_get_cought_up (XmppMessageArchiveManagementFlag* self);
VALA_EXTERN void xmpp_message_archive_management_flag_set_cought_up (XmppMessageArchiveManagementFlag* self,
                                                         gboolean value);
VALA_EXTERN GeeSet* xmpp_message_archive_management_flag_get_active_query_ids (XmppMessageArchiveManagementFlag* self);
VALA_EXTERN void xmpp_message_archive_management_flag_set_active_query_ids (XmppMessageArchiveManagementFlag* self,
                                                                GeeSet* value);
VALA_EXTERN GType xmpp_message_archive_management_message_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppMessageArchiveManagementMessageFlag, g_object_unref)
VALA_EXTERN XmppMessageArchiveManagementMessageFlag* xmpp_message_archive_management_message_flag_new (XmppJid* sender_jid,
                                                                                           GDateTime* server_time,
                                                                                           const gchar* mam_id,
                                                                                           const gchar* query_id);
VALA_EXTERN XmppMessageArchiveManagementMessageFlag* xmpp_message_archive_management_message_flag_construct (GType object_type,
                                                                                                 XmppJid* sender_jid,
                                                                                                 GDateTime* server_time,
                                                                                                 const gchar* mam_id,
                                                                                                 const gchar* query_id);
VALA_EXTERN XmppMessageArchiveManagementMessageFlag* xmpp_message_archive_management_message_flag_get_flag (XmppMessageStanza* message);
VALA_EXTERN XmppJid* xmpp_message_archive_management_message_flag_get_sender_jid (XmppMessageArchiveManagementMessageFlag* self);
VALA_EXTERN GDateTime* xmpp_message_archive_management_message_flag_get_server_time (XmppMessageArchiveManagementMessageFlag* self);
VALA_EXTERN const gchar* xmpp_message_archive_management_message_flag_get_mam_id (XmppMessageArchiveManagementMessageFlag* self);
VALA_EXTERN const gchar* xmpp_message_archive_management_message_flag_get_query_id (XmppMessageArchiveManagementMessageFlag* self);
VALA_EXTERN GType xmpp_xep_chat_markers_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepChatMarkersModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_chat_markers_module_IDENTITY;
VALA_EXTERN void xmpp_xep_chat_markers_module_send_marker (XmppXepChatMarkersModule* self,
                                               XmppXmppStream* stream,
                                               XmppJid* jid,
                                               const gchar* message_id,
                                               const gchar* type_,
                                               const gchar* marker);
VALA_EXTERN gboolean xmpp_xep_chat_markers_module_requests_marking (XmppMessageStanza* message);
VALA_EXTERN XmppXepChatMarkersModule* xmpp_xep_chat_markers_module_new (void);
VALA_EXTERN XmppXepChatMarkersModule* xmpp_xep_chat_markers_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_chat_markers_send_pipeline_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepChatMarkersSendPipelineListener, g_object_unref)
VALA_EXTERN XmppXepChatMarkersSendPipelineListener* xmpp_xep_chat_markers_send_pipeline_listener_new (void);
VALA_EXTERN XmppXepChatMarkersSendPipelineListener* xmpp_xep_chat_markers_send_pipeline_listener_construct (GType object_type);
VALA_EXTERN void xmpp_xep_message_processing_hints_set_message_hint (XmppMessageStanza* message,
                                                         const gchar* message_hint);
VALA_EXTERN GType xmpp_xep_jingle_message_initiation_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJingleMessageInitiationModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_jingle_message_initiation_module_IDENTITY;
VALA_EXTERN void xmpp_xep_jingle_message_initiation_module_send_session_propose_to_peer (XmppXepJingleMessageInitiationModule* self,
                                                                             XmppXmppStream* stream,
                                                                             XmppJid* to,
                                                                             const gchar* sid,
                                                                             GeeList* descriptions);
VALA_EXTERN void xmpp_xep_jingle_message_initiation_module_send_session_retract_to_peer (XmppXepJingleMessageInitiationModule* self,
                                                                             XmppXmppStream* stream,
                                                                             XmppJid* to,
                                                                             const gchar* sid);
VALA_EXTERN void xmpp_xep_jingle_message_initiation_module_send_session_accept_to_self (XmppXepJingleMessageInitiationModule* self,
                                                                            XmppXmppStream* stream,
                                                                            const gchar* sid);
VALA_EXTERN void xmpp_xep_jingle_message_initiation_module_send_session_reject_to_self (XmppXepJingleMessageInitiationModule* self,
                                                                            XmppXmppStream* stream,
                                                                            const gchar* sid);
VALA_EXTERN void xmpp_xep_jingle_message_initiation_module_send_session_proceed_to_peer (XmppXepJingleMessageInitiationModule* self,
                                                                             XmppXmppStream* stream,
                                                                             XmppJid* to,
                                                                             const gchar* sid);
VALA_EXTERN void xmpp_xep_jingle_message_initiation_module_send_session_reject_to_peer (XmppXepJingleMessageInitiationModule* self,
                                                                            XmppXmppStream* stream,
                                                                            XmppJid* to,
                                                                            const gchar* sid);
VALA_EXTERN XmppXepJingleMessageInitiationModule* xmpp_xep_jingle_message_initiation_module_new (void);
VALA_EXTERN XmppXepJingleMessageInitiationModule* xmpp_xep_jingle_message_initiation_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_unique_stable_stanza_ids_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepUniqueStableStanzaIDsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_unique_stable_stanza_ids_module_IDENTITY;
VALA_EXTERN XmppXepUniqueStableStanzaIDsModule* xmpp_xep_unique_stable_stanza_ids_module_new (void);
VALA_EXTERN XmppXepUniqueStableStanzaIDsModule* xmpp_xep_unique_stable_stanza_ids_module_construct (GType object_type);
VALA_EXTERN void xmpp_xep_unique_stable_stanza_ids_set_origin_id (XmppMessageStanza* message,
                                                      const gchar* origin_id);
VALA_EXTERN gchar* xmpp_xep_unique_stable_stanza_ids_get_origin_id (XmppMessageStanza* message);
VALA_EXTERN gchar* xmpp_xep_unique_stable_stanza_ids_get_stanza_id (XmppMessageStanza* message,
                                                        XmppJid* by);
VALA_EXTERN GQuark xmpp_xep_http_file_upload_http_file_transfer_error_quark (void);
VALA_EXTERN GType xmpp_xep_http_file_upload_http_file_transfer_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType xmpp_xep_http_file_upload_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepHttpFileUploadModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_http_file_upload_module_IDENTITY;
VALA_EXTERN void xmpp_xep_http_file_upload_module_request_slot (XmppXepHttpFileUploadModule* self,
                                                    XmppXmppStream* stream,
                                                    const gchar* filename,
                                                    gint64 file_size,
                                                    const gchar* content_type,
                                                    GAsyncReadyCallback _callback_,
                                                    gpointer _user_data_);
VALA_EXTERN GType xmpp_xep_http_file_upload_module_slot_result_get_type (void) G_GNUC_CONST ;
VALA_EXTERN XmppXepHttpFileUploadModuleSlotResult* xmpp_xep_http_file_upload_module_slot_result_dup (const XmppXepHttpFileUploadModuleSlotResult* self);
VALA_EXTERN void xmpp_xep_http_file_upload_module_slot_result_free (XmppXepHttpFileUploadModuleSlotResult* self);
VALA_EXTERN void xmpp_xep_http_file_upload_module_slot_result_copy (const XmppXepHttpFileUploadModuleSlotResult* self,
                                                        XmppXepHttpFileUploadModuleSlotResult* dest);
VALA_EXTERN void xmpp_xep_http_file_upload_module_slot_result_destroy (XmppXepHttpFileUploadModuleSlotResult* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (XmppXepHttpFileUploadModuleSlotResult, xmpp_xep_http_file_upload_module_slot_result_destroy)
VALA_EXTERN void xmpp_xep_http_file_upload_module_request_slot_finish (XmppXepHttpFileUploadModule* self,
                                                           GAsyncResult* _res_,
                                                           XmppXepHttpFileUploadModuleSlotResult* result,
                                                           GError** error);
VALA_EXTERN XmppXepHttpFileUploadModule* xmpp_xep_http_file_upload_module_new (void);
VALA_EXTERN XmppXepHttpFileUploadModule* xmpp_xep_http_file_upload_module_construct (GType object_type);
VALA_EXTERN const gchar* xmpp_xep_http_file_upload_module_slot_result_get_url_get (XmppXepHttpFileUploadModuleSlotResult* self);
VALA_EXTERN void xmpp_xep_http_file_upload_module_slot_result_set_url_get (XmppXepHttpFileUploadModuleSlotResult* self,
                                                               const gchar* value);
VALA_EXTERN const gchar* xmpp_xep_http_file_upload_module_slot_result_get_url_put (XmppXepHttpFileUploadModuleSlotResult* self);
VALA_EXTERN void xmpp_xep_http_file_upload_module_slot_result_set_url_put (XmppXepHttpFileUploadModuleSlotResult* self,
                                                               const gchar* value);
VALA_EXTERN GeeHashMap* xmpp_xep_http_file_upload_module_slot_result_get_headers (XmppXepHttpFileUploadModuleSlotResult* self);
VALA_EXTERN void xmpp_xep_http_file_upload_module_slot_result_set_headers (XmppXepHttpFileUploadModuleSlotResult* self,
                                                               GeeHashMap* value);
VALA_EXTERN GType xmpp_xep_http_file_upload_received_pipeline_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepHttpFileUploadReceivedPipelineListener, g_object_unref)
VALA_EXTERN XmppXepHttpFileUploadReceivedPipelineListener* xmpp_xep_http_file_upload_received_pipeline_listener_new (void);
VALA_EXTERN XmppXepHttpFileUploadReceivedPipelineListener* xmpp_xep_http_file_upload_received_pipeline_listener_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_http_file_upload_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepHttpFileUploadFlag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_xep_http_file_upload_flag_IDENTITY;
VALA_EXTERN XmppXepHttpFileUploadFlag* xmpp_xep_http_file_upload_flag_new (XmppJid* file_store_jid,
                                                               const gchar* ns_ver);
VALA_EXTERN XmppXepHttpFileUploadFlag* xmpp_xep_http_file_upload_flag_construct (GType object_type,
                                                                     XmppJid* file_store_jid,
                                                                     const gchar* ns_ver);
VALA_EXTERN gchar* xmpp_xep_message_attaching_get_attach_to (XmppStanzaNode* node);
VALA_EXTERN XmppStanzaNode* xmpp_xep_message_attaching_to_stanza_node (const gchar* id);
VALA_EXTERN void xmpp_xep_explicit_encryption_add_encryption_tag_to_message (XmppMessageStanza* message,
                                                                 const gchar* ns,
                                                                 const gchar* name);
VALA_EXTERN gchar* xmpp_xep_explicit_encryption_get_encryption_tag (XmppMessageStanza* message);
VALA_EXTERN GType xmpp_xep_omemo_omemo_decryptor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepOmemoOmemoDecryptor, g_object_unref)
VALA_EXTERN gpointer xmpp_xep_omemo_parsed_data_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_omemo_parsed_data_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_omemo_param_spec_parsed_data (const gchar* name,
                                                   const gchar* nick,
                                                   const gchar* blurb,
                                                   GType object_type,
                                                   GParamFlags flags);
VALA_EXTERN void xmpp_xep_omemo_value_set_parsed_data (GValue* value,
                                           gpointer v_object);
VALA_EXTERN void xmpp_xep_omemo_value_take_parsed_data (GValue* value,
                                            gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_omemo_value_get_parsed_data (const GValue* value);
VALA_EXTERN GType xmpp_xep_omemo_parsed_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepOmemoParsedData, xmpp_xep_omemo_parsed_data_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_omemo_omemo_decryptor_IDENTITY;
VALA_EXTERN gchar* xmpp_xep_omemo_omemo_decryptor_decrypt (XmppXepOmemoOmemoDecryptor* self,
                                               guint8* ciphertext,
                                               gint ciphertext_length1,
                                               guint8* key,
                                               gint key_length1,
                                               guint8* iv,
                                               gint iv_length1,
                                               GError** error);
VALA_EXTERN guint8* xmpp_xep_omemo_omemo_decryptor_decrypt_key (XmppXepOmemoOmemoDecryptor* self,
                                                    XmppXepOmemoParsedData* data,
                                                    XmppJid* from_jid,
                                                    gint* result_length1,
                                                    GError** error);
VALA_EXTERN XmppXepOmemoParsedData* xmpp_xep_omemo_omemo_decryptor_parse_node (XmppXepOmemoOmemoDecryptor* self,
                                                                   XmppStanzaNode* encrypted_node);
VALA_EXTERN XmppXepOmemoOmemoDecryptor* xmpp_xep_omemo_omemo_decryptor_construct (GType object_type);
VALA_EXTERN guint32 xmpp_xep_omemo_omemo_decryptor_get_own_device_id (XmppXepOmemoOmemoDecryptor* self);
VALA_EXTERN XmppXepOmemoParsedData* xmpp_xep_omemo_parsed_data_new (void);
VALA_EXTERN XmppXepOmemoParsedData* xmpp_xep_omemo_parsed_data_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_omemo_omemo_encryptor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepOmemoOmemoEncryptor, g_object_unref)
VALA_EXTERN gpointer xmpp_xep_omemo_encryption_data_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_omemo_encryption_data_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_omemo_param_spec_encryption_data (const gchar* name,
                                                       const gchar* nick,
                                                       const gchar* blurb,
                                                       GType object_type,
                                                       GParamFlags flags);
VALA_EXTERN void xmpp_xep_omemo_value_set_encryption_data (GValue* value,
                                               gpointer v_object);
VALA_EXTERN void xmpp_xep_omemo_value_take_encryption_data (GValue* value,
                                                gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_omemo_value_get_encryption_data (const GValue* value);
VALA_EXTERN GType xmpp_xep_omemo_encryption_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepOmemoEncryptionData, xmpp_xep_omemo_encryption_data_unref)
VALA_EXTERN gpointer xmpp_xep_omemo_encryption_result_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_omemo_encryption_result_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_omemo_param_spec_encryption_result (const gchar* name,
                                                         const gchar* nick,
                                                         const gchar* blurb,
                                                         GType object_type,
                                                         GParamFlags flags);
VALA_EXTERN void xmpp_xep_omemo_value_set_encryption_result (GValue* value,
                                                 gpointer v_object);
VALA_EXTERN void xmpp_xep_omemo_value_take_encryption_result (GValue* value,
                                                  gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_omemo_value_get_encryption_result (const GValue* value);
VALA_EXTERN GType xmpp_xep_omemo_encryption_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepOmemoEncryptionResult, xmpp_xep_omemo_encryption_result_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_omemo_omemo_encryptor_IDENTITY;
VALA_EXTERN XmppXepOmemoEncryptionData* xmpp_xep_omemo_omemo_encryptor_encrypt_plaintext (XmppXepOmemoOmemoEncryptor* self,
                                                                              const gchar* plaintext,
                                                                              GError** error);
VALA_EXTERN void xmpp_xep_omemo_omemo_encryptor_encrypt_key (XmppXepOmemoOmemoEncryptor* self,
                                                 XmppXepOmemoEncryptionData* encryption_data,
                                                 XmppJid* jid,
                                                 gint32 device_id,
                                                 GError** error);
VALA_EXTERN XmppXepOmemoEncryptionResult* xmpp_xep_omemo_omemo_encryptor_encrypt_key_to_recipient (XmppXepOmemoOmemoEncryptor* self,
                                                                                       XmppXmppStream* stream,
                                                                                       XmppXepOmemoEncryptionData* enc_data,
                                                                                       XmppJid* recipient,
                                                                                       GError** error);
VALA_EXTERN XmppXepOmemoOmemoEncryptor* xmpp_xep_omemo_omemo_encryptor_construct (GType object_type);
VALA_EXTERN guint32 xmpp_xep_omemo_omemo_encryptor_get_own_device_id (XmppXepOmemoOmemoEncryptor* self);
VALA_EXTERN XmppXepOmemoEncryptionData* xmpp_xep_omemo_encryption_data_new (guint32 own_device_id);
VALA_EXTERN XmppXepOmemoEncryptionData* xmpp_xep_omemo_encryption_data_construct (GType object_type,
                                                                      guint32 own_device_id);
VALA_EXTERN void xmpp_xep_omemo_encryption_data_add_device_key (XmppXepOmemoEncryptionData* self,
                                                    gint device_id,
                                                    guint8* device_key,
                                                    gint device_key_length1,
                                                    gboolean prekey);
VALA_EXTERN XmppStanzaNode* xmpp_xep_omemo_encryption_data_get_encrypted_node (XmppXepOmemoEncryptionData* self);
VALA_EXTERN XmppXepOmemoEncryptionResult* xmpp_xep_omemo_encryption_result_new (void);
VALA_EXTERN XmppXepOmemoEncryptionResult* xmpp_xep_omemo_encryption_result_construct (GType object_type);
VALA_EXTERN gint xmpp_xep_omemo_encryption_result_get_lost (XmppXepOmemoEncryptionResult* self);
VALA_EXTERN void xmpp_xep_omemo_encryption_result_set_lost (XmppXepOmemoEncryptionResult* self,
                                                gint value);
VALA_EXTERN gint xmpp_xep_omemo_encryption_result_get_success (XmppXepOmemoEncryptionResult* self);
VALA_EXTERN void xmpp_xep_omemo_encryption_result_set_success (XmppXepOmemoEncryptionResult* self,
                                                   gint value);
VALA_EXTERN gint xmpp_xep_omemo_encryption_result_get_unknown (XmppXepOmemoEncryptionResult* self);
VALA_EXTERN void xmpp_xep_omemo_encryption_result_set_unknown (XmppXepOmemoEncryptionResult* self,
                                                   gint value);
VALA_EXTERN gint xmpp_xep_omemo_encryption_result_get_failure (XmppXepOmemoEncryptionResult* self);
VALA_EXTERN void xmpp_xep_omemo_encryption_result_set_failure (XmppXepOmemoEncryptionResult* self,
                                                   gint value);
VALA_EXTERN gpointer xmpp_xep_omemo_encrypt_state_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_omemo_param_spec_encrypt_state (const gchar* name,
                                                     const gchar* nick,
                                                     const gchar* blurb,
                                                     GType object_type,
                                                     GParamFlags flags);
VALA_EXTERN void xmpp_xep_omemo_value_set_encrypt_state (GValue* value,
                                             gpointer v_object);
VALA_EXTERN void xmpp_xep_omemo_value_take_encrypt_state (GValue* value,
                                              gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_omemo_value_get_encrypt_state (const GValue* value);
VALA_EXTERN GType xmpp_xep_omemo_encrypt_state_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepOmemoEncryptState, xmpp_xep_omemo_encrypt_state_unref)
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_add_result (XmppXepOmemoEncryptState* self,
                                              XmppXepOmemoEncryptionResult* enc_res,
                                              gboolean own);
VALA_EXTERN gchar* xmpp_xep_omemo_encrypt_state_to_string (XmppXepOmemoEncryptState* self);
VALA_EXTERN XmppXepOmemoEncryptState* xmpp_xep_omemo_encrypt_state_new (void);
VALA_EXTERN XmppXepOmemoEncryptState* xmpp_xep_omemo_encrypt_state_construct (GType object_type);
VALA_EXTERN gboolean xmpp_xep_omemo_encrypt_state_get_encrypted (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_encrypted (XmppXepOmemoEncryptState* self,
                                                 gboolean value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_other_devices (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_other_devices (XmppXepOmemoEncryptState* self,
                                                     gint value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_other_success (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_other_success (XmppXepOmemoEncryptState* self,
                                                     gint value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_other_lost (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_other_lost (XmppXepOmemoEncryptState* self,
                                                  gint value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_other_unknown (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_other_unknown (XmppXepOmemoEncryptState* self,
                                                     gint value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_other_failure (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_other_failure (XmppXepOmemoEncryptState* self,
                                                     gint value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_other_waiting_lists (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_other_waiting_lists (XmppXepOmemoEncryptState* self,
                                                           gint value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_own_devices (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_own_devices (XmppXepOmemoEncryptState* self,
                                                   gint value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_own_success (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_own_success (XmppXepOmemoEncryptState* self,
                                                   gint value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_own_lost (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_own_lost (XmppXepOmemoEncryptState* self,
                                                gint value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_own_unknown (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_own_unknown (XmppXepOmemoEncryptState* self,
                                                   gint value);
VALA_EXTERN gint xmpp_xep_omemo_encrypt_state_get_own_failure (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_own_failure (XmppXepOmemoEncryptState* self,
                                                   gint value);
VALA_EXTERN gboolean xmpp_xep_omemo_encrypt_state_get_own_list (XmppXepOmemoEncryptState* self);
VALA_EXTERN void xmpp_xep_omemo_encrypt_state_set_own_list (XmppXepOmemoEncryptState* self,
                                                gboolean value);
VALA_EXTERN GType xmpp_xep_jet_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJetModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_jet_module_IDENTITY;
VALA_EXTERN void xmpp_xep_jet_module_is_available (XmppXepJetModule* self,
                                       XmppXmppStream* stream,
                                       XmppJid* full_jid,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_jet_module_is_available_finish (XmppXepJetModule* self,
                                                  GAsyncResult* _res_);
VALA_EXTERN gpointer xmpp_xep_jet_transport_secret_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_jet_transport_secret_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_jet_param_spec_transport_secret (const gchar* name,
                                                      const gchar* nick,
                                                      const gchar* blurb,
                                                      GType object_type,
                                                      GParamFlags flags);
VALA_EXTERN void xmpp_xep_jet_value_set_transport_secret (GValue* value,
                                              gpointer v_object);
VALA_EXTERN void xmpp_xep_jet_value_take_transport_secret (GValue* value,
                                               gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_jet_value_get_transport_secret (const GValue* value);
VALA_EXTERN GType xmpp_xep_jet_transport_secret_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJetTransportSecret, xmpp_xep_jet_transport_secret_unref)
VALA_EXTERN GType xmpp_xep_jet_security_parameters_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJetSecurityParameters, g_object_unref)
VALA_EXTERN GType xmpp_xep_jet_envelop_encoding_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJetEnvelopEncoding, g_object_unref)
VALA_EXTERN void xmpp_xep_jet_module_register_envelop_encoding (XmppXepJetModule* self,
                                                    XmppXepJetEnvelopEncoding* encoding);
VALA_EXTERN GType xmpp_xep_jet_cipher_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJetCipher, g_object_unref)
VALA_EXTERN void xmpp_xep_jet_module_register_cipher (XmppXepJetModule* self,
                                          XmppXepJetCipher* cipher);
VALA_EXTERN XmppXepJetModule* xmpp_xep_jet_module_new (void);
VALA_EXTERN XmppXepJetModule* xmpp_xep_jet_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_jet_options_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepJetOptions, g_object_unref)
VALA_EXTERN XmppXepJetOptions* xmpp_xep_jet_options_new (const gchar* type_uri,
                                             const gchar* cipher_uri);
VALA_EXTERN XmppXepJetOptions* xmpp_xep_jet_options_construct (GType object_type,
                                                   const gchar* type_uri,
                                                   const gchar* cipher_uri);
VALA_EXTERN const gchar* xmpp_xep_jet_options_get_type_uri (XmppXepJetOptions* self);
VALA_EXTERN const gchar* xmpp_xep_jet_options_get_cipher_uri (XmppXepJetOptions* self);
VALA_EXTERN XmppXepJetSecurityParameters* xmpp_xep_jet_security_parameters_new (XmppXepJetCipher* cipher,
                                                                    XmppXepJetEnvelopEncoding* encoding,
                                                                    XmppXepJetTransportSecret* secret,
                                                                    XmppXepJetOptions* options);
VALA_EXTERN XmppXepJetSecurityParameters* xmpp_xep_jet_security_parameters_construct (GType object_type,
                                                                          XmppXepJetCipher* cipher,
                                                                          XmppXepJetEnvelopEncoding* encoding,
                                                                          XmppXepJetTransportSecret* secret,
                                                                          XmppXepJetOptions* options);
VALA_EXTERN XmppXepJetCipher* xmpp_xep_jet_security_parameters_get_cipher (XmppXepJetSecurityParameters* self);
VALA_EXTERN XmppXepJetEnvelopEncoding* xmpp_xep_jet_security_parameters_get_encoding (XmppXepJetSecurityParameters* self);
VALA_EXTERN XmppXepJetTransportSecret* xmpp_xep_jet_security_parameters_get_secret (XmppXepJetSecurityParameters* self);
VALA_EXTERN XmppXepJetOptions* xmpp_xep_jet_security_parameters_get_options (XmppXepJetSecurityParameters* self);
VALA_EXTERN gchar* xmpp_xep_jet_cipher_get_cipher_uri (XmppXepJetCipher* self);
VALA_EXTERN XmppXepJetTransportSecret* xmpp_xep_jet_cipher_generate_random_secret (XmppXepJetCipher* self);
VALA_EXTERN GInputStream* xmpp_xep_jet_cipher_wrap_input_stream (XmppXepJetCipher* self,
                                                     GInputStream* input,
                                                     XmppXepJetTransportSecret* secret);
VALA_EXTERN GOutputStream* xmpp_xep_jet_cipher_wrap_output_stream (XmppXepJetCipher* self,
                                                       GOutputStream* output,
                                                       XmppXepJetTransportSecret* secret);
VALA_EXTERN XmppXepJetTransportSecret* xmpp_xep_jet_transport_secret_new (guint8* transport_key,
                                                              gint transport_key_length1,
                                                              guint8* initialization_vector,
                                                              gint initialization_vector_length1);
VALA_EXTERN XmppXepJetTransportSecret* xmpp_xep_jet_transport_secret_construct (GType object_type,
                                                                    guint8* transport_key,
                                                                    gint transport_key_length1,
                                                                    guint8* initialization_vector,
                                                                    gint initialization_vector_length1);
VALA_EXTERN guint8* xmpp_xep_jet_transport_secret_get_transport_key (XmppXepJetTransportSecret* self,
                                                         gint* result_length1);
VALA_EXTERN guint8* xmpp_xep_jet_transport_secret_get_initialization_vector (XmppXepJetTransportSecret* self,
                                                                 gint* result_length1);
VALA_EXTERN gchar* xmpp_xep_jet_envelop_encoding_get_type_uri (XmppXepJetEnvelopEncoding* self);
VALA_EXTERN XmppXepJetTransportSecret* xmpp_xep_jet_envelop_encoding_decode_envolop (XmppXepJetEnvelopEncoding* self,
                                                                         XmppXmppStream* stream,
                                                                         XmppJid* local_full_jid,
                                                                         XmppJid* peer_full_jid,
                                                                         XmppStanzaNode* security,
                                                                         GError** error);
VALA_EXTERN void xmpp_xep_jet_envelop_encoding_encode_envelop (XmppXepJetEnvelopEncoding* self,
                                                   XmppXmppStream* stream,
                                                   XmppJid* local_full_jid,
                                                   XmppJid* peer_full_jid,
                                                   XmppXepJetSecurityParameters* security_params,
                                                   XmppStanzaNode* security);
VALA_EXTERN gfloat xmpp_xep_consistent_color_string_to_angle (const gchar* s);
VALA_EXTERN gfloat* xmpp_xep_consistent_color_string_to_rgbf (const gchar* s,
                                                  gint* result_length1);
VALA_EXTERN guint8* xmpp_xep_consistent_color_string_to_rgb (const gchar* s,
                                                 gint* result_length1);
VALA_EXTERN GType xmpp_xep_bookmarks2_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepBookmarks2Module, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_bookmarks2_module_IDENTITY;
VALA_EXTERN XmppXepBookmarks2Module* xmpp_xep_bookmarks2_module_new (void);
VALA_EXTERN XmppXepBookmarks2Module* xmpp_xep_bookmarks2_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_bookmarks2_flag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepBookmarks2Flag, g_object_unref)
VALA_EXTERN XmppFlagIdentity* xmpp_xep_bookmarks2_flag_IDENTITY;
VALA_EXTERN XmppXepBookmarks2Flag* xmpp_xep_bookmarks2_flag_new (GeeHashMap* conferences);
VALA_EXTERN XmppXepBookmarks2Flag* xmpp_xep_bookmarks2_flag_construct (GType object_type,
                                                           GeeHashMap* conferences);
VALA_EXTERN void xmpp_xep_muc_self_ping_is_joined (XmppXmppStream* stream,
                                       XmppJid* jid,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN gboolean xmpp_xep_muc_self_ping_is_joined_finish (GAsyncResult* _res_);
VALA_EXTERN gchar* xmpp_xep_occupant_ids_get_occupant_id (XmppStanzaNode* stanza);
VALA_EXTERN GType xmpp_xep_occupant_ids_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepOccupantIdsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_occupant_ids_module_IDENTITY;
VALA_EXTERN void xmpp_xep_occupant_ids_module_parse_occupant_id_from_presence (XmppXepOccupantIdsModule* self,
                                                                   XmppXmppStream* stream,
                                                                   XmppPresenceStanza* presence);
VALA_EXTERN XmppXepOccupantIdsModule* xmpp_xep_occupant_ids_module_new (void);
VALA_EXTERN XmppXepOccupantIdsModule* xmpp_xep_occupant_ids_module_construct (GType object_type);
VALA_EXTERN gpointer xmpp_xep_fallback_indication_fallback_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_fallback_indication_fallback_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_fallback_indication_param_spec_fallback (const gchar* name,
                                                              const gchar* nick,
                                                              const gchar* blurb,
                                                              GType object_type,
                                                              GParamFlags flags);
VALA_EXTERN void xmpp_xep_fallback_indication_value_set_fallback (GValue* value,
                                                      gpointer v_object);
VALA_EXTERN void xmpp_xep_fallback_indication_value_take_fallback (GValue* value,
                                                       gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_fallback_indication_value_get_fallback (const GValue* value);
VALA_EXTERN GType xmpp_xep_fallback_indication_fallback_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepFallbackIndicationFallback, xmpp_xep_fallback_indication_fallback_unref)
VALA_EXTERN gpointer xmpp_xep_fallback_indication_fallback_location_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_fallback_indication_fallback_location_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_fallback_indication_param_spec_fallback_location (const gchar* name,
                                                                       const gchar* nick,
                                                                       const gchar* blurb,
                                                                       GType object_type,
                                                                       GParamFlags flags);
VALA_EXTERN void xmpp_xep_fallback_indication_value_set_fallback_location (GValue* value,
                                                               gpointer v_object);
VALA_EXTERN void xmpp_xep_fallback_indication_value_take_fallback_location (GValue* value,
                                                                gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_fallback_indication_value_get_fallback_location (const GValue* value);
VALA_EXTERN GType xmpp_xep_fallback_indication_fallback_location_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepFallbackIndicationFallbackLocation, xmpp_xep_fallback_indication_fallback_location_unref)
VALA_EXTERN XmppXepFallbackIndicationFallback* xmpp_xep_fallback_indication_fallback_new (const gchar* ns_uri,
                                                                              GeeList* locations);
VALA_EXTERN XmppXepFallbackIndicationFallback* xmpp_xep_fallback_indication_fallback_construct (GType object_type,
                                                                                    const gchar* ns_uri,
                                                                                    GeeList* locations);
VALA_EXTERN const gchar* xmpp_xep_fallback_indication_fallback_get_ns_uri (XmppXepFallbackIndicationFallback* self);
VALA_EXTERN void xmpp_xep_fallback_indication_fallback_set_ns_uri (XmppXepFallbackIndicationFallback* self,
                                                       const gchar* value);
VALA_EXTERN XmppXepFallbackIndicationFallbackLocation* xmpp_xep_fallback_indication_fallback_location_new_partial_body (gint from_char,
                                                                                                            gint to_char);
VALA_EXTERN XmppXepFallbackIndicationFallbackLocation* xmpp_xep_fallback_indication_fallback_location_construct_partial_body (GType object_type,
                                                                                                                  gint from_char,
                                                                                                                  gint to_char);
VALA_EXTERN XmppXepFallbackIndicationFallbackLocation* xmpp_xep_fallback_indication_fallback_location_new_whole_body (void);
VALA_EXTERN XmppXepFallbackIndicationFallbackLocation* xmpp_xep_fallback_indication_fallback_location_construct_whole_body (GType object_type);
VALA_EXTERN XmppXepFallbackIndicationFallbackLocation* xmpp_xep_fallback_indication_fallback_location_new (void);
VALA_EXTERN XmppXepFallbackIndicationFallbackLocation* xmpp_xep_fallback_indication_fallback_location_construct (GType object_type);
VALA_EXTERN gboolean xmpp_xep_fallback_indication_fallback_location_get_is_whole (XmppXepFallbackIndicationFallbackLocation* self);
VALA_EXTERN gint xmpp_xep_fallback_indication_fallback_location_get_from_char (XmppXepFallbackIndicationFallbackLocation* self);
VALA_EXTERN void xmpp_xep_fallback_indication_fallback_location_set_from_char (XmppXepFallbackIndicationFallbackLocation* self,
                                                                   gint value);
VALA_EXTERN gint xmpp_xep_fallback_indication_fallback_location_get_to_char (XmppXepFallbackIndicationFallbackLocation* self);
VALA_EXTERN void xmpp_xep_fallback_indication_fallback_location_set_to_char (XmppXepFallbackIndicationFallbackLocation* self,
                                                                 gint value);
VALA_EXTERN void xmpp_xep_fallback_indication_set_fallback (XmppMessageStanza* message,
                                                XmppXepFallbackIndicationFallback* fallback);
VALA_EXTERN GeeList* xmpp_xep_fallback_indication_get_fallbacks (XmppMessageStanza* message);
VALA_EXTERN GType xmpp_xep_reactions_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepReactionsModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_reactions_module_IDENTITY;
VALA_EXTERN void xmpp_xep_reactions_module_send_reaction (XmppXepReactionsModule* self,
                                              XmppXmppStream* stream,
                                              XmppJid* jid,
                                              const gchar* stanza_type,
                                              const gchar* message_id,
                                              GeeList* reactions,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
VALA_EXTERN void xmpp_xep_reactions_module_send_reaction_finish (XmppXepReactionsModule* self,
                                                     GAsyncResult* _res_,
                                                     GError** error);
VALA_EXTERN XmppXepReactionsModule* xmpp_xep_reactions_module_new (void);
VALA_EXTERN XmppXepReactionsModule* xmpp_xep_reactions_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_reactions_received_pipeline_listener_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepReactionsReceivedPipelineListener, g_object_unref)
VALA_EXTERN XmppXepReactionsReceivedPipelineListener* xmpp_xep_reactions_received_pipeline_listener_new (void);
VALA_EXTERN XmppXepReactionsReceivedPipelineListener* xmpp_xep_reactions_received_pipeline_listener_construct (GType object_type);
VALA_EXTERN gpointer xmpp_xep_file_metadata_element_file_metadata_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_file_metadata_element_file_metadata_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_file_metadata_element_param_spec_file_metadata (const gchar* name,
                                                                     const gchar* nick,
                                                                     const gchar* blurb,
                                                                     GType object_type,
                                                                     GParamFlags flags);
VALA_EXTERN void xmpp_xep_file_metadata_element_value_set_file_metadata (GValue* value,
                                                             gpointer v_object);
VALA_EXTERN void xmpp_xep_file_metadata_element_value_take_file_metadata (GValue* value,
                                                              gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_file_metadata_element_value_get_file_metadata (const GValue* value);
VALA_EXTERN GType xmpp_xep_file_metadata_element_file_metadata_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepFileMetadataElementFileMetadata, xmpp_xep_file_metadata_element_file_metadata_unref)
VALA_EXTERN XmppStanzaNode* xmpp_xep_file_metadata_element_file_metadata_to_stanza_node (XmppXepFileMetadataElementFileMetadata* self);
VALA_EXTERN XmppXepFileMetadataElementFileMetadata* xmpp_xep_file_metadata_element_file_metadata_new (void);
VALA_EXTERN XmppXepFileMetadataElementFileMetadata* xmpp_xep_file_metadata_element_file_metadata_construct (GType object_type);
VALA_EXTERN const gchar* xmpp_xep_file_metadata_element_file_metadata_get_name (XmppXepFileMetadataElementFileMetadata* self);
VALA_EXTERN void xmpp_xep_file_metadata_element_file_metadata_set_name (XmppXepFileMetadataElementFileMetadata* self,
                                                            const gchar* value);
VALA_EXTERN const gchar* xmpp_xep_file_metadata_element_file_metadata_get_mime_type (XmppXepFileMetadataElementFileMetadata* self);
VALA_EXTERN void xmpp_xep_file_metadata_element_file_metadata_set_mime_type (XmppXepFileMetadataElementFileMetadata* self,
                                                                 const gchar* value);
VALA_EXTERN gint64 xmpp_xep_file_metadata_element_file_metadata_get_size (XmppXepFileMetadataElementFileMetadata* self);
VALA_EXTERN void xmpp_xep_file_metadata_element_file_metadata_set_size (XmppXepFileMetadataElementFileMetadata* self,
                                                            gint64 value);
VALA_EXTERN const gchar* xmpp_xep_file_metadata_element_file_metadata_get_desc (XmppXepFileMetadataElementFileMetadata* self);
VALA_EXTERN void xmpp_xep_file_metadata_element_file_metadata_set_desc (XmppXepFileMetadataElementFileMetadata* self,
                                                            const gchar* value);
VALA_EXTERN GDateTime* xmpp_xep_file_metadata_element_file_metadata_get_date (XmppXepFileMetadataElementFileMetadata* self);
VALA_EXTERN void xmpp_xep_file_metadata_element_file_metadata_set_date (XmppXepFileMetadataElementFileMetadata* self,
                                                            GDateTime* value);
VALA_EXTERN gint xmpp_xep_file_metadata_element_file_metadata_get_width (XmppXepFileMetadataElementFileMetadata* self);
VALA_EXTERN void xmpp_xep_file_metadata_element_file_metadata_set_width (XmppXepFileMetadataElementFileMetadata* self,
                                                             gint value);
VALA_EXTERN gint xmpp_xep_file_metadata_element_file_metadata_get_height (XmppXepFileMetadataElementFileMetadata* self);
VALA_EXTERN void xmpp_xep_file_metadata_element_file_metadata_set_height (XmppXepFileMetadataElementFileMetadata* self,
                                                              gint value);
VALA_EXTERN gint64 xmpp_xep_file_metadata_element_file_metadata_get_length (XmppXepFileMetadataElementFileMetadata* self);
VALA_EXTERN void xmpp_xep_file_metadata_element_file_metadata_set_length (XmppXepFileMetadataElementFileMetadata* self,
                                                              gint64 value);
VALA_EXTERN XmppXepFileMetadataElementFileMetadata* xmpp_xep_file_metadata_element_get_file_metadata (XmppStanzaNode* node);
VALA_EXTERN GType xmpp_xep_stateless_file_sharing_file_share_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepStatelessFileSharingFileShare, g_object_unref)
VALA_EXTERN GeeList* xmpp_xep_stateless_file_sharing_get_file_shares (XmppMessageStanza* message);
VALA_EXTERN GType xmpp_xep_stateless_file_sharing_source_attachment_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepStatelessFileSharingSourceAttachment, g_object_unref)
VALA_EXTERN GeeList* xmpp_xep_stateless_file_sharing_get_source_attachments (XmppMessageStanza* message);
VALA_EXTERN gboolean xmpp_xep_stateless_file_sharing_is_sfs_fallback_message (XmppMessageStanza* message);
VALA_EXTERN GType xmpp_xep_stateless_file_sharing_source_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepStatelessFileSharingSource, g_object_unref)
VALA_EXTERN void xmpp_xep_stateless_file_sharing_set_sfs_element (XmppMessageStanza* message,
                                                      const gchar* file_sharing_id,
                                                      XmppXepFileMetadataElementFileMetadata* metadata,
                                                      GeeList* sources);
VALA_EXTERN void xmpp_xep_stateless_file_sharing_set_sfs_attachment (XmppMessageStanza* message,
                                                         const gchar* attach_to_id,
                                                         const gchar* attach_to_file_id,
                                                         GeeList* sources);
VALA_EXTERN XmppXepStatelessFileSharingFileShare* xmpp_xep_stateless_file_sharing_file_share_new (void);
VALA_EXTERN XmppXepStatelessFileSharingFileShare* xmpp_xep_stateless_file_sharing_file_share_construct (GType object_type);
VALA_EXTERN const gchar* xmpp_xep_stateless_file_sharing_file_share_get_id (XmppXepStatelessFileSharingFileShare* self);
VALA_EXTERN void xmpp_xep_stateless_file_sharing_file_share_set_id (XmppXepStatelessFileSharingFileShare* self,
                                                        const gchar* value);
VALA_EXTERN XmppXepFileMetadataElementFileMetadata* xmpp_xep_stateless_file_sharing_file_share_get_metadata (XmppXepStatelessFileSharingFileShare* self);
VALA_EXTERN void xmpp_xep_stateless_file_sharing_file_share_set_metadata (XmppXepStatelessFileSharingFileShare* self,
                                                              XmppXepFileMetadataElementFileMetadata* value);
VALA_EXTERN GeeList* xmpp_xep_stateless_file_sharing_file_share_get_sources (XmppXepStatelessFileSharingFileShare* self);
VALA_EXTERN void xmpp_xep_stateless_file_sharing_file_share_set_sources (XmppXepStatelessFileSharingFileShare* self,
                                                             GeeList* value);
VALA_EXTERN XmppXepStatelessFileSharingSourceAttachment* xmpp_xep_stateless_file_sharing_source_attachment_new (void);
VALA_EXTERN XmppXepStatelessFileSharingSourceAttachment* xmpp_xep_stateless_file_sharing_source_attachment_construct (GType object_type);
VALA_EXTERN const gchar* xmpp_xep_stateless_file_sharing_source_attachment_get_to_message_id (XmppXepStatelessFileSharingSourceAttachment* self);
VALA_EXTERN void xmpp_xep_stateless_file_sharing_source_attachment_set_to_message_id (XmppXepStatelessFileSharingSourceAttachment* self,
                                                                          const gchar* value);
VALA_EXTERN const gchar* xmpp_xep_stateless_file_sharing_source_attachment_get_to_file_transfer_id (XmppXepStatelessFileSharingSourceAttachment* self);
VALA_EXTERN void xmpp_xep_stateless_file_sharing_source_attachment_set_to_file_transfer_id (XmppXepStatelessFileSharingSourceAttachment* self,
                                                                                const gchar* value);
VALA_EXTERN GeeList* xmpp_xep_stateless_file_sharing_source_attachment_get_sources (XmppXepStatelessFileSharingSourceAttachment* self);
VALA_EXTERN void xmpp_xep_stateless_file_sharing_source_attachment_set_sources (XmppXepStatelessFileSharingSourceAttachment* self,
                                                                    GeeList* value);
VALA_EXTERN gchar* xmpp_xep_stateless_file_sharing_source_type (XmppXepStatelessFileSharingSource* self);
VALA_EXTERN XmppStanzaNode* xmpp_xep_stateless_file_sharing_source_to_stanza_node (XmppXepStatelessFileSharingSource* self);
VALA_EXTERN gboolean xmpp_xep_stateless_file_sharing_source_equals (XmppXepStatelessFileSharingSource* self,
                                                        XmppXepStatelessFileSharingSource* source);
VALA_EXTERN gboolean xmpp_xep_stateless_file_sharing_source_equals_func (XmppXepStatelessFileSharingSource* s1,
                                                             XmppXepStatelessFileSharingSource* s2);
VALA_EXTERN GType xmpp_xep_stateless_file_sharing_http_source_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepStatelessFileSharingHttpSource, g_object_unref)
VALA_EXTERN XmppXepStatelessFileSharingHttpSource* xmpp_xep_stateless_file_sharing_http_source_new (void);
VALA_EXTERN XmppXepStatelessFileSharingHttpSource* xmpp_xep_stateless_file_sharing_http_source_construct (GType object_type);
VALA_EXTERN const gchar* xmpp_xep_stateless_file_sharing_http_source_get_url (XmppXepStatelessFileSharingHttpSource* self);
VALA_EXTERN void xmpp_xep_stateless_file_sharing_http_source_set_url (XmppXepStatelessFileSharingHttpSource* self,
                                                          const gchar* value);
VALA_EXTERN gpointer xmpp_xep_replies_reply_to_ref (gpointer instance);
VALA_EXTERN void xmpp_xep_replies_reply_to_unref (gpointer instance);
VALA_EXTERN GParamSpec* xmpp_xep_replies_param_spec_reply_to (const gchar* name,
                                                  const gchar* nick,
                                                  const gchar* blurb,
                                                  GType object_type,
                                                  GParamFlags flags);
VALA_EXTERN void xmpp_xep_replies_value_set_reply_to (GValue* value,
                                          gpointer v_object);
VALA_EXTERN void xmpp_xep_replies_value_take_reply_to (GValue* value,
                                           gpointer v_object);
VALA_EXTERN gpointer xmpp_xep_replies_value_get_reply_to (const GValue* value);
VALA_EXTERN GType xmpp_xep_replies_reply_to_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepRepliesReplyTo, xmpp_xep_replies_reply_to_unref)
VALA_EXTERN XmppXepRepliesReplyTo* xmpp_xep_replies_reply_to_new (XmppJid* to_jid,
                                                      const gchar* to_message_id);
VALA_EXTERN XmppXepRepliesReplyTo* xmpp_xep_replies_reply_to_construct (GType object_type,
                                                            XmppJid* to_jid,
                                                            const gchar* to_message_id);
VALA_EXTERN XmppJid* xmpp_xep_replies_reply_to_get_to_jid (XmppXepRepliesReplyTo* self);
VALA_EXTERN void xmpp_xep_replies_reply_to_set_to_jid (XmppXepRepliesReplyTo* self,
                                           XmppJid* value);
VALA_EXTERN const gchar* xmpp_xep_replies_reply_to_get_to_message_id (XmppXepRepliesReplyTo* self);
VALA_EXTERN void xmpp_xep_replies_reply_to_set_to_message_id (XmppXepRepliesReplyTo* self,
                                                  const gchar* value);
VALA_EXTERN void xmpp_xep_replies_set_reply_to (XmppMessageStanza* message,
                                    XmppXepRepliesReplyTo* reply_to);
VALA_EXTERN XmppXepRepliesReplyTo* xmpp_xep_replies_get_reply_to (XmppMessageStanza* message);
VALA_EXTERN GType xmpp_xep_call_invites_module_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepCallInvitesModule, g_object_unref)
VALA_EXTERN XmppModuleIdentity* xmpp_xep_call_invites_module_IDENTITY;
VALA_EXTERN void xmpp_xep_call_invites_module_send_jingle_propose (XmppXepCallInvitesModule* self,
                                                       XmppXmppStream* stream,
                                                       const gchar* call_id,
                                                       XmppJid* invitee,
                                                       const gchar* sid,
                                                       gboolean video,
                                                       const gchar* message_type);
VALA_EXTERN void xmpp_xep_call_invites_module_send_muji_propose (XmppXepCallInvitesModule* self,
                                                     XmppXmppStream* stream,
                                                     const gchar* call_id,
                                                     XmppJid* invitee,
                                                     XmppJid* muc_jid,
                                                     gboolean video,
                                                     const gchar* message_type);
VALA_EXTERN void xmpp_xep_call_invites_module_send_propose (XmppXepCallInvitesModule* self,
                                                XmppXmppStream* stream,
                                                const gchar* call_id,
                                                XmppJid* invitee,
                                                gboolean video,
                                                gboolean multi,
                                                const gchar* message_type,
                                                XmppStanzaNode* method,
                                                XmppStanzaNode* legacy_method);
VALA_EXTERN void xmpp_xep_call_invites_module_send_jingle_accept (XmppXepCallInvitesModule* self,
                                                      XmppXmppStream* stream,
                                                      XmppJid* inviter,
                                                      const gchar* call_id,
                                                      const gchar* sid,
                                                      const gchar* message_type);
VALA_EXTERN void xmpp_xep_call_invites_module_send_muji_accept (XmppXepCallInvitesModule* self,
                                                    XmppXmppStream* stream,
                                                    XmppJid* inviter,
                                                    const gchar* call_id,
                                                    XmppJid* room,
                                                    const gchar* message_type);
VALA_EXTERN void xmpp_xep_call_invites_module_send_accept (XmppXepCallInvitesModule* self,
                                               XmppXmppStream* stream,
                                               XmppJid* inviter,
                                               const gchar* call_id,
                                               const gchar* message_type,
                                               XmppStanzaNode* method,
                                               XmppStanzaNode* legacy_method);
VALA_EXTERN void xmpp_xep_call_invites_module_send_retract (XmppXepCallInvitesModule* self,
                                                XmppXmppStream* stream,
                                                XmppJid* to,
                                                const gchar* call_id,
                                                const gchar* message_type);
VALA_EXTERN void xmpp_xep_call_invites_module_send_reject (XmppXepCallInvitesModule* self,
                                               XmppXmppStream* stream,
                                               XmppJid* to,
                                               const gchar* call_id,
                                               const gchar* message_type);
VALA_EXTERN void xmpp_xep_call_invites_module_send_left (XmppXepCallInvitesModule* self,
                                             XmppXmppStream* stream,
                                             XmppJid* to,
                                             const gchar* call_id,
                                             const gchar* message_type);
VALA_EXTERN XmppXepCallInvitesModule* xmpp_xep_call_invites_module_new (void);
VALA_EXTERN XmppXepCallInvitesModule* xmpp_xep_call_invites_module_construct (GType object_type);
VALA_EXTERN GType xmpp_xep_pixbuf_storage_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (XmppXepPixbufStorage, g_object_unref)
VALA_EXTERN void xmpp_xep_pixbuf_storage_store (XmppXepPixbufStorage* self,
                                    const gchar* id,
                                    GBytes* data);
VALA_EXTERN gboolean xmpp_xep_pixbuf_storage_has_image (XmppXepPixbufStorage* self,
                                            const gchar* id);
VALA_EXTERN void xmpp_xep_pixbuf_storage_get_image (XmppXepPixbufStorage* self,
                                        const gchar* id,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_);
VALA_EXTERN GdkPixbuf* xmpp_xep_pixbuf_storage_get_image_finish (XmppXepPixbufStorage* self,
                                                     GAsyncResult* _res_);
VALA_EXTERN glong xmpp_util_from_hex (const gchar* numeral);

VALA_EXTERN const XmppXepMucStatusCode XMPP_XEP_MUC_ROOM_CONFIGURATION_CODES[4];
VALA_EXTERN const XmppXepMucStatusCode XMPP_XEP_MUC_USER_REMOVED_CODES[5];
VALA_EXTERN const gchar* XMPP_XEP_JINGLE_REASON_ELEMENT_NORMAL_TERMINATE_REASONS[5];

G_END_DECLS

#endif
